@@ -40,10 +40,10 @@
 #include "selection.h"
 #include "position.h"
 #include "ranges.h"
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "workbook-view.h"
 #include "workbook.h"
-#include "error-info.h"
+#include <goffice/app/error-info.h>
 
 #include <string.h>
 #include <gsf/gsf-output.h>
@@ -75,7 +75,7 @@ applix_write_header (ApplixWriteState const *state)
 #warning "FIXME: filename is fs encoded; that's not right, but neither is UTF-8."
 	gsf_output_printf (state->sink,
 			   "Current Doc Real Name: %s",
-			   workbook_get_filename (state->wb));
+			   workbook_get_uri (state->wb));
 }
 
 static void
