@@ -3,23 +3,20 @@
  * boot.c: MS Excel support for Gnumeric
  *
  * Author:
- *    Michael Meeks (michael@ximian.com)
  *    Jody Goldberg (jody@gnome.org)
+ *    Michael Meeks (michael@ximian.com)
  *
- * (C) 1998-2003 Michael Meeks, Jody Goldberg
+ * (C) 1998-2001 Michael Meeks
+ * (C) 2002-2005 Jody Goldberg
  **/
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include <gnumeric.h>
 
-#include "file.h"
 #include "libgnumeric.h"
-#include "io-context.h"
 #include "command-context.h"
 #include "workbook-view.h"
 #include "workbook.h"
-#include "plugin-util.h"
-#include "module-plugin-defs.h"
+#include "gnm-plugin.h"
 
 #include "excel.h"
 #include "ms-excel-write.h"
@@ -28,17 +25,20 @@
 #include "ms-excel-read.h"
 #include "excel-xml-read.h"
 
+#include <goffice/app/file.h>
+#include <goffice/app/io-context.h>
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-infile.h>
 #include <gsf/gsf-infile-msole.h>
 #include <gsf/gsf-msole-utils.h>
-
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-outfile.h>
 #include <gsf/gsf-outfile-msole.h>
 #include <gsf/gsf-structured-blob.h>
+#include <glib/gi18n.h>
+#include <string.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
 /* Used to toggle debug messages on & off */
 /*
@@ -47,25 +47,19 @@ GNUMERIC_MODULE_PLUGIN_INFO_DECL;
  * 1 = enable experimental features
  * >1 increasing levels of detail.
  */
-/* Enables debugging mesgs while reading excel workbooks */
 gint ms_excel_read_debug = 0;
-/* Enables debugging mesgs while reading parsing escher streams */
+gint ms_excel_pivot_debug = 10;
 gint ms_excel_escher_debug = 0;
-/* Enables debugging mesgs while reading excel functions */
 gint ms_excel_formula_debug = 0;
-/* Enables debugging mesgs while reading excel charts */
 gint ms_excel_chart_debug = 0;
-/* Enables debugging mesgs while writing excel workbooks */
 gint ms_excel_write_debug = 0;
-/* Enables debugging mesgs while reading excel objects */
 gint ms_excel_object_debug = 0;
 
-gboolean excel_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl);
-void excel_file_open (GnmFileOpener const *fo, IOContext *context, WorkbookView *wbv, GsfInput *input);
-void excel_biff7_file_save (GnmFileSaver const *fs, IOContext *context, WorkbookView const *wbv, GsfOutput *output);
-void excel_biff8_file_save (GnmFileSaver const *fs, IOContext *context, WorkbookView const *wbv, GsfOutput *output);
-void excel_dsf_file_save   (GnmFileSaver const *fs, IOContext *context, WorkbookView const *wbv, GsfOutput *output);
-void plugin_cleanup (void);
+gboolean excel_file_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl);
+void excel_file_open (GOFileOpener const *fo, IOContext *context, WorkbookView *wbv, GsfInput *input);
+void excel_biff7_file_save (GOFileSaver const *fs, IOContext *context, WorkbookView const *wbv, GsfOutput *output);
+void excel_biff8_file_save (GOFileSaver const *fs, IOContext *context, WorkbookView const *wbv, GsfOutput *output);
+void excel_dsf_file_save   (GOFileSaver const *fs, IOContext *context, WorkbookView const *wbv, GsfOutput *output);
 
 static GsfInput *
 find_content_stream (GsfInfile *ole, gboolean *is_97)
@@ -90,7 +84,7 @@ find_content_stream (GsfInfile *ole, gboolean *is_97)
 }
 
 gboolean
-excel_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
+excel_file_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
 	GsfInfile *ole;
 	GsfInput  *stream;
@@ -117,22 +111,19 @@ excel_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 }
 
 static void
-excel_read_metadata (Workbook  *wb, GsfInfile *ole, char const *name,
+excel_read_metadata (GsfDocMetaData *meta_data, GsfInfile *ole, char const *name,
 		     IOContext *context)
 {
-	GError   *err = NULL;
 	GsfInput *stream = gsf_infile_child_by_name (ole, name);
 
 	if (stream != NULL) {
-		gsf_msole_metadata_read (stream, &err);
+		GError *err = gsf_msole_metadata_read (stream, meta_data);
 		if (err != NULL) {
 			gnm_io_warning (context, err->message);
 			g_error_free (err);
 		}
-		gsf_input_seek (stream, 0, G_SEEK_SET);
-		g_object_set_data_full (G_OBJECT (wb), name,
-			gsf_structured_blob_read (stream), g_object_unref);
-		g_object_unref (G_OBJECT (stream));
+
+		g_object_unref (stream);
 	}
 }
 
@@ -146,7 +137,7 @@ excel_read_metadata (Workbook  *wb, GsfInfile *ole, char const *name,
  * Load en excel workbook.
  */
 void
-excel_file_open (GnmFileOpener const *fo, IOContext *context,
+excel_file_open (GOFileOpener const *fo, IOContext *context,
                  WorkbookView *wbv, GsfInput *input)
 {
 	GsfInput  *stream = NULL;
@@ -154,6 +145,7 @@ excel_file_open (GnmFileOpener const *fo, IOContext *context,
 	GsfInfile *ole = gsf_infile_msole_new (input, &err);
 	Workbook  *wb = wb_view_workbook (wbv);
 	gboolean   is_double_stream_file, is_97;
+	GsfDocMetaData *meta_data;
 
 	if (ole == NULL) {
 		guint8 const *data;
@@ -171,7 +163,7 @@ excel_file_open (GnmFileOpener const *fo, IOContext *context,
 
 		/* OK, it really isn't an Excel file */
 		g_return_if_fail (err != NULL);
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (context),
+		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
 			err->message);
 		g_error_free (err);
 		return;
@@ -179,7 +171,7 @@ excel_file_open (GnmFileOpener const *fo, IOContext *context,
 
 	stream = find_content_stream (ole, &is_97);
 	if (stream == NULL) {
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (context),
+		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
 			 _("No Workbook or Book streams found."));
 		g_object_unref (G_OBJECT (ole));
 		return;
@@ -188,8 +180,11 @@ excel_file_open (GnmFileOpener const *fo, IOContext *context,
 	excel_read_workbook (context, wbv, stream, &is_double_stream_file);
 	g_object_unref (G_OBJECT (stream));
 
-	excel_read_metadata (wb, ole, "\05SummaryInformation", context);
-	excel_read_metadata (wb, ole, "\05DocumentSummaryInformation", context);
+	meta_data = gsf_doc_meta_data_new ();
+	excel_read_metadata (meta_data, ole, "\05DocumentSummaryInformation", context);
+	excel_read_metadata (meta_data, ole, "\05SummaryInformation", context);
+	g_object_set_data_full (G_OBJECT (wb), "GsfDocMetaData",
+		meta_data, g_object_unref);
 
 	/* See if there are any macros to keep around */
 	stream = gsf_infile_child_by_name (ole, "\01CompObj");
@@ -210,13 +205,13 @@ excel_file_open (GnmFileOpener const *fo, IOContext *context,
 	/* simple guess of format based on stream names */
 	if (is_double_stream_file)
 		workbook_set_saveinfo (wb, FILE_FL_AUTO,
-			gnm_file_saver_for_id ("Gnumeric_Excel:excel_dsf"));
+			go_file_saver_for_id ("Gnumeric_Excel:excel_dsf"));
 	else if (is_97)
 		workbook_set_saveinfo (wb, FILE_FL_AUTO,
-			gnm_file_saver_for_id ("Gnumeric_Excel:excel_biff8"));
+			go_file_saver_for_id ("Gnumeric_Excel:excel_biff8"));
 	else
 		workbook_set_saveinfo (wb, FILE_FL_AUTO,
-			gnm_file_saver_for_id ("Gnumeric_Excel:excel_biff7"));
+			go_file_saver_for_id ("Gnumeric_Excel:excel_biff7"));
 }
 
 static void
@@ -228,6 +223,7 @@ excel_save (IOContext *context, WorkbookView const *wbv, GsfOutput *output,
 	GsfOutfile *outfile;
 	ExcelWriteState *ewb = NULL;
 	GsfStructuredBlob *blob;
+	GsfDocMetaData *meta_data;
 
 	io_progress_message (context, _("Preparing to save..."));
 	io_progress_range_push (context, 0.0, 0.1);
@@ -250,25 +246,20 @@ excel_save (IOContext *context, WorkbookView const *wbv, GsfOutput *output,
 	excel_write_state_free (ewb);
 	io_progress_range_pop (context);
 
-	blob = g_object_get_data (G_OBJECT (wb), "\05DocumentSummaryInformation");
-	if (blob == NULL) {
+	meta_data = g_object_get_data (G_OBJECT (wb), "GsfDocMetaData");
+	if (meta_data != NULL) {
 		content = gsf_outfile_new_child (outfile,
 			"\05DocumentSummaryInformation", FALSE);
-		gsf_msole_metadata_write (content, TRUE, NULL);
+		gsf_msole_metadata_write (content, meta_data, TRUE);
 		gsf_output_close (content);
 		g_object_unref (G_OBJECT (content));
-	} else
-		gsf_structured_blob_write (blob, outfile);
 
-	blob = g_object_get_data (G_OBJECT (wb), "\05SummaryInformation");
-	if (blob == NULL) {
 		content = gsf_outfile_new_child (outfile,
 			"\05SummaryInformation", FALSE);
-		gsf_msole_metadata_write (content, FALSE, NULL);
+		gsf_msole_metadata_write (content, meta_data, FALSE);
 		gsf_output_close (content);
 		g_object_unref (G_OBJECT (content));
-	} else
-		gsf_structured_blob_write (blob, outfile);
+	}
 
 	/* restore the macros we loaded */
 	blob = g_object_get_data (G_OBJECT (wb), "MS_EXCEL_COMPOBJ");
@@ -283,20 +274,20 @@ excel_save (IOContext *context, WorkbookView const *wbv, GsfOutput *output,
 }
 
 void
-excel_dsf_file_save (GnmFileSaver const *fs, IOContext *context,
+excel_dsf_file_save (GOFileSaver const *fs, IOContext *context,
 		       WorkbookView const *wbv, GsfOutput *output)
 {
 	excel_save (context, wbv, output, TRUE, TRUE);
 }
 void
-excel_biff8_file_save (GnmFileSaver const *fs, IOContext *context,
+excel_biff8_file_save (GOFileSaver const *fs, IOContext *context,
 		       WorkbookView const *wbv, GsfOutput *output)
 {
 	excel_save (context, wbv, output, FALSE, TRUE);
 }
 
 void
-excel_biff7_file_save (GnmFileSaver const *fs, IOContext *context,
+excel_biff7_file_save (GOFileSaver const *fs, IOContext *context,
 		       WorkbookView const *wbv, GsfOutput *output)
 {
 	excel_save (context, wbv, output, TRUE, FALSE);
@@ -304,8 +295,8 @@ excel_biff7_file_save (GnmFileSaver const *fs, IOContext *context,
 
 
 #include <formula-types.h>
-void
-plugin_init (void)
+G_MODULE_EXPORT void
+go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 {
 	excel_read_init ();
 	excel_xml_read_init ();
@@ -331,17 +322,6 @@ plugin_init (void)
 			fprintf (stderr, "%s : min_args < 0\n", name);
 		if (fd->max_args < 0)
 			fprintf (stderr, "%s : min_args < 0\n", name);
-		if (fd->min_args != fd->max_args) {
-			if (0 == (fd->flags & XL_VARARG))
-				fprintf (stderr, "%s : should be vararg\n", name);
-			if (fd->flags & XL_FIXED)
-				fprintf (stderr, "%s : should not be fixed\n", name);
-		} else {
-			if (fd->flags & XL_VARARG)
-				fprintf (stderr, "%s : should not be vararg\n", name);
-			if (0 == (fd->flags & XL_FIXED))
-				fprintf (stderr, "%s : should be fixed\n", name);
-		}
 		if (fd->known_args != NULL &&
 		    fd->num_known_args != strlen (fd->known_args))
 			fprintf (stderr, "%s : num_expected_args inconsistent\n", name);
@@ -354,8 +334,8 @@ plugin_init (void)
  * Cleanup allocations made by this plugin.
  * (Called right before we are unloaded.)
  */
-void
-plugin_cleanup (void)
+G_MODULE_EXPORT void
+go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
 	destroy_xl_font_widths ();
 	excel_read_cleanup ();
