@@ -3,11 +3,11 @@
  * ms-biff.c: MS Excel Biff support...
  *
  * Author:
- *    Michael Meeks (michael@ximian.com)
  *    Jody Goldberg (jody@gnome.org)
+ *    Michael Meeks (michael@ximian.com)
  *
- * (C) 1998-2002 Michael Meeks
- *     2002-2004 Jody Goldberg
+ * (C) 1998-2001 Michael Meeks
+ * (C) 2002-2005 Jody Goldberg
  **/
 
 #include <gnumeric-config.h>
@@ -74,11 +74,10 @@ ms_biff_query_bound_check (BiffQuery *q, guint32 offset, unsigned len)
  *  ms_biff_password_hash and ms_biff_crypt_seq
  * based on pseudo-code in the OpenOffice.org XL documentation
  **/
-
 static guint16
 ms_biff_password_hash  (char const *password)
 {
-	int tmp, index= 0, len= strlen(password);
+	int tmp, index = 0, len = strlen(password);
 	guint16 chr, hash= 0;
 
 	do {
@@ -93,24 +92,28 @@ ms_biff_password_hash  (char const *password)
 }
 
 static void
-ms_biff_crypt_seq  (guint8 *seq, guint16 key, char const *password)
+ms_biff_crypt_seq (BiffQuery *q, guint16 key, char const *password)
 {
-	guint8 low = key & 0xff, high = key >> 8;
-	guint8 preset[15] = {0xbb, 0xff, 0xff, 0xba, 0xff, 0xff, 0xb9, 0x80,
-                             0x00, 0xbe, 0x0f, 0x00, 0xbf, 0x0f, 0x00 };
-	int k, len= strlen(password);
+	static guint8 const preset [] = {
+		0xbb, 0xff, 0xff, 0xba, 0xff, 0xff, 0xb9, 0x80,
+		0x00, 0xbe, 0x0f, 0x00, 0xbf, 0x0f, 0x00, 0x00
+	};
+	guint8 const low  =        key & 0xff;
+	guint8 const high = (key >> 8) & 0xff;
+	unsigned i, len = strlen (password);
+	guint8 *seq = q->xor_key;
 
-	strcpy(seq, password);
-	for (k= 0; len + k < 16; ++k) {
-		seq[len + k]= preset[k];
-	}
-	for (k= 0; k < 16; k+=2) {
-		seq[k] ^= low;
-		seq[k+1] ^= high;
-	}
-	for (k= 0; k < 16; ++k) {
-		seq[k] = (seq[k] << 2) | (seq[k] >> 6);
+	strncpy (seq, password, 16);
+	for (i = 0; (len + i) < 16; i++)
+		seq[len + i] = preset[i];
+
+	for (i = 0; i < 16; i += 2) {
+		seq[i]   ^= low;
+		seq[i+1] ^= high;
 	}
+
+	for (i = 0; i < 16; i++)
+		seq[i] = (seq[i] << 2) | (seq[i] >> 6);
 }
 
 static gboolean
@@ -134,7 +137,7 @@ ms_biff_pre_biff8_query_set_decrypt  (BiffQuery *q, char const *password)
 	if (hash != pw_hash)
 		return FALSE;
 
-	ms_biff_crypt_seq(q->xor_key, key, password);
+	ms_biff_crypt_seq (q, key, password);
 
 	q->encryption = MS_BIFF_CRYPTO_XOR;
 	return TRUE;
@@ -302,7 +305,7 @@ skip_bytes (BiffQuery *q, int start, int count)
  * ms_biff_query_set_decrypt :
  * @q :
  * @password : password in UTF-8 encoding.
- */
+ **/
 gboolean
 ms_biff_query_set_decrypt (BiffQuery *q, MsBiffVersion version,
 			   char const *password)
@@ -334,6 +337,24 @@ ms_biff_query_set_decrypt (BiffQuery *q, MsBiffVersion version,
 
 	return TRUE;
 }
+void
+ms_biff_query_copy_decrypt (BiffQuery *dst, BiffQuery const *src)
+{
+	g_return_if_fail (dst != NULL);
+	g_return_if_fail (src != NULL);
+
+#warning FINISH this
+	switch (src->encryption) {
+	default :
+	case MS_BIFF_CRYPTO_NONE:
+		g_return_if_fail (dst->encryption == MS_BIFF_CRYPTO_NONE);
+		break;
+	case MS_BIFF_CRYPTO_XOR :
+		break;
+	case MS_BIFF_CRYPTO_RC4 :
+		break;
+	};
+}
 
 BiffQuery *
 ms_biff_query_new (GsfInput *input)
@@ -404,8 +425,6 @@ ms_biff_query_next (BiffQuery *q)
 		return FALSE;
 	q->opcode = GSF_LE_GET_GUINT16 (data);
 	q->length = GSF_LE_GET_GUINT16 (data + 2);
-	q->ms_op  = (q->opcode>>8);
-	q->ls_op  = (q->opcode&0xff);
 
 	/* no biff record should be larger than around 20,000 */
 	g_return_val_if_fail (q->length < 20000, FALSE);
@@ -516,7 +535,7 @@ ms_biff_put_new (GsfOutput *output, MsBiffVersion version, int codepage)
 
 	bp = g_new (BiffPut, 1);
 
-	bp->ms_op         = bp->ls_op = 0;
+	bp->opcode        = 0;
 	bp->length        = 0;
 	bp->length        = 0;
 	bp->streamPos     = gsf_output_tell (output);
@@ -579,8 +598,7 @@ ms_biff_put_len_next (BiffPut *bp, guint16 opcode, guint32 len)
 #endif
 
 	bp->len_fixed  = 1;
-	bp->ms_op      = (opcode >>   8);
-	bp->ls_op      = (opcode & 0xff);
+	bp->opcode     = opcode;
 	bp->length     = len;
 	bp->streamPos  = gsf_output_tell (bp->output);
 	if (len > 0) {
@@ -602,8 +620,7 @@ ms_biff_put_var_next (BiffPut *bp, guint16 opcode)
 #endif
 
 	bp->len_fixed  = 0;
-	bp->ms_op      = (opcode >>   8);
-	bp->ls_op      = (opcode & 0xff);
+	bp->opcode     = opcode;
 	bp->curpos     = 0;
 	bp->length     = 0;
 	bp->data       = 0;
@@ -675,7 +692,7 @@ ms_biff_put_var_commit (BiffPut *bp)
 	endpos = bp->streamPos + bp->length + 4;
 	gsf_output_seek (bp->output, bp->streamPos, G_SEEK_SET);
 
-	GSF_LE_SET_GUINT16 (tmp, (bp->ms_op<<8) + bp->ls_op);
+	GSF_LE_SET_GUINT16 (tmp, bp->opcode);
 	GSF_LE_SET_GUINT16 (tmp+2, bp->length);
 	gsf_output_write (bp->output, 4, tmp);
 
@@ -700,7 +717,7 @@ ms_biff_put_len_commit (BiffPut *bp)
 /*	if (!bp->data_malloced) Unimplemented optimisation
 		bp->output->lseek (bp->output, bp->length, G_SEEK_CUR);
 		else */
-	GSF_LE_SET_GUINT16 (tmp, (bp->ms_op<<8) + bp->ls_op);
+	GSF_LE_SET_GUINT16 (tmp, bp->opcode);
 	GSF_LE_SET_GUINT16 (tmp + 2, bp->length);
 	gsf_output_write (bp->output, 4, tmp);
 	gsf_output_write (bp->output, bp->length, bp->data);
