@@ -7,7 +7,7 @@
  * Author:
  *    Jody Goldberg (jody@gnome.org)
  *
- * (C) 2000-2004 Jody Goldberg
+ * (C) 2000-2005 Jody Goldberg
  **/
 
 #include <gnumeric-config.h>
@@ -20,6 +20,8 @@
 #include <str.h>
 #include <value.h>
 
+#include <gsf/gsf-utils.h>
+
 void
 ms_container_init (MSContainer *container, MSContainerClass const *vtbl,
 		   MSContainer *parent,
@@ -34,7 +36,8 @@ ms_container_init (MSContainer *container, MSContainerClass const *vtbl,
 	container->parent = parent;
 
 	container->names = NULL;
-	container->v7.externsheet = NULL;
+	container->v7.externsheets = NULL;
+	container->v7.externnames = NULL;
 }
 
 void
@@ -64,9 +67,24 @@ ms_container_finalize (MSContainer *container)
 		container->obj_queue = NULL;
 	}
 
-	if (container->v7.externsheet != NULL) {
-		g_ptr_array_free (container->v7.externsheet, TRUE);
-		container->v7.externsheet = NULL;
+	if (container->v7.externsheets != NULL) {
+		g_ptr_array_free (container->v7.externsheets, TRUE);
+		container->v7.externsheets = NULL;
+	}
+	if (container->v7.externnames != NULL) {
+		for (i = container->v7.externnames->len; i-- > 0 ; )
+			if (g_ptr_array_index (container->v7.externnames, i) != NULL) {
+				GnmNamedExpr *nexpr = g_ptr_array_index (container->v7.externnames, i);
+				if (nexpr != NULL) {
+					/* NAME placeholders need removal, EXTERNNAME placeholders
+					 * will no be active */
+					if (nexpr->active && nexpr->is_placeholder && nexpr->ref_count == 2)
+						expr_name_remove (nexpr);
+					expr_name_unref (nexpr);
+				}
+			}
+		g_ptr_array_free (container->v7.externnames, TRUE);
+		container->v7.externnames = NULL;
 	}
 	if (container->names != NULL) {
 		for (i = container->names->len; i-- > 0 ; )
@@ -201,7 +219,7 @@ ms_container_sheet (MSContainer const *c)
 	return (*c->vtbl->sheet) (c);
 }
 
-GnmFormat *
+GOFormat *
 ms_container_get_fmt (MSContainer const *c, unsigned indx)
 {
 	for ( ; TRUE ; c = c->parent) {
@@ -231,3 +249,38 @@ ms_container_get_markup (MSContainer const *c, unsigned indx)
 	}
 	return (*c->vtbl->get_markup) (c, indx);
 }
+
+typedef struct {
+	unsigned first, last;
+	PangoAttrList *accum;
+} TXORun;
+
+static gboolean
+append_txorun (PangoAttribute *src, TXORun *run)
+{
+	PangoAttribute *dst = pango_attribute_copy (src);
+	dst->start_index = run->first;	/* inclusive */
+	dst->end_index = run->last;	/* exclusive */
+	pango_attr_list_change (run->accum, dst);
+	return FALSE;
+}
+PangoAttrList *
+ms_container_read_markup (MSContainer const *c,
+			  guint8 const *data, int txo_len, char const *str)
+{
+	TXORun txo_run;
+
+	g_return_val_if_fail (txo_len >= 16, NULL); /* min two records */
+
+	txo_run.last = G_MAXINT;
+	txo_run.accum = pango_attr_list_new ();
+	for (txo_len -= 16 ; txo_len >= 0 ; txo_len -= 8) {
+		txo_run.first = g_utf8_offset_to_pointer (str,
+			GSF_LE_GET_GUINT16 (data + txo_len)) - str;
+		pango_attr_list_filter (ms_container_get_markup (
+			c, GSF_LE_GET_GUINT16 (data + txo_len + 2)),
+			(PangoAttrFilterFunc) append_txorun, &txo_run);
+		txo_run.last = txo_run.first;
+	}
+	return txo_run.accum;
+}
