@@ -1,14 +1,15 @@
-#ifndef GNUMERIC_MS_OBJ_H
-#define GNUMERIC_MS_OBJ_H
+#ifndef GNM_MS_OBJ_H
+#define GNM_MS_OBJ_H
 
 /**
  * ms-obj.h: MS Excel Graphic Object support for Gnumeric
  *
- * Author:
- *    Michael Meeks (michael@ximian.com)
+ * Authors:
  *    Jody Goldberg (jody@gnome.org)
+ *    Michael Meeks (michael@ximian.com)
  *
- * (C) 1998-2004 Michael Meeks, Jody Goldberg
+ * (C) 1998-2001 Michael Meeks
+ * (C) 2002-2005 Jody Goldberg
  **/
 
 #include "ms-excel-read.h"
@@ -103,8 +104,7 @@ MSObjAttr    *ms_obj_attr_bag_lookup  (MSObjAttrBag *attrs,
 guint32   ms_obj_attr_get_uint	      (MSObjAttrBag *attrs, MSObjAttrID id, guint32 default_value);
 gint32    ms_obj_attr_get_int	      (MSObjAttrBag *attrs, MSObjAttrID id, gint32 default_value);
 gpointer  ms_obj_attr_get_ptr	      (MSObjAttrBag *attrs, MSObjAttrID id, gpointer default_value);
-GArray	      *ms_obj_attr_get_array  (MSObjAttrBag *ab, MSObjAttrID id,
-				       GArray *default_value, gboolean steal);
+GArray   *ms_obj_attr_get_array	      (MSObjAttrBag *attrs, MSObjAttrID id, GArray *default_value);
 GnmExpr const *ms_obj_attr_get_expr   (MSObjAttrBag *attrs, MSObjAttrID id, GnmExpr const *default_value);
 PangoAttrList *ms_obj_attr_get_markup (MSObjAttrBag *attrs, MSObjAttrID id, PangoAttrList *default_value);
 
@@ -136,4 +136,4 @@ void ms_objv8_write_scrollbar	(BiffPut *bp);
 void ms_objv8_write_listbox	(BiffPut *bp, gboolean filtered);
 void ms_objv8_write_chart	(BiffPut *bp, SheetObject *sog);
 
-#endif /* GNUMERIC_MS_OBJ_H */
+#endif /* GNM_MS_OBJ_H */
