@@ -23,14 +23,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include <func.h>
-
 #include <parse-util.h>
 #include <cell.h>
-#include <format.h>
+#include <gnm-format.h>
 #include <str.h>
+#include <gutils.h>
 #include <sheet.h>
 #include <workbook.h>
 #include <value.h>
@@ -39,25 +38,25 @@
 #include <mathfunc.h>
 #include <rangefunc-strings.h>
 #include <collect.h>
-#include <regutf8.h>
+#include <goffice/utils/regutf8.h>
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-msole-utils.h>
+#include <gnm-i18n.h>
+#include <goffice/app/go-plugin.h>
+#include <gnm-plugin.h>
 
 #include <limits.h>
 #include <string.h>
 
-#include "plugin.h"
-#include "plugin-util.h"
-#include "module-plugin-defs.h"
-
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
 /***************************************************************************/
 
 static GIConv CHAR_iconv;
 
-static char const *help_char = {
-	N_("@FUNCTION=CHAR\n"
+static GnmFuncHelp const help_char[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=CHAR\n"
 	   "@SYNTAX=CHAR(x)\n"
 
 	   "@DESCRIPTION="
@@ -67,6 +66,8 @@ static char const *help_char = {
 	   "CHAR(65) equals A.\n"
 	   "\n"
 	   "@SEEALSO=CODE")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -98,8 +99,9 @@ gnumeric_char (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_unichar = {
-	N_("@FUNCTION=UNICHAR\n"
+static GnmFuncHelp const help_unichar[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=UNICHAR\n"
 	   "@SYNTAX=UNICHAR(x)\n"
 
 	   "@DESCRIPTION="
@@ -107,9 +109,11 @@ static char const *help_unichar = {
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "UNICHAR(65) equals A.\n"
-	   "UNICHAR(960) equals a small greek pi.\n"
+	   "UNICHAR(960) equals a small Greek pi.\n"
 	   "\n"
 	   "@SEEALSO=CHAR,UNICODE,CODE")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -130,8 +134,9 @@ gnumeric_unichar (FunctionEvalInfo *ei, GnmValue **argv)
 
 static GIConv CODE_iconv;
 
-static char const *help_code = {
-	N_("@FUNCTION=CODE\n"
+static GnmFuncHelp const help_code[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=CODE\n"
 	   "@SYNTAX=CODE(char)\n"
 
 	   "@DESCRIPTION="
@@ -142,6 +147,8 @@ static char const *help_code = {
 	   "CODE(\"A\") equals 65.\n"
 	   "\n"
 	   "@SEEALSO=CHAR")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -175,8 +182,9 @@ gnumeric_code (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_unicode = {
-	N_("@FUNCTION=UNICODE\n"
+static GnmFuncHelp const help_unicode[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=UNICODE\n"
 	   "@SYNTAX=UNICODE(char)\n"
 
 	   "@DESCRIPTION="
@@ -186,6 +194,8 @@ static char const *help_unicode = {
 	   "UNICODE(\"A\") equals 65.\n"
 	   "\n"
 	   "@SEEALSO=UNICHAR,CODE,CHAR")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -201,8 +211,9 @@ gnumeric_unicode (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_exact = {
-	N_("@FUNCTION=EXACT\n"
+static GnmFuncHelp const help_exact[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=EXACT\n"
 	   "@SYNTAX=EXACT(string1, string2)\n"
 
 	   "@DESCRIPTION="
@@ -215,6 +226,8 @@ static char const *help_exact = {
 	   "EXACT(\"key\",\"Key\") equals FALSE.\n"
 	   "\n"
 	   "@SEEALSO=LEN, SEARCH, DELTA")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -226,8 +239,9 @@ gnumeric_exact (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_len = {
-	N_("@FUNCTION=LEN\n"
+static GnmFuncHelp const help_len[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=LEN\n"
 	   "@SYNTAX=LEN(string)\n"
 
 	   "@DESCRIPTION="
@@ -237,9 +251,10 @@ static char const *help_len = {
 	   "@EXAMPLES=\n"
 	   "LEN(\"Helsinki\") equals 8.\n"
 	   "\n"
-	   "@SEEALSO=CHAR, CODE")
+	   "@SEEALSO=CHAR, CODE, LENB")
+	},
+	{ GNM_FUNC_HELP_END }
 };
-#warning Add LENB to seealso
 
 static GnmValue *
 gnumeric_len (FunctionEvalInfo *ei, GnmValue **argv)
@@ -248,8 +263,9 @@ gnumeric_len (FunctionEvalInfo *ei, GnmValue **argv)
 }
 
 /***************************************************************************/
-static char const *help_lenb = {
-	N_("@FUNCTION=LENB\n"
+static GnmFuncHelp const help_lenb[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=LENB\n"
 	   "@SYNTAX=LENB(string)\n"
 
 	   "@DESCRIPTION="
@@ -260,6 +276,8 @@ static char const *help_lenb = {
 	   "LENB(\"Helsinki\") equals 8.\n"
 	   "\n"
 	   "@SEEALSO=CHAR, CODE, LEN")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -270,8 +288,9 @@ gnumeric_lenb (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_left = {
-	N_("@FUNCTION=LEFT\n"
+static GnmFuncHelp const help_left[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=LEFT\n"
 	   "@SYNTAX=LEFT(text[,num_chars])\n"
 
 	   "@DESCRIPTION="
@@ -283,6 +302,8 @@ static char const *help_left = {
 	   "LEFT(\"Directory\",3) equals \"Dir\".\n"
 	   "\n"
 	   "@SEEALSO=MID, RIGHT")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -306,8 +327,9 @@ gnumeric_left (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_lower = {
-	N_("@FUNCTION=LOWER\n"
+static GnmFuncHelp const help_lower[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=LOWER\n"
 	   "@SYNTAX=LOWER(text)\n"
 
 	   "@DESCRIPTION="
@@ -318,6 +340,8 @@ static char const *help_lower = {
 	   "LOWER(\"J. F. Kennedy\") equals \"j. f. kennedy\".\n"
 	   "\n"
 	   "@SEEALSO=UPPER")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -328,8 +352,9 @@ gnumeric_lower (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_mid = {
-	N_("@FUNCTION=MID\n"
+static GnmFuncHelp const help_mid[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=MID\n"
 	   "@SYNTAX=MID(string, position, length)\n"
 
 	   "@DESCRIPTION="
@@ -341,6 +366,8 @@ static char const *help_mid = {
 	   "MID(\"testing\",2,3) equals \"est\".\n"
 	   "\n"
 	   "@SEEALSO=LEFT, RIGHT")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -373,8 +400,9 @@ gnumeric_mid (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_right = {
-	N_("@FUNCTION=RIGHT\n"
+static GnmFuncHelp const help_right[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=RIGHT\n"
 	   "@SYNTAX=RIGHT(text[,num_chars])\n"
 
 	   "@DESCRIPTION="
@@ -387,6 +415,8 @@ static char const *help_right = {
 	   "RIGHT(\"end\",2) equals \"nd\".\n"
 	   "\n"
 	   "@SEEALSO=MID, LEFT")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -417,8 +447,9 @@ gnumeric_right (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_upper = {
-	N_("@FUNCTION=UPPER\n"
+static GnmFuncHelp const help_upper[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=UPPER\n"
 	   "@SYNTAX=UPPER(text)\n"
 
 	   "@DESCRIPTION="
@@ -429,6 +460,8 @@ static char const *help_upper = {
 	   "UPPER(\"cancelled\") equals \"CANCELLED\".\n"
 	   "\n"
 	   "@SEEALSO=LOWER")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -439,8 +472,9 @@ gnumeric_upper (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_concatenate = {
-	N_("@FUNCTION=CONCATENATE\n"
+static GnmFuncHelp const help_concatenate[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=CONCATENATE\n"
 	   "@SYNTAX=CONCATENATE(string1[,string2...])\n"
 	   "@DESCRIPTION="
 	   "CONCATENATE returns the string obtained by concatenation of "
@@ -451,6 +485,8 @@ static char const *help_concatenate = {
 	   "CONCATENATE(\"aa\",\"bb\") equals \"aabb\".\n"
 	   "\n"
 	   "@SEEALSO=LEFT, MID, RIGHT")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -464,8 +500,9 @@ gnumeric_concatenate (FunctionEvalInfo *ei, GnmExprList *nodes)
 
 /***************************************************************************/
 
-static char const *help_rept = {
-	N_("@FUNCTION=REPT\n"
+static GnmFuncHelp const help_rept[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=REPT\n"
 	   "@SYNTAX=REPT(string,num)\n"
 	   "@DESCRIPTION="
 	   "REPT returns @num repetitions of @string.\n\n"
@@ -475,6 +512,8 @@ static char const *help_rept = {
 	   "REPT(\".\",3) equals \"...\".\n"
 	   "\n"
 	   "@SEEALSO=CONCATENATE")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -510,8 +549,9 @@ gnumeric_rept (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_clean = {
-	N_("@FUNCTION=CLEAN\n"
+static GnmFuncHelp const help_clean[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=CLEAN\n"
 	   "@SYNTAX=CLEAN(string)\n"
 	   "@DESCRIPTION="
 	   "CLEAN removes any non-printable characters from @string.\n\n"
@@ -521,6 +561,8 @@ static char const *help_clean = {
 	   "CLEAN(\"one\"\\&char(7)) equals \"one\".\n"
 	   "\n"
 	   "@SEEALSO=")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -543,8 +585,9 @@ gnumeric_clean (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_find = {
-	N_("@FUNCTION=FIND\n"
+static GnmFuncHelp const help_find[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=FIND\n"
 	   "@SYNTAX=FIND(string1,string2[,start])\n"
 	   "@DESCRIPTION="
 	   "FIND returns position of @string1 in @string2 (case-sensitive), "
@@ -556,6 +599,8 @@ static char const *help_find = {
 	   "FIND(\"ac\",\"Jack\") equals 2.\n"
 	   "\n"
 	   "@SEEALSO=EXACT, LEN, MID, SEARCH")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -601,8 +646,9 @@ gnumeric_find (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_fixed = {
-	N_("@FUNCTION=FIXED\n"
+static GnmFuncHelp const help_fixed[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=FIXED\n"
 	   "@SYNTAX=FIXED(num,[decimals, no_commas])\n"
 	   "@DESCRIPTION="
 	   "FIXED returns @num as a formatted string with @decimals numbers "
@@ -614,6 +660,8 @@ static char const *help_fixed = {
 	   "FIXED(1234.567,2) equals \"1,234.57\".\n"
 	   "\n"
 	   "@SEEALSO=TEXT, VALUE, DOLLAR")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -639,8 +687,8 @@ gnumeric_fixed (FunctionEvalInfo *ei, GnmValue **argv)
 
 	if (decimals <= 0) {
 		/* no decimal point : just round and pad 0's */
-		gnm_float mult = gpow10 (decimals);
-		num = (gnumeric_fake_round (num * mult) / mult);
+		gnm_float mult = gnm_pow10 (decimals);
+		num = (gnm_fake_round (num * mult) / mult);
 		fmt.right_req = fmt.right_allowed = 0;
 	} else /* decimal point format */
 		fmt.right_req = fmt.right_allowed = decimals;
@@ -658,7 +706,7 @@ gnumeric_fixed (FunctionEvalInfo *ei, GnmValue **argv)
 		num = -num;
 		g_string_append_c (str, '-');
 	}
-	render_number (str, num, &fmt);
+	gnm_render_number (str, num, &fmt);
 	if (str->len == 0)
 		g_string_append_c (str, '0');
 	return value_new_string_nocopy (g_string_free (str, FALSE));
@@ -666,8 +714,9 @@ gnumeric_fixed (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_proper = {
-	N_("@FUNCTION=PROPER\n"
+static GnmFuncHelp const help_proper[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=PROPER\n"
 	   "@SYNTAX=PROPER(string)\n"
 
 	   "@DESCRIPTION="
@@ -678,6 +727,8 @@ static char const *help_proper = {
 	   "PROPER(\"j. f. kennedy\") equals \"J. F. Kennedy\".\n"
 	   "\n"
 	   "@SEEALSO=LOWER, UPPER")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 /*
@@ -718,8 +769,9 @@ gnumeric_proper (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_replace = {
-	N_("@FUNCTION=REPLACE\n"
+static GnmFuncHelp const help_replace[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=REPLACE\n"
 	   "@SYNTAX=REPLACE(old,start,num,new)\n"
 	   "@DESCRIPTION="
 	   "REPLACE returns @old with @new replacing @num characters from "
@@ -730,6 +782,8 @@ static char const *help_replace = {
 	   "REPLACE(\"testing\",2,3,\"*****\") equals \"t*****ing\".\n"
 	   "\n"
 	   "@SEEALSO=MID, SEARCH, SUBSTITUTE, TRIM")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -767,8 +821,9 @@ gnumeric_replace (FunctionEvalInfo *ei, GnmValue **argv)
 /***************************************************************************/
 /* Note: help_t is a reserved symbol.  */
 
-static char const *help_t_ = {
-	N_("@FUNCTION=T\n"
+static GnmFuncHelp const help_t_[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=T\n"
 	   "@SYNTAX=T(value)\n"
 	   "@DESCRIPTION="
 	   "T returns @value if and only if it is text, otherwise a blank "
@@ -780,6 +835,8 @@ static char const *help_t_ = {
 	   "T(64) returns an empty cell.\n"
 	   "\n"
 	   "@SEEALSO=CELL, N, VALUE")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 /* Note: gnumeric_t is a reserved symbol.  */
@@ -795,8 +852,9 @@ gnumeric_t_ (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_text = {
-	N_("@FUNCTION=TEXT\n"
+static GnmFuncHelp const help_text[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=TEXT\n"
 	   "@SYNTAX=TEXT(value,format_text)\n"
 	   "@DESCRIPTION="
 	   "TEXT returns @value as a string with the specified format.\n\n"
@@ -807,6 +865,8 @@ static char const *help_text = {
 	   "TEXT(date(1999,4,15),\"mmmm, dd, yy\") equals \"April, 15, 99\".\n"
 	   "\n"
 	   "@SEEALSO=DOLLAR, FIXED, VALUE")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -814,8 +874,8 @@ gnumeric_text (FunctionEvalInfo *ei, GnmValue **args)
 {
 	GnmValue       *res, *match = NULL;
 	GnmValue const *v  = args[0];
-	GnmFormat *fmt;
-	GnmDateConventions const *conv =
+	GOFormat *fmt;
+	GODateConventions const *conv =
 		workbook_date_conv (ei->pos->sheet->workbook);
 
 	if (v->type == VALUE_STRING) {
@@ -836,8 +896,9 @@ gnumeric_text (FunctionEvalInfo *ei, GnmValue **args)
 
 /***************************************************************************/
 
-static char const *help_trim = {
-	N_("@FUNCTION=TRIM\n"
+static GnmFuncHelp const help_trim[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=TRIM\n"
 	   "@SYNTAX=TRIM(text)\n"
 	   "@DESCRIPTION="
 	   "TRIM returns @text with only single spaces between words.\n\n"
@@ -847,6 +908,8 @@ static char const *help_trim = {
 	   "TRIM(\"  a bbb  cc\") equals \"a bbb cc\".\n"
 	   "\n"
 	   "@SEEALSO=CLEAN, MID, REPLACE, SUBSTITUTE")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -888,8 +951,9 @@ gnumeric_trim (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_value = {
-	N_("@FUNCTION=VALUE\n"
+static GnmFuncHelp const help_value[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=VALUE\n"
 	   "@SYNTAX=VALUE(text)\n"
 	   "@DESCRIPTION="
 	   "VALUE returns numeric value of @text.\n\n"
@@ -899,6 +963,8 @@ static char const *help_value = {
 	   "VALUE(\"$1,000\") equals 1000.\n"
 	   "\n"
 	   "@SEEALSO=DOLLAR, FIXED, TEXT")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -931,8 +997,9 @@ gnumeric_value (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_substitute = {
-	N_("@FUNCTION=SUBSTITUTE\n"
+static GnmFuncHelp const help_substitute[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=SUBSTITUTE\n"
 	   "@SYNTAX=SUBSTITUTE(text, old, new [,num])\n"
 	   "@DESCRIPTION="
 	   "SUBSTITUTE replaces @old with @new in @text.  Substitutions "
@@ -944,6 +1011,8 @@ static char const *help_substitute = {
 	   "SUBSTITUTE(\"testing\",\"test\",\"wait\") equals \"waiting\".\n"
 	   "\n"
 	   "@SEEALSO=REPLACE, TRIM")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -956,9 +1025,18 @@ gnumeric_substitute (FunctionEvalInfo *ei, GnmValue **argv)
 	char const *text = value_peek_string (argv[0]);
 	char const *old  = value_peek_string (argv[1]);
 	char const *new  = value_peek_string (argv[2]);
-	int num = argv[3] ? value_get_as_int (argv[3]) : 0;
+	int num = 0;
+
+	if (argv[3]) {
+		num = value_get_as_int (argv[3]);
+		if (num <= 0)
+			return value_new_error_VALUE (ei->pos);
+	}
 
 	oldlen = strlen (old);
+	if (oldlen == 0)
+		return value_dup (argv[0]);
+
 	newlen = strlen (new);
 	len = strlen (text);
 	s = g_string_sized_new (len);
@@ -988,8 +1066,9 @@ gnumeric_substitute (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_dollar = {
-	N_("@FUNCTION=DOLLAR\n"
+static GnmFuncHelp const help_dollar[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=DOLLAR\n"
 	   "@SYNTAX=DOLLAR(num[,decimals])\n"
 	   "@DESCRIPTION="
 	   "DOLLAR returns @num formatted as currency.\n\n"
@@ -999,13 +1078,15 @@ static char const *help_dollar = {
 	   "DOLLAR(12345) equals \"$12,345.00\".\n"
 	   "\n"
 	   "@SEEALSO=FIXED, TEXT, VALUE")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
 gnumeric_dollar (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	FormatCharacteristics info;
-	GnmFormat *sf;
+	GOFormat *sf;
 	gnm_float p10;
 	GnmValue *v;
 	char *s, *end;
@@ -1017,11 +1098,11 @@ gnumeric_dollar (FunctionEvalInfo *ei, GnmValue **argv)
 		return value_new_error_VALUE (ei->pos);
 
 	/* Since decimals can be negative, round the number.  */
-	p10 = gpow10 (decimals);
+	p10 = gnm_pow10 (decimals);
 	if (p10 == 0)
 		number = 0; /* Underflow.  */
 	else
-		number = gnumeric_fake_round (number * p10) / p10;
+		number = gnm_fake_round (number * p10) / p10;
 
 	info = style_format_default_money ()->family_info;
 	info.num_decimals = MAX (decimals, 0);
@@ -1044,8 +1125,9 @@ gnumeric_dollar (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 
-static char const *help_search = {
-	N_("@FUNCTION=SEARCH\n"
+static GnmFuncHelp const help_search[] = {
+	{ GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=SEARCH\n"
 	   "@SYNTAX=SEARCH(search_string,text[,start_num])\n"
 	   "@DESCRIPTION="
 	   "SEARCH returns the location of the @search_ string within "
@@ -1071,6 +1153,8 @@ static char const *help_search = {
 	   "SEARCH(\"c\",\"Cancel\",2) equals 4.\n"
 	   "\n"
 	   "@SEEALSO=FIND")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -1116,82 +1200,82 @@ gnumeric_search (FunctionEvalInfo *ei, GnmValue **argv)
 /***************************************************************************/
 
 const GnmFuncDescriptor string_functions[] = {
-        { "char",       "f",     N_("number"),                  &help_char,
+        { "char",       "f",     N_("number"),                  help_char,
 	  gnumeric_char, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "unichar",    "f",     N_("number"),                  &help_unichar,
+        { "unichar",    "f",     N_("number"),                  help_unichar,
 	  gnumeric_unichar, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_BASIC },
-        { "clean",      "S",     N_("text"),                    &help_clean,
+        { "clean",      "S",     N_("text"),                    help_clean,
           gnumeric_clean, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "code",       "S",     N_("text"),                    &help_code,
+        { "code",       "S",     N_("text"),                    help_code,
 	  gnumeric_code, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "unicode",    "S",     N_("text"),                    &help_unicode,
+        { "unicode",    "S",     N_("text"),                    help_unicode,
 	  gnumeric_unicode, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_BASIC },
-        { "concatenate", NULL,   N_("text,text,"),            &help_concatenate,
+        { "concatenate", NULL,   N_("text,text,"),            help_concatenate,
 	  NULL, gnumeric_concatenate, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "dollar",     "f|f",   N_("num,decimals"),            &help_dollar,
+        { "dollar",     "f|f",   N_("num,decimals"),            help_dollar,
 	  gnumeric_dollar, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "exact",      "SS",    N_("text1,text2"),             &help_exact,
+        { "exact",      "SS",    N_("text1,text2"),             help_exact,
 	  gnumeric_exact, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "find",       "SS|f",  N_("text1,text2,num"),         &help_find,
+        { "find",       "SS|f",  N_("text1,text2,num"),         help_find,
 	  gnumeric_find, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "fixed",      "f|fb",  N_("num,decs,no_commas"),      &help_fixed,
+        { "fixed",      "f|fb",  N_("num,decs,no_commas"),      help_fixed,
 	  gnumeric_fixed, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "left",       "S|f",   N_("text,num_chars"),          &help_left,
+        { "left",       "S|f",   N_("text,num_chars"),          help_left,
 	  gnumeric_left, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "len",        "S",     N_("text"),                    &help_len,
+        { "len",        "S",     N_("text"),                    help_len,
 	  gnumeric_len, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "lenb",       "S",     N_("text"),                    &help_lenb,
+        { "lenb",       "S",     N_("text"),                    help_lenb,
 	  gnumeric_lenb, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
-        { "lower",      "S",     N_("text"),                    &help_lower,
+        { "lower",      "S",     N_("text"),                    help_lower,
 	  gnumeric_lower, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "mid",        "Sff",   N_("text,pos,num"),            &help_mid,
+        { "mid",        "Sff",   N_("text,pos,num"),            help_mid,
 	  gnumeric_mid, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "proper",     "S",     N_("text"),                    &help_proper,
+        { "proper",     "S",     N_("text"),                    help_proper,
 	  gnumeric_proper, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "replace",    "SffS",  N_("old,start,num,new"),       &help_replace,
+        { "replace",    "SffS",  N_("old,start,num,new"),       help_replace,
 	  gnumeric_replace, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "rept",       "Sf",    N_("text,num"),                &help_rept,
+        { "rept",       "Sf",    N_("text,num"),                help_rept,
 	  gnumeric_rept, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "right",      "S|f",   N_("text,num_chars"),          &help_right,
+        { "right",      "S|f",   N_("text,num_chars"),          help_right,
 	  gnumeric_right, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "search",     "SS|f",  N_("search_string,text,start_num"),   &help_search,
+        { "search",     "SS|f",  N_("search_string,text,start_num"),   help_search,
 	  gnumeric_search, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "substitute", "SSS|f", N_("text,old,new,num"),       &help_substitute,
+        { "substitute", "SSS|f", N_("text,old,new,num"),       help_substitute,
 	  gnumeric_substitute, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "t",          "S",     N_("value"),                   &help_t_,
+        { "t",          "S",     N_("value"),                   help_t_,
           gnumeric_t_, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "text",       "Ss",    N_("value,format_text"),       &help_text,
+        { "text",       "Ss",    N_("value,format_text"),       help_text,
 	  gnumeric_text, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "trim",       "S",     N_("text"),                    &help_trim,
+        { "trim",       "S",     N_("text"),                    help_trim,
 	  gnumeric_trim, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "upper",      "S",     N_("text"),                    &help_upper,
+        { "upper",      "S",     N_("text"),                    help_upper,
 	  gnumeric_upper, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "value",      "S",     N_("text"),                    &help_value,
+        { "value",      "S",     N_("text"),                    help_value,
 	  gnumeric_value, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
@@ -1199,16 +1283,16 @@ const GnmFuncDescriptor string_functions[] = {
 };
 
 
-void
-plugin_init (void)
+G_MODULE_EXPORT void
+go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 {
 	int codepage = gsf_msole_iconv_win_codepage ();
 	CHAR_iconv = gsf_msole_iconv_open_for_import (codepage);
 	CODE_iconv = gsf_msole_iconv_open_for_export ();
 }
 
-void
-plugin_cleanup (void)
+G_MODULE_EXPORT void
+go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
 	gsf_iconv_close (CHAR_iconv);
 	gsf_iconv_close (CODE_iconv);
