@@ -40,9 +40,8 @@
 #include <gnumeric.h>
 #include <gnumeric-gconf.h>
 #include "latex.h"
-#include <plugin-util.h>
-#include <io-context.h>
-#include <error-info.h>
+#include <goffice/app/io-context.h>
+#include <goffice/app/error-info.h>
 #include <workbook-view.h>
 #include <workbook.h>
 #include <sheet.h>
@@ -51,7 +50,7 @@
 #include <style-color.h>
 #include <font.h>
 #include <cell.h>
-#include <format.h>
+#include <gnm-format.h>
 #include <style-border.h>
 #include <sheet-style.h>
 #include <parse-util.h>
@@ -525,7 +524,7 @@ latex2e_write_table_header(GsfOutput *output, int num_cols)
 
 	gsf_output_printf (output, "%%\t\\multicolumn{%d}{c}{The First Header} \\\\ \\hline \n", num_cols);
 	gsf_output_printf (output, "%%\t\\multicolumn{1}{c}{colTag}\t%%Column 1\n");
-	for (col = 2 ; col < num_cols; col++)
+	for (col = 1 ; col < num_cols; col++)
 		gsf_output_printf (output, "%%\t&\\multicolumn{1}{c}{colTag}\t%%Column %d\n",col);
 	gsf_output_printf (output, "%%\t&\\multicolumn{1}{c}{colTag}\t\\\\ \\hline %%Last column\n");
 	gsf_output_printf (output, "%%\t\\endfirsthead\n\n");
@@ -534,7 +533,7 @@ latex2e_write_table_header(GsfOutput *output, int num_cols)
 	gsf_output_printf (output, "%%\t\\hline\n");
 	gsf_output_printf (output, "%%\t\\multicolumn{%d}{l}{\\ldots\\small\\slshape continued} \\\\ \\hline\n", num_cols);
 	gsf_output_printf (output, "%%\t\\multicolumn{1}{c}{colTag}\t%%Column 1\n");
-	for (col = 2 ; col < num_cols; col++)
+	for (col = 1 ; col < num_cols; col++)
 				gsf_output_printf (output, "%%\t&\\multicolumn{1}{c}{colTag}\t%%Column %d\n",col);
 	gsf_output_printf (output, "%%\t&\\multicolumn{1}{c}{colTag}\t\\\\ \\hline %%Last column\n");
 	gsf_output_printf (output, "%%\t\\endhead\n\n");
@@ -821,13 +820,13 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 
 	if (!cell_is_empty (cell)) {
                 /* Check the foreground (text) colour. */
-		const PangoColor *fore = cell_get_render_color (cell);
-		if (fore == NULL)
+		GOColor fore = cell_get_render_color (cell);
+		if (fore == 0)
 			r = g = b = 0;
 		else {
-			r = fore->red;
-			g = fore->green;
-			b = fore->blue;
+			r = UINT_RGBA_R (fore);
+			g = UINT_RGBA_G (fore);
+			b = UINT_RGBA_B (fore);
 		}
 		if (r != 0 || g != 0 || b != 0) {
 			char *locale;
@@ -1019,7 +1018,7 @@ latex2e_print_hhline (GsfOutput *output, StyleBorderType *clines, int n, StyleBo
  * to render the format and contents of the cell.
  */
 void
-latex_file_save (GnmFileSaver const *fs, IOContext *io_context,
+latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 		 WorkbookView const *wb_view, GsfOutput *output)
 {
 	GnmCell *cell;
