@@ -11,34 +11,33 @@
 #include "lotus.h"
 #include "lotus-types.h"
 
-#include <file.h>
+#include <goffice/app/file.h>
 #include <workbook-view.h>
-#include <plugin.h>
-#include <plugin-util.h>
-#include <module-plugin-defs.h>
-#include <error-info.h>
+#include <goffice/app/go-plugin.h>
+#include <gnm-plugin.h>
+#include <goffice/app/error-info.h>
 #include <gutils.h>
-#include <io-context.h>
+#include <goffice/app/io-context.h>
 
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-utils.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
-gboolean lotus_file_probe (GnmFileOpener const *fo, GsfInput *input,
+gboolean lotus_file_probe (GOFileOpener const *fo, GsfInput *input,
                            FileProbeLevel pl);
-void     lotus_file_open (GnmFileOpener const *fo, IOContext *io_context,
+void     lotus_file_open (GOFileOpener const *fo, IOContext *io_context,
                           WorkbookView *wb_view, GsfInput *input);
 
 
 gboolean
-lotus_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
+lotus_file_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
 	char const *h = NULL;
 	if (!gsf_input_seek (input, 0, G_SEEK_SET))
 		h = gsf_input_read (input, 6, NULL);
 
-	if (h == NULL &&
+	if (h == NULL ||
 	    GSF_LE_GET_GUINT16 (h+0) != LOTUS_BOF)
 		return FALSE;
 
@@ -56,7 +55,7 @@ lotus_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 }
 
 void
-lotus_file_open (GnmFileOpener const *fo, IOContext *io_context,
+lotus_file_open (GOFileOpener const *fo, IOContext *io_context,
                  WorkbookView *wb_view, GsfInput *input)
 {
 	LotusWk1Read state;
