@@ -30,21 +30,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include <gnumeric.h>
-#include <sys/types.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
+#include "mps.h"
 #include "cell.h"
 #include "sheet.h"
 #include "value.h"
-#include "file.h"
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "workbook-view.h"
 #include "workbook.h"
-#include "plugin-util.h"
-#include "module-plugin-defs.h"
+#include <gnm-plugin.h>
 #include "ranges.h"
 #include "style.h"
 #include "value.h"
@@ -53,9 +47,15 @@
 #include "parse-util.h"
 #include "func.h"
 #include "expr.h"
-#include "mps.h"
+#include <goffice/app/file.h>
+#include <goffice/app/error-info.h>
+#include <glib/gi18n.h>
+#include <sys/types.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
 
 /*************************************************************************
@@ -65,20 +65,17 @@ GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
 /* Writes a string into a cell. */
 static inline void
-mps_set_cell (Sheet *sh, int col, int row, const gchar *str)
+mps_set_cell (Sheet *sheet, int col, int row, const gchar *str)
 {
-        GnmCell *cell = sheet_cell_fetch (sh, col, row);
-
-        sheet_cell_set_value (cell, value_new_string (str));
+        cell_set_value (sheet_cell_fetch (sheet, col, row),
+			value_new_string (str));
 }
 
 /* Writes a float into a cell. */
 static inline void
-mps_set_cell_float (Sheet *sh, int col, int row, const gnm_float f)
+mps_set_cell_float (Sheet *sheet, int col, int row, const gnm_float f)
 {
-        GnmCell *cell = sheet_cell_fetch (sh, col, row);
-
-        sheet_cell_set_value (cell, value_new_float (f));
+        cell_set_value (sheet_cell_fetch (sheet, col, row), value_new_float (f));
 }
 
 static void
@@ -528,7 +525,7 @@ mps_input_context_new (IOContext *io_context, Workbook *wb, GsfInput *input)
 	ctxt->input	     = (GsfInputTextline *)gsf_input_textline_new (input);
 	ctxt->line_no        = 1;
 	ctxt->line           = NULL;
-	ctxt->sheet          = workbook_sheet_add (wb, NULL, FALSE);
+	ctxt->sheet          = workbook_sheet_add (wb, -1, FALSE);
 
 	ctxt->name           = NULL;
 	ctxt->rows           = NULL;
@@ -638,7 +635,7 @@ mps_input_context_destroy (MpsInputContext *ctxt)
  */
 
 void
-mps_file_open (GnmFileOpener const *fo, IOContext *io_context,
+mps_file_open (GOFileOpener const *fo, IOContext *io_context,
                WorkbookView *wbv, GsfInput *input)
 {
         MpsInputContext *ctxt;
@@ -654,6 +651,6 @@ mps_file_open (GnmFileOpener const *fo, IOContext *io_context,
 		} else
 			mps_create_sheet (ctxt, wbv);
 		mps_input_context_destroy (ctxt);
-	} else if (!gnumeric_io_error_occurred)
+	} else if (!gnumeric_io_error_occurred (io_context))
 		gnumeric_io_error_unknown (io_context);
 }
