@@ -23,7 +23,7 @@
 #include <gnumeric-config.h>
 #include <gnumeric.h>
 
-#include <module-plugin-defs.h>
+#include <gnm-plugin.h>
 #include <workbook-view.h>
 #include <workbook.h>
 #include <sheet.h>
@@ -35,25 +35,25 @@
 #include <expr-impl.h>
 #include <expr-name.h>
 #include <parse-util.h>
-#include <datetime.h>
 #include <style-color.h>
 #include <sheet-style.h>
 #include <mstyle.h>
-#include <format.h>
+#include <gnm-format.h>
 #include <command-context.h>
-#include <io-context.h>
+#include <goffice/app/io-context.h>
 #include <goffice/utils/go-units.h>
+#include <goffice/utils/datetime.h>
 
-#include <glib/gi18n.h>
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-infile.h>
 #include <gsf/gsf-infile-zip.h>
+#include <glib/gi18n.h>
 
 #include <string.h>
 #include <locale.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
 typedef enum {
 	OO_STYLE_UNKNOWN,
@@ -179,7 +179,7 @@ oo_attr_float (OOParseState *state, xmlChar const * const *attrs,
 	if (!gsf_xml_in_namecmp (&state->base, attrs[0], ns_id, name))
 		return FALSE;
 
-	tmp = strtognum ((gchar *)attrs[1], &end);
+	tmp = gnm_strto ((gchar *)attrs[1], &end);
 	if (*end)
 		return oo_warning (state, "Invalid attribute '%s', expected number, received '%s'",
 				   name, attrs[1]);
@@ -326,11 +326,23 @@ enum {
 	OO_NS_CONFIG,
 	OO_NS_MATH,
 	OO_NS_FO,
+	OO_NS_DC,
+	OO_NS_META,
 	OO_NS_XLINK,
-	OO_NS_SVG
+	OO_NS_SVG,
+
+	/* new in 2.0 */
+	OO_NS_OOO,
+	OO_NS_OOOW,
+	OO_NS_OOOC,
+	OO_NS_DOM,
+	OO_NS_XFORMS,
+	OO_NS_XSD,
+	OO_NS_XSI
 };
 
-static GsfXMLInNS content_ns[] = {
+static GsfXMLInNS ooo_ns[] = {
+	/* OOo 1.0.x & 1.1.x */
 	GSF_XML_IN_NS (OO_NS_OFFICE,	"http://openoffice.org/2000/office"),
 	GSF_XML_IN_NS (OO_NS_STYLE,	"http://openoffice.org/2000/style"),
 	GSF_XML_IN_NS (OO_NS_TEXT,	"http://openoffice.org/2000/text"),
@@ -342,10 +354,33 @@ static GsfXMLInNS content_ns[] = {
 	GSF_XML_IN_NS (OO_NS_FORM,	"http://openoffice.org/2000/form"),
 	GSF_XML_IN_NS (OO_NS_SCRIPT,	"http://openoffice.org/2000/script"),
 	GSF_XML_IN_NS (OO_NS_CONFIG,	"http://openoffice.org/2001/config"),
-	GSF_XML_IN_NS (OO_NS_MATH,	"http://www.w3.org/1998/Math/MathML"),
+	GSF_XML_IN_NS (OO_NS_MATH,	"http://www.w3.org/1998/Math/MathML"),	/* also in 2.0 */
 	GSF_XML_IN_NS (OO_NS_FO,	"http://www.w3.org/1999/XSL/Format"),
-	GSF_XML_IN_NS (OO_NS_XLINK,	"http://www.w3.org/1999/xlink"),
+	GSF_XML_IN_NS (OO_NS_XLINK,	"http://www.w3.org/1999/xlink"),	/* also in 2.0 */
 	GSF_XML_IN_NS (OO_NS_SVG,	"http://www.w3.org/2000/svg"),
+
+	/* OOo 1.9.x & 2.0.x */
+	GSF_XML_IN_NS (OO_NS_OFFICE,	"urn:oasis:names:tc:opendocument:xmlns:office:1.0"),
+	GSF_XML_IN_NS (OO_NS_STYLE,	"urn:oasis:names:tc:opendocument:xmlns:style:1.0"),
+	GSF_XML_IN_NS (OO_NS_TEXT,	"urn:oasis:names:tc:opendocument:xmlns:text:1.0"),
+	GSF_XML_IN_NS (OO_NS_TABLE,	"urn:oasis:names:tc:opendocument:xmlns:table:1.0"),
+	GSF_XML_IN_NS (OO_NS_DRAW,	"urn:oasis:names:tc:opendocument:xmlns:drawing:1.0"),
+	GSF_XML_IN_NS (OO_NS_FO,	"urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0"),
+	GSF_XML_IN_NS (OO_NS_META,	"urn:oasis:names:tc:opendocument:xmlns:meta:1.0"),
+	GSF_XML_IN_NS (OO_NS_NUMBER,	"urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0"),
+	GSF_XML_IN_NS (OO_NS_SVG,	"urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0"),
+	GSF_XML_IN_NS (OO_NS_CHART,	"urn:oasis:names:tc:opendocument:xmlns:chart:1.0"),
+	GSF_XML_IN_NS (OO_NS_DR3D,	"urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0"),
+	GSF_XML_IN_NS (OO_NS_FORM,	"urn:oasis:names:tc:opendocument:xmlns:form:1.0"),
+	GSF_XML_IN_NS (OO_NS_SCRIPT,	"urn:oasis:names:tc:opendocument:xmlns:script:1.0"),
+	GSF_XML_IN_NS (OO_NS_DC,	"http://purl.org/dc/elements/1.1/"),
+	GSF_XML_IN_NS (OO_NS_OOO,	"http://openoffice.org/2004/office"),
+	GSF_XML_IN_NS (OO_NS_OOOW,	"http://openoffice.org/2004/writer"),
+	GSF_XML_IN_NS (OO_NS_OOOC,	"http://openoffice.org/2004/calc"),
+	GSF_XML_IN_NS (OO_NS_DOM,	"http://www.w3.org/2001/xml-events"),
+	GSF_XML_IN_NS (OO_NS_XFORMS,	"http://www.w3.org/2002/xforms"),
+	GSF_XML_IN_NS (OO_NS_XSD,	"http://www.w3.org/2001/XMLSchema"),
+	GSF_XML_IN_NS (OO_NS_XSI,	"http://www.w3.org/2001/XMLSchema-instance"),
 	{ NULL }
 };
 
@@ -376,7 +411,7 @@ oo_table_start (GsfXMLIn *xin, xmlChar const **attrs)
 			state->pos.sheet = workbook_sheet_by_name (state->pos.wb, attrs[1]);
 			if (NULL == state->pos.sheet) {
 				state->pos.sheet = sheet_new (state->pos.wb, attrs[1]);
-				workbook_sheet_attach (state->pos.wb, state->pos.sheet, NULL);
+				workbook_sheet_attach (state->pos.wb, state->pos.sheet);
 			}
 
 			/* store a list of the sheets in the correct order */
@@ -460,7 +495,7 @@ oo_cellref_parse (GnmCellRef *ref, char const *start, GnmParsePos const *pp)
 		ref->sheet = workbook_sheet_by_name (pp->wb, name);
 		if (ref->sheet == NULL) {
 			ref->sheet = sheet_new (pp->wb, name);
-			workbook_sheet_attach (pp->wb, ref->sheet, NULL);
+			workbook_sheet_attach (pp->wb, ref->sheet);
 		}
 	} else {
 		ptr++; /* local ref */
@@ -757,7 +792,7 @@ oo_style (GsfXMLIn *xin, xmlChar const **attrs)
 	xmlChar const *name = NULL;
 	xmlChar const *parent_name = NULL;
 	GnmStyle *style;
-	GnmFormat *fmt = NULL;
+	GOFormat *fmt = NULL;
 	int tmp;
 
 	g_return_if_fail (state->cur_style_type == OO_STYLE_UNKNOWN);
@@ -770,7 +805,7 @@ oo_style (GsfXMLIn *xin, xmlChar const **attrs)
 		else if (gsf_xml_in_namecmp (xin, attrs[0], OO_NS_STYLE, "parent-style-name"))
 			parent_name = attrs[1];
 		else if (gsf_xml_in_namecmp (xin, attrs[0], OO_NS_STYLE, "data-style-name")) {
-			GnmFormat *tmp = g_hash_table_lookup (state->formats, attrs[1]);
+			GOFormat *tmp = g_hash_table_lookup (state->formats, attrs[1]);
 			if (tmp != NULL)
 				fmt = tmp;
 		}
@@ -987,7 +1022,6 @@ oo_date_style_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 
 	g_hash_table_insert (state->formats, state->fmt_name,
 		style_format_new_XL (state->accum_fmt->str, FALSE));
-	g_warning ("%s == %s", state->fmt_name, state->accum_fmt->str);
 	g_string_free (state->accum_fmt, TRUE);
 	state->accum_fmt = NULL;
 	state->fmt_name = NULL;
@@ -1177,10 +1211,16 @@ GSF_XML_IN_NODE (START, OFFICE_STYLES, OO_NS_OFFICE, "styles", FALSE, NULL, NULL
   GSF_XML_IN_NODE (OFFICE_STYLES, STYLE, OO_NS_STYLE, "style", FALSE, &oo_style, &oo_style_end),
     GSF_XML_IN_NODE (STYLE, STYLE_PROP, OO_NS_STYLE, "properties", FALSE, &oo_style_prop, NULL),
 
+  GSF_XML_IN_NODE (OFFICE_STYLES, DEFAULT_STYLE, OO_NS_STYLE, "default-style", FALSE, &oo_style, &oo_style_end),
+    GSF_XML_IN_NODE (DEFAULT_STYLE, DEFAULT_STYLE_PROP, OO_NS_STYLE, "properties", FALSE, &oo_style_prop, NULL),
+
   GSF_XML_IN_NODE (OFFICE_STYLES, NUMBER_STYLE, OO_NS_NUMBER, "number-style", FALSE, NULL, NULL),
-    GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_PROP, OO_NS_NUMBER,	"number", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_NUMBER, OO_NS_NUMBER,	"number", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_TEXT, OO_NS_NUMBER,	"text", FALSE, NULL, NULL),
     GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_FRACTION, OO_NS_NUMBER, "fraction", FALSE, NULL, NULL),
     GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_SCI_STYLE_PROP, OO_NS_NUMBER, "scientific-number", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_PROP, OO_NS_STYLE,	"properties", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_MAP, OO_NS_STYLE,		"map", FALSE, NULL, NULL),
 
   GSF_XML_IN_NODE (OFFICE_STYLES, DATE_STYLE, OO_NS_NUMBER, "date-style", FALSE, &oo_date_style, &oo_date_style_end),
     GSF_XML_IN_NODE (DATE_STYLE, DATE_DAY, OO_NS_NUMBER,		"day", FALSE,	&oo_date_day, NULL),
@@ -1196,7 +1236,7 @@ GSF_XML_IN_NODE (START, OFFICE_STYLES, OO_NS_OFFICE, "styles", FALSE, NULL, NULL
     GSF_XML_IN_NODE (DATE_STYLE, DATE_AM_PM, OO_NS_NUMBER,		"am-pm", FALSE,	&oo_date_am_pm, NULL),
     GSF_XML_IN_NODE (DATE_STYLE, DATE_TEXT, OO_NS_NUMBER,		"text", TRUE,	NULL, &oo_date_text_end),
     GSF_XML_IN_NODE (DATE_STYLE, DATE_TEXT_PROP, OO_NS_STYLE,		"text-properties", FALSE, NULL, NULL),
-    GSF_XML_IN_NODE (DATE_STYLE, DATE_MAP, OO_NS_STYLE,		"map", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (DATE_STYLE, DATE_MAP, OO_NS_STYLE,			"map", FALSE, NULL, NULL),
 
   GSF_XML_IN_NODE (OFFICE_STYLES, TIME_STYLE, OO_NS_NUMBER, "time-style", FALSE, &oo_date_style, &oo_date_style_end),
     GSF_XML_IN_NODE (TIME_STYLE, TIME_HOURS, OO_NS_NUMBER,		"hours", FALSE,	&oo_date_hours, NULL),
@@ -1222,7 +1262,9 @@ GSF_XML_IN_NODE (START, OFFICE_STYLES, OO_NS_OFFICE, "styles", FALSE, NULL, NULL
     GSF_XML_IN_NODE (STYLE_PERCENTAGE, PERCENTAGE_TEXT, OO_NS_NUMBER, "text", FALSE, NULL, NULL),
 
   GSF_XML_IN_NODE (OFFICE_STYLES, STYLE_TEXT, OO_NS_NUMBER, "text-style", FALSE, NULL, NULL),
-    GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_PROP, OO_NS_NUMBER, "text-content", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_CONTENT, OO_NS_NUMBER,	"text-content", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_PROP, OO_NS_NUMBER,		"text", FALSE, NULL, NULL),
+    GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_MAP, OO_NS_STYLE,		"map", FALSE, NULL, NULL),
 
   { NULL }
 };
@@ -1238,9 +1280,12 @@ GSF_XML_IN_NODE (START, OFFICE, OO_NS_OFFICE, "document-content", FALSE, NULL, N
       GSF_XML_IN_NODE (STYLE, STYLE_PROP, OO_NS_STYLE, "properties", FALSE, &oo_style_prop, NULL),
 
     GSF_XML_IN_NODE (OFFICE_STYLES, NUMBER_STYLE, OO_NS_NUMBER, "number-style", FALSE, NULL, NULL),
-      GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_PROP, OO_NS_NUMBER, "number", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_NUMBER, OO_NS_NUMBER,	  "number", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_TEXT, OO_NS_NUMBER,	  "text", FALSE, NULL, NULL),
       GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_FRACTION, OO_NS_NUMBER, "fraction", FALSE, NULL, NULL),
       GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_SCI_STYLE_PROP, OO_NS_NUMBER, "scientific-number", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_STYLE_PROP, OO_NS_STYLE,	  "properties", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (NUMBER_STYLE, NUMBER_MAP, OO_NS_STYLE,		  "map", FALSE, NULL, NULL),
 
     GSF_XML_IN_NODE (OFFICE_STYLES, DATE_STYLE, OO_NS_NUMBER, "date-style", FALSE, &oo_date_style, &oo_date_style_end),
       GSF_XML_IN_NODE (DATE_STYLE, DATE_DAY, OO_NS_NUMBER,		"day", FALSE,	&oo_date_day, NULL),
@@ -1279,7 +1324,9 @@ GSF_XML_IN_NODE (START, OFFICE, OO_NS_OFFICE, "document-content", FALSE, NULL, N
       GSF_XML_IN_NODE (STYLE_PERCENTAGE, PERCENTAGE_STYLE_PROP, OO_NS_NUMBER, "number", FALSE, NULL, NULL),
       GSF_XML_IN_NODE (STYLE_PERCENTAGE, PERCENTAGE_TEXT, OO_NS_NUMBER, "text", FALSE, NULL, NULL),
     GSF_XML_IN_NODE (OFFICE_STYLES, STYLE_TEXT, OO_NS_NUMBER, "text-style", FALSE, NULL, NULL),
-      GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_PROP, OO_NS_NUMBER, "text-content", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_CONTENT, OO_NS_NUMBER,	"text-content", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_PROP, OO_NS_NUMBER,		"text", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (STYLE_TEXT, STYLE_TEXT_MAP, OO_NS_STYLE,		"map", FALSE, NULL, NULL),
 
   GSF_XML_IN_NODE (OFFICE, OFFICE_BODY, OO_NS_OFFICE, "body", FALSE, NULL, NULL),
     GSF_XML_IN_NODE (OFFICE_BODY, TABLE_CALC_SETTINGS, OO_NS_TABLE, "calculation-settings", FALSE, NULL, NULL),
@@ -1346,9 +1393,7 @@ GSF_XML_IN_NODE (START, OFFICE, OO_NS_OFFICE, "document-settings", FALSE, NULL,
 /****************************************************************************/
 
 static GnmExpr const *
-function_renamer (char const *name,
-		  GnmExprList *args,
-		  GnmExprConventions *convs)
+errortype_renamer (char const *name, GnmExprList *args, GnmExprConventions *convs)
 {
 	GnmFunc *f = gnm_func_lookup ("ERROR.TYPE", NULL);
 	if (f != NULL)
@@ -1356,6 +1401,20 @@ function_renamer (char const *name,
 	return gnm_func_placeholder_factory (name, args, convs);
 }
 
+static GnmExpr const *
+oo_unknown_hander (char const *name,
+		   GnmExprList *args,
+		   GnmExprConventions *convs)
+{
+	if (0 == strncmp ("com.sun.star.sheet.addin.Analysis.get", name, 37)) {
+		GnmFunc *f = gnm_func_lookup (name + 37, NULL);
+		if (f != NULL)
+			return gnm_expr_new_funcall (f, args);
+		g_warning ("unknown function");
+	}
+	return gnm_func_placeholder_factory (name, args, convs);
+}
+
 static GnmExprConventions *
 oo_conventions (void)
 {
@@ -1365,9 +1424,10 @@ oo_conventions (void)
 	res->decimal_sep_dot = TRUE;
 	res->argument_sep_semicolon = TRUE;
 	res->array_col_sep_comma = TRUE;
+	res->dots_in_names = TRUE; /* things like com.sun.star.sheet.addin.Analysis.getErf */
 	res->output_argument_sep = ";";
 	res->output_array_col_sep = ",";
-	res->unknown_function_handler = gnm_func_placeholder_factory;
+	res->unknown_function_handler = oo_unknown_hander;
 	res->ref_parser = oo_rangeref_parse;
 
 #warning "TODO : OO adds a 'mode' parm to floor/ceiling"
@@ -1375,18 +1435,17 @@ oo_conventions (void)
 	res->function_rewriter_hash =
 		g_hash_table_new (g_str_hash, g_str_equal);
 	g_hash_table_insert (res->function_rewriter_hash,
-			     (gchar *)"ERRORTYPE",
-			     function_renamer);
+		(gchar *)"ERRORTYPE", errortype_renamer);
 	return res;
 }
 
 static GsfXMLInDoc *content_doc, *settings_doc, *styles_doc;
 
 void
-openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
+openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 		      WorkbookView *wb_view, GsfInput *input);
 void
-openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
+openoffice_file_open (GOFileOpener const *fo, IOContext *io_context,
 		      WorkbookView *wb_view, GsfInput *input)
 {
 	char *old_num_locale, *old_monetary_locale;
@@ -1403,7 +1462,7 @@ openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	zip = gsf_infile_zip_new (input, &err);
 	if (zip == NULL) {
 		g_return_if_fail (err != NULL);
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (io_context),
+		go_cmd_context_error_import (GO_CMD_CONTEXT (io_context),
 			err->message);
 		g_error_free (err);
 		return;
@@ -1411,24 +1470,24 @@ openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
 
 	content = gsf_infile_child_by_name (zip, "content.xml");
 	if (content == NULL) {
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (io_context),
+		go_cmd_context_error_import (GO_CMD_CONTEXT (io_context),
 			 _("No stream named content.xml found."));
 		g_object_unref (G_OBJECT (zip));
 		return;
 	}
 	styles = gsf_infile_child_by_name (zip, "styles.xml");
 	if (styles == NULL) {
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (io_context),
+		go_cmd_context_error_import (GO_CMD_CONTEXT (io_context),
 			 _("No stream named styles.xml found."));
 		g_object_unref (G_OBJECT (zip));
 		return;
 	}
 
-	old_num_locale = g_strdup (gnm_setlocale (LC_NUMERIC, NULL));
-	gnm_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (gnm_setlocale (LC_MONETARY, NULL));
-	gnm_setlocale (LC_MONETARY, "C");
-	gnm_set_untranslated_bools ();
+	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
+	go_setlocale (LC_NUMERIC, "C");
+	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
+	go_setlocale (LC_MONETARY, "C");
+	go_set_untranslated_bools ();
 
 	/* init */
 	state.context = io_context;
@@ -1490,22 +1549,22 @@ openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
 
 	gnm_expr_conventions_free (state.exprconv);
 
-	/* gnm_setlocale restores bools to locale translation */
-	gnm_setlocale (LC_MONETARY, old_monetary_locale);
+	/* go_setlocale restores bools to locale translation */
+	go_setlocale (LC_MONETARY, old_monetary_locale);
 	g_free (old_monetary_locale);
-	gnm_setlocale (LC_NUMERIC, old_num_locale);
+	go_setlocale (LC_NUMERIC, old_num_locale);
 	g_free (old_num_locale);
 }
 
-void
-plugin_init (void)
+G_MODULE_EXPORT void
+go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 {
-	styles_doc   = gsf_xml_in_doc_new (opencalc_styles_dtd, content_ns);
-	content_doc  = gsf_xml_in_doc_new (opencalc_content_dtd, content_ns);
-	settings_doc = gsf_xml_in_doc_new (opencalc_settings_dtd, content_ns);
+	styles_doc   = gsf_xml_in_doc_new (opencalc_styles_dtd, ooo_ns);
+	content_doc  = gsf_xml_in_doc_new (opencalc_content_dtd, ooo_ns);
+	settings_doc = gsf_xml_in_doc_new (opencalc_settings_dtd, ooo_ns);
 }
-void
-plugin_cleanup (void)
+G_MODULE_EXPORT void
+go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
 	gsf_xml_in_doc_free (styles_doc);
 	gsf_xml_in_doc_free (content_doc);
