@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /**
- * boot.c: Paradox support for Gnumeric
+ * paradox.c: Paradox support for Gnumeric
  *
  * Author:
  *    Uwe Steinmann <uwe@steinmann.cx>
@@ -15,23 +15,23 @@
 #include <workbook.h>
 #include <cell.h>
 #include <value.h>
-#include <plugin.h>
-#include <plugin-util.h>
-#include <module-plugin-defs.h>
+#include <goffice/app/go-plugin.h>
+#include <gnm-plugin.h>
 #include <sheet.h>
-#include <datetime.h>
 #include <ranges.h>
 #include <mstyle.h>
 #include <sheet-style.h>
-#include <io-context.h>
+#include <goffice/app/io-context.h>
+#include <goffice/utils/datetime.h>
+#include <goffice/app/error-info.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
-void paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
+void paradox_file_open (GOFileOpener const *fo, IOContext *io_context,
                         WorkbookView *wb_view, GsfInput *input);
 
 gboolean
-paradox_file_probe (GnmFileOpener const *fo, GsfInput *input,
+paradox_file_probe (GOFileOpener const *fo, GsfInput *input,
                     FileProbeLevel pl);
 
 static void *gn_malloc(pxdoc_t *p, size_t len, const char *caller) {
@@ -52,7 +52,7 @@ static void gn_errorhandler(pxdoc_t *p, int error, const char *str, void *data)
 }
 
 void
-paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
+paradox_file_open (GOFileOpener const *fo, IOContext *io_context,
                    WorkbookView *wb_view, GsfInput *input)
 {
 	Workbook  *wb;
@@ -84,7 +84,7 @@ paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	name = workbook_sheet_get_free_name (wb, pxh->px_tablename, FALSE, TRUE);
 	sheet = sheet_new (wb, name);
 	g_free (name);
-	workbook_sheet_attach (wb, sheet, NULL);
+	workbook_sheet_attach (wb, sheet);
 
 	pxf = pxh->px_fields;
 	for (i = 0 ; i < (guint) pxh->px_numfields; i++) {
@@ -98,7 +98,7 @@ paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
 		snprintf (str, 30, "%s,%c,%d", pxf->px_fname, ctypes[(int)pxf->px_ftype], pxf->px_flen);
 #if PXLIB_MAJOR_VERSION == 0 && (PXLIB_MINOR_VERION < 3 || (PXLIB_MAJOR_VERSION == 3 && PXLIB_MICRO_VERSION == 0))
 		/* Convert the field names to utf-8. This is actually in pxlib
-		 * responsibility, but hasn't been implemented. For the mean time
+		 * responsibility, but hasn't been implemented yet. For the mean time
 		 * we *misuse* PX_get_data_alpha()
 		 */
 		PX_get_data_alpha(pxdoc, str, strlen(str), &str2);
@@ -150,7 +150,6 @@ paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
 						break;
 					}
 					case pxfAutoInc:
-					case pxfTimestamp:
 					case pxfLong: {
 						long value;
 						if(0 < PX_get_data_long(pxdoc, &data[offset], pxf->px_flen, &value)) {
@@ -166,6 +165,16 @@ paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
 						}
 						break;
 					}
+					case pxfTimestamp: {
+						double value;
+						if(0 < PX_get_data_double(pxdoc, &data[offset], pxf->px_flen, &value)) {
+							value = value / 86400000.0;
+							/* 693595 = number of days up to 31.12.1899 */
+							value -= 693595;
+							val = value_new_float (value);
+						}
+						break;
+					}
 					case  pxfLogical: {
 						char value;
 						if(0 < PX_get_data_byte(pxdoc, &data[offset], pxf->px_flen, &value)) {
@@ -184,6 +193,13 @@ paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
 						}
 						break;
 					}
+					case pxfTime: {
+						long value;
+						if(0 < PX_get_data_long(pxdoc, &data[offset], pxf->px_flen, &value)) {
+							val = value_new_float (value/86400000.0);
+						}
+						break;
+					}
 					case pxfBCD: {
 						char *value;
 						if(0 < PX_get_data_bcd(pxdoc, &data[offset], pxf->px_fdc, &value)) {
@@ -191,6 +207,14 @@ paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
 						}
 						break;
 					}
+					case pxfMemoBLOb: {
+						char *value;
+						int size, mod_nr;
+						if(0 < PX_get_data_blob(pxdoc, &data[offset], pxf->px_flen, &mod_nr, &size, &value)) {
+							val = value_new_string_nocopy (value);
+						}
+						break;
+					}
 					default: {
 						val = value_new_string_nocopy (
 							g_strdup_printf (_("Field type %d is not supported."), pxf->px_ftype));
@@ -236,7 +260,7 @@ paradox_file_open (GnmFileOpener const *fo, IOContext *io_context,
 }
 
 gboolean
-paradox_file_probe (GnmFileOpener const *fo, GsfInput *input,
+paradox_file_probe (GOFileOpener const *fo, GsfInput *input,
                     FileProbeLevel pl)
 {
 	pxdoc_t	  *pxdoc;
