@@ -6,156 +6,97 @@
 #undef dirty
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include "perl-loader.h"
 #include <gnumeric.h>
 
+#include <application.h>
+#include <workbook-view.h>
+#include <workbook.h>
+#include <sheet.h>
+#include <value.h>
+#include <expr.h>
+#include <expr-impl.h>
+#include <gnm-plugin.h>
+
+#include <goffice/app/error-info.h>
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/go-plugin-loader.h>
+#include <goffice/app/go-plugin-service.h>
+#include <goffice/app/io-context.h>
+#include <goffice/app/module-plugin-defs.h>
+#include <gsf/gsf-impl-utils.h>
+
+#include <glib/gi18n.h>
 #include <stdlib.h>
-#include <glib.h>
-#include "application.h"
-#include "workbook.h"
-#include "sheet.h"
-#include "workbook-view.h"
-#include "workbook-control-gui.h"
-#include "gui-util.h"
-#include "value.h"
-#include "expr.h"
-#include "expr-impl.h"
-#include "io-context.h"
-#include "plugin-util.h"
-#include "plugin.h"
-#include "plugin-service.h"
-#include "plugin-loader.h"
-#include "module-plugin-defs.h"
-#include "perl-loader.h"
+
+#define TYPE_GNM_PERL_PLUGIN_LOADER	(gnm_perl_plugin_loader_get_type ())
+#define GNM_PERL_PLUGIN_LOADER(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_GNM_PERL_PLUGIN_LOADER, GnmPerlPluginLoader))
+#define IS_GNM_PERL_PLUGIN_LOADER(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_GNM_PERL_PLUGIN_LOADER))
 
 #define dirty _perl_dirty
 #undef _perl_dirty
 
-PerlInterpreter* gnm_perl_interp;
-PerlInterpreter* my_perl;
-extern void xs_init(void);
+extern void xs_init(pTHX);
 
-typedef struct _GnmPluginLoaderPerl GnmPluginLoaderPerl;
-
-struct _GnmPluginLoaderPerl {
-	GnmPluginLoader loader;
-	gchar* module_name;
-};
+static PerlInterpreter* gnm_perl_interp;
+static PerlInterpreter* my_perl;
 
 typedef struct {
-	GnmPluginLoaderClass parent_class;
-} GnmPluginLoaderPerlClass;
+	GObject	base;
+	gchar* module_name;
+} GnmPerlPluginLoader;
+typedef GObjectClass GnmPerlPluginLoaderClass;
 
-static GObjectClass *parent_class = NULL;
-
-static void gplp_set_attributes (GnmPluginLoader *loader, GHashTable* attrs, ErrorInfo **ret_error);
-static void gplp_load_base (GnmPluginLoader *loader, ErrorInfo **ret_error);
-static void gplp_load_service_function_group (GnmPluginLoader *loader, GnmPluginService *service, ErrorInfo **ret_error);
-static gboolean gplp_func_desc_load (GnmPluginService *service, char const *name, GnmFuncDescriptor *res);
-static GnmValue* call_perl_function_args (FunctionEvalInfo *ei, GnmValue **args);
-static GnmValue* call_perl_function_nodes (FunctionEvalInfo *ei, GnmExprList *expr_tree_list);
-static void gplp_finalize (GObject *obj);
-
-static void
-gplp_init (GnmPluginLoaderPerl *loader_perl)
+static GnmValue*
+call_perl_function_args (FunctionEvalInfo *ei, GnmValue **args)
 {
-	g_return_if_fail (IS_GNM_PLUGIN_LOADER_PERL (loader_perl));
+	GnmFunc const *fndef;
+	gint min_n_args, max_n_args, n_args;
+	gint i;
+	gchar *perl_func = NULL;
+	GnmValue* result = NULL;
+	dSP;
 
-	loader_perl->module_name = NULL;
-}
+	fndef = ei->func_call->func;
+	perl_func = g_strconcat ("func_", fndef->name, NULL);
 
-static void
-gplp_class_init (GObjectClass *gobject_class)
-{
-	GnmPluginLoaderClass *loader_class = GNM_PLUGIN_LOADER_CLASS (gobject_class);
+	function_def_count_args (fndef, &min_n_args, &max_n_args);
+	for (n_args = min_n_args; n_args < max_n_args && args[n_args] != NULL; n_args++);
 
-	parent_class = g_type_class_peek_parent (gobject_class);
-
-	gobject_class->finalize = gplp_finalize;
-
-	loader_class->set_attributes = gplp_set_attributes;
-	loader_class->load_base = gplp_load_base;
-	loader_class->load_service_function_group = gplp_load_service_function_group;
-}
-
-static void
-gplp_finalize (GObject *obj)
-{
-	GnmPluginLoaderPerl *loader_perl = GNM_PLUGIN_LOADER_PERL (obj);
-
-	g_free(loader_perl->module_name);
-	loader_perl->module_name = NULL;
-
-	parent_class->finalize (obj);
-}
-
-PLUGIN_CLASS (GnmPluginLoaderPerl, gnm_plugin_loader_perl,
-	      gplp_class_init, gplp_init,
-	      TYPE_GNM_PLUGIN_LOADER)
-
-static void
-gplp_set_attributes (GnmPluginLoader *loader, GHashTable *attrs, ErrorInfo **ret_error)
-{
-	GnmPluginLoaderPerl *loader_perl = GNM_PLUGIN_LOADER_PERL (loader);
-
-	gchar *module_name = NULL;
-
-	GNM_INIT_RET_ERROR_INFO (ret_error);
-	module_name = g_hash_table_lookup (attrs, "module_name");
-	if (module_name) {
-		loader_perl->module_name = g_strdup (module_name);
-	} else {
-		*ret_error = error_info_new_str (
-			     _("Module name not given."));
+	ENTER;
+	SAVETMPS;
+	PUSHMARK(SP);
+	for (i=0;i<n_args;i++) {
+		g_assert(args[i]->type == VALUE_INTEGER);
+		XPUSHs(sv_2mortal(newSViv(args[i]->v_int.val)));
 	}
-}
+	PUTBACK;
+	call_pv (perl_func, G_EVAL | G_SCALAR);
+	SPAGAIN;
 
-static void
-gplp_load_base (GnmPluginLoader *loader, ErrorInfo **ret_error)
-{
-	//GnmPluginLoaderPerl *loader_perl = GNM_PLUGIN_LOADER_PERL (loader);
+	if (SvTRUE(ERRSV)) { /* Error handling */
+		gchar *errmsg;
+		STRLEN n_a;
+		errmsg = g_strconcat (_("Perl error: "), SvPV (ERRSV, n_a), NULL);
+		POPs;
 
-	char *argv[] = { (char*)"", NULL, NULL, NULL };
-	const char *arg;
-
-	arg = gnm_plugin_get_dir_name (loader->plugin);
-	argv[1] = g_strconcat ("-I", arg, NULL);
-	argv[2] = g_build_filename (arg, "perl_func.pl", NULL);
-
-	if (g_file_test (argv[2], G_FILE_TEST_EXISTS)) {
-		gnm_perl_interp = perl_alloc ();
-		perl_construct (gnm_perl_interp);
-		perl_parse (gnm_perl_interp, xs_init, 3, argv, NULL);
-		my_perl = gnm_perl_interp;
-#ifdef PERL_EXIT_DESTRUCT_END
-		PL_exit_flags |= PERL_EXIT_DESTRUCT_END;
-#endif
+		result = value_new_error (ei->pos, errmsg);
+		g_free (errmsg);
 	} else {
-		*ret_error = error_info_new_printf (
-			     _("perl_func.pl doesn't exist."));
+		result = perl2value (POPs);
 	}
 
-	g_free (argv[1]);
-	g_free (argv[2]);
-}
+	PUTBACK;
+	FREETMPS;
+	LEAVE;
 
-static void
-gplp_load_service_function_group (GnmPluginLoader *loader,
-				  GnmPluginService *service,
-				  ErrorInfo **ret_error)
-{
-	PluginServiceFunctionGroupCallbacks *cbs;
+	g_free (perl_func);
 
-	g_return_if_fail (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service));
-
-	GNM_INIT_RET_ERROR_INFO (ret_error);
-
-	cbs = plugin_service_get_cbs (service);
-	cbs->func_desc_load = &gplp_func_desc_load;
+	return result;
 }
 
 static gboolean
-gplp_func_desc_load (GnmPluginService *service,
+gplp_func_desc_load (GOPluginService *service,
 		     char const *name,
 		     GnmFuncDescriptor *res)
 {
@@ -212,7 +153,10 @@ gplp_func_desc_load (GnmPluginService *service,
 	res->name = g_strdup(name);
 	res->arg_spec = arg_spec;
 	res->arg_names = arg_names;
+#warning FIXME adapt for the new GnmFuncHelp struct.
+#if 0
 	res->help = (const char**)&help_text;
+#endif
 	res->fn_args = NULL;
 	res->fn_args = &call_perl_function_args;
 	res->fn_nodes = NULL;
@@ -224,56 +168,133 @@ gplp_func_desc_load (GnmPluginService *service,
 	return TRUE;
 }
 
-static GnmValue*
-call_perl_function_args (FunctionEvalInfo *ei, GnmValue **args)
+static void
+gplp_set_attributes (GOPluginLoader *loader, GHashTable *attrs, ErrorInfo **ret_error)
 {
-	GnmFunc const *fndef;
-	gint min_n_args, max_n_args, n_args;
-	gint i;
-	gchar *perl_func = NULL;
-	GnmValue* result = NULL;
-	dSP;
+	GnmPerlPluginLoader *loader_perl = GNM_PERL_PLUGIN_LOADER (loader);
 
-	fndef = ei->func_call->func;
-	perl_func = g_strconcat ("func_", fndef->name, NULL);
+	gchar *module_name = NULL;
 
-	function_def_count_args (fndef, &min_n_args, &max_n_args);
-	for (n_args = min_n_args; n_args < max_n_args && args[n_args] != NULL; n_args++);
-
-	ENTER;
-	SAVETMPS;
-	PUSHMARK(SP);
-	for (i=0;i<n_args;i++) {
-		g_assert(args[i]->type == VALUE_INTEGER);
-		XPUSHs(sv_2mortal(newSViv(args[i]->v_int.val)));
-	}
-	PUTBACK;
-	call_pv (perl_func, G_EVAL | G_SCALAR);
-	SPAGAIN;
-
-	if (SvTRUE(ERRSV)) { /* Error handling */
-		gchar *errmsg;
-		STRLEN n_a;
-		errmsg = g_strconcat (_("Perl error: "), SvPV (ERRSV, n_a), NULL);
-		POPs;
-
-		result = value_new_error (ei->pos, errmsg);
-		g_free (errmsg);
+	GO_INIT_RET_ERROR_INFO (ret_error);
+	module_name = g_hash_table_lookup (attrs, "module_name");
+	if (module_name) {
+		loader_perl->module_name = g_strdup (module_name);
 	} else {
-		result = perl2value (POPs);
+		*ret_error = error_info_new_str (
+			     _("Module name not given."));
+	}
+}
+
+static void
+gplp_load_base (GOPluginLoader *loader, ErrorInfo **ret_error)
+{
+	char *argv[] = { (char*)"", NULL, NULL, NULL };
+	char const *arg;
+
+	arg = go_plugin_get_dir_name (go_plugin_loader_get_plugin (loader));
+	argv[1] = g_strconcat ("-I", arg, NULL);
+	argv[2] = g_build_filename (arg, "perl_func.pl", NULL);
+
+	if (g_file_test (argv[2], G_FILE_TEST_EXISTS)) {
+		gnm_perl_interp = perl_alloc ();
+		perl_construct (gnm_perl_interp);
+		perl_parse (gnm_perl_interp, xs_init, 3, argv, NULL);
+		my_perl = gnm_perl_interp;
+#ifdef PERL_EXIT_DESTRUCT_END
+		PL_exit_flags |= PERL_EXIT_DESTRUCT_END;
+#endif
+	} else {
+		*ret_error = error_info_new_printf (
+			     _("perl_func.pl doesn't exist."));
 	}
 
-	PUTBACK;
-	FREETMPS;
-	LEAVE;
-
-	g_free (perl_func);
-
-	return result;
+	g_free (argv[1]);
+	g_free (argv[2]);
 }
 
-static GnmValue*
-call_perl_function_nodes (FunctionEvalInfo *ei, GnmExprList *expr_tree_list)
+static void
+gplp_load_service_function_group (GOPluginLoader *loader,
+				  GOPluginService *service,
+				  ErrorInfo **ret_error)
 {
-	return value_new_int(0);
+	PluginServiceFunctionGroupCallbacks *cbs;
+
+	g_return_if_fail (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service));
+
+	GO_INIT_RET_ERROR_INFO (ret_error);
+
+	cbs = plugin_service_get_cbs (service);
+	cbs->func_desc_load = &gplp_func_desc_load;
+}
+
+static gboolean
+gplp_service_load (GOPluginLoader *l, GOPluginService *s, ErrorInfo **err)
+{
+	if (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (s))
+		gplp_load_service_function_group (l, s, err);
+	else
+		return FALSE;
+	return TRUE;
+}
+
+static gboolean
+gplp_service_unload (GOPluginLoader *l, GOPluginService *s, ErrorInfo **err)
+{
+	if (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (s))
+		;
+	else
+		return FALSE;
+	return TRUE;
+}
+
+static void
+gplp_finalize (GObject *obj)
+{
+	GnmPerlPluginLoader *loader_perl = GNM_PERL_PLUGIN_LOADER (obj);
+
+	g_free (loader_perl->module_name);
+	loader_perl->module_name = NULL;
+
+	G_OBJECT_CLASS (g_type_class_peek (G_TYPE_OBJECT))->finalize (obj);
+}
+
+static void
+go_plugin_loader_init (GOPluginLoaderClass *iface)
+{
+	iface->set_attributes		= gplp_set_attributes;
+	iface->load_base		= gplp_load_base;
+
+	iface->service_load		= gplp_service_load;
+	iface->service_unload		= gplp_service_unload;
+}
+
+static void
+gplp_class_init (GObjectClass *gobject_class)
+{
+	gobject_class->finalize = gplp_finalize;
+}
+
+static void
+gplp_init (GnmPerlPluginLoader *loader_perl)
+{
+	g_return_if_fail (IS_GNM_PERL_PLUGIN_LOADER (loader_perl));
+
+	loader_perl->module_name = NULL;
+}
+
+static GType gnm_perl_plugin_loader_type;
+GType
+gnm_perl_plugin_loader_get_type ()
+{
+	return gnm_perl_plugin_loader_type;
+}
+
+void
+gnm_perl_plugin_loader_register (GOPlugin *plugin)
+{
+	GSF_DYNAMIC_CLASS_FULL (GnmPerlPluginLoader, gnm_perl_plugin_loader,
+		gplp_class_init, gplp_init,
+		G_TYPE_OBJECT, 0,
+		GSF_INTERFACE_FULL (gnm_perl_plugin_loader_type, go_plugin_loader_init, GO_PLUGIN_LOADER_TYPE),
+		G_TYPE_MODULE (plugin), gnm_perl_plugin_loader_type);
 }
