@@ -7,12 +7,11 @@
  */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
-#include <plugin.h>
-#include <plugin-util.h>
-#include <module-plugin-defs.h>
-#include <io-context.h>
+#include <goffice/app/go-plugin.h>
+#include <gnm-plugin.h>
+#include <goffice/app/io-context.h>
 #include <sheet.h>
 #include <ranges.h>
 #include <value.h>
@@ -24,18 +23,19 @@
 #include <sheet-style.h>
 #include <style.h>
 #include <mstyle.h>
-#include <gutils.h>
+#include <goffice/utils/go-glib-extras.h>
+#include <goffice/app/error-info.h>
 
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-input.h>
 #include <string.h>
 #include <math.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
-gboolean pln_file_probe (GnmFileOpener const *fo, GsfInput *input,
+gboolean pln_file_probe (GOFileOpener const *fo, GsfInput *input,
 			 FileProbeLevel pl);
-void     pln_file_open (GnmFileOpener const *fo, IOContext *io_context,
+void     pln_file_open (GOFileOpener const *fo, IOContext *io_context,
 			WorkbookView *wb_view, GsfInput *input);
 
 static char const *formula1[] = {
@@ -173,7 +173,7 @@ pln_get_func_table2 (unsigned i)
 }
 
 gboolean
-pln_file_probe (GnmFileOpener const *fo, GsfInput *input,
+pln_file_probe (GOFileOpener const *fo, GsfInput *input,
 		FileProbeLevel pl)
 {
 	/*
@@ -269,7 +269,7 @@ pln_get_number (guint8 const * ch)
 	}
 	if (exp & 128)
 		dvalue = -dvalue;
-	dvalue = ldexpgnum (dvalue, ((exp & 127) - 64) * 4);
+	dvalue = gnm_ldexp (dvalue, ((exp & 127) - 64) * 4);
 
 	return dvalue;
 }
@@ -337,7 +337,7 @@ pln_convert_expr (GnmParsePos const *pp, guint8 const *ch)
 			len = *ch;
 			str = pln_get_str (ch + 1, len);
 			g_string_append_c (expr, '\"');
-			gnm_strescape (expr, str);
+			go_strescape (expr, str);
 			g_string_append_c (expr, '\"');
 			ch += len + 1;
 			g_free (str);
@@ -654,7 +654,7 @@ pln_parse_sheet (GsfInput *input, PlanPerfectImport *state)
 }
 
 void
-pln_file_open (GnmFileOpener const *fo, IOContext *io_context,
+pln_file_open (GOFileOpener const *fo, IOContext *io_context,
                WorkbookView *wb_view, GsfInput *input)
 {
 	Workbook *wb;
@@ -667,7 +667,7 @@ pln_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	name  = workbook_sheet_get_free_name (wb, "PlanPerfect", FALSE, TRUE);
 	sheet = sheet_new (wb, name);
 	g_free (name);
-	workbook_sheet_attach (wb, sheet, NULL);
+	workbook_sheet_attach (wb, sheet);
 	sheet_flag_recompute_spans (sheet);
 
 	state.sheet  = sheet;
@@ -677,7 +677,7 @@ pln_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	error = pln_parse_sheet (input, &state);
 	g_hash_table_destroy (state.styles);
 	if (error != NULL) {
-		workbook_sheet_detach (wb, sheet, FALSE);
+		workbook_sheet_delete (sheet);
 		gnumeric_io_error_info_set (io_context, error);
 	}
 }
