@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gnm-py-interpreter.c : GObject wrapper around Python interpreter
  *
@@ -6,23 +7,24 @@
 
 #include <gnumeric-config.h>
 #include <Python.h>
-#include <glib/gi18n.h>
-#include <stdio.h>
-#include <glib.h>
 #include <gnumeric.h>
-#include <plugin.h>
 #include <gutils.h>
-#include <module-plugin-defs.h>
 #include "py-gnumeric.h"
 #include "gnm-py-interpreter.h"
+#include "gnm-python.h"
 
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/module-plugin-defs.h>
+#include <gsf/gsf-impl-utils.h>
+#include <glib/gi18n.h>
+#include <stdio.h>
 
 struct _GnmPyInterpreter {
 	GObject parent_instance;
 
 	PyThreadState *py_thread_state;
 	PyObject      *stringio_class;
-	GnmPlugin *plugin;
+	GOPlugin *plugin;
 };
 
 typedef struct {
@@ -77,20 +79,15 @@ gnm_py_interpreter_class_init (GObjectClass *gobject_class)
 		G_TYPE_NONE, 0);
 }
 
-PLUGIN_CLASS (
-	GnmPyInterpreter, gnm_py_interpreter, gnm_py_interpreter_class_init,
-	gnm_py_interpreter_init, G_TYPE_OBJECT)
-
-
 static char *plugin_argv[] = {(char *) "gnumeric", NULL};
 
 GnmPyInterpreter *
-gnm_py_interpreter_new (GnmPlugin *plugin)
+gnm_py_interpreter_new (GOPlugin *plugin)
 {
 	GnmPyInterpreter *interpreter;
 	PyThreadState *py_thread_state;
 
-	g_return_val_if_fail (plugin == NULL || IS_GNM_PLUGIN (plugin), NULL);
+	g_return_val_if_fail (plugin == NULL || IS_GO_PLUGIN (plugin), NULL);
 
 	if (plugin != NULL) {
 		py_thread_state = Py_NewInterpreter ();
@@ -253,13 +250,13 @@ gnm_py_interpreter_get_name (GnmPyInterpreter *interpreter)
 	g_return_val_if_fail (IS_GNM_PY_INTERPRETER (interpreter), NULL);
 
 	if (interpreter->plugin != NULL) {
-		return gnm_plugin_get_name (interpreter->plugin);
+		return go_plugin_get_name (interpreter->plugin);
 	} else {
 		return _("Default interpreter");
 	}
 }
 
-GnmPlugin *
+GOPlugin *
 gnm_py_interpreter_get_plugin (GnmPyInterpreter *interpreter)
 {
 	g_return_val_if_fail (IS_GNM_PY_INTERPRETER (interpreter), NULL);
@@ -279,7 +276,24 @@ gnm_py_interpreter_compare (gconstpointer a, gconstpointer b)
 	} else if (int_b->plugin == NULL) {
 		return 1;
 	} else {
-		return g_utf8_collate (gnm_plugin_get_name (int_a->plugin),
-				       gnm_plugin_get_name (int_b->plugin));
+		return g_utf8_collate (go_plugin_get_name (int_a->plugin),
+				       go_plugin_get_name (int_b->plugin));
 	}
 }
+
+static GType gnm_py_interpreter_type;
+GType
+gnm_py_interpreter_get_type ()
+{
+	return gnm_py_interpreter_type;
+}
+
+void
+gnm_py_interpreter_register (GOPlugin *plugin)
+{
+	GSF_DYNAMIC_CLASS (GnmPyInterpreter, gnm_py_interpreter,
+		gnm_py_interpreter_class_init, gnm_py_interpreter_init,
+		G_TYPE_OBJECT,
+		G_TYPE_MODULE (plugin), gnm_py_interpreter_type);
+}
+
