@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gnm-python.c :
  *
@@ -5,18 +6,20 @@
  */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
 #include <Python.h>
 #include <pygobject.h>
 #include <glib.h>
-#include <gutils.h>
-#include <plugin.h>
-#include <error-info.h>
-#include <module-plugin-defs.h>
 #include "gnm-py-interpreter.h"
 #include "gnm-python.h"
 #include "py-gnumeric.h"
 
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/error-info.h>
+#include <goffice/app/module-plugin-defs.h>
+#include <goffice/utils/go-glib-extras.h>
+#include <gsf/gsf-impl-utils.h>
+
+#include <glib/gi18n.h>
 #include <unistd.h>
 
 struct _GnmPython {
@@ -44,7 +47,6 @@ static GObjectClass *parent_class = NULL;
 
 static GnmPython *gnm_python_obj = NULL;
 
-
 static void
 gnm_python_init (GnmPython *gpy)
 {
@@ -61,7 +63,7 @@ gnm_python_finalize (GObject *obj)
 	GnmPython *gpy = GNM_PYTHON (obj);
 
 	if (gpy->default_interpreter != NULL) {
-		GNM_SLIST_FOREACH (gpy->interpreters, GnmPyInterpreter, interpreter,
+		GO_SLIST_FOREACH (gpy->interpreters, GnmPyInterpreter, interpreter,
 			if (interpreter != gpy->default_interpreter) {
 				gnm_py_interpreter_destroy (interpreter, gpy->default_interpreter);
 			}
@@ -104,10 +106,6 @@ gnm_python_class_init (GObjectClass *gobject_class)
 		1, G_TYPE_POINTER);
 }
 
-PLUGIN_CLASS (
-	GnmPython, gnm_python, gnm_python_class_init, gnm_python_init,
-	G_TYPE_OBJECT)
-
 /* ---------- */
 
 
@@ -122,7 +120,7 @@ gnm_init_pygobject (ErrorInfo **err)
 {
 	PyObject *pygtk, *mdict, *require, *ret, *gobject, *cobject;
 	
-	GNM_INIT_RET_ERROR_INFO (err);
+	GO_INIT_RET_ERROR_INFO (err);
 	_PyGObject_API = NULL;
 	pygtk = PyImport_ImportModule((char *) "pygtk");
 	if (pygtk == NULL) {
@@ -167,7 +165,7 @@ gnm_init_pygobject (ErrorInfo **err)
 GnmPython *
 gnm_python_object_get (ErrorInfo **err)
 {
-	GNM_INIT_RET_ERROR_INFO (err);
+	GO_INIT_RET_ERROR_INFO (err);
 	if (!Py_IsInitialized ()) {
 		Py_Initialize ();
 #ifdef WITH_THREAD
@@ -201,15 +199,15 @@ cb_interpreter_switched (GnmPyInterpreter *interpreter, GnmPython *gpy)
 }
 
 GnmPyInterpreter *
-gnm_python_new_interpreter (GnmPython *gpy, GnmPlugin *plugin)
+gnm_python_new_interpreter (GnmPython *gpy, GOPlugin *plugin)
 {
 	GnmPyInterpreter *interpreter;
 
 	g_return_val_if_fail (IS_GNM_PYTHON (gpy), NULL);
-	g_return_val_if_fail (IS_GNM_PLUGIN (plugin), NULL);
+	g_return_val_if_fail (IS_GO_PLUGIN (plugin), NULL);
 
 	interpreter = gnm_py_interpreter_new (plugin);
-	GNM_SLIST_PREPEND (gpy->interpreters, interpreter);
+	GO_SLIST_PREPEND (gpy->interpreters, interpreter);
 	gpy->current_interpreter = interpreter;
 	g_signal_connect (
 		interpreter, "set_current", G_CALLBACK (cb_interpreter_switched), gpy);
@@ -226,7 +224,7 @@ gnm_python_destroy_interpreter (GnmPython *gpy, GnmPyInterpreter *interpreter)
 	g_return_if_fail (IS_GNM_PY_INTERPRETER (interpreter));
 	g_return_if_fail (interpreter != gpy->default_interpreter);
 
-	GNM_SLIST_REMOVE (gpy->interpreters, interpreter);
+	GO_SLIST_REMOVE (gpy->interpreters, interpreter);
 	gnm_py_interpreter_destroy (interpreter, gpy->default_interpreter);
 	g_object_unref (gpy);
 }
@@ -264,3 +262,18 @@ gnm_python_clear_error_if_needed (GnmPython *gpy)
 		PyErr_Clear ();
 	}
 }
+
+static GType gnm_python_type;
+GType
+gnm_python_get_type ()
+{
+	return gnm_python_type;
+}
+void
+gnm_python_register (GOPlugin *plugin)
+{
+	GSF_DYNAMIC_CLASS (GnmPython, gnm_python,
+		gnm_python_class_init, gnm_python_init, G_TYPE_OBJECT,
+		G_TYPE_MODULE (plugin), gnm_python_type);
+}
+
