@@ -13,11 +13,17 @@ GType gnm_python_get_type (void);
 typedef struct _GnmPython GnmPython;
 
 GnmPython        *gnm_python_object_get (ErrorInfo **err);
-GnmPyInterpreter *gnm_python_new_interpreter (GnmPython *gpy, GnmPlugin *plugin);
+GnmPyInterpreter *gnm_python_new_interpreter (GnmPython *gpy, GOPlugin *plugin);
 void              gnm_python_destroy_interpreter (GnmPython *gpy, GnmPyInterpreter *interpreter);
 GnmPyInterpreter *gnm_python_get_current_interpreter (GnmPython *gpy);
 GnmPyInterpreter *gnm_python_get_default_interpreter (GnmPython *gpy);
 GSList           *gnm_python_get_interpreters (GnmPython *gpy);
 void              gnm_python_clear_error_if_needed (GnmPython *gpy);
 
+void gnm_py_interpreter_register	  (GOPlugin *plugin);
+void gnm_python_register		  (GOPlugin *plugin);
+void gnm_py_command_line_register	  (GOPlugin *plugin);
+void gnm_py_interpreter_selector_register (GOPlugin *plugin);
+void gnm_python_plugin_loader_register	  (GOPlugin *plugin);
+
 #endif /* PLUGIN_GNM_PYTHON_H */
