@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * py-command-line.c: Simple wrapper around GtkEntry with history support
  *
@@ -5,15 +6,17 @@
  */
 
 #include <gnumeric-config.h>
-#include <string.h>
+#include "py-command-line.h"
+#include "gnm-python.h"
+#include <gnumeric.h>
+#include <gutils.h>
+#include <goffice/utils/go-glib-extras.h>
+#include <goffice/app/module-plugin-defs.h>
+#include <gsf/gsf-impl-utils.h>
 #include <glib-object.h>
 #include <gtk/gtkentry.h>
 #include <gdk/gdkkeysyms.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gnumeric.h>
-#include <gutils.h>
-#include <module-plugin-defs.h>
-#include "py-command-line.h"
+#include <string.h>
 
 #define MAX_HISTORY_SIZE  100
 
@@ -132,7 +135,7 @@ gnm_py_command_line_finalize (GObject *obj)
 {
 	GnmPyCommandLine *cline = GNM_PY_COMMAND_LINE (obj);
 
-	gnm_list_free_custom (cline->history, g_free);
+	go_list_free_custom (cline->history, g_free);
 	cline->history = NULL;
 
 	parent_class->finalize (obj);
@@ -154,17 +157,26 @@ gnm_py_command_line_class_init (GObjectClass *gobject_class)
 		NULL, NULL,
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
-
-	/* we registered a static class, don't unload the plugin */
-	g_type_plugin_use (G_TYPE_PLUGIN (PLUGIN));
 }
 
-GSF_CLASS (
-	GnmPyCommandLine, gnm_py_command_line, gnm_py_command_line_class_init,
-	gnm_py_command_line_init, GTK_TYPE_ENTRY)
-
 GtkWidget *
 gnm_py_command_line_new (void)
 {
 	return g_object_new (GNM_PY_COMMAND_LINE_TYPE, NULL);
 }
+
+static GType gnm_py_command_line_type;
+GType
+gnm_py_command_line_get_type ()
+{
+	return gnm_py_command_line_type;
+}
+void
+gnm_py_command_line_register (GOPlugin *plugin)
+{
+	GSF_DYNAMIC_CLASS (GnmPyCommandLine, gnm_py_command_line,
+		gnm_py_command_line_class_init, gnm_py_command_line_init,
+		GTK_TYPE_ENTRY,
+		G_TYPE_MODULE (plugin), gnm_py_command_line_type);
+}
+
