@@ -21,16 +21,15 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include <gnumeric.h>
 
 #include "func.h"
-#include "plugin.h"
 #include "value.h"
 #include "workbook.h"
 #include "sheet.h"
-#include "plugin-util.h"
-#include "module-plugin-defs.h"
+#include "gnm-i18n.h"
+#include <goffice/app/go-plugin.h>
+#include <gnm-plugin.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -40,11 +39,12 @@
 #include <string.h>
 #include <fcntl.h>
 #include <stdio.h>
+#include <glib/gstdio.h>
 
 #undef G_LOG_DOMAIN
 #define G_LOG_DOMAIN "gnumeric:atl"
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
 static int    atl_fd = -1;
 static char * atl_filename = NULL;
@@ -141,8 +141,8 @@ cb_atl_input (GIOChannel *gioc, GIOCondition cond, gpointer ignored)
 	return TRUE;
 }
 
-void
-plugin_init (void)
+G_MODULE_EXPORT void
+go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 {
 	GIOChannel *channel = NULL;
 	char *filename;
@@ -150,13 +150,14 @@ plugin_init (void)
 	fprintf (stderr, ">>>>>>>>>>>>>>>>>>>>>>>>>>>> LOAD ATL\n");
 	g_return_if_fail (atl_fd < 0);
 
-	filename = g_strdup_printf ("%s/%s", g_get_home_dir (), "atl");
+	filename = g_build_filename (g_get_home_dir (), "atl", NULL);
 
 	/* NOTE : better to use popen here, but this is fine for testing */
 #ifdef HAVE_MKFIFO
+#warning "If gstdio.h had g_mkfifo, that's what we should use here"
 	if (mkfifo (filename, S_IRUSR | S_IWUSR) == 0) {
 		atl_filename = filename;
-		atl_fd = open (atl_filename, O_RDWR|O_NONBLOCK);
+		atl_fd = g_open (atl_filename, O_RDWR|O_NONBLOCK, 0);
 	} else
 #endif /* HAVE_MKFIFO */
 		g_free (filename);
@@ -180,8 +181,8 @@ plugin_init (void)
 /* TODO : init and cleanup should be given CommandContexts
  * to make things tidier
  */
-void
-plugin_cleanup (void)
+G_MODULE_EXPORT void
+go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
 	fprintf (stderr, "UNLOAD ATL >>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
 
@@ -191,7 +192,7 @@ plugin_cleanup (void)
 	}
 
 	if (atl_filename) {
-		unlink (atl_filename);
+		g_unlink (atl_filename);
 		g_free (atl_filename);
 		atl_filename = NULL;
 	}
@@ -267,9 +268,10 @@ atl_last_unlink (FunctionEvalInfo *ei)
 	puts ("unlink atl_last");
 }
 
-static const char *help_atl_last = {
+static GnmFuncHelp const help_atl_last[] = {
+	{ GNM_FUNC_HELP_OLD,
         /* xgettext:no-c-format */
-	N_("@FUNCTION=atl_last\n"
+	F_("@FUNCTION=atl_last\n"
 	   "@SYNTAX=ATL_LAST (tag)\n"
 	   "@DESCRIPTION="
 	   "ATL_LAST is a sample implemention of a real time data source. "
@@ -282,10 +284,12 @@ static const char *help_atl_last = {
 	   "ATL_LAST(\"IBM\")"
 	   "\n"
 	   "@SEEALSO=")
+	},
+	{ GNM_FUNC_HELP_END }
 };
 
 GnmFuncDescriptor const ATL_functions[] = {
-	{"atl_last", "s", "tag", &help_atl_last, atl_last, NULL, atl_last_link, atl_last_unlink },
+	{"atl_last", "s", "tag", help_atl_last, atl_last, NULL, atl_last_link, atl_last_unlink },
 
 	{NULL}
 };
