@@ -11,16 +11,15 @@
 #include <string.h>
 #include <errno.h>
 #include <stdio.h>
-#include "plugin.h"
-#include "plugin-util.h"
-#include "module-plugin-defs.h"
-#include "io-context.h"
-#include "error-info.h"
+#include <goffice/app/go-plugin.h>
+#include <gnm-plugin.h>
+#include <goffice/app/io-context.h>
+#include <goffice/app/error-info.h>
 #include "workbook-view.h"
 #include "workbook.h"
 #include "parse-util.h"
 #include "value.h"
-#include "file.h"
+#include <goffice/app/file.h>
 #include "cell.h"
 #include "style.h"
 #include "sheet.h"
@@ -32,11 +31,11 @@
 #include <math.h>
 #include <stdlib.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
-gboolean sc_file_probe (GnmFileOpener const *fo, GsfInput *input,
+gboolean sc_file_probe (GOFileOpener const *fo, GsfInput *input,
 			FileProbeLevel pl);
-void sc_file_open (GnmFileOpener const *fo, IOContext *io_context,
+void sc_file_open (GOFileOpener const *fo, IOContext *io_context,
                    WorkbookView *wb_view, GsfInput *input);
 
 typedef enum {
@@ -245,7 +244,7 @@ sc_parse_cell_name_list (Sheet *sheet, char const *cell_name_str,
 #endif
 
 
-static char const *
+G_GNUC_UNUSED static char const *
 sc_rangeref_parse (GnmRangeRef *res, char const *start, GnmParsePos const *pp)
 {
 	/* This is a hack.  We still cannot handle sc's row 0.  */
@@ -257,6 +256,7 @@ sc_rangeref_parse (GnmRangeRef *res, char const *start, GnmParsePos const *pp)
 	return end;
 }
 
+
 static gboolean
 sc_parse_let (Sheet *sheet, char const *cmd, char const *str, int col, int row)
 {
@@ -384,7 +384,7 @@ sc_parse_sheet (GsfInputTextline *input, Sheet *sheet, GIConv ic)
 }
 
 void
-sc_file_open (GnmFileOpener const *fo, IOContext *io_context,
+sc_file_open (GOFileOpener const *fo, IOContext *io_context,
               WorkbookView *wb_view, GsfInput *input)
 {
 	Workbook  *wb;
@@ -398,7 +398,7 @@ sc_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	name  = workbook_sheet_get_free_name (wb, "SC", FALSE, TRUE);
 	sheet = sheet_new (wb, name);
 	g_free (name);
-	workbook_sheet_attach (wb, sheet, NULL);
+	workbook_sheet_attach (wb, sheet);
 
 	/* This should probably come from import dialog.  */
 	ic = g_iconv_open ("UTF-8", "ISO-8859-1");
@@ -406,7 +406,7 @@ sc_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	textline = (GsfInputTextline *) gsf_input_textline_new (input);
 	error = sc_parse_sheet (textline, sheet, ic);
 	if (error != NULL) {
-		workbook_sheet_detach (wb, sheet, FALSE);
+		workbook_sheet_delete (sheet);
 		gnumeric_io_error_info_set (io_context, error);
 	}
 	g_object_unref (G_OBJECT (textline));
@@ -417,7 +417,7 @@ static guint8 const signature[] =
 "# This data file was generated by the Spreadsheet Calculator.";
 
 gboolean
-sc_file_probe (GnmFileOpener const *fo, GsfInput *input,
+sc_file_probe (GOFileOpener const *fo, GsfInput *input,
 	       FileProbeLevel pl)
 {
 	char const *header = NULL;
