@@ -15,24 +15,23 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n.h>
 #include <gnumeric.h>
-#include "file.h"
-#include "io-context.h"
+#include <goffice/app/file.h>
+#include <goffice/app/io-context.h>
 #include "workbook-view.h"
 #include "workbook.h"
 #include "cell.h"
 #include "sheet.h"
 #include "value.h"
 #include "expr.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "mstyle.h"
 #include "style-border.h"
 #include "style-color.h"
 #include "sheet-style.h"
 #include "number-match.h"
-#include "error-info.h"
-#include "plugin-util.h"
-#include "plugin.h"
-#include "module-plugin-defs.h"
+#include <goffice/app/error-info.h>
+#include <goffice/app/go-plugin.h>
+#include <gnm-plugin.h>
 
 #include <string.h>
 #include <errno.h>
@@ -42,10 +41,10 @@
 #include <gsf/gsf-input-textline.h>
 #include <gsf/gsf-utils.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
-gboolean sylk_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl);
-void     sylk_file_open (GnmFileOpener const *fo, IOContext *io_context,
+gboolean sylk_file_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl);
+void     sylk_file_open (GOFileOpener const *fo, IOContext *io_context,
                          WorkbookView *wb_view, GsfInput *input);
 
 typedef struct {
@@ -480,7 +479,7 @@ sylk_parse_sheet (SylkReadState *state, ErrorInfo **ret_error)
 }
 
 void
-sylk_file_open (GnmFileOpener const *fo,
+sylk_file_open (GOFileOpener const *fo,
 		IOContext	*io_context,
                 WorkbookView	*wb_view,
 		GsfInput	*input)
@@ -507,21 +506,21 @@ sylk_file_open (GnmFileOpener const *fo,
 	state.formats	= g_ptr_array_new ();
 	state.finished = FALSE;
 
-	workbook_sheet_attach (book, state.sheet, NULL);
+	workbook_sheet_attach (book, state.sheet);
 	g_free (base);
 
-	old_num_locale = g_strdup (gnm_setlocale (LC_NUMERIC, NULL));
-	gnm_setlocale (LC_NUMERIC, "C");
-	old_monetary_locale = g_strdup (gnm_setlocale (LC_MONETARY, NULL));
-	gnm_setlocale (LC_MONETARY, "C");
-	gnm_set_untranslated_bools ();
+	old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
+	go_setlocale (LC_NUMERIC, "C");
+	old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
+	go_setlocale (LC_MONETARY, "C");
+	go_set_untranslated_bools ();
 
 	sylk_parse_sheet (&state, &sheet_error);
 
-	/* gnm_setlocale restores bools to locale translation */
-	gnm_setlocale (LC_MONETARY, old_monetary_locale);
+	/* go_setlocale restores bools to locale translation */
+	go_setlocale (LC_MONETARY, old_monetary_locale);
 	g_free (old_monetary_locale);
-	gnm_setlocale (LC_NUMERIC, old_num_locale);
+	go_setlocale (LC_NUMERIC, old_num_locale);
 	g_free (old_num_locale);
 
 	if (sheet_error != NULL)
@@ -538,7 +537,7 @@ sylk_file_open (GnmFileOpener const *fo,
 }
 
 gboolean
-sylk_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
+sylk_file_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
 	char const *header = NULL;
 	if (!gsf_input_seek (input, 0, G_SEEK_SET))
