@@ -20,7 +20,7 @@
 #include "expr-impl.h"
 #include "sheet.h"
 #include "workbook.h"
-#include "format.h"
+#include <goffice/utils/format.h>
 
 /* ------------------------------------------------------------------------- */
 /*
@@ -59,15 +59,15 @@
 #define AF_EXPLICIT ((GnmFuncFlags)(GNM_FUNC_AUTO_MASK + 1))
 
 static GnmFuncFlags do_af_suggest_list (GnmExprList *list,
-					EvalPos const *epos,
-					StyleFormat **explicit);
+					GnmEvalPos const *epos,
+					GOFormat **explicit);
 
-struct cb_af_suggest { GnmFuncFlags typ; StyleFormat **explicit; };
+struct cb_af_suggest { GnmFuncFlags typ; GOFormat **explicit; };
 
-static Value *
+static GnmValue *
 cb_af_suggest (G_GNUC_UNUSED Sheet *sheet,
 	       G_GNUC_UNUSED int col, G_GNUC_UNUSED int row,
-	       Cell *cell, void *_data)
+	       GnmCell *cell, void *_data)
 {
 	struct cb_af_suggest *data = _data;
 
@@ -80,7 +80,7 @@ cb_af_suggest (G_GNUC_UNUSED Sheet *sheet,
 }
 
 static gboolean
-is_date (GnmFuncFlags typ, StyleFormat *explicit)
+is_date (GnmFuncFlags typ, GOFormat *explicit)
 {
 	return (typ == GNM_FUNC_AUTO_DATE ||
 		(typ == AF_EXPLICIT &&
@@ -88,8 +88,21 @@ is_date (GnmFuncFlags typ, StyleFormat *explicit)
 }
 
 static GnmFuncFlags
-do_af_suggest (GnmExpr const *expr, const EvalPos *epos, StyleFormat **explicit)
+do_af_suggest (GnmExpr const *expr, const GnmEvalPos *epos, GOFormat **explicit)
 {
+#if 0
+	{
+		GnmParsePos pp;
+		pp.eval = epos->eval;
+		pp.sheet = epos->sheet;
+		pp.wb = pp.sheet->workbook;
+		g_printerr ("Suggesting format for [%s]\n",
+			    gnm_expr_as_string (expr,
+						&pp,
+						gnm_expr_conventions_default));
+	}
+#endif
+
 	switch (expr->any.oper) {
 	case GNM_EXPR_OP_EQUAL:
 	case GNM_EXPR_OP_GT:
@@ -114,7 +127,7 @@ do_af_suggest (GnmExpr const *expr, const EvalPos *epos, StyleFormat **explicit)
 
 	case GNM_EXPR_OP_SUB: {
 		GnmFuncFlags typ1, typ2;
-		StyleFormat *explicit1 = NULL, *explicit2 = NULL;
+		GOFormat *explicit1 = NULL, *explicit2 = NULL;
 
 		typ1 = do_af_suggest (expr->binary.value_a, epos, &explicit1);
 		typ2 = do_af_suggest (expr->binary.value_b, epos, &explicit2);
@@ -156,7 +169,7 @@ do_af_suggest (GnmExpr const *expr, const EvalPos *epos, StyleFormat **explicit)
 	}
 
 	case GNM_EXPR_OP_CONSTANT: {
-		const Value *v = expr->constant.value;
+		GnmValue const *v = expr->constant.value;
 
 		switch (v->type) {
 		case VALUE_STRING:
@@ -186,9 +199,9 @@ do_af_suggest (GnmExpr const *expr, const EvalPos *epos, StyleFormat **explicit)
 
 	case GNM_EXPR_OP_CELLREF: {
 		Sheet const *sheet;
-		CellRef const *ref;
-		Cell const *cell;
-		CellPos pos;
+		GnmCellRef const *ref;
+		GnmCell const *cell;
+		GnmCellPos pos;
 
 		ref = &expr->cellref.ref;
 		sheet = eval_sheet (ref->sheet, epos->sheet);
@@ -222,7 +235,7 @@ do_af_suggest (GnmExpr const *expr, const EvalPos *epos, StyleFormat **explicit)
 }
 
 static GnmFuncFlags
-do_af_suggest_list (GnmExprList *list, const EvalPos *epos, StyleFormat **explicit)
+do_af_suggest_list (GnmExprList *list, const GnmEvalPos *epos, GOFormat **explicit)
 {
 	GnmFuncFlags typ = GNM_FUNC_AUTO_UNKNOWN;
 	while (list && (typ == GNM_FUNC_AUTO_UNKNOWN || typ == GNM_FUNC_AUTO_UNITLESS)) {
@@ -234,10 +247,10 @@ do_af_suggest_list (GnmExprList *list, const EvalPos *epos, StyleFormat **explic
 
 /* ------------------------------------------------------------------------- */
 
-StyleFormat *
-auto_style_format_suggest (GnmExpr const *expr, EvalPos const *epos)
+GOFormat *
+auto_style_format_suggest (GnmExpr const *expr, GnmEvalPos const *epos)
 {
-	StyleFormat *explicit = NULL;
+	GOFormat *explicit = NULL;
 
 	g_return_val_if_fail (expr != NULL, NULL);
 	g_return_val_if_fail (epos != NULL, NULL);
