@@ -14,8 +14,10 @@
 #include "style.h"
 #include "cell.h"
 #include "sheet.h"
+#include "gnm-format.h"
 #include "rendered-value.h"
 #include "parse-util.h"
+#include <goffice/utils/go-color.h>
 
 #include <gdk/gdk.h>
 #include <string.h>
@@ -23,8 +25,6 @@
 static char const hashes[] =
 "################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################";
 
-gunichar const zero_width_space = 0x200b;
-
 /*
  *             G      G
  *             r      r
@@ -44,11 +44,10 @@ gunichar const zero_width_space = 0x200b;
  *             of the cell.  NOTE This can be asymetric.  Passing
  *             <= 0 will use width / 2
  */
-
 gboolean
 cell_calc_layout (GnmCell const *cell, RenderedValue *rv, int y_direction,
 		  int width, int height, int h_center,
-		  GdkColor **res_color, gint *res_x, gint *res_y)
+		  GOColor *res_color, gint *res_x, gint *res_y)
 {
 	ColRowInfo const * const ci = cell->col_info; /* DEPRECATED */
 	ColRowInfo const * const ri = cell->row_info; /* DEPRECATED */
@@ -122,7 +121,7 @@ cell_calc_layout (GnmCell const *cell, RenderedValue *rv, int y_direction,
 				int i;
 				for (i = 0; i < copies; i++) {
 					if (i)
-						g_string_append_unichar (multi, zero_width_space);
+						g_string_append_unichar (multi, UNICODE_ZERO_WIDTH_SPACE_C);
 					g_string_append_len (multi, copy1, len1);
 				}
 				pango_layout_set_text (layout, multi->str, multi->len);
@@ -168,6 +167,7 @@ cell_calc_layout (GnmCell const *cell, RenderedValue *rv, int y_direction,
 	}
 
 	case VALIGN_JUSTIFY:
+	case VALIGN_DISTRIBUTED: /* dunno what this does yet */
 		text_base = rect_y;
 		if (!rv->vfilled && height > rv->layout_natural_height) {
 			int line_count = pango_layout_get_line_count (layout);
@@ -189,7 +189,7 @@ cell_calc_layout (GnmCell const *cell, RenderedValue *rv, int y_direction,
 			 rv->layout_natural_width, rv->layout_natural_height);
 #endif
 
-	*res_color = &rv->color;
+	*res_color = rv->go_fore_color;
 	*res_x = rect_x + hoffset;
 	*res_y = text_base;
 
@@ -201,7 +201,7 @@ void
 cell_draw (GnmCell const *cell, GdkGC *gc, GdkDrawable *drawable,
 	   int x1, int y1, int width, int height, int h_center)
 {
-	GdkColor *color;
+	GOColor fore_color;
 	gint x;
 	gint y;
 	RenderedValue *rv = cell->rendered_value;
@@ -220,8 +220,9 @@ cell_draw (GnmCell const *cell, GdkGC *gc, GdkDrawable *drawable,
 			      width * PANGO_SCALE,
 			      height * PANGO_SCALE,
 			      h_center == -1 ? -1 : (h_center * PANGO_SCALE),
-			      &color, &x, &y)) {
+			      &fore_color, &x, &y)) {
 		PangoContext *context = NULL;
+		GdkColor tmp;
 
 		/* +1 to get past left grid-line.  */
 		GdkRectangle rect;
@@ -243,7 +244,8 @@ cell_draw (GnmCell const *cell, GdkGC *gc, GdkDrawable *drawable,
 		gdk_gc_set_clip_rectangle (gc, &rect);
 
 		/* See http://bugzilla.gnome.org/show_bug.cgi?id=105322 */
-		gdk_gc_set_rgb_fg_color (gc, color);
+		gdk_gc_set_rgb_fg_color (gc,
+			go_color_to_gdk (fore_color, &tmp));
 
 		if (rv->rotation) {
 			PangoMatrix rotmat = PANGO_MATRIX_INIT;
