@@ -19,10 +19,11 @@
 #include "value.h"
 #include "str.h"
 #include "style.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "sheet-object-cell-comment.h"
 #include "sheet-style.h"
 #include "parse-util.h"
+#include <goffice/utils/go-glib-extras.h>
 
 #define USE_CELL_POOL 1
 
@@ -86,7 +87,7 @@ cell_cleanout (GnmCell *cell)
 }
 
 /* The pool from which all cells are allocated.  */
-static GnmMemChunk *cell_pool;
+static GOMemChunk *cell_pool;
 
 /**
  * cell_new:
@@ -97,7 +98,7 @@ static GnmMemChunk *cell_pool;
 GnmCell *
 cell_new (void)
 {
-	GnmCell *cell = USE_CELL_POOL ? gnm_mem_chunk_alloc0 (cell_pool) : g_new0 (GnmCell, 1);
+	GnmCell *cell = USE_CELL_POOL ? go_mem_chunk_alloc0 (cell_pool) : g_new0 (GnmCell, 1);
 	cell->base.flags = DEPENDENT_CELL;
 	return cell;
 }
@@ -152,7 +153,7 @@ cell_destroy (GnmCell *cell)
 	g_return_if_fail (cell != NULL);
 
 	cell_cleanout (cell);
-	if (USE_CELL_POOL) gnm_mem_chunk_free (cell_pool, cell); else g_free (cell);
+	if (USE_CELL_POOL) go_mem_chunk_free (cell_pool, cell); else g_free (cell);
 }
 
 /*
@@ -333,7 +334,11 @@ cell_set_expr_internal (GnmCell *cell, GnmExpr const *expr)
 	cell->base.flags |= CELL_HAS_NEW_EXPR;
 	cell->base.expression = expr;
 
-	/* Until the value is recomputed, we put in this value.  */
+	/* Until the value is recomputed, we put in this value.
+	 *
+	 * We should consider using 0 instead and take out the
+	 * cell_needs_recalc call in sheet_foreach_cell_in_range.
+	 */
 	cell->value = value_new_empty ();
 	cell_dirty (cell);
 }
@@ -542,15 +547,15 @@ void
 cell_render_value (GnmCell *cell, gboolean allow_variable_width)
 {
 	RenderedValue *rv;
-	GnmStyle *mstyle;
-	PangoContext *context;
+	Sheet *sheet;
 
 	g_return_if_fail (cell != NULL);
 
-	mstyle = cell_get_mstyle (cell);
-	context = cell->base.sheet->context;
-
-	rv = rendered_value_new (cell, mstyle, allow_variable_width, context);
+	sheet = cell->base.sheet;
+	rv = rendered_value_new (cell, cell_get_mstyle (cell),
+				 allow_variable_width,
+				 sheet->context,
+				 sheet->last_zoom_factor_used);
 	if (cell->rendered_value)
 		rendered_value_destroy (cell->rendered_value);
 	cell->rendered_value = rv;
@@ -592,10 +597,10 @@ cell_get_mstyle (GnmCell const *cell)
  * Get the display format.  If the assigned format is General,
  * the format of the value will be used.
  */
-GnmFormat *
+GOFormat *
 cell_get_format (GnmCell const *cell)
 {
-	GnmFormat *fmt;
+	GOFormat *fmt;
 
 	g_return_val_if_fail (cell != NULL, style_format_general ());
 
@@ -694,7 +699,7 @@ void
 cell_init (void)
 {
 #if USE_CELL_POOL
-	cell_pool = gnm_mem_chunk_new ("cell pool",
+	cell_pool = go_mem_chunk_new ("cell pool",
 				       sizeof (GnmCell),
 				       128 * 1024 - 128);
 #endif
@@ -713,8 +718,8 @@ void
 cell_shutdown (void)
 {
 #if USE_CELL_POOL
-	gnm_mem_chunk_foreach_leak (cell_pool, cb_cell_pool_leak, NULL);
-	gnm_mem_chunk_destroy (cell_pool, FALSE);
+	go_mem_chunk_foreach_leak (cell_pool, cb_cell_pool_leak, NULL);
+	go_mem_chunk_destroy (cell_pool, FALSE);
 	cell_pool = NULL;
 #endif
 }
