@@ -1,12 +1,25 @@
-/* vim: set sw=8: */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Clipboard.c: Implements the copy/paste operations
+ * clipboard.c: A temporary store for content from a worksheet
  *
- * Author:
- *  Miguel de Icaza (miguel@gnu.org)
+ * Copyright (C) 2000-2005 Jody Goldberg   (jody@gnome.org)
+ *  		 1999      Miguel de Icaza (miguel@gnu.org)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "clipboard.h"
 
@@ -16,7 +29,6 @@
 #include "dependent.h"
 #include "selection.h"
 #include "application.h"
-#include "rendered-value.h"
 #include "command-context.h"
 #include "workbook-control.h"
 #include "workbook.h"
@@ -25,12 +37,28 @@
 #include "expr-impl.h"
 #include "commands.h"
 #include "value.h"
-#include <gtk/gtkmain.h>
 #include "stf-parse.h"
 #include "sheet-object-cell-comment.h"
 
+#include <gtk/gtkmain.h>
+#include <glib/gi18n.h>
 #include <locale.h>
 #include <string.h>
+#include <goffice/utils/go-glib-extras.h>
+
+#ifndef USE_CELL_COPY_POOLS
+#define USE_CELL_COPY_POOLS 1
+#endif
+
+#if USE_CELL_COPY_POOLS
+/* Memory pool for GnmCellCopy.  */
+static GOMemChunk *cell_copy_pool;
+#define CHUNK_ALLOC(T,p) ((T*)go_mem_chunk_alloc (p))
+#define CHUNK_FREE(p,v) go_mem_chunk_free ((p), (v))
+#else
+#define CHUNK_ALLOC(T,c) g_new (T,1)
+#define CHUNK_FREE(p,v) g_free ((v))
+#endif
 
 static gboolean
 cell_has_expr_or_number_or_blank (GnmCell const * cell)
@@ -41,23 +69,17 @@ cell_has_expr_or_number_or_blank (GnmCell const * cell)
 }
 
 static GnmExpr const *
-cell_get_contents_as_expr (GnmCell const * cell)
+contents_as_expr (GnmExpr const *expr, GnmValue const *val)
 {
-	GnmExpr const *expr = NULL;
-
-	g_return_val_if_fail (cell_has_expr_or_number_or_blank (cell), NULL);
-
-	if (cell_is_empty (cell))
-		expr = gnm_expr_new_constant (value_new_float (0.0));
-	else if (cell_has_expr (cell)) {
-		expr = cell->base.expression;
+	if (NULL != expr) {
 		gnm_expr_ref (expr);
-	} else if (cell_is_number (cell))
-		expr = gnm_expr_new_constant (value_dup (cell->value));
-	else
-		g_assert_not_reached ();
-
-	return expr;
+		return expr;
+	}
+	if (VALUE_IS_EMPTY (val))
+		return gnm_expr_new_constant (value_new_float (0.0));
+	if (VALUE_IS_NUMBER (val))
+		return gnm_expr_new_constant (value_dup (val));
+	return NULL;
 }
 
 static GnmExprOp
@@ -73,70 +95,52 @@ paste_op_to_expr_op (int paste_flags)
 		return GNM_EXPR_OP_MULT;
 	else if (paste_flags & PASTE_OPER_DIV)
 		return GNM_EXPR_OP_DIV;
-	else
-		g_assert_not_reached ();
 
 	return 0;
 }
 
-#warning handle formating
-static GnmValue *
-apply_paste_oper_to_values (GnmCell const *old_cell, GnmCell const *copied_cell,
-			    GnmCell const *new_cell, int paste_flags)
-{
-	GnmEvalPos pos;
-	GnmExpr expr, arg_a, arg_b;
-	GnmExprOp op = paste_op_to_expr_op (paste_flags);
-
-	arg_a.constant.oper = GNM_EXPR_OP_CONSTANT;
-	arg_a.constant.value = old_cell->value;
-	arg_b.constant.oper = GNM_EXPR_OP_CONSTANT;
-	arg_b.constant.value = copied_cell->value;
-
-	expr.binary.oper = op;
-	expr.binary.value_a = &arg_a;
-	expr.binary.value_b = &arg_b;
-
-	eval_pos_init_cell (&pos, new_cell);
-	pos.dep = NULL; /* no dynamic deps */
-	return gnm_expr_eval (&expr, &pos, GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
-}
-
 static void
-paste_cell_with_operation (Sheet *dest_sheet,
+paste_cell_with_operation (Sheet *dst_sheet,
 			   int target_col, int target_row,
 			   GnmExprRewriteInfo const *rwinfo,
-			   CellCopy *c_copy, int paste_flags)
+			   GnmCellCopy const *src,
+			   int paste_flags)
 {
-	GnmCell *new_cell;
+	GnmCell *dst;
+	GnmExprOp op;
 
-	g_return_if_fail (paste_flags & PASTE_OPER_MASK);
-
-	if (!(c_copy->type == CELL_COPY_TYPE_CELL))
+	if (src->expr == NULL && !VALUE_IS_EMPTY (src->val) && !VALUE_IS_NUMBER (src->val))
 		return;
 
-	new_cell = sheet_cell_fetch (dest_sheet, target_col, target_row);
-
-	if ((!cell_has_expr_or_number_or_blank (new_cell)) ||
-	    (!cell_has_expr_or_number_or_blank (c_copy->u.cell)))
+	dst = sheet_cell_fetch (dst_sheet, target_col, target_row);
+	if (!cell_has_expr_or_number_or_blank (dst))
 		return;
 
+	op = paste_op_to_expr_op (paste_flags);
 	/* FIXME : This does not handle arrays, linked cells, ranges, etc. */
 	if ((paste_flags & PASTE_CONTENT) &&
-	    ((c_copy->u.cell != NULL && cell_has_expr (c_copy->u.cell)) ||
-	           (new_cell != NULL && cell_has_expr (new_cell)))) {
-		GnmExpr const *old_expr    = cell_get_contents_as_expr (new_cell);
-		GnmExpr const *copied_expr = cell_get_contents_as_expr (c_copy->u.cell);
-		GnmExprOp op	           = paste_op_to_expr_op (paste_flags);
-		GnmExpr const *new_expr    = gnm_expr_new_binary (old_expr, op, copied_expr);
-		cell_set_expr (new_cell, new_expr);
-		cell_relocate (new_cell, rwinfo);
-		gnm_expr_unref (new_expr);
+	    (NULL != src->expr || cell_has_expr (dst))) {
+		GnmExpr const *old_expr    = contents_as_expr (dst->base.expression, dst->value);
+		GnmExpr const *copied_expr = contents_as_expr (src->expr, src->val);
+		GnmExpr const *res = gnm_expr_new_binary (old_expr, op, copied_expr);
+		cell_set_expr (dst, res);
+		cell_relocate (dst, rwinfo);
+		gnm_expr_unref (res);
 	} else {
-		GnmValue *new_val = apply_paste_oper_to_values (new_cell, c_copy->u.cell,
-							     new_cell, paste_flags);
+		GnmEvalPos pos;
+		GnmExpr	   expr, arg_a, arg_b;
+		arg_a.constant.oper = GNM_EXPR_OP_CONSTANT;
+		arg_a.constant.value = dst->value;
+		arg_b.constant.oper = GNM_EXPR_OP_CONSTANT;
+		arg_b.constant.value = src->val;
+		expr.binary.oper = op;
+		expr.binary.value_a = &arg_a;
+		expr.binary.value_b = &arg_b;
 
-		cell_set_value (new_cell, new_val);
+		eval_pos_init_cell (&pos, dst);
+		pos.dep = NULL; /* no dynamic deps */
+		cell_set_value (dst,
+			gnm_expr_eval (&expr, &pos, GNM_EXPR_EVAL_SCALAR_NON_EMPTY));
 	}
 }
 
@@ -185,50 +189,32 @@ paste_link (GnmPasteTarget const *pt, int top, int left,
 /**
  * paste_cell: Pastes a cell in the spreadsheet
  *
- * @dest_sheet:  The sheet where the pasting will be done
+ * @dst_sheet:   The sheet where the pasting will be done
  * @target_col:  Column to put the cell into
  * @target_row:  Row to put the cell into.
  * @new_cell:    A new cell (not linked into the sheet, or wb->expr_list)
  * @paste_flags: Bit mask that describes the paste options.
  */
 static void
-paste_cell (Sheet *dest_sheet,
+paste_cell (Sheet *dst_sheet,
 	    int target_col, int target_row,
 	    GnmExprRewriteInfo const *rwinfo,
-	    CellCopy *c_copy, int paste_flags)
+	    GnmCellCopy const *src, int paste_flags)
 {
-	if (!(paste_flags & (PASTE_CONTENT | PASTE_AS_VALUES)))
-		return;
-
-	if (paste_flags & PASTE_OPER_MASK) {
-		paste_cell_with_operation (dest_sheet, target_col, target_row,
-					   rwinfo, c_copy, paste_flags);
-		return;
-	}
-
-	if (c_copy->type == CELL_COPY_TYPE_CELL) {
-		GnmCell *new_cell = sheet_cell_fetch (dest_sheet, target_col, target_row);
-		GnmCell *src_cell = c_copy->u.cell;
-
-		if (!src_cell) {
-			g_warning ("Cell copy type set but no cell found (this is bad!)");
-			return;
-		}
-
-		if (cell_has_expr (src_cell)) {
-			cell_set_expr_and_value (new_cell, src_cell->base.expression,
-						 value_dup (src_cell->value), FALSE);
-
-			if (paste_flags & PASTE_CONTENT)
-				cell_relocate (new_cell, rwinfo);
-			else
-				cell_convert_expr_to_value (new_cell);
-		} else
-				cell_set_value (new_cell, value_dup (src_cell->value));
-
-	} else if (c_copy->u.text)
-		cell_set_text (sheet_cell_fetch (dest_sheet, target_col, target_row),
-			       c_copy->u.text);
+	if (paste_flags & PASTE_OPER_MASK)
+		paste_cell_with_operation (dst_sheet, target_col, target_row,
+					   rwinfo, src, paste_flags);
+	else if (NULL != src->expr) {
+		GnmCell *dst = sheet_cell_fetch (dst_sheet, target_col, target_row);
+		cell_set_expr_and_value (dst, src->expr,
+			value_dup (src->val), FALSE);
+		if (paste_flags & PASTE_CONTENT)
+			cell_relocate (dst, rwinfo);
+		else
+			cell_convert_expr_to_value (dst);
+	} else
+		cell_set_value (sheet_cell_fetch (dst_sheet, target_col, target_row),
+			value_dup (src->val));
 }
 
 static void
@@ -237,12 +223,14 @@ paste_object (GnmPasteTarget const *pt, SheetObject const *src, int left, int to
 	if ((pt->paste_flags & PASTE_OBJECTS) ||
 	    G_OBJECT_TYPE (src) == CELL_COMMENT_TYPE) {
 		SheetObject *dst = sheet_object_dup (src);
-		SheetObjectAnchor tmp;
-		sheet_object_anchor_cpy (&tmp, sheet_object_get_anchor (src));
-		range_translate (&tmp.cell_bound, left, top);
-		sheet_object_set_anchor (dst, &tmp);
-		sheet_object_set_sheet (dst, pt->sheet);
-		g_object_unref (dst);
+		if (dst != NULL) {
+			SheetObjectAnchor tmp;
+			sheet_object_anchor_cpy (&tmp, sheet_object_get_anchor (src));
+			range_translate (&tmp.cell_bound, left, top);
+			sheet_object_set_anchor (dst, &tmp);
+			sheet_object_set_sheet (dst, pt->sheet);
+			g_object_unref (dst);
+		}
 	}
 }
 
@@ -262,7 +250,7 @@ paste_object (GnmPasteTarget const *pt, SheetObject const *src, int left, int to
 gboolean
 clipboard_paste_region (GnmCellRegion const *content,
 			GnmPasteTarget const *pt,
-			GnmCmdContext *cc)
+			GOCmdContext *cc)
 {
 	int repeat_horizontal, repeat_vertical, clearFlags;
 	int dst_cols, dst_rows, src_cols, src_rows;
@@ -310,7 +298,7 @@ clipboard_paste_region (GnmCellRegion const *content,
 	}
 
 	if (content->not_as_content && (pt->paste_flags & PASTE_CONTENT)) {
-		gnm_cmd_context_error_invalid (cc,
+		go_cmd_context_error_invalid (cc,
 					_("Unable to paste"),
 					_("Content can only be pasted by value or by link."));
 		return TRUE;
@@ -323,7 +311,7 @@ clipboard_paste_region (GnmCellRegion const *content,
 			_("destination does not have an even multiple of source columns (%d vs %d)\n\n"
 			  "Try selecting a single cell or an area of the same shape and size."),
 			dst_cols, src_cols);
-		gnm_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
+		go_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
 		g_free (msg);
 		return TRUE;
 	}
@@ -334,14 +322,14 @@ clipboard_paste_region (GnmCellRegion const *content,
 			_("destination does not have an even multiple of source rows (%d vs %d)\n\n"
 			  "Try selecting a single cell or an area of the same shape and size."),
 			dst_rows, src_rows);
-		gnm_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
+		go_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
 		g_free (msg);
 		return TRUE;
 	}
 
 	if ((pt->range.start.col + dst_cols) > SHEET_MAX_COLS ||
 	    (pt->range.start.row + dst_rows) > SHEET_MAX_ROWS) {
-		gnm_cmd_context_error_invalid (cc,
+		go_cmd_context_error_invalid (cc,
 					_("Unable to paste"),
 					_("result passes the sheet boundary"));
 		return TRUE;
@@ -379,7 +367,6 @@ clipboard_paste_region (GnmCellRegion const *content,
 		for (j = 0; j < repeat_vertical ; j++) {
 			int const left = i * src_cols + pt->range.start.col;
 			int const top = j * src_rows + pt->range.start.row;
-			CellCopyList *c_ptr;
 			GnmExprRewriteInfo   rwinfo;
 			GnmExprRelocateInfo *rinfo;
 
@@ -427,70 +414,71 @@ clipboard_paste_region (GnmCellRegion const *content,
 				continue;
 			}
 
+			if (has_content)
+				for (ptr = content->content; ptr; ptr = ptr->next) {
+					GnmCellCopy const *src = ptr->data;
+					int target_col = left;
+					int target_row = top;
 
-			for (c_ptr = content->content; c_ptr; c_ptr = c_ptr->next) {
-				CellCopy *c_copy = c_ptr->data;
-				int target_col = left;
-				int target_row = top;
+					if (pt->paste_flags & PASTE_TRANSPOSE) {
+						target_col += src->row_offset;
+						target_row += src->col_offset;
+					} else {
+						target_col += src->col_offset;
+						target_row += src->row_offset;
+					}
 
-				if (pt->paste_flags & PASTE_TRANSPOSE) {
-					target_col += c_copy->row_offset;
-					target_row += c_copy->col_offset;
-				} else {
-					target_col += c_copy->col_offset;
-					target_row += c_copy->row_offset;
+					rinfo->pos.sheet = pt->sheet;
+					if (pt->paste_flags & PASTE_EXPR_LOCAL_RELOCATE) {
+						rinfo->pos.eval.col = content->base.col + src->col_offset;
+						rinfo->pos.eval.row = content->base.row + src->row_offset;
+					} else {
+						rinfo->pos.eval.col = target_col;
+						rinfo->pos.eval.row = target_row;
+					}
+
+					paste_cell (pt->sheet, target_col, target_row,
+						    &rwinfo, src, pt->paste_flags);
 				}
-
-				rinfo->pos.sheet = pt->sheet;
-				if (pt->paste_flags & PASTE_EXPR_LOCAL_RELOCATE) {
-					rinfo->pos.eval.col = content->base.col + c_copy->col_offset;
-					rinfo->pos.eval.row = content->base.row + c_copy->row_offset;
-				} else {
-					rinfo->pos.eval.col = target_col;
-					rinfo->pos.eval.row = target_row;
-				}
-
-				paste_cell (pt->sheet, target_col, target_row,
-					    &rwinfo, c_copy, pt->paste_flags);
-			}
 			if (pt->paste_flags & (PASTE_COMMENTS | PASTE_OBJECTS))
 				for (ptr = content->objects; ptr; ptr = ptr->next)
 					paste_object (pt, ptr->data, left, top);
 		}
 
-        if (has_content) {
-		sheet_region_queue_recalc (pt->sheet, r);
-		sheet_flag_status_update_range (pt->sheet, r);
-	} else
-		sheet_flag_format_update_range (pt->sheet, r);
+	if (!(pt->paste_flags & PASTE_NO_RECALC)) {
+		if (has_content) {
+			sheet_region_queue_recalc (pt->sheet, r);
+			sheet_flag_status_update_range (pt->sheet, r);
+		} else
+			sheet_flag_format_update_range (pt->sheet, r);
 
-	sheet_range_calc_spans (pt->sheet, r,
-		(pt->paste_flags & PASTE_FORMATS) ? SPANCALC_RE_RENDER : SPANCALC_RENDER);
-	if (pt->paste_flags & PASTE_UPDATE_ROW_HEIGHT)
-		rows_height_update (pt->sheet, &pt->range, FALSE);
-	sheet_redraw_all (pt->sheet, FALSE);
+		sheet_range_calc_spans (pt->sheet, r,
+					(pt->paste_flags & PASTE_FORMATS) ? SPANCALC_RE_RENDER : SPANCALC_RENDER);
+		if (pt->paste_flags & PASTE_UPDATE_ROW_HEIGHT)
+			rows_height_update (pt->sheet, &pt->range, FALSE);
+		sheet_redraw_all (pt->sheet, FALSE);
+	}
 
 	return FALSE;
 }
 
 static GnmValue *
 cb_clipboard_prepend_cell (Sheet *sheet, int col, int row,
-			   GnmCell *cell, GnmCellRegion *cr)
+			   GnmCell const *cell, GnmCellRegion *cr)
 {
 	GnmExprArray const *a;
-	CellCopy *copy;
-
-	copy = g_new (CellCopy, 1);
-	copy->type       = CELL_COPY_TYPE_CELL;
-	copy->u.cell     = cell_copy (cell);
-	copy->u.cell->pos.col = copy->col_offset = col - cr->base.col;
-	copy->u.cell->pos.row = copy->row_offset = row - cr->base.row;
+	GnmCellCopy *copy = gnm_cell_copy_new (
+		col - cr->base.col, row - cr->base.row);
+	copy->val = value_dup (cell->value);
+	if (cell_has_expr (cell))
+		gnm_expr_ref (copy->expr = cell->base.expression);
+	else
+		copy->expr = NULL;
 	cr->content = g_slist_prepend (cr->content, copy);
 
 	/* Check for array division */
 	if (!cr->not_as_content && NULL != (a = cell_is_array (cell))) {
-		int base;
-		base = copy->col_offset - a->x;
+		int base = copy->col_offset - a->x;
 		if (base < 0 || (base + a->cols) > cr->cols)
 			cr->not_as_content = TRUE;
 		else {
@@ -507,11 +495,13 @@ static void
 cb_dup_objects (SheetObject const *src, GnmCellRegion *cr)
 {
 	SheetObject *dst = sheet_object_dup (src);
-	SheetObjectAnchor tmp;
-	sheet_object_anchor_cpy (&tmp, sheet_object_get_anchor (src));
-	range_translate (&tmp.cell_bound, - cr->base.col, - cr->base.row);
-	sheet_object_set_anchor (dst, &tmp);
-	cr->objects = g_slist_prepend (cr->objects, dst);
+	if (dst != NULL) {
+		SheetObjectAnchor tmp;
+		sheet_object_anchor_cpy (&tmp, sheet_object_get_anchor (src));
+		range_translate (&tmp.cell_bound, - cr->base.col, - cr->base.row);
+		sheet_object_set_anchor (dst, &tmp);
+		cr->objects = g_slist_prepend (cr->objects, dst);
+	}
 }
 
 /**
@@ -555,6 +545,47 @@ clipboard_copy_range (Sheet *sheet, GnmRange const *r)
 	return cr;
 }
 
+/**
+ * clipboard_copy_obj:
+ *
+ * Returns a cell region with copies of objects in list.
+ */
+GnmCellRegion *
+clipboard_copy_obj (Sheet *sheet, GSList *objects)
+{
+	GnmCellRegion *cr;
+	GnmRange *r;
+	GSList *ptr;
+	SheetObject *so;
+	double coords [4];
+	guint w, h;
+
+	g_return_val_if_fail (IS_SHEET (sheet), NULL);
+	g_return_val_if_fail (objects != NULL, NULL);
+
+	cr = cellregion_new (sheet);
+	for (ptr = objects ; ptr != NULL ; ptr = ptr->next) {
+		sheet_object_position_pts_get (SHEET_OBJECT (ptr->data),
+					       coords);
+		w = fabs (coords[2] - coords[0]) + 1;
+		h = fabs (coords[3] - coords[1]) + 1.;
+		so = sheet_object_dup (ptr->data);
+		if (so != NULL) {
+			r = (GnmRange *) sheet_object_get_range	(so);
+			range_translate (r,
+					 -MIN (r->start.col, r->end.col),
+					 -MIN (r->start.row, r->end.row));
+			g_object_set_data (G_OBJECT (so),  "pt-width-at-copy",
+					   GUINT_TO_POINTER (w));
+			g_object_set_data (G_OBJECT (so),  "pt-height-at-copy",
+					   GUINT_TO_POINTER (h));
+			cr->objects = g_slist_prepend (cr->objects, so);
+		}
+	}
+
+	return cr;
+}
+
 GnmPasteTarget*
 paste_target_init (GnmPasteTarget *pt, Sheet *sheet, GnmRange const *r, int flags)
 {
@@ -596,7 +627,8 @@ cellregion_ref (GnmCellRegion *cr)
 void
 cellregion_unref (GnmCellRegion *cr)
 {
-	CellCopyList *ptr;
+	GSList	*ptr;
+	GnmCellCopy *cc;
 
 	g_return_if_fail (cr != NULL);
 	if (cr->ref_count > 1) {
@@ -605,17 +637,16 @@ cellregion_unref (GnmCellRegion *cr)
 	}
 
 	for (ptr = cr->content; ptr; ptr = ptr->next) {
-		CellCopy *this_cell = ptr->data;
-
-		if (this_cell->type == CELL_COPY_TYPE_CELL) {
-			/* The cell is not really in the rows or columns */
-			this_cell->u.cell->base.sheet = NULL;
-			this_cell->u.cell->row_info = NULL;
-			this_cell->u.cell->col_info = NULL;
-			cell_destroy (this_cell->u.cell);
-		} else if (this_cell->u.text)
-			g_free (this_cell->u.text);
-		g_free (this_cell);
+		cc = ptr->data;
+		if (NULL != cc->expr) {
+			gnm_expr_unref (cc->expr);
+			cc->expr = NULL;
+		}
+		if (cc->val != NULL) {
+			value_release (cc->val);
+			cc->val = NULL;
+		}
+		CHUNK_FREE (cell_copy_pool, cc);
 	}
 	g_slist_free (cr->content);
 	cr->content = NULL;
@@ -642,73 +673,43 @@ cellregion_unref (GnmCellRegion *cr)
 	g_free (cr);
 }
 
-/**
- * cellregion_to_string
- * @cr :
- *
- * Renders a GnmCellRegion as a sequence of strings.
- */
-char *
-cellregion_to_string (GnmCellRegion const *cr, PangoContext *context)
+GnmCellCopy *
+gnm_cell_copy_new (int col_offset, int row_offset)
 {
-	GString *all, *line;
-	CellCopyList *ptr;
-	char ***data, *return_val;
-	int col, row;
-
-	g_return_val_if_fail (cr != NULL, NULL);
-
-	data = g_new0 (char **, cr->rows);
-
-	for (row = 0; row < cr->rows; row++)
-		data[row] = g_new0 (char *, cr->cols);
-
-	for (ptr = cr->content; ptr; ptr = ptr->next) {
-		CellCopy *c_copy = ptr->data;
-		char *v;
-
-		if (c_copy->type != CELL_COPY_TYPE_TEXT) {
-			/* FIXME: feels bogus to use rendered value.  */
-			GnmStyle const *mstyle = style_list_get_style (cr->styles,
-				&c_copy->u.cell->pos);
-			RenderedValue *rv;
-
-			rv = rendered_value_new (c_copy->u.cell,
-						 mstyle, FALSE,
-						 context);
-			v = g_strdup (rendered_value_get_text (rv));
-			rendered_value_destroy (rv);
-		} else
-			v = g_strdup (c_copy->u.text);
-
-		data[c_copy->row_offset][c_copy->col_offset] = v;
-	}
-
-	all = g_string_new (NULL);
-	line = g_string_new (NULL);
-	for (row = 0; row < cr->rows;) {
-		g_string_assign (line, "");
-
-		for (col = 0; col < cr->cols;) {
-			if (data[row][col]) {
-				g_string_append (line, data[row][col]);
-				g_free (data[row][col]);
-			}
-			if (++col < cr->cols)
-				g_string_append_c (line, '\t');
-		}
-		g_string_append_len (all, line->str, line->len);
-		if (++row < cr->rows)
-			g_string_append_c (all, '\n');
-	}
-
-	/* Release, everything we used */
-	g_string_free (line, TRUE);
-	return_val = g_string_free (all, FALSE);
-
-	for (row = 0; row < cr->rows; row++)
-		g_free (data[row]);
-	g_free (data);
-
-	return return_val;
+	GnmCellCopy *res = CHUNK_ALLOC (GnmCellCopy, cell_copy_pool);
+	res->col_offset = col_offset;
+	res->row_offset = row_offset;
+	res->expr = NULL;
+	res->val = NULL;
+	return res;
+}
+
+void
+clipboard_init (void)
+{
+#if USE_CELL_COPY_POOLS
+	cell_copy_pool =
+		go_mem_chunk_new ("cell copy pool",
+				  sizeof (GnmCellCopy),
+				  4 * 1024 - 128);
+#endif
+}
+
+#if USE_CELL_COPY_POOLS
+static void
+cb_cell_copy_pool_leak (gpointer data, G_GNUC_UNUSED gpointer user)
+{
+	GnmCellCopy const *cc = data;
+	g_printerr ("Leaking cell copy at %p.\n", cc);
+}
+#endif
+
+void
+clipboard_shutdown (void)
+{
+#if USE_CELL_COPY_POOLS
+	go_mem_chunk_foreach_leak (cell_copy_pool, cb_cell_copy_pool_leak, NULL);
+	go_mem_chunk_destroy (cell_copy_pool, FALSE);
+	cell_copy_pool = NULL;
+#endif
 }
