@@ -45,27 +45,17 @@ enum {
 #define PASTE_DEFAULT   PASTE_ALL_TYPES
 #define PASTE_OPER_MASK (PASTE_OPER_ADD | PASTE_OPER_SUB | PASTE_OPER_MULT | PASTE_OPER_DIV)
 
-typedef enum {
-	CELL_COPY_TYPE_CELL,
-	CELL_COPY_TYPE_TEXT
-} CellCopyType;
-
 typedef struct {
 	int col_offset, row_offset; /* Position of the cell */
-	CellCopyType type;
-	union {
-		GnmCell *cell;
-		char *text;
-	} u;
-} CellCopy;
-
-typedef GSList CellCopyList;
+	GnmValue *val;
+	GnmExpr  const *expr;
+} GnmCellCopy;
 
 struct _GnmCellRegion {
 	Sheet		*origin_sheet; /* can be NULL */
 	GnmCellPos	 base;
 	int		 cols, rows;
-	CellCopyList	*content;
+	GSList		*content;
 	GnmStyleList	*styles;
 	GSList		*merged;
 	GSList		*objects;
@@ -80,15 +70,21 @@ struct _GnmPasteTarget {
 };
 
 GnmCellRegion *clipboard_copy_range   (Sheet *sheet, GnmRange const *r);
+GnmCellRegion *clipboard_copy_obj     (Sheet *sheet, GSList *objects);
 gboolean       clipboard_paste_region (GnmCellRegion const *content,
 				       GnmPasteTarget const *pt,
-				       GnmCmdContext *cc);
+				       GOCmdContext *cc);
 GnmPasteTarget*paste_target_init      (GnmPasteTarget *pt,
 				       Sheet *sheet, GnmRange const *r, int flags);
 
-GnmCellRegion *cellregion_new	 (Sheet *origin_sheet);
-void        cellregion_ref       (GnmCellRegion *content);
-void        cellregion_unref     (GnmCellRegion *content);
-char	   *cellregion_to_string (GnmCellRegion const *content, PangoContext *context);
+GnmCellRegion *cellregion_new	(Sheet *origin_sheet);
+void           cellregion_ref   (GnmCellRegion *content);
+void           cellregion_unref (GnmCellRegion *content);
+
+GnmCellCopy *gnm_cell_copy_new	(int col_offset, int row_offset);
+
+void clipboard_init (void);
+void clipboard_shutdown (void);
+
 
 #endif /* GNUMERIC_CLIPBOARD_H */
