@@ -39,6 +39,7 @@
 #include "ranges.h"
 #include "commands.h"
 #include "clipboard.h"
+#include "value.h"
 
 #include <gtk/gtk.h>
 
@@ -122,6 +123,9 @@ cb_compare_deps (gconstpointer a, gconstpointer b)
 	GnmCell const *cell_b = b;
 	int tmp;
 
+	if (cell_a->base.sheet != cell_b->base.sheet)
+		return cell_a->base.sheet->index_in_wb - cell_b->base.sheet->index_in_wb;
+
 	tmp = cell_a->pos.row - cell_b->pos.row;
 	if (tmp != 0)
 		return tmp;
@@ -146,16 +150,18 @@ cb_collect_deps (GnmDependent *dep, gpointer user)
 void
 sv_select_cur_depends (SheetView *sv)
 {
-	GnmCell  *cur_cell;
+	GnmCell  *cur_cell, dummy;
 	GList *deps = NULL, *ptr = NULL;
 
 	g_return_if_fail (IS_SHEET_VIEW (sv));
 
 	cur_cell = sheet_cell_get (sv->sheet,
-				   sv->edit_pos.col,
-				   sv->edit_pos.row);
-	if (cur_cell == NULL)
-		return;
+		sv->edit_pos.col, sv->edit_pos.row);
+	if (cur_cell == NULL) {
+		dummy.base.sheet = sv_sheet (sv);
+		dummy.pos = sv->edit_pos;
+		cur_cell = &dummy;
+	}
 
 	cell_foreach_dep (cur_cell, cb_collect_deps, &deps);
 	if (deps == NULL)
@@ -234,22 +240,50 @@ sv_select_cur_depends (SheetView *sv)
  *
  * Select all cells that are direct potential inputs to the
  * current cell.
- */
+ **/
 void
 sv_select_cur_inputs (SheetView *sv)
 {
-	GnmCell *cell;
+	GnmCell  *cell;
+	GSList   *ranges, *ptr;
+	GnmEvalPos ep;
 
 	g_return_if_fail (IS_SHEET_VIEW (sv));
 
 	cell = sheet_cell_get (sv->sheet,
-			       sv->edit_pos.col,
-			       sv->edit_pos.row);
-
+		sv->edit_pos.col, sv->edit_pos.row);
 	if (cell == NULL || !cell_has_expr (cell))
 		return;
+	ranges = gnm_expr_get_ranges (cell->base.expression);
+	if (ranges == NULL)
+		return;
+
+	ep.eval = sv->edit_pos;
+	ep.sheet = sv->sheet;
+	ep.dep = NULL;
+
+	sv_selection_reset (sv);
+	for (ptr = ranges ; ptr != NULL ; ptr = ptr->next) {
+		GnmValue *v = ptr->data;
+		GnmRangeRef const *r = value_get_rangeref (v);
+
+#warning "FIXME: What do we do in these 3D cases?"
+		if (r->a.sheet != r->b.sheet)
+			continue;
+		if (r->a.sheet != NULL && r->a.sheet != sv->sheet)
+			continue;
+
+		sv_selection_add_range (sv,
+					cellref_get_abs_col (&r->a, &ep),
+					cellref_get_abs_row (&r->a, &ep),
+					cellref_get_abs_col (&r->a, &ep),
+					cellref_get_abs_row (&r->a, &ep),
+					cellref_get_abs_col (&r->b, &ep),
+					cellref_get_abs_row (&r->b, &ep));
+		value_release (v);
+	}
+	g_slist_free (ranges);
 
-	/* TODO : finish this */
 	sheet_update (sv->sheet);
 }
 
@@ -303,7 +337,7 @@ cmd_paste (WorkbookControl *wbc, GnmPasteTarget const *pt)
 				(dst.end.row - dst.start.row)+1,
 				(dst.end.col - dst.start.col)+1,
 				rows+1, cols+1);
-			gnm_cmd_context_error_invalid (GNM_CMD_CONTEXT (wbc),
+			go_cmd_context_error_invalid (GO_CMD_CONTEXT (wbc),
 				_("Unable to paste into selection"), msg);
 			g_free (msg);
 			return;
@@ -341,7 +375,7 @@ cmd_paste_to_selection (WorkbookControl *wbc, SheetView *dest_sv, int paste_flag
 	GnmRange const *r;
 	GnmPasteTarget pt;
 
-	if (!(r = selection_first_range (dest_sv, GNM_CMD_CONTEXT (wbc), _("Paste"))))
+	if (!(r = selection_first_range (dest_sv, GO_CMD_CONTEXT (wbc), _("Paste"))))
 		return;
 
 	g_return_if_fail (r !=NULL);
