@@ -78,8 +78,7 @@ gboolean cmd_merge_cells	(WorkbookControl *wbc, Sheet *sheet,
 gboolean cmd_unmerge_cells	(WorkbookControl *wbc, Sheet *sheet,
 				 GSList const *selection);
 
-gboolean cmd_search_replace     (WorkbookControl *wbc, Sheet *sheet,
-				 GnmSearchReplace *sr);
+gboolean cmd_search_replace     (WorkbookControl *wbc, GnmSearchReplace *sr);
 
 gboolean cmd_colrow_std_size    (WorkbookControl *wbc, Sheet *sheet,
 				 gboolean is_cols, double new_default);
@@ -102,9 +101,11 @@ gboolean cmd_reorganize_sheets	(WorkbookControl *wbc, GSList *new_order,
 				 GSList *protection_changed, GSList *new_locks,
 				 GSList *visibility_changed, 
 				 GSList *new_visibility);
+gboolean cmd_reorganize_sheets2 (WorkbookControl *wbc,
+				 WorkbookSheetState *old_state);
 
 gboolean cmd_rename_sheet	(WorkbookControl *wbc, Sheet *sheet,
-				 char const *old_name, char const *new_name);
+				 char const *new_name);
 
 gboolean cmd_set_comment	(WorkbookControl *wbc, Sheet *sheet,
 				 GnmCellPos const *pos, const char *new_text);
