@@ -25,7 +25,8 @@
 #include "dialogs.h"
 
 #include <gui-util.h>
-#include <libfoocanvas/foo-canvas.h>
+#include <mathfunc.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-styled-object.h>
 #include <goffice/graph/gog-style.h>
@@ -35,7 +36,7 @@
 #include <goffice/graph/gog-series.h>
 #include <goffice/graph/gog-data-set.h>
 #include <goffice/graph/gog-control-foocanvas.h>
-#include <goffice/graph/go-data-simple.h>
+#include <goffice/data/go-data-simple.h>
 #include <goffice/utils/go-color.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkstock.h>
@@ -58,7 +59,7 @@ typedef enum {
 	GNM_PACKAGING		= 1 << 11
 } ContribTypes;
 #define GNM_ABOUT_NUM_TYPES	       12
-static char const *about_types[GNM_ABOUT_NUM_TYPES] = {
+static char const * const about_types[GNM_ABOUT_NUM_TYPES] = {
 	N_("Core"),
 	N_("Features"),
 	N_("Analytics"),
@@ -78,76 +79,88 @@ static struct {
 	unsigned contributions;
 	char const *details; /* optionally NULL */
 } const contributors[] = {
-	{ "Sean Atkinson",		GNM_ANALYTICS | GNM_IMPORT_EXPORT,
+	{ N_("Harald Ashburner"),		GNM_ANALYTICS,
+		N_("Options pricers") },
+	{ N_("Sean Atkinson"),		GNM_ANALYTICS | GNM_IMPORT_EXPORT,
 		N_("Functions and X-Base importing.") },
-	{ "Michel Berkelaar",		GNM_ANALYTICS,
+	{ N_("Michel Berkelaar"),		GNM_ANALYTICS,
 		N_("Simplex algorithm for Solver (LP Solve).") },
-	{ "Grandma Chema Celorio",	GNM_FEATURE_HACKER|GNM_USABILITY|GNM_QA,
+	{ N_("Jean Brefort"),		GNM_CORE | GNM_FEATURE_HACKER,
+		N_("Core charting engine.") },
+	{ N_("Grandma Chema Celorio"),	GNM_FEATURE_HACKER|GNM_USABILITY|GNM_QA,
 		N_("Quality Assurance and sheet copy.") },
-	{ "Frank Chiulli",		GNM_IMPORT_EXPORT,
+	{ N_("Frank Chiulli"),		GNM_IMPORT_EXPORT,
 		N_("OLE2 support.") },
-	{ "Kenneth Christiansen",	GNM_TRANSLATION,
+	{ N_("Kenneth Christiansen"),	GNM_TRANSLATION,
 		N_("Localization.") },
-	{ "Zbigniew Chyla",		GNM_CORE,
+	{ N_("Zbigniew Chyla"),		GNM_CORE,
 		N_("Plugin system, localization.") },
-	{ "J.H.M. Dassen (Ray)",	GNM_PACKAGING,
+	{ N_("J.H.M. Dassen (Ray)"),	GNM_PACKAGING,
 		N_("Debian packaging.") },
-	{ "Jeroen Dirks",		GNM_ANALYTICS,
+	{ N_("Jeroen Dirks"),		GNM_ANALYTICS,
 		N_("Simplex algorithm for Solver (LP Solve).") },
-	{ "Tom Dyas",			GNM_FEATURE_HACKER,
+	{ N_("Tom Dyas"),			GNM_FEATURE_HACKER,
 		N_("Original plugin engine.") },
-	{ "Gergo Erdi",			GNM_GUI,
+	{ N_("Gergo Erdi"),			GNM_GUI,
 		N_("Custom UI tools") },
-	{ "John Gotts",			GNM_PACKAGING,
+	{ N_("John Gotts"),			GNM_PACKAGING,
 		N_("RPM packaging") },
-	{ "Andreas J. G\xc3\xbclzow",	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
+	{ N_("Andreas J. G\xc3\xbclzow"),	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
 		N_("Statistics and GUI master") },
-	{ "Jon K\xc3\xa5re Hellan",	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_SCRIPTING|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
+	{ N_("Jon K\xc3\xa5re Hellan"),	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_SCRIPTING|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
 		N_("UI Polish and all round bug fixer") },
-	{ "Ross Ihaka",			GNM_ANALYTICS,
-		N_("pgamma fucntion") },
-	{ "Jukka-Pekka Iivonen",	GNM_ANALYTICS|GNM_GUI|GNM_FEATURE_HACKER,
+	{ N_("Ross Ihaka"),			GNM_ANALYTICS,
+		N_("Special functions") },
+	{ N_("Jukka-Pekka Iivonen"),	GNM_ANALYTICS|GNM_GUI|GNM_FEATURE_HACKER,
 		N_("Solver, lots of worksheet functions, and general trailblazer") },
-	{ "Jakub Jelinek",		GNM_CORE,
+	{ N_("Jakub Jelinek"),		GNM_CORE,
 		N_("One of the original core contributors") },
-	{ "Jakub Steiner",		GNM_ART,
+	{ N_("Jakub Steiner"),		GNM_ART,
 		N_("Icons and Images") },
-	{ "Chris Lahey",		GNM_FEATURE_HACKER,
-		N_("The original value format engine") },
-	{ "Takashi Matsuda",		GNM_FEATURE_HACKER,
+	{ N_("Chris Lahey"),		GNM_FEATURE_HACKER,
+		N_("The original value format engine and libgoffice work") },
+	{ N_("Takashi Matsuda"),		GNM_FEATURE_HACKER,
 		N_("The original text plugin") },
-	{ "Michael Meeks",		GNM_CORE|GNM_IMPORT_EXPORT,
+	{ N_("Michael Meeks"),		GNM_CORE|GNM_IMPORT_EXPORT,
 		N_("Started the MS Excel import/export engine, and 'GnmStyle'") },
-	{ "Lutz Muller",		GNM_FEATURE_HACKER,
+	{ N_("Lutz Muller"),		GNM_FEATURE_HACKER,
 		N_("SheetObject improvement") },
-	{ "Federico M. Quintero",	GNM_CORE,
+	{ N_("Yukihiro Nakai"),             GNM_FEATURE_HACKER | GNM_TRANSLATION | GNM_QA,
+	        N_("Support for non-Latin languages") },
+	{ N_("Emmanuel Pacaud"),		GNM_CORE | GNM_FEATURE_HACKER,
+		N_("Many plot types for charting engine.") },
+	{ N_("Federico M. Quintero"),	GNM_CORE,
 		N_("canvas support") },
-	{ "Mark Probst",		GNM_SCRIPTING,
+	{ N_("Mark Probst"),		GNM_SCRIPTING,
 		N_("Guile support") },
-	{ "Rasca",			GNM_IMPORT_EXPORT,
+	{ N_("Rasca"),			GNM_IMPORT_EXPORT,
 		N_("HTML, troff, LaTeX exporters") },
-	{ "Vincent Renardias",		GNM_IMPORT_EXPORT|GNM_TRANSLATION,
+	{ N_("Vincent Renardias"),		GNM_IMPORT_EXPORT|GNM_TRANSLATION,
 		N_("original CSV support, French localization") },
-	{ "Ariel Rios",			GNM_SCRIPTING,
+	{ N_("Ariel Rios"),			GNM_SCRIPTING,
 		N_("Guile support") },
-	{ "Arturo Tena",		GNM_IMPORT_EXPORT,
+	{ N_("Uwe Steinmann"),		GNM_FEATURE_HACKER|GNM_IMPORT_EXPORT,
+		N_("Paradox Importer") },
+	{ N_("Arturo Tena"),		GNM_IMPORT_EXPORT,
 		N_("Initial work on OLE2 for libgsf") },
-	{ "Almer S. Tigelaar",		GNM_FEATURE_HACKER|GNM_IMPORT_EXPORT,
+	{ N_("Almer S. Tigelaar"),		GNM_FEATURE_HACKER|GNM_IMPORT_EXPORT,
 		N_("Consolidation and Structured Text importer") },
-	{ "Bruno Unna",			GNM_IMPORT_EXPORT,
+	{ N_("Bruno Unna"),			GNM_IMPORT_EXPORT,
 		N_("Pieces of MS Excel import") },
-	{ "Daniel Veillard",		GNM_IMPORT_EXPORT,
+	{ N_("Arief Mulya Utama"),              GNM_ANALYTICS,
+		N_("Telecommunications functions") },
+	{ N_("Daniel Veillard"),		GNM_IMPORT_EXPORT,
 		N_("Initial XML support") },
-	{ "Vladimir Vuksan",		GNM_ANALYTICS,
+	{ N_("Vladimir Vuksan"),		GNM_ANALYTICS,
 		N_("Some financial functions") },
-	{ "Morten Welinder",		GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_SCRIPTING|GNM_GUI|GNM_USABILITY|GNM_TRANSLATION|GNM_QA,
+	{ N_("Morten Welinder"),		GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_SCRIPTING|GNM_GUI|GNM_USABILITY|GNM_TRANSLATION|GNM_QA,
 		N_("All round powerhouse") },
-	{ "Kevin Breit",		GNM_DOCUMENTATION, NULL },
-	{ "Thomas Canty",		GNM_DOCUMENTATION, NULL },
-	{ "Adrian Custer",		GNM_DOCUMENTATION, NULL },
-	{ "Adrian Likins",		GNM_DOCUMENTATION, NULL },
-	{ "Aaron Weber",		GNM_DOCUMENTATION, NULL },
-	{ "Alexander Kirillov",		GNM_DOCUMENTATION, NULL },
+	{ N_("Kevin Breit"),		GNM_DOCUMENTATION, NULL },
+	{ N_("Thomas Canty"),		GNM_DOCUMENTATION, NULL },
+	{ N_("Adrian Custer"),		GNM_DOCUMENTATION, NULL },
+	{ N_("Adrian Likins"),		GNM_DOCUMENTATION, NULL },
+	{ N_("Aaron Weber"),		GNM_DOCUMENTATION, NULL },
+	{ N_("Alexander Kirillov"),		GNM_DOCUMENTATION, NULL },
 };
 
 static void
@@ -196,7 +209,7 @@ gnm_about_state_free (GnmAboutState *state)
 	g_free (state);
 }
 
-#define FADE_STATES	15
+#define FADE_STATES	5
 #define MAX_FADE_STATE	(FADE_STATES*2)
 
 static gboolean
@@ -228,7 +241,7 @@ cb_about_animate (GnmAboutState *state)
 	state->contributor_style->font.color = UINT_RGBA_CHANGE_A (
 		state->contributor_style->font.color, (unsigned)(255 * (1. - alpha)));
 	go_data_scalar_str_set_str (GO_DATA_SCALAR_STR (state->contributor_name),
-		contributors [state->item_index].name, FALSE);
+		_(contributors [state->item_index].name), FALSE);
 	go_data_emit_changed (GO_DATA (state->contribs_data));
 	go_data_emit_changed (GO_DATA (state->individual_data));
 	return TRUE;
@@ -254,7 +267,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 		GTK_STOCK_OK,		GTK_RESPONSE_OK,
 		NULL);
 	state->fade_state = MAX_FADE_STATE;	/* prime things to start at item 0 */
-	state->item_index = -1;
+	state->item_index = (int) (random_01 () * G_N_ELEMENTS (contributors)) - 1;
 	state->dec = FALSE;
 	for (i = GNM_ABOUT_NUM_TYPES ; i-- > 0 ; )
 		state->contribs[i] = state->individual[i] = 0.;
@@ -271,12 +284,13 @@ dialog_about (WorkbookControlGUI *wbcg)
 		GOG_STYLED_OBJECT (state->graph)->style, 70.);
 #if 0
 	gog_style_set_fill_image_filename (GOG_STYLED_OBJECT (state->graph)->style,
-		gnumeric_icondir ("gnumeric-about.png"));
+		g_build_filename (gnm_icon_dir (), "gnumeric-about.png", NULL));
 #endif
 
 	/* A bar plot of the current contributors activities */
 	chart = gog_object_add_by_name (state->graph, "Chart", NULL);
-	GOG_STYLED_OBJECT (chart)->style->outline.width = -1;
+	GOG_STYLED_OBJECT (chart)->style->outline.dash_type = GO_LINE_NONE;
+	GOG_STYLED_OBJECT (chart)->style->outline.auto_dash = FALSE;
 	GOG_STYLED_OBJECT (chart)->style->fill.type = GOG_FILL_STYLE_NONE;
 	plot = gog_plot_new_by_name ("GogBarColPlot");
 	if (!plot) {
@@ -286,18 +300,19 @@ dialog_about (WorkbookControlGUI *wbcg)
 	}
 	g_object_set (G_OBJECT (plot),
 		"horizontal",			TRUE,
-		"vary_style_by_element",	TRUE,
+		"vary-style-by-element",	TRUE,
 		NULL);
 	gog_object_add_by_name (chart, "Plot", GOG_OBJECT (plot));
 	series = gog_plot_new_series (plot);
-	labels = go_data_vector_str_new ( about_types, G_N_ELEMENTS (about_types));
+	labels = go_data_vector_str_new ( about_types, G_N_ELEMENTS (about_types), NULL);
 	go_data_vector_str_set_translation_domain (GO_DATA_VECTOR_STR (labels), NULL);
 	g_object_ref (labels); /* set_dim absorbs the ref, add an extra for next plot */
 	gog_series_set_dim (series, 0, labels, NULL);
 	state->individual_data = go_data_vector_val_new (
-		state->individual, G_N_ELEMENTS (state->individual));
+		state->individual, G_N_ELEMENTS (state->individual), NULL);
 	gog_series_set_dim (series, 1, state->individual_data, NULL);
-	GOG_STYLED_OBJECT (series)->style->outline.width = -1;
+	GOG_STYLED_OBJECT (series)->style->outline.dash_type = GO_LINE_NONE;
+	GOG_STYLED_OBJECT (series)->style->outline.auto_dash = FALSE;
 	GOG_STYLED_OBJECT (series)->style->fill.type = GOG_FILL_STYLE_GRADIENT;
 	GOG_STYLED_OBJECT (series)->style->fill.gradient.dir = GO_GRADIENT_N_TO_S_MIRRORED;
 	gog_style_set_fill_brightness (
@@ -316,10 +331,11 @@ dialog_about (WorkbookControlGUI *wbcg)
 		"major-tick-labeled",	FALSE,
 		"major-tick-out",	FALSE,
 		NULL);
-	GOG_STYLED_OBJECT (tmp)->style->line.width = -1;
+	GOG_STYLED_OBJECT (tmp)->style->line.dash_type = GO_LINE_NONE;
+	GOG_STYLED_OBJECT (tmp)->style->line.auto_dash = FALSE;
 	tmp = gog_object_get_child_by_role (chart,
 		gog_object_find_role_by_name (chart, "Y-Axis"));
-	gog_style_set_font (GOG_STYLED_OBJECT (tmp)->style,
+	gog_style_set_font_desc (GOG_STYLED_OBJECT (tmp)->style,
 		pango_font_description_from_string ("Sans 10"));
 
 	tmp = gog_object_add_by_name (chart, "Title", NULL);
@@ -327,12 +343,13 @@ dialog_about (WorkbookControlGUI *wbcg)
 	state->contributor_name = go_data_scalar_str_new ("", FALSE);
 	gog_dataset_set_dim (GOG_DATASET (tmp), 0, state->contributor_name, NULL);
 	state->contributor_style = GOG_STYLED_OBJECT (tmp)->style;
-	gog_style_set_font (GOG_STYLED_OBJECT (tmp)->style,
+	gog_style_set_font_desc (GOG_STYLED_OBJECT (tmp)->style,
 		pango_font_description_from_string ("Sans Bold 10"));
 
 	/* A pie of the cumulative contributions */
 	chart = gog_object_add_by_name (state->graph, "Chart", NULL);
-	GOG_STYLED_OBJECT (chart)->style->outline.width = -1;
+	GOG_STYLED_OBJECT (chart)->style->outline.dash_type = GO_LINE_NONE;
+	GOG_STYLED_OBJECT (chart)->style->outline.auto_dash = FALSE;
 	GOG_STYLED_OBJECT (chart)->style->fill.type = GOG_FILL_STYLE_NONE;
 	gog_chart_set_position  (GOG_CHART (chart), 1, 0, 1, 1);
 	plot = gog_plot_new_by_name ("GogPiePlot");
@@ -345,9 +362,10 @@ dialog_about (WorkbookControlGUI *wbcg)
 	series = gog_plot_new_series (plot);
 	gog_series_set_dim (series, 0, labels, NULL);
 	state->contribs_data = go_data_vector_val_new (
-		state->contribs, G_N_ELEMENTS (state->contribs));
+		state->contribs, G_N_ELEMENTS (state->contribs), NULL);
 	gog_series_set_dim (series, 1, state->contribs_data, NULL);
-	GOG_STYLED_OBJECT (series)->style->outline.width = -1;
+	GOG_STYLED_OBJECT (series)->style->outline.dash_type = GO_LINE_NONE;
+	GOG_STYLED_OBJECT (series)->style->outline.auto_dash = FALSE;
 	GOG_STYLED_OBJECT (series)->style->fill.type = GOG_FILL_STYLE_GRADIENT;
 	GOG_STYLED_OBJECT (series)->style->fill.gradient.dir = GO_GRADIENT_NW_TO_SE;
 	gog_style_set_fill_brightness (
@@ -357,14 +375,15 @@ dialog_about (WorkbookControlGUI *wbcg)
 	gog_object_set_pos (tmp, GOG_POSITION_S | GOG_POSITION_ALIGN_END);
 	gog_dataset_set_dim (GOG_DATASET (tmp), 0,
 		go_data_scalar_str_new (
+			"Gnumeric " GNUMERIC_VERSION "\n"
 			"Copyright \xc2\xa9 2001-2004 Jody Goldberg\n"
 			"Copyright \xc2\xa9 1998-2000 Miguel de Icaza", FALSE),
 		NULL);
-	gog_style_set_font (GOG_STYLED_OBJECT (tmp)->style,
+	gog_style_set_font_desc (GOG_STYLED_OBJECT (tmp)->style,
 		pango_font_description_from_string ("Sans Bold 12"));
 
 	state->canvas = foo_canvas_new ();
-	gtk_widget_set_size_request (state->canvas, 400, 300);
+	gtk_widget_set_size_request (state->canvas, 450, 400);
 	foo_canvas_scroll_to (FOO_CANVAS (state->canvas), 0, 0);
 
 	state->ctrl = foo_canvas_item_new (foo_canvas_root (FOO_CANVAS (state->canvas)),
@@ -382,6 +401,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 	g_signal_connect (state->about, "response",
 		G_CALLBACK (gtk_widget_destroy), NULL);
 
-	state->timer = g_timeout_add (100,
-		(GSourceFunc) cb_about_animate, state);
+	state->timer = g_timeout_add_full (G_PRIORITY_LOW, 100,
+					   (GSourceFunc) cb_about_animate, state,
+					   NULL);
 }
