@@ -40,7 +40,7 @@
 #include <cell.h>
 #include <expr.h>
 #include <value.h>
-#include <format.h>
+#include <gnm-format.h>
 #include <pattern.h>
 #include <position.h>
 #include <mstyle.h>
@@ -55,10 +55,10 @@
 #include <widgets/gnumeric-expr-entry.h>
 #include <widgets/widget-font-selector.h>
 #include <widgets/gnumeric-dashed-canvas-line.h>
-#include <widgets/widget-format-selector.h>
-#include <goffice/gui-utils/go-combo-color.h>
-#include <goffice/gui-utils/go-combo-box.h>
-#include <goffice/gui-utils/go-combo-text.h>
+#include <widgets/gnm-format-sel.h>
+#include <goffice/gtk/go-combo-color.h>
+#include <goffice/gtk/go-combo-box.h>
+#include <goffice/gtk/go-combo-text.h>
 #include <goffice/utils/go-font.h>
 #include <libart_lgpl/art_alphagamma.h>
 #include <libart_lgpl/art_pixbuf.h>
@@ -78,11 +78,15 @@
 #include <gtk/gtktextview.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkicontheme.h>
 #include <gtk/gtkbox.h>
-#include <libgnomecanvas/gnome-canvas-util.h>
-#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
-#include <libgnomecanvas/gnome-canvas-pixbuf.h>
-#include <pango/pangoft2.h>
+#include <goffice/utils/go-glib-extras.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-util.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-line.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-pixbuf.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-rect-ellipse.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-widget.h>
 
 static struct {
 	char const *Cname;
@@ -157,7 +161,7 @@ typedef struct _FormatState
 	int	 	 selection_mask;
 	gboolean	 enable_edit;
 
-	GtkWidget *	number_format_selector;
+	GtkWidget *	format_sel;
 
 	struct {
 		GtkCheckButton	*wrap;
@@ -166,9 +170,11 @@ typedef struct _FormatState
 		int		 indent;
 
 		GtkSpinButton	*rotate_spinner;
-		GnomeCanvasItem *rotate_marks[13];
-		GnomeCanvasItem *line;
-		GnomeCanvasItem *text;
+		FooCanvas       *rotate_canvas;
+		FooCanvasItem   *rotate_marks[13];
+		FooCanvasItem   *line;
+		GtkWidget       *text_widget;
+		FooCanvasItem   *text;
 		int		 rot_width, rot_height;
 		int		 rotation;
 		gulong		 motion_handle;
@@ -178,10 +184,10 @@ typedef struct _FormatState
 		ColorPicker      color;
 	} font;
 	struct {
-		GnomeCanvas	*canvas;
+		FooCanvas	*canvas;
 		GtkButton 	*preset[BORDER_PRESET_MAX];
-		GnomeCanvasItem	*back;
-		GnomeCanvasItem *lines[20];
+		FooCanvasItem	*back;
+		FooCanvasItem *lines[20];
 
 		BorderPicker	 edge[STYLE_BORDER_EDGE_MAX];
 		ColorPicker      color;
@@ -307,7 +313,8 @@ cb_toggle_changed (GtkToggleButton *button, PatternPicker *picker)
  * and to adjust the relief so it looks nice.
  */
 static void
-setup_pattern_button (GladeXML  *gui,
+setup_pattern_button (GdkScreen *screen,
+		      GladeXML  *gui,
 		      char const *const name,
 		      PatternPicker *picker,
 		      gboolean const flag,
@@ -318,7 +325,11 @@ setup_pattern_button (GladeXML  *gui,
 	if (tmp != NULL) {
 		GtkButton *button = GTK_BUTTON (tmp);
 		if (flag) {
-			GtkWidget *image = gtk_image_new_from_pixbuf (gnm_app_get_pixbuf (name));
+			GdkPixbuf *pixbuf = gtk_icon_theme_load_icon (
+				gtk_icon_theme_get_for_screen (screen),
+				name, 16, 0, NULL);
+			GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
+			g_object_unref (pixbuf);
 			gtk_widget_show (image);
 			gtk_container_add (GTK_CONTAINER (tmp), image);
 		}
@@ -385,7 +396,7 @@ setup_color_pickers (ColorPicker *picker,
 	cg = go_color_group_fetch (color_group,
 		 wb_control_view (WORKBOOK_CONTROL (state->wbcg)));
 	combo = go_combo_color_new (NULL, default_caption, 
-		def_sc ? GDK_TO_UINT (def_sc->color) : RGBA_BLACK, cg);
+		def_sc ? GDK_TO_UINT (def_sc->gdk_color) : RGBA_BLACK, cg);
 	go_combo_box_set_title (GO_COMBO_BOX (combo), caption);
 
 	/* Connect to the sample canvas and redraw it */
@@ -394,7 +405,7 @@ setup_color_pickers (ColorPicker *picker,
 		G_CALLBACK (preview_update), state);
 
 	go_combo_color_set_color_gdk (GO_COMBO_COLOR (combo),
-		(mcolor && !mcolor->is_auto) ? &mcolor->color : NULL);
+		(mcolor && !mcolor->is_auto) ? &mcolor->gdk_color : NULL);
 
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
@@ -422,11 +433,16 @@ setup_color_pickers (ColorPicker *picker,
  * button of the same name.
  */
 static GtkWidget *
-init_button_image (GladeXML *gui, char const *const name)
+init_button_image (GladeXML *gui, char const *name)
 {
 	GtkWidget *tmp = glade_xml_get_widget (gui, name);
 	if (tmp != NULL) {
-		GtkWidget *image = gtk_image_new_from_pixbuf (gnm_app_get_pixbuf (name));
+		GdkScreen *screen = gtk_widget_get_screen (tmp);
+		GdkPixbuf *pixbuf = gtk_icon_theme_load_icon (
+			gtk_icon_theme_get_for_screen (screen),
+			name, 16, 0, NULL);
+		GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
 		gtk_widget_show (image);
 		gtk_container_add (GTK_CONTAINER (tmp), image);
 	}
@@ -460,28 +476,27 @@ cb_number_format_changed (G_GNUC_UNUSED GtkWidget *widget,
 static void
 fmt_dialog_init_format_page (FormatState *state)
 {
-	NumberFormatSelector *nfs;
+	GOFormatSel *gfs;
 
-	state->number_format_selector = number_format_selector_new ();
-	nfs = NUMBER_FORMAT_SELECTOR (state->number_format_selector);
+	state->format_sel = gnm_format_sel_new ();
+	gfs = GO_FORMAT_SEL (state->format_sel);
 
 	gtk_notebook_prepend_page (GTK_NOTEBOOK (state->notebook),
-				   state->number_format_selector,
+				   state->format_sel,
 				   gtk_label_new (_("Number")));
-	gtk_widget_show (GTK_WIDGET (nfs));
+	gtk_widget_show (GTK_WIDGET (gfs));
 
 	if (!mstyle_is_element_conflict (state->style, MSTYLE_FORMAT))
-		number_format_selector_set_style_format (nfs,
-							 mstyle_get_format (state->style));
+		go_format_sel_set_style_format (gfs,
+			mstyle_get_format (state->style));
 	if (state->value)
-		number_format_selector_set_value (nfs, state->value);
-	number_format_selector_set_date_conv (nfs,
-					      workbook_date_conv (state->sheet->workbook));
-	number_format_selector_editable_enters (nfs, GTK_WINDOW (state->dialog));
+		gnm_format_sel_set_value (gfs, state->value);
+	go_format_sel_set_dateconv (gfs,
+		workbook_date_conv (state->sheet->workbook));
+	go_format_sel_editable_enters (gfs, GTK_WINDOW (state->dialog));
 
-	g_signal_connect (G_OBJECT (state->number_format_selector),
-			  "number_format_changed",
-			  G_CALLBACK (cb_number_format_changed), state);
+	g_signal_connect (G_OBJECT (state->format_sel), "format_changed",
+		G_CALLBACK (cb_number_format_changed), state);
 }
 
 /*****************************************************************************/
@@ -569,191 +584,140 @@ fmt_dialog_init_align_radio (char const *const name,
 static void
 cb_rotate_changed (GtkEditable *editable, FormatState *state)
 {
-	double res[6], trans[6];
 	char const *colour;
 	int i;
 
 	if (editable != NULL && state->enable_edit) {
 		GtkSpinButton *sb = GTK_SPIN_BUTTON (editable);
-		int val = gtk_spin_button_get_value_as_int (sb);
+		int val = gtk_spin_button_get_value_as_int (sb) % 360;
 
 		if (state->align.rotation != val) {
 			state->align.rotation = val;
+			if (val < 0)
+				val += 360;
 			mstyle_set_rotation (state->result, val);
 			fmt_dialog_changed (state);
 		}
 	}
 
 	for (i = 0 ; i <= 12 ; i++)
-		if (state->align.rotate_marks [i] != NULL) {
+		if (state->align.rotate_marks[i] != NULL) {
 			colour = (state->align.rotation == (i-6)*15) ? "green" : "black";
-			gnome_canvas_item_set (state->align.rotate_marks [i],
-					       "fill_color",	colour,
-					       NULL);
+			foo_canvas_item_set (state->align.rotate_marks[i],
+					     "fill-color", colour,
+					     NULL);
 		}
 	if (state->align.line != NULL) {
-		GnomeCanvasPoints *points = gnome_canvas_points_new (2);
+		FooCanvasPoints *points = foo_canvas_points_new (2);
 		double rad = state->align.rotation * M_PIgnum / 180.;
-		points->coords [0] =  15 + cos (rad) * state->align.rot_width;
-		points->coords [1] = 100 - sin (rad) * state->align.rot_width;
-		points->coords [2] =  15 + cos (rad) * 72.;
-		points->coords [3] = 100 - sin (rad) * 72.;
-		gnome_canvas_item_set (state->align.line,
-				       "points", points,
-				       NULL);
-		gnome_canvas_points_free (points);
+		points->coords[0] =  15 + cos (rad) * state->align.rot_width;
+		points->coords[1] = 100 - sin (rad) * state->align.rot_width;
+		points->coords[2] =  15 + cos (rad) * 72.;
+		points->coords[3] = 100 - sin (rad) * 72.;
+		foo_canvas_item_set (state->align.line,
+				     "points", points,
+				     NULL);
+		foo_canvas_points_free (points);
 	}
 
 	if (state->align.text) {
-		art_affine_translate (trans, 0., -state->align.rot_height/2);
-		art_affine_rotate (res, -state->align.rotation);
-		art_affine_multiply (res, trans, res);
-		art_affine_translate (trans, 15., 100.);
-		art_affine_multiply (res, res, trans);
-		gnome_canvas_item_affine_absolute (state->align.text, res);
+		double x = 15.0;
+		double y = 100.0;
+		double rad = state->align.rotation * M_PIgnum / 180.;
+		x -= state->align.rot_height * sin (fabs (rad)) / 2;
+		y -= state->align.rot_height * cos (rad) / 2;
+		if (rad >= 0)
+			y -= state->align.rot_width * sin (rad);
+		foo_canvas_item_set (state->align.text,
+				     "x", x, "y", y,
+				     NULL);
+		gtk_label_set_angle (GTK_LABEL (state->align.text_widget),
+				     (state->align.rotation + 360) % 360);
 	}
 }
 
 static void
-cb_rotate_canvas_realize (GnomeCanvas *canvas, FormatState *state)
+cb_rotate_canvas_realize (FooCanvas *canvas, FormatState *state)
 {
-	GnomeCanvasItem *item;
-	GnomeCanvasGroup  *group;
-	double rad, x, y, size;
-	int i, bx, by;
-	gint w, h;
-	GdkPixbuf *pixbuf;
-	FT_Bitmap ft_bitmap;
-	PangoLayout *layout;
-	PangoContext *context;
-	PangoAttrList	*attrs;
-	PangoAttribute  *attr;
-	PangoFT2FontMap *font_map;
-	guint8 const *ps;
-	guint8 *pd;
-
+	FooCanvasGroup  *group = FOO_CANVAS_GROUP (foo_canvas_root (canvas));
+	int i;
 	GtkStyle *style = gtk_style_copy (GTK_WIDGET (canvas)->style);
 	style->bg[GTK_STATE_NORMAL] = style->white;
 	gtk_widget_set_style (GTK_WIDGET (canvas), style);
 	g_object_unref (style);
 
-	gnome_canvas_set_scroll_region (canvas, 0, 0, 100, 200);
-	gnome_canvas_scroll_to (canvas, 0, 0);
+	foo_canvas_set_scroll_region (canvas, 0, 0, 100, 200);
+	foo_canvas_scroll_to (canvas, 0, 0);
 
-	group = GNOME_CANVAS_GROUP (gnome_canvas_root (canvas));
 	for (i = 0 ; i <= 12 ; i++) {
-		rad = (i-6) * M_PIgnum / 12.;
-		x = 15 + cos (rad) * 80.;
-		y = 100 - sin (rad) * 80.;
-		size = (i % 3) ? 3 : 4;
-		item = gnome_canvas_item_new (group,
-			GNOME_TYPE_CANVAS_ELLIPSE,
-			"x1", x-size,	"y1", y-size,
-			"x2", x+size,	"y2", y+size,
-			"width_pixels", (int) 1,
-			"outline_color","black",
-			"fill_color",	"black",
-			NULL);
-		state->align.rotate_marks [i] = item;
+		double rad = (i-6) * M_PIgnum / 12.;
+		double x = 15 + cos (rad) * 80.;
+		double y = 100 - sin (rad) * 80.;
+		double size = (i % 3) ? 3.0 : 4.0;
+		FooCanvasItem *item =
+			foo_canvas_item_new (group,
+					     FOO_TYPE_CANVAS_ELLIPSE,
+					     "x1", x-size,	"y1", y-size,
+					     "x2", x+size,	"y2", y+size,
+					     "width-pixels", (int) 1,
+					     "outline-color","black",
+					     "fill-color",	"black",
+					     NULL);
+		state->align.rotate_marks[i] = item;
 	}
-	state->align.line = gnome_canvas_item_new (group,
-		GNOME_TYPE_CANVAS_LINE,
-		"fill_color",	"black",
+	state->align.line = foo_canvas_item_new (group,
+		FOO_TYPE_CANVAS_LINE,
+		"fill-color",	"black",
 		"width_units",	2.,
 		NULL);
-	state->align.text = gnome_canvas_item_new (group,
-		GNOME_TYPE_CANVAS_PIXBUF,
-		NULL);
 
-	font_map = PANGO_FT2_FONT_MAP (pango_ft2_font_map_new ());
-	pango_ft2_font_map_set_resolution (font_map,
-		gnm_app_display_dpi_get (TRUE),
-		gnm_app_display_dpi_get (FALSE));
-	context = pango_ft2_font_map_create_context (font_map);
-	// g_object_unref (font_map);
-	layout = pango_layout_new (context);
-	g_object_unref (context);
-	pango_layout_set_font_description (layout,
-		pango_context_get_font_description (gtk_widget_get_pango_context (GTK_WIDGET (canvas))));
-	pango_layout_set_text (layout, _("Text"), -1);
- 	attrs = pango_attr_list_new ();
-	attr = pango_attr_scale_new (1.3);
-	attr->start_index = 0;
-	attr->end_index = -1;
-	pango_attr_list_insert (attrs, attr);
-	pango_layout_set_attributes (layout, attrs);
-	pango_attr_list_unref (attrs);
-
-#if 0
-	w = h = 1;
-#else
-	pango_layout_get_pixel_size (layout, &w, &h);
+	{
+		int w, h;
+		GtkWidget *tw = state->align.text_widget = gtk_label_new (_("Text"));
+		PangoAttrList *attrs = pango_attr_list_new ();
+		PangoAttribute *attr = pango_attr_scale_new (1.3);
+		attr->start_index = 0;
+		attr->end_index = -1;
+		pango_attr_list_insert (attrs, attr);
+#ifdef DEBUG_ROTATION
+		attr = pango_attr_background_new (0xffff, 0, 0);
+		attr->start_index = 0;
+		attr->end_index = -1;
+		pango_attr_list_insert (attrs, attr);
 #endif
+		gtk_label_set_attributes (GTK_LABEL (tw), attrs);
+		pango_attr_list_unref (attrs);
 
-	if (w == 0 || h == 0)
-		goto out;
+		pango_layout_get_pixel_size (gtk_label_get_layout (GTK_LABEL (tw)), &w, &h);
+		state->align.rot_width  = w;
+		state->align.rot_height = h;
 
-	ft_bitmap.rows         = h;
-	ft_bitmap.width        = w;
-	ft_bitmap.pitch        = (w+3) & ~3;
-	ft_bitmap.buffer       = g_malloc0 (ft_bitmap.rows * ft_bitmap.pitch);
-	ft_bitmap.num_grays    = 256;
-	ft_bitmap.pixel_mode   = ft_pixel_mode_grays;
-	ft_bitmap.palette_mode = 0;
-	ft_bitmap.palette      = NULL;
-
-#if 1
-	pango_ft2_render_layout (&ft_bitmap, layout, 0, 0);
-#endif
-
-	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
-				 ft_bitmap.width, ft_bitmap.rows);
-	for (by = 0; by < ft_bitmap.rows; by++) {
-	        pd = gdk_pixbuf_get_pixels (pixbuf)
-			+ by * gdk_pixbuf_get_rowstride (pixbuf);
-		ps = ft_bitmap.buffer + by * ft_bitmap.pitch;
-		for (bx = 0; bx < ft_bitmap.width; bx++) {
-			*pd++ = 0;
-		        *pd++ = 0;
-			*pd++ = 0;
-			*pd++ = *ps++;
-		}
+		state->align.text = foo_canvas_item_new (group,
+							 FOO_TYPE_CANVAS_WIDGET,
+							 "widget", tw,
+							 NULL);
+		gtk_widget_show (tw);
 	}
-	g_free (ft_bitmap.buffer);
 
-	gnome_canvas_item_set (state->align.text,
-		"pixbuf",	pixbuf,
-		NULL);
-	g_object_unref (G_OBJECT (pixbuf));
-	state->align.rot_width  = w;
-	state->align.rot_height = h;
 	cb_rotate_changed (NULL, state);
-
- out:
-	g_object_unref (layout);
-
-	/* See http://bugzilla.gnome.org/show_bug.cgi?id=143542  */
-	go_pango_fc_font_map_cache_clear (PANGO_FC_FONT_MAP (font_map));
-
-	g_object_unref (font_map);
 }
 
 static void
-set_rot_from_point (FormatState *state, GnomeCanvas *canvas, double x, double y)
+set_rot_from_point (FormatState *state, FooCanvas *canvas, double x, double y)
 {
 	double degrees;
-	gnome_canvas_window_to_world (canvas, x, y, &x, &y);
+	foo_canvas_window_to_world (canvas, x, y, &x, &y);
 	x -= 15.;	if (x < 0.) x = 0.;
 	y -= 100.;
 
 	degrees = atan2 (-y, x) * 180 / M_PIgnum;
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->align.rotate_spinner),
-				   gnumeric_fake_round (degrees));
+				   gnm_fake_round (degrees));
 }
 
 static gboolean
-cb_rotate_motion_notify_event (GnomeCanvas *canvas, GdkEventMotion *event,
+cb_rotate_motion_notify_event (FooCanvas *canvas, GdkEventMotion *event,
 			       FormatState *state)
 {
 	set_rot_from_point (state, canvas, event->x, event->y);
@@ -761,7 +725,7 @@ cb_rotate_motion_notify_event (GnomeCanvas *canvas, GdkEventMotion *event,
 }
 
 static gboolean
-cb_rotate_canvas_button (GnomeCanvas *canvas, GdkEventButton *event,
+cb_rotate_canvas_button (FooCanvas *canvas, GdkEventButton *event,
 			 FormatState *state)
 {
 	if (event->type == GDK_BUTTON_PRESS) {
@@ -812,6 +776,7 @@ fmt_dialog_init_align_page (FormatState *state)
 	    { "valign_center", VALIGN_CENTER },
 	    { "valign_bottom", VALIGN_BOTTOM },
 	    { "valign_justify", VALIGN_JUSTIFY },
+	    { "valign_distributed", VALIGN_DISTRIBUTED },
 	    { NULL }
 	};
 
@@ -879,6 +844,7 @@ fmt_dialog_init_align_page (FormatState *state)
 	/* setup the rotation canvas */
 	state->align.line = NULL;
 	state->align.text = NULL;
+	state->align.text_widget = NULL;
 	state->align.rotation =
 		mstyle_is_element_conflict (state->style, MSTYLE_ROTATION)
 		? 0
@@ -892,7 +858,7 @@ fmt_dialog_init_align_page (FormatState *state)
 		G_CALLBACK (cb_rotate_changed), state);
 
 	state->align.motion_handle = 0;
-	w = glade_xml_get_widget (state->gui, "rotate_canvas");
+	w = GTK_WIDGET (state->align.rotate_canvas);
 	g_signal_connect (G_OBJECT (w),
 		"realize",
 		G_CALLBACK (cb_rotate_canvas_realize), state);
@@ -986,7 +952,7 @@ cb_font_underline_changed (G_GNUC_UNUSED GtkWidget *ct,
 		return FALSE;
 
 	for (i = G_N_ELEMENTS (underline_types); i-- > 0; )
-		if (gnm_utf8_collate_casefold (new_text, _(underline_types[i].Cname)) == 0) {
+		if (go_utf8_collate_casefold (new_text, _(underline_types[i].Cname)) == 0) {
 			res = underline_types[i].ut;
 			break;
 		}
@@ -1286,9 +1252,9 @@ border_format_has_changed (FormatState *state, BorderPicker *edge)
 		for (i = 0; line_info[i].states != 0 ; ++i ) {
 			if (line_info[i].location == edge->index &&
 			    state->border.lines[i] != NULL)
-				gnome_canvas_item_set (
-					GNOME_CANVAS_ITEM (state->border.lines[i]),
-					"fill_color_rgba", edge->rgba,
+				foo_canvas_item_set (
+					FOO_CANVAS_ITEM (state->border.lines[i]),
+					"fill-color-rgba", edge->rgba,
 					NULL);
 		}
 	}
@@ -1432,27 +1398,31 @@ draw_border_preview (FormatState *state)
 
 	/* The first time through lets initialize */
 	if (state->border.canvas == NULL) {
-		GnomeCanvasGroup  *group;
-		GnomeCanvasPoints *points;
+		FooCanvasGroup  *group;
+		FooCanvasPoints *points;
 
-		state->border.canvas =
-			GNOME_CANVAS (glade_xml_get_widget (state->gui, "border_sample"));
-		group = GNOME_CANVAS_GROUP (gnome_canvas_root (state->border.canvas));
+		state->border.canvas = FOO_CANVAS (foo_canvas_new ());
+		gtk_widget_show (GTK_WIDGET (state->border.canvas));
+		gtk_widget_set_size_request (GTK_WIDGET (state->border.canvas),
+					     150, 100);
+		gtk_container_add (GTK_CONTAINER (glade_xml_get_widget (state->gui, "border_sample_container")),
+				   GTK_WIDGET (state->border.canvas));
+		group = FOO_CANVAS_GROUP (foo_canvas_root (state->border.canvas));
 
 		g_signal_connect (G_OBJECT (state->border.canvas),
 			"button-press-event",
 			G_CALLBACK (border_event), state);
 
-		state->border.back = gnome_canvas_item_new (group,
-			GNOME_TYPE_CANVAS_RECT,
+		state->border.back = foo_canvas_item_new (group,
+			FOO_TYPE_CANVAS_RECT,
 			"x1", L-10.,	"y1", T-10.,
 			"x2", R+10.,	"y2", B+10.,
-			"width_pixels", (int) 0,
-			"fill_color",	"white",
+			"width-pixels", (int) 0,
+			"fill-color",	"white",
 			NULL);
 
 		/* Draw the corners */
-		points = gnome_canvas_points_new (3);
+		points = foo_canvas_points_new (3);
 
 		for (i = 0; i < 12 ; ++i) {
 			if (i >= 8) {
@@ -1466,16 +1436,16 @@ draw_border_preview (FormatState *state)
 			for (j = 6 ; --j >= 0 ;)
 				points->coords[j] = corners[i][j];
 
-			gnome_canvas_item_new (group,
-					       gnome_canvas_line_get_type (),
-					       "width_pixels",	(int) 0,
-					       "fill_color",	"gray63",
+			foo_canvas_item_new (group,
+					       foo_canvas_line_get_type (),
+					       "width-pixels",	(int) 0,
+					       "fill-color",	"gray63",
 					       "points",	points,
 					       NULL);
 		}
-		gnome_canvas_points_free (points);
+		foo_canvas_points_free (points);
 
-		points = gnome_canvas_points_new (2);
+		points = foo_canvas_points_new (2);
 		for (i = 0; line_info[i].states != 0 ; ++i ) {
 			for (j = 4; --j >= 0 ; )
 				points->coords[j] = line_info[i].points[j];
@@ -1484,9 +1454,9 @@ draw_border_preview (FormatState *state)
 				BorderPicker const *p =
 				    & state->border.edge[line_info[i].location];
 				state->border.lines[i] =
-					gnome_canvas_item_new (group,
+					foo_canvas_item_new (group,
 							       gnumeric_dashed_canvas_line_get_type (),
-							       "fill_color_rgba", p->rgba,
+							       "fill-color-rgba", p->rgba,
 							       "points",	  points,
 							       NULL);
 				gnumeric_dashed_canvas_line_set_dash_index (
@@ -1495,13 +1465,13 @@ draw_border_preview (FormatState *state)
 			} else
 				state->border.lines[i] = NULL;
 		}
-		gnome_canvas_points_free (points);
+		foo_canvas_points_free (points);
 	}
 
 	for (i = 0; i < STYLE_BORDER_EDGE_MAX; ++i) {
 		BorderPicker *border = &state->border.edge[i];
-		void (*func)(GnomeCanvasItem *item) = border->is_selected
-			? &gnome_canvas_item_show : &gnome_canvas_item_hide;
+		void (*func)(FooCanvasItem *item) = border->is_selected
+			? &foo_canvas_item_show : &foo_canvas_item_hide;
 
 		for (j = 0; line_info[j].states != 0 ; ++j) {
 			if ((int)line_info[j].location == i &&
@@ -1618,10 +1588,10 @@ init_border_button (FormatState *state, StyleBorderLocation const i,
 		state->border.edge[i].is_selected = TRUE;
 	} else {
 		GnmColor const *c = border->color;
-		state->border.edge[i].rgba =
-		    GNOME_CANVAS_COLOR (c->color.red >> 8,
-					c->color.green >> 8,
-					c->color.blue >> 8);
+		state->border.edge[i].rgba = FOO_CANVAS_COLOR (
+			c->gdk_color.red >> 8,
+			c->gdk_color.green >> 8,
+			c->gdk_color.blue >> 8);
 		state->border.edge[i].is_auto_color = c->is_auto;
 		state->border.edge[i].pattern_index = border->line_type;
 		state->border.edge[i].is_selected = (border->line_type != STYLE_BORDER_NONE);
@@ -1744,10 +1714,11 @@ validation_rebuild_validation (FormatState *state)
 								 state->validation.expr0.entry);
 		GnmExpr const *expr1 = NULL;
 
-
-
 		if (expr0 != NULL) {
-			if (op == VALIDATION_OP_BETWEEN || op == VALIDATION_OP_NOT_BETWEEN) {
+			if (type == VALIDATION_TYPE_CUSTOM || type == VALIDATION_TYPE_IN_LIST) {
+				state->validation.valid = 1;
+				op = VALIDATION_OP_NONE;
+			} else if (op == VALIDATION_OP_BETWEEN || op == VALIDATION_OP_NOT_BETWEEN) {
 				expr1 = validation_entry_to_expr (state->sheet, state->validation.expr1.entry);
 				if (expr1 != NULL)
 					state->validation.valid = 2;
@@ -2123,9 +2094,10 @@ cb_fmt_dialog_dialog_buttons (GtkWidget *btn, FormatState *state)
 			validation_rebuild_validation (state);
 
 		if (state->validation.valid < 0) {
-			if (gnumeric_dialog_question_yes_no (
+			if (go_gtk_query_yes_no (
 				    GTK_WINDOW (state->dialog),
-				    _ ("The validation criteria are unusable. Disable validation?"), FALSE))
+				    FALSE,
+				    _ ("The validation criteria are unusable. Disable validation?")))
 			{
 				gtk_combo_box_set_active (state->validation.constraint_type, 0);
 				cb_validation_sensitivity (NULL, state);
@@ -2143,7 +2115,6 @@ cb_fmt_dialog_dialog_buttons (GtkWidget *btn, FormatState *state)
 		if (state->protection.sheet_protected_changed) {
 			WorkbookView *wbv = wb_control_view (WORKBOOK_CONTROL (state->wbcg));
 			wbv->is_protected = state->protection.sheet_protected_value;
-			wb_view_prefs_update (wbv);
 			state->protection.sheet_protected_changed = FALSE;
 		}
 
@@ -2204,12 +2175,10 @@ set_initial_focus (FormatState *s)
 	pagew = gtk_notebook_get_nth_page (s->notebook, fmt_dialog_page);
 	name = gtk_widget_get_name (pagew);
 
-	if (strcmp (name, "number_box") == 0)
-	{
-		number_format_selector_set_focus (NUMBER_FORMAT_SELECTOR(s->number_format_selector));
+	if (strcmp (name, "number_box") == 0) {
+		go_format_sel_set_focus (GO_FORMAT_SEL (s->format_sel));
 		return;
-	}
-	else if (strcmp (name, "alignment_box") == 0)
+	} else if (strcmp (name, "alignment_box") == 0)
 	      focus_widget = glade_xml_get_widget (s->gui, "halign_left");
 	else if (strcmp (name, "font_box") == 0)
 	      focus_widget = GTK_WIDGET (s->font.selector);
@@ -2337,7 +2306,6 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 
 	default_border_color = &GTK_WIDGET (state->dialog)->style->black;
 
-
 	if (pageno == FD_CURRENT)
 		pageno = fmt_dialog_page;
 	gtk_notebook_set_current_page (state->notebook, pageno);
@@ -2353,7 +2321,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	for (i = MSTYLE_BORDER_TOP; i < MSTYLE_BORDER_DIAGONAL; i++) {
 		GnmBorder const *border = mstyle_get_border (state->style, i);
 		if (!style_border_is_blank (border)) {
-			default_border_color = &border->color->color;
+			default_border_color = &border->color->gdk_color;
 			default_border_style = border->line_type;
 			break;
 		}
@@ -2362,15 +2330,16 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	state->border.pattern.draw_preview = NULL;
 	state->border.pattern.current_pattern = NULL;
 	state->border.pattern.state = state;
-	state->border.rgba = GNOME_CANVAS_COLOR (
+	state->border.rgba = FOO_CANVAS_COLOR (
 		default_border_color->red   >> 8,
 		default_border_color->green >> 8,
 		default_border_color->blue  >> 8);
 	for (i = 0; (name = line_pattern_buttons[i].name) != NULL; ++i)
-		setup_pattern_button (state->gui, name, &state->border.pattern,
-			i != 0, /* No image for None */
-			line_pattern_buttons[i].pattern,
-			default_border_style);
+		setup_pattern_button (gtk_widget_get_screen (GTK_WIDGET (state->dialog)),
+				      state->gui, name, &state->border.pattern,
+				      i != 0, /* No image for None */
+				      line_pattern_buttons[i].pattern,
+				      default_border_style);
 
 	setup_color_pickers (&state->border.color, "border_color_group",
 			     "border_color_hbox",	"border_color_label",
@@ -2424,7 +2393,8 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	state->back.pattern.current_pattern = NULL;
 	state->back.pattern.state = state;
 	for (i = 0; (name = pattern_buttons[i]) != NULL; ++i)
-		setup_pattern_button (state->gui, name,
+		setup_pattern_button (gtk_widget_get_screen (GTK_WIDGET (state->dialog)),
+				      state->gui, name,
 				      &state->back.pattern, TRUE,
 				      i+1, /* Pattern #s start at 1 */
 				      selected);
@@ -2493,7 +2463,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify)cb_fmt_dialog_dialog_destroy);
 	wbcg_edit_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
-	gnumeric_non_modal_dialog (wbcg_toplevel (state->wbcg),
+	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 				   GTK_WINDOW (state->dialog));
 	gtk_widget_show (GTK_WIDGET (state->dialog));
 }
@@ -2533,7 +2503,7 @@ dialog_cell_format (WorkbookControlGUI *wbcg, FormatDialogPosition_t pageno)
 
 	g_return_if_fail (wbcg != NULL);
 
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"cell-format.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -2544,6 +2514,10 @@ dialog_cell_format (WorkbookControlGUI *wbcg, FormatDialogPosition_t pageno)
 	state->gui	= gui;
 	state->sv	= wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
 	state->sheet	= sv_sheet (state->sv);
+	state->align.rotate_canvas = FOO_CANVAS (foo_canvas_new ());
+	gtk_container_add (GTK_CONTAINER (glade_xml_get_widget (state->gui, "rotate_canvas_container")),
+			   GTK_WIDGET (state->align.rotate_canvas));
+	gtk_widget_show (GTK_WIDGET (state->align.rotate_canvas));
 
 	edit_cell = sheet_cell_get (state->sheet,
 				    state->sv->edit_pos.col,
