@@ -1176,7 +1176,7 @@ dialog_cell_sort (WorkbookControlGUI *wbcg)
 	if (gnumeric_dialog_raise_if_exists (wbcg, CELL_SORT_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"cell-sort.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -1201,7 +1201,7 @@ dialog_cell_sort (WorkbookControlGUI *wbcg)
                                              GTK_ICON_SIZE_LARGE_TOOLBAR,
                                              "Gnumeric-Cell-Sort");
 	if (dialog_init (state)) {
-		gnumeric_notice (wbcg, GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
 				 _("Could not create the Cell-Sort dialog."));
 		g_free (state);
 		return;
