@@ -40,7 +40,7 @@
 #include <expr.h>
 #include <expr-impl.h>
 #include <func.h>
-#include <format.h>
+#include <gnm-format.h>
 #include <widgets/gnumeric-expr-entry.h>
 #include <widgets/gnumeric-cell-renderer-expr-entry.h>
 
@@ -926,7 +926,7 @@ dialog_formula_guru (WorkbookControlGUI *wbcg, GnmFunc const *fd)
 	}
 
 	/* Get the dialog and check for errors */
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"formula-guru.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
@@ -972,7 +972,7 @@ dialog_formula_guru (WorkbookControlGUI *wbcg, GnmFunc const *fd)
 	state->dialog = glade_xml_get_widget (state->gui, "formula_guru");
 
 	if (dialog_formula_guru_init (state)) {
-		gnumeric_notice (wbcg, GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
 				 _("Could not create the formula guru."));
 		g_free (state);
 		return;
