@@ -37,7 +37,7 @@
 #include <sheet-style.h>
 #include <value.h>
 #include <workbook-edit.h>
-#include <glib/gi18n.h>
+#include <goffice/utils/go-file.h>
 
 #include <gtk/gtkbox.h>
 #include <gtk/gtkimage.h>
@@ -49,6 +49,8 @@
 #include <gtk/gtkcelllayout.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcellrendererpixbuf.h>
+#include <glib/gi18n.h>
+
 #include <string.h>
 
 typedef struct {
@@ -66,13 +68,6 @@ typedef struct {
 	gboolean   is_new;
 } HyperlinkState;
 
-/*
- * FIXME: The special GUI for email is nice, but it really requires proper
- * URL escaping/unescaping (not much code) and RFC 2047 header
- * encoding/decoding (much code). Disable for now.
- */
-#define GNM_NO_MAILTO
-
 static void
 dhl_free (HyperlinkState *state)
 {
@@ -144,7 +139,7 @@ dhl_get_target_cur_wb (HyperlinkState *state, gboolean *success)
 			ret = (char *) target;
 			value_release (val);
 		} else {
-			gnumeric_notice (GTK_WINDOW (state->dialog), 
+			go_gtk_notice_dialog (GTK_WINDOW (state->dialog), 
 					 GTK_MESSAGE_ERROR,
 					 _("Not a range or name"));
 			gnm_expr_entry_grab_focus (gee, TRUE);
@@ -171,6 +166,64 @@ dhl_get_target_external (HyperlinkState *state, gboolean *success)
 	return strlen (target) > 0 ? target : NULL;
 }
 
+static void
+dhl_set_target_email (HyperlinkState *state, const char* const target)
+{
+	GtkWidget *w = glade_xml_get_widget (state->gui, "email-address");
+	GtkWidget *w2 = glade_xml_get_widget (state->gui, "email-subject");
+	gchar* cursor;
+	gchar* subject;
+	gchar* guitext;
+
+	if (!target || *target == '\0')
+		return;
+
+	if( strncmp (target, "mailto:", strlen ("mailto:")) != 0)
+		return;
+
+	cursor = g_strdup (target + strlen ("mailto:"));
+
+	subject = strstr (cursor, "?subject=");
+	if (subject) {
+		gtk_entry_set_text (GTK_ENTRY (w2), subject + strlen ("?subject="));
+		*subject = '\0';
+	}
+
+	guitext = go_url_decode (cursor);
+
+	gtk_entry_set_text (GTK_ENTRY (w), guitext);
+
+	g_free (guitext);
+	g_free (cursor);
+}
+
+static const char*
+dhl_get_target_email (HyperlinkState *state, gboolean *success)
+{
+	GtkWidget *w = glade_xml_get_widget (state->gui, "email-address");
+	GtkWidget *w2 = glade_xml_get_widget (state->gui, "email-subject");
+	const char *address = gtk_entry_get_text (GTK_ENTRY (w));
+	const char *subject = gtk_entry_get_text (GTK_ENTRY (w2));
+	gchar* encoded;
+	gchar* result;
+
+	*success = TRUE;
+	if (!address || *address == '\0') {
+		return NULL;
+	}
+
+	if (!subject || *subject == '\0') {
+		return g_strconcat ("mailto:", address, NULL);
+	}
+
+	encoded = go_url_encode ((char*)subject);
+
+	result = g_strconcat ("mailto:", address, "?subject=", encoded, NULL);
+	g_free (encoded);
+
+	return result;
+}
+
 static void
 dhl_set_target_url (HyperlinkState *state, const char* const target)
 {
@@ -209,11 +262,11 @@ static struct {
 	  N_("Open an external file with the specified name"),
 	  dhl_set_target_external,
 	  dhl_get_target_external },
-#ifndef GNM_NO_MAILTO
-	{ N_("Send _Email"),	"Gnumeric_Link_EMail",
+	{ N_("Email Link"),	"Gnumeric_Link_EMail",
 	  "GnmHLinkEMail",	"email-box" ,
-	  N_("Prepare an email"), NULL },
-#endif
+	  N_("Prepare an email"),
+	  dhl_set_target_email,
+	  dhl_get_target_email },
 	{ N_("Web Link"),		"Gnumeric_Link_URL",
 	  "GnmHLinkURL",	"url-box" ,
 	  N_("Browse to the specified URL"),
@@ -459,7 +512,7 @@ dialog_hyperlink (WorkbookControlGUI *wbcg, SheetControl *sc)
 	if (gnumeric_dialog_raise_if_exists (wbcg, DIALOG_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"hyperlink.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -486,7 +539,7 @@ dialog_hyperlink (WorkbookControlGUI *wbcg, SheetControl *sc)
 
 	state->link = link;
 	if (dhl_init (state)) {
-		gnumeric_notice (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
 				 _("Could not create the hyperlink dialog."));
 		g_free (state);
 		return;
@@ -502,7 +555,7 @@ dialog_hyperlink (WorkbookControlGUI *wbcg, SheetControl *sc)
 			       DIALOG_KEY);
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) dhl_free);
-	gnumeric_non_modal_dialog (wbcg_toplevel (state->wbcg),
+	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 				   GTK_WINDOW (state->dialog));
 	wbcg_edit_attach_guru (state->wbcg, state->dialog);
 	gtk_widget_show (state->dialog);
