@@ -251,9 +251,8 @@ cb_merge_merge_clicked (G_GNUC_UNUSED GtkWidget *ignore,
 		g_free (field_string);
 
 		g_return_if_fail (v_data != NULL && v_field != NULL);
-		if (!global_range_contained (v_field, v_zone)) {
+		if (!global_range_contained (state->sheet, v_field, v_zone))
 			field_problems++;
-		}
 		data_list = g_slist_prepend (data_list, v_data);
 		field_list = g_slist_prepend (field_list, v_field);
 		n++;
@@ -266,7 +265,7 @@ cb_merge_merge_clicked (G_GNUC_UNUSED GtkWidget *ignore,
 		else
 			text = g_strdup_printf (_("%i fields are not part of the merge zone!"),
 						field_problems);
-		gnumeric_notice_nonmodal ((GtkWindow *) state->dialog,
+		go_gtk_notice_nonmodal_dialog ((GtkWindow *) state->dialog,
 					  &(state->warning_dialog),
 					  GTK_MESSAGE_ERROR,
 					  text);
@@ -286,8 +285,8 @@ cb_merge_merge_clicked (G_GNUC_UNUSED GtkWidget *ignore,
 						"%i and proceed?"), min_length, max_length,
 					      min_length);
 
-		if (gnumeric_dialog_question_yes_no (
-			    GTK_WINDOW (state->dialog), text, TRUE)) {
+		if (go_gtk_query_yes_no (
+			    GTK_WINDOW (state->dialog), TRUE, text)) {
 			g_slist_foreach (data_list, cb_merge_trim_data, &min_length);
 			g_free (text);
 		} else {
@@ -329,7 +328,7 @@ dialog_merge (WorkbookControlGUI *wbcg)
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, MERGE_KEY))
 		return;
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"merge.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -449,7 +448,7 @@ dialog_merge (WorkbookControlGUI *wbcg)
 	/* a candidate for merging into attach guru */
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_merge_destroy);
-	gnumeric_non_modal_dialog (wbcg_toplevel (state->wbcg),
+	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 				   GTK_WINDOW (state->dialog));
 	wbcg_edit_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
 	gtk_widget_show_all (GTK_WIDGET (state->dialog));
