@@ -42,11 +42,11 @@
 #include <libgnomeprintui/gnome-print-paper-selector.h>
 #include <libgnomeprintui/gnome-print-unit-selector.h>
 
-#include <libfoocanvas/foo-canvas.h>
-#include <libfoocanvas/foo-canvas-util.h>
-#include <libfoocanvas/foo-canvas-line.h>
-#include <libfoocanvas/foo-canvas-text.h>
-#include <libfoocanvas/foo-canvas-rect-ellipse.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-util.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-line.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-text.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-rect-ellipse.h>
 #include <glade/glade.h>
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtknotebook.h>
@@ -135,6 +135,7 @@ typedef struct {
 	Sheet            *sheet;
 	GladeXML         *gui;
 	PrintInformation *pi;
+	GnomePrintConfig *gp_config;
 	GtkWidget        *dialog;
 	GtkWidget        *sheet_selector;
 	GtkWidget        *unit_selector;
@@ -216,8 +217,7 @@ get_paper_pswidth (PrinterSetupState *state)
 {
 	double height;
 	double width;
-	if (gnome_print_job_get_page_size_from_config (state->pi->print_config,
-							  &width, &height))
+	if (gnome_print_config_get_page_size (state->gp_config, &width, &height))
 		return width;
 	else
 		return 1.0;
@@ -234,8 +234,7 @@ get_paper_psheight (PrinterSetupState *state)
 {
 	double height;
 	double width;
-	if (gnome_print_job_get_page_size_from_config (state->pi->print_config,
-							  &width, &height))
+	if (gnome_print_config_get_page_size (state->gp_config, &width, &height))
 		return height;
 	else
 		return 0.0;
@@ -328,8 +327,8 @@ make_line (FooCanvasGroup *g, double x1, double y1, double x2, double y2)
 	item = foo_canvas_item_new (
 		FOO_CANVAS_GROUP (g), foo_canvas_line_get_type (),
 		"points", points,
-		"width_pixels", 1,
-		"fill_color",   MARGIN_COLOR_DEFAULT,
+		"width-pixels", 1,
+		"fill-color",   MARGIN_COLOR_DEFAULT,
 		NULL);
 	foo_canvas_points_unref (points);
 
@@ -475,9 +474,9 @@ preview_page_create (PrinterSetupState *state)
 		"y1",  	      	 (double) y1+2,
 		"x2",  	      	 (double) x2+2,
 		"y2",         	 (double) y2+2,
-		"fill_color",    "black",
-		"outline_color", "black",
-		"width_pixels",   1,
+		"fill-color",    "black",
+		"outline-color", "black",
+		"width-pixels",   1,
 		NULL);
 
 	foo_canvas_item_new (FOO_CANVAS_GROUP (pi->group),
@@ -486,44 +485,14 @@ preview_page_create (PrinterSetupState *state)
 		"y1",  	      	 (double) y1,
 		"x2",  	      	 (double) x2,
 		"y2",         	 (double) y2,
-		"fill_color",    "white",
-		"outline_color", "black",
-		"width_pixels",   1,
+		"fill-color",    "white",
+		"outline-color", "black",
+		"width-pixels",   1,
 		NULL);
 
 	draw_margins (state, x1, y1, x2, y2);
 }
 
-static void
-canvas_update (PrinterSetupState *state)
-{
-	guchar *unit_txt;
-
-	preview_page_destroy (state);
-	preview_page_create (state);
-	set_vertical_bounds (state);
-
-	unit_txt = gnome_print_config_get (state->pi->print_config, GNOME_PRINT_KEY_PREFERED_UNIT);
-	if (unit_txt) {
-		gnome_print_unit_selector_set_unit (GNOME_PRINT_UNIT_SELECTOR
-						    (state->unit_selector),
-						    gnome_print_unit_get_by_abbreviation
-						    (unit_txt));
-		g_free (unit_txt);
-	}
-
-}
-
-static void
-notebook_flipped (G_GNUC_UNUSED GtkNotebook *notebook,
-		  G_GNUC_UNUSED GtkNotebookPage *page,
-		  gint page_num,
-		  PrinterSetupState *state)
-{
-	if (page_num == HF_PAGE)
-		canvas_update (state);
-}
-
 /**
  * spin_button_adapt_to_unit
  * @spin      spinbutton
@@ -550,7 +519,7 @@ spin_button_adapt_to_unit (GtkSpinButton *spin, const GnomePrintUnit *new_unit)
 	adjustment = gtk_spin_button_get_adjustment (spin);
 	g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
 
-	if (new_unit->unittobase <= 1) {
+	if (new_unit->unittobase <= 3) {
 		/* "mm" and "pt" */
 		step_increment = 1.0;
 		digits = 1;
@@ -569,6 +538,39 @@ spin_button_adapt_to_unit (GtkSpinButton *spin, const GnomePrintUnit *new_unit)
 	gtk_spin_button_set_digits (spin, digits);
 }
 
+static void
+canvas_update (PrinterSetupState *state)
+{
+	guchar *unit_txt;
+
+	preview_page_destroy (state);
+	preview_page_create (state);
+	set_vertical_bounds (state);
+
+	unit_txt = gnome_print_config_get (state->gp_config, GNOME_PRINT_KEY_PREFERED_UNIT);
+	if (unit_txt) {
+		GnomePrintUnitSelector *sel =
+			GNOME_PRINT_UNIT_SELECTOR (state->unit_selector);
+		const GnomePrintUnit *unit =
+			gnome_print_unit_get_by_abbreviation (unit_txt);
+
+		g_free (unit_txt);
+		gnome_print_unit_selector_set_unit (sel, unit);
+		spin_button_adapt_to_unit (state->margins.header.spin, unit);
+		spin_button_adapt_to_unit (state->margins.footer.spin, unit);
+	}
+}
+
+static void
+notebook_flipped (G_GNUC_UNUSED GtkNotebook *notebook,
+		  G_GNUC_UNUSED GtkNotebookPage *page,
+		  gint page_num,
+		  PrinterSetupState *state)
+{
+	if (page_num == HF_PAGE)
+		canvas_update (state);
+}
+
 static void
 unit_changed (G_GNUC_UNUSED GtkSpinButton *spin_button,
 	      UnitInfo_cbdata *data)
@@ -587,7 +589,7 @@ unit_activated (G_GNUC_UNUSED GtkSpinButton *spin_button,
 		UnitInfo_cbdata *data)
 {
 	foo_canvas_item_set (data->target->line,
-			       "fill_color", MARGIN_COLOR_ACTIVE,
+			       "fill-color", MARGIN_COLOR_ACTIVE,
 			       NULL);
 	return FALSE;
 }
@@ -598,7 +600,7 @@ unit_deactivated (G_GNUC_UNUSED GtkSpinButton *spin_button,
 		  UnitInfo_cbdata *data)
 {
 	foo_canvas_item_set (data->target->line,
-			       "fill_color", MARGIN_COLOR_DEFAULT,
+			       "fill-color", MARGIN_COLOR_DEFAULT,
 			       NULL);
 	return FALSE;
 }
@@ -623,7 +625,7 @@ unit_editor_configure (UnitInfo *target, PrinterSetupState *state,
 	target->spin = spin;
 	gtk_spin_button_configure (spin, target->adj, 1, 1);
 	gtk_widget_ensure_style (GTK_WIDGET (spin));
-	len = gnm_measure_string (
+	len = go_pango_measure_string (
 		gtk_widget_get_pango_context (gtk_widget_get_toplevel (GTK_WIDGET (spin))),
 		GTK_WIDGET (spin)->style->font_desc,
 		"123.45XXX");
@@ -643,7 +645,7 @@ unit_editor_configure (UnitInfo *target, PrinterSetupState *state,
 	gnome_print_unit_selector_add_adjustment (GNOME_PRINT_UNIT_SELECTOR (state->unit_selector),
 						  target->adj);
 	g_signal_connect (G_OBJECT (target->spin),
-		"value-changed",
+		"value_changed",
 		G_CALLBACK (unit_changed), cbdata);
 	g_object_set_data_full (G_OBJECT (target->spin),
 		"cbdata", cbdata, g_free); /* avoid a leak */
@@ -659,7 +661,7 @@ cb_unit_selector_changed (GnomePrintUnitSelector *sel, PrinterSetupState *state)
 
 	unit = gnome_print_unit_selector_get_unit (sel);
 	if (unit) {
-		gnome_print_config_set (state->pi->print_config, GNOME_PRINT_KEY_PREFERED_UNIT,
+		gnome_print_config_set (state->gp_config, GNOME_PRINT_KEY_PREFERED_UNIT,
 					unit->abbr);
 		spin_button_adapt_to_unit (state->margins.header.spin, unit);
 		spin_button_adapt_to_unit (state->margins.footer.spin, unit);
@@ -1007,7 +1009,7 @@ do_hf_customize (gboolean header, PrinterSetupState *state)
 		return;
 	}
 
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (state->wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (state->wbcg),
 		"hf-config.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -1097,8 +1099,8 @@ header_preview_event (G_GNUC_UNUSED FooCanvas *canvas,
 		      GdkEvent *event, PrinterSetupState *state)
 {
 	if (event == NULL ||
-	    event->button.button != 1 ||
-	    event->type != GDK_2BUTTON_PRESS)
+	    event->type != GDK_2BUTTON_PRESS ||
+	    event->button.button != 1)
 		return FALSE;
 	do_hf_customize (TRUE, state);
 	return TRUE;
@@ -1109,8 +1111,8 @@ footer_preview_event (G_GNUC_UNUSED FooCanvas *canvas,
 		      GdkEvent *event, PrinterSetupState *state)
 {
 	if (event == NULL ||
-	    event->button.button != 1 ||
-	    event->type != GDK_2BUTTON_PRESS)
+	    event->type != GDK_2BUTTON_PRESS ||
+	    event->button.button != 1)
 		return FALSE;
 	do_hf_customize (FALSE, state);
 	return TRUE;
@@ -1150,7 +1152,7 @@ create_hf_preview_canvas (PrinterSetupState *state, gboolean header)
 		"y1",		(header ? shadow : 0),
 		"x2",		width + shadow,
 		"y2",		height + (header ? 0 : shadow),
-		"fill_color",	"black",
+		"fill-color",	"black",
 		NULL);
 
         foo_canvas_item_new (foo_canvas_root (FOO_CANVAS (pi->canvas)),
@@ -1159,7 +1161,7 @@ create_hf_preview_canvas (PrinterSetupState *state, gboolean header)
 		"y1",		0.0,
 		"x2",		width,
 		"y2",		height,
-		"fill_color",	"white",
+		"fill-color",	"white",
 		NULL);
 
 	/* Use the Gnumeric default font. */
@@ -1176,8 +1178,8 @@ create_hf_preview_canvas (PrinterSetupState *state, gboolean header)
 		"x",		padding,
 		"y",		header ? margin : bottom_margin,
 		"anchor",	GTK_ANCHOR_WEST,
-		"font_desc",	font_desc,
-		"fill_color",	"black",
+		"font-desc",	font_desc,
+		"fill-color",	"black",
 		"text",		"Left",
 		NULL);
 
@@ -1187,8 +1189,8 @@ create_hf_preview_canvas (PrinterSetupState *state, gboolean header)
 		"x",		width / 2,
 		"y",		header ? margin : bottom_margin,
 		"anchor",	GTK_ANCHOR_CENTER,
-		"font_desc",	font_desc,
-		"fill_color",	"black",
+		"font-desc",	font_desc,
+		"fill-color",	"black",
 		"text",		"Center",
 		NULL);
 
@@ -1198,8 +1200,8 @@ create_hf_preview_canvas (PrinterSetupState *state, gboolean header)
 		"x",		width - padding,
 		"y",		header ? margin : bottom_margin,
 		"anchor",	GTK_ANCHOR_EAST,
-		"font_desc",    font_desc,
-		"fill_color",	"black",
+		"font-desc",    font_desc,
+		"fill-color",	"black",
 		"text",		"Right",
 		NULL);
 
@@ -1419,8 +1421,8 @@ do_setup_page (PrinterSetupState *state)
 	gui = state->gui;
 	table = GTK_TABLE (glade_xml_get_widget (gui, "table-paper-selector"));
 
-	paper_selector = gnome_paper_selector_new_with_flags (pi->print_config,
-							      GNOME_PAPER_SELECTOR_MARGINS);
+	paper_selector = gnome_paper_selector_new_with_flags (
+		state->gp_config, GNOME_PAPER_SELECTOR_MARGINS);
 	gtk_widget_show (paper_selector);
 	gtk_table_attach_defaults (table, paper_selector, 0, 1, 0, 1);
 
@@ -1508,14 +1510,14 @@ cb_do_print_ok (G_GNUC_UNUSED GtkWidget *w,
 {
 	/* Detach BEFORE we finish editing */
 	wbcg_edit_detach_guru (state->wbcg);
-	wbcg_edit_finish (state->wbcg, TRUE, NULL);
+	wbcg_edit_finish (state->wbcg, WBC_EDIT_ACCEPT, NULL);
 	fetch_settings (state);
+	print_info_load_config (state->pi, state->gp_config);
 	if (gtk_toggle_button_get_active (
 		    GTK_TOGGLE_BUTTON (
 			    glade_xml_get_widget (state->gui, 
 						  "is_default_check")))) {
 		print_info_save (state->pi);
-		printf ("Saved settings\n");
 	}
 	cmd_print_setup (WORKBOOK_CONTROL (state->wbcg),
 		print_setup_get_sheet (state), state->pi);
@@ -1539,7 +1541,7 @@ cb_do_print_destroy (G_GNUC_UNUSED GtkWidget *button,
 		     PrinterSetupState *state)
 {
 	wbcg_edit_detach_guru (state->wbcg);
-	wbcg_edit_finish (state->wbcg, FALSE, NULL);
+	wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
 
 	g_signal_handler_disconnect (glade_xml_get_widget (state->gui, "print-setup-notebook"),
 				     state->notebook_signal_connection);
@@ -1650,7 +1652,7 @@ printer_setup_state_new (WorkbookControlGUI *wbcg, Sheet *sheet)
 	PrinterSetupState *state;
 	GladeXML *gui;
 
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"print.glade", NULL, NULL);
         if (gui == NULL)
                 return NULL;
@@ -1660,6 +1662,7 @@ printer_setup_state_new (WorkbookControlGUI *wbcg, Sheet *sheet)
 	state->sheet = sheet;
 	state->gui   = gui;
 	state->pi    = print_info_dup(sheet->print_info);
+	state->gp_config = print_info_make_config (state->pi);
 	state->customize_header = NULL;
 	state->customize_footer = NULL;
 
@@ -1676,7 +1679,8 @@ printer_setup_state_new (WorkbookControlGUI *wbcg, Sheet *sheet)
 static void
 printer_setup_state_free (PrinterSetupState *state)
 {
-	g_object_unref (G_OBJECT (state->gui));
+	g_object_unref (state->gui);
+	g_object_unref (state->gp_config);
 
 	print_hf_free (state->header);
 	print_hf_free (state->footer);
