@@ -41,14 +41,15 @@
 #include <application.h>
 #include <widgets/gnumeric-cell-renderer-text.h>
 #include <widgets/gnumeric-cell-renderer-toggle.h>
-#include <goffice/gui-utils/go-combo-box.h>
-#include <goffice/gui-utils/go-combo-color.h>
+#include <goffice/gtk/go-combo-box.h>
+#include <goffice/gtk/go-combo-color.h>
 
 #include <glade/glade.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkliststore.h>
+#include <gtk/gtkicontheme.h>
 #include <gtk/gtkbox.h>
 #include <string.h>
 #include <stdio.h>
@@ -327,9 +328,9 @@ populate_sheet_list (SheetManager *state)
 		GdkColor *text_color = NULL;
 
 		if (sheet->tab_color)
-			color = &sheet->tab_color->color;
+			color = &sheet->tab_color->gdk_color;
 		if (sheet->tab_text_color)
-			text_color = &sheet->tab_text_color->color;
+			text_color = &sheet->tab_text_color->gdk_color;
 
 		gtk_list_store_append (state->model, &iter);
 		gtk_list_store_set (state->model, &iter,
@@ -645,11 +646,11 @@ cb_ok_clicked (G_GNUC_UNUSED GtkWidget *ignore, SheetManager *state)
 			back_changed = (this_sheet == NULL) ||
 				!sheet_order_gdk_color_equal (back,
 					      this_sheet->tab_color ?
-					      &this_sheet->tab_color->color : NULL);
+					      &this_sheet->tab_color->gdk_color : NULL);
 			fore_changed = (this_sheet == NULL) ||
 				!sheet_order_gdk_color_equal (fore,
 					      this_sheet->tab_text_color ?
-					      &this_sheet->tab_text_color->color : NULL);
+					      &this_sheet->tab_text_color->gdk_color : NULL);
 			if (fore_changed || back_changed) {
 				color_changed = g_slist_prepend (color_changed, 
 					 GINT_TO_POINTER (this_sheet_idx));
@@ -686,7 +687,7 @@ cb_ok_clicked (G_GNUC_UNUSED GtkWidget *ignore, SheetManager *state)
 					 GINT_TO_POINTER (is_visible));
 			}
 			
-			sheet_set_direction (this_sheet, is_rtl);
+			g_object_set (this_sheet, "text-is-rtl", is_rtl, NULL);
 		} else {
 			deleted_sheets = g_slist_prepend (deleted_sheets, 
 				 GINT_TO_POINTER (this_sheet_idx));
@@ -714,17 +715,17 @@ cb_ok_clicked (G_GNUC_UNUSED GtkWidget *ignore, SheetManager *state)
 	changed_names = g_slist_reverse (changed_names);
 
 	if (!one_is_visible) {
-		gnumeric_notice (GTK_WINDOW (state->dialog), GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (GTK_WINDOW (state->dialog), GTK_MESSAGE_ERROR,
 				 _("At least one sheet must remain visible!"));
 		goto cleanup;
 	}
 	if (new_order == NULL) {
-		gnumeric_notice (GTK_WINDOW (state->dialog), GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (GTK_WINDOW (state->dialog), GTK_MESSAGE_ERROR,
 				 _("You may not delete all sheets in a workbook!"));
 		goto cleanup;
 	}
 	if (workbook_sheet_count (wb) <= (int)g_slist_length (deleted_sheets) ) {
-		gnumeric_notice (GTK_WINDOW (state->dialog), GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (GTK_WINDOW (state->dialog), GTK_MESSAGE_ERROR,
 				 _("To replace all exisiting sheets, please "
 				   "delete the current workbook and create "
 				   "a new one!"));
@@ -979,9 +980,10 @@ cb_sheet_order_changed (Workbook *wb, SheetManager *state)
 	 * The order in the dialog and the new sheet order are totally
 	 * different. Ask the user what to do.
 	 */
-	if (gnumeric_dialog_question_yes_no (GTK_WINDOW (state->dialog),
-			_("The sheet order has changed. Do you want to "
-			  "update the list?"), TRUE))
+	if (go_gtk_query_yes_no (GTK_WINDOW (state->dialog),
+				 TRUE,
+				 _("The sheet order has changed. Do you want to "
+				   "update the list?")))
 		dialog_sheet_order_update_sheet_order (state);
 }
 
@@ -996,7 +998,7 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
 
 	g_return_if_fail (wbcg != NULL);
 
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"sheet-order.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -1049,7 +1051,8 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
 	vbox = GTK_BOX (glade_xml_get_widget (gui,"sheet_order_buttons_vbox"));
 	cg = go_color_group_fetch ("back_color_group",
 		wb_control_view (WORKBOOK_CONTROL (wbcg)));
-	state->ccombo_back = go_combo_color_new (gnm_app_get_pixbuf ("bucket"),
+	state->ccombo_back = go_combo_color_new (
+		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "bucket", 24, 0, NULL),
 		_("Default"), 0, cg);
 	go_combo_color_set_instant_apply (
 		GO_COMBO_COLOR (state->ccombo_back), TRUE);
@@ -1058,7 +1061,8 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
 
 	cg = go_color_group_fetch ("fore_color_group",
 		wb_control_view (WORKBOOK_CONTROL (wbcg)));
-	state->ccombo_fore = go_combo_color_new (gnm_app_get_pixbuf ("font"),
+	state->ccombo_fore = go_combo_color_new (
+		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "font", 24, 0, NULL),
 		_("Default"), 0, cg);
 	go_combo_color_set_instant_apply (
 		GO_COMBO_COLOR (state->ccombo_fore), TRUE);
@@ -1102,7 +1106,7 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
 	/* a candidate for merging into attach guru */
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_sheet_order_destroy);
-	gnumeric_non_modal_dialog (wbcg_toplevel (state->wbcg),
+	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 				   GTK_WINDOW (state->dialog));
 	wbcg_edit_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
 	gtk_widget_show_all (GTK_WIDGET (state->dialog));
