@@ -21,16 +21,17 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialog-stf-preview.h"
 #include "dialog-stf.h"
 
-#include <format.h>
+#include <gnm-format.h>
 #include <number-match.h>
 #include <value.h>
 #include <style.h>
 #include <gtk/gtkcellrenderertext.h>
+#include <widgets/gnumeric-lazy-list.h>
 
 /******************************************************************************************************************
  * ADVANCED DRAWING FUNCTIONS
@@ -40,7 +41,7 @@ static void
 render_get_value (gint row, gint column, gpointer _rd, GValue *value)
 {
 	RenderData_t *rd = (RenderData_t *)_rd;
-	GnumericLazyList *ll = rd->ll;
+	GnumericLazyList *ll = GNUMERIC_LAZY_LIST (gtk_tree_view_get_model (rd->tree_view));
 	GPtrArray *lines = rd->lines;
 	GPtrArray *line = (row < (int)lines->len)
 		? g_ptr_array_index (lines, row)
@@ -81,9 +82,10 @@ render_get_value (gint row, gint column, gpointer _rd, GValue *value)
  **/
 RenderData_t*
 stf_preview_new (GtkWidget *data_container,
-		 GnmDateConventions const *date_conv)
+		 GODateConventions const *date_conv)
 {
 	RenderData_t* renderdata;
+	GnumericLazyList *ll;
 
 	g_return_val_if_fail (data_container != NULL, NULL);
 
@@ -98,16 +100,11 @@ stf_preview_new (GtkWidget *data_container,
 
 	renderdata->date_conv	   = date_conv;
 
-	renderdata->ll =
-		gnumeric_lazy_list_new (render_get_value, renderdata, 0);
-	gnumeric_lazy_list_add_column (renderdata->ll,
-#warning "FIXME: we should not need to limit the shown columns to 4 times SHEET_MAX_COLS"
-				       4 * SHEET_MAX_COLS,
-				       G_TYPE_STRING);
-
+	ll = gnumeric_lazy_list_new (render_get_value, renderdata, 0, 1, G_TYPE_STRING);
 	renderdata->tree_view =
-		GTK_TREE_VIEW (gtk_tree_view_new_with_model
-			       (GTK_TREE_MODEL (renderdata->ll)));
+		GTK_TREE_VIEW (gtk_tree_view_new_with_model (GTK_TREE_MODEL (ll)));
+	g_object_ref (renderdata->tree_view);
+	g_object_unref (ll);
 
 	renderdata->tooltips = gtk_tooltips_new ();
 	g_object_ref (renderdata->tooltips);
@@ -162,6 +159,8 @@ stf_preview_free (RenderData_t *renderdata)
 	stf_preview_set_lines (renderdata, NULL, NULL);
 	g_object_unref (renderdata->tooltips);
 
+	g_object_unref (renderdata->tree_view);
+
 	g_free (renderdata);
 }
 
@@ -171,12 +170,14 @@ stf_preview_set_lines (RenderData_t *renderdata,
 		       GPtrArray *lines)
 {
 	unsigned int i;
-	int colcount = 0;
+	int colcount = 1;
+	GnumericLazyList *ll;
 	
 	g_return_if_fail (renderdata != NULL);
 
 	/* Empty the table.  */
-	gnumeric_lazy_list_set_rows (renderdata->ll, 0);
+	gtk_tree_view_set_model (renderdata->tree_view, NULL);
+	renderdata->colcount = 0;
 
 	if (renderdata->lines != lines) {
 		if (renderdata->lines)
@@ -198,17 +199,6 @@ stf_preview_set_lines (RenderData_t *renderdata,
 		colcount = MAX (colcount, (int)line->len);
 	}
 
-	if (colcount <= 0)
-		colcount = 1;
-	/* See stf_preview_new.  */
-	colcount = MIN (colcount, 4 * SHEET_MAX_COLS);
-
-	/* Fix number of columns.  */
-	while (renderdata->colcount > colcount)
-		gtk_tree_view_remove_column
-			(renderdata->tree_view,
-			 gtk_tree_view_get_column (renderdata->tree_view,
-						   --(renderdata->colcount)));
 	while (renderdata->colcount < colcount) {
 		char *text = g_strdup_printf (_(COLUMN_CAPTION),
 					      renderdata->colcount + 1);
@@ -218,14 +208,20 @@ stf_preview_set_lines (RenderData_t *renderdata,
 			(text, cell,
 			 "text", renderdata->colcount,
 			 NULL);
+		g_object_set (cell,
+			      "single_paragraph_mode", TRUE,
+			      NULL);
 		gtk_tree_view_append_column (renderdata->tree_view, column);
 		g_free (text);
 		renderdata->colcount++;
 	}
 
-	/* Fill the table.  */
-	gnumeric_lazy_list_set_rows (renderdata->ll,
-				     MIN (lines->len, LINE_DISPLAY_LIMIT));
+	ll = gnumeric_lazy_list_new (render_get_value, renderdata,
+				     MIN (lines->len, LINE_DISPLAY_LIMIT),
+				     0);
+	gnumeric_lazy_list_add_column (ll, colcount, G_TYPE_STRING);
+	gtk_tree_view_set_model (renderdata->tree_view, GTK_TREE_MODEL (ll));
+	g_object_unref (ll);
 }
 
 /**
@@ -279,7 +275,7 @@ stf_preview_colformats_clear (RenderData_t *renderdata)
  * returns : nothing
  **/
 void
-stf_preview_colformats_add (RenderData_t *renderdata, GnmFormat *format)
+stf_preview_colformats_add (RenderData_t *renderdata, GOFormat *format)
 {
 
 	g_return_if_fail (renderdata != NULL);
@@ -311,3 +307,26 @@ stf_preview_get_cell_renderer (RenderData_t *renderdata, int col)
 	}
 	return res;
 }
+
+void
+stf_preview_find_column (RenderData_t *renderdata, int x, int *pcol, int *dx)
+{
+	int col;
+
+	/* Figure out what column we pressed in.  */
+	for (col = 0; 1; col++) {
+		GtkWidget *w;
+		GtkTreeViewColumn *column =
+			stf_preview_get_column (renderdata, col);
+		if (!column)
+			break;
+		w = GTK_BIN (column->button)->child;
+		if (x < w->allocation.x + w->allocation.width) {
+			*dx = x - w->allocation.x;
+			break;
+		}
+	}
+
+	*pcol = col;
+	*dx = 0;
+}
