@@ -41,7 +41,7 @@
 #include "mathfunc.h"
 #include "cell.h"
 #include "commands.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "number-match.h"
 #include "mstyle.h"
 #include "style-border.h"
@@ -75,7 +75,7 @@ typedef struct {
 	GnmExprEntry *resultrangetext;
 } DialogState;
 
-static const char *mode_group[] = {
+static const char * const mode_group[] = {
 	"mode_visual",
 	"mode_coordinate",
 	NULL
@@ -143,7 +143,7 @@ get_table_float_entry (GtkTable *t, int y, int x, GnmCell *cell, gnm_float *numb
 		       GtkEntry **wp, gboolean with_default, gnm_float default_float)
 {
 	GList *l;
-	GnmFormat *format;
+	GOFormat *format;
 
 	*wp = NULL;
 	for (l = t->children; l; l = l->next) {
@@ -200,13 +200,15 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 
 		cells[dims] = single_cell (dd->sheet, w);
 		if (!cells[dims]) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("You should introduce a single valid cell as dependency cell"));
 			gnm_expr_entry_grab_focus (GNM_EXPR_ENTRY (w), TRUE);
 			goto error;
 		}
 		if (cell_has_expr (cells[dims])) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("The dependency cells should not contain an expression"));
 			gnm_expr_entry_grab_focus (GNM_EXPR_ENTRY (w), TRUE);
 			goto error;
@@ -214,7 +216,8 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 
 		if (get_table_float_entry (dd->source_table, row, COL_MIN, cells[dims],
 					   &(minima[dims]), &e_w, FALSE, 0.0)) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("You should introduce a valid number as minimum"));
 			focus_on_entry (e_w);
 			goto error;
@@ -222,14 +225,16 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 
 		if (get_table_float_entry (dd->source_table, row, COL_MAX, cells[dims],
 					   &(maxima[dims]), &e_w, FALSE, 0.0)) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("You should introduce a valid number as maximum"));
 			focus_on_entry (e_w);
 			goto error;
 		}
 
 		if (maxima[dims] < minima[dims]) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("The maximum value should be bigger than the minimum"));
 			focus_on_entry (e_w);
 			goto error;
@@ -237,14 +242,16 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 
 		if (get_table_float_entry (dd->source_table, row, COL_STEP, cells[dims],
 					   &(steps[dims]), &e_w, TRUE, 1.0)) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("You should introduce a valid number as step size"));
 			focus_on_entry (e_w);
 			goto error;
 		}
 
 		if (steps[dims] <= 0) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("The step size should be positive"));
 			focus_on_entry (e_w);
 			goto error;
@@ -254,7 +261,8 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 	}
 
 	if (dims == 0) {
-		gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+				 GTK_MESSAGE_ERROR,
 				 _("You should introduce one or more dependency cells"));
 		goto error;
 	}
@@ -263,14 +271,16 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 		resultcell = single_cell (dd->sheet, dd->resultrangetext);
 
 		if (!resultcell) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("You should introduce a single valid cell as result cell"));
 			gnm_expr_entry_grab_focus (dd->resultrangetext, TRUE);
 			goto error;
 		}
 
 		if (!cell_has_expr (resultcell)) {
-			gnumeric_notice (dd->wbcg, GTK_MESSAGE_ERROR,
+			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
+					 GTK_MESSAGE_ERROR,
 					 _("The target cell should contain an expression"));
 			gnm_expr_entry_grab_focus (dd->resultrangetext, TRUE);
 			goto error;
@@ -320,7 +330,7 @@ dialog_tabulate (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, TABULATE_KEY))
 		return;
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"tabulate.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -334,8 +344,8 @@ dialog_tabulate (WorkbookControlGUI *wbcg, Sheet *sheet)
 	dd->sheet = sheet;
 
 	g_object_set (G_OBJECT (dialog),
-		"allow_shrink",	FALSE,
-		"allow_grow",	TRUE,
+		"allow-shrink",	FALSE,
+		"allow-grow",	TRUE,
 		NULL);
 
 	dd->source_table = GTK_TABLE (glade_xml_get_widget (gui, "source_table"));
