@@ -28,6 +28,7 @@
 #include "sheet-style.h"
 
 #include <gdk/gdkkeysyms.h>
+#include <goffice/utils/go-glib-extras.h>
 
 static void
 cb_nexpr_remove (GnmNamedExpr *nexpr)
@@ -645,10 +646,8 @@ expr_name_cmp_by_name (GnmNamedExpr const *a, GnmNamedExpr const *b)
 				      sheetb->name_case_insensitive);
 	}
 
-	if (res == 0) {
-		/* By name.  */
-		res = gnumeric_utf8_collate_casefold (a->name->str, b->name->str);
-	}
+	if (res == 0)	/* By name.  */
+		res = go_utf8_collate_casefold (a->name->str, b->name->str);
 
 	return res;
 }
