@@ -27,7 +27,7 @@
 #include "expr-impl.h"
 #include "expr-name.h"
 #include "dependent.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "func.h"
 #include "cell.h"
 #include "sheet.h"
@@ -44,6 +44,7 @@
 #include <math.h>
 #include <string.h>
 #include <stdlib.h>
+#include <goffice/utils/go-glib-extras.h>
 
 /*
  * Using pools here probably does not save anything, but it's a darn
@@ -55,9 +56,9 @@
 
 #if USE_EXPR_POOLS
 /* Memory pool for expressions.  */
-static GnmMemChunk *expression_pool;
-#define CHUNK_ALLOC(T,p) ((T*)gnm_mem_chunk_alloc (p))
-#define CHUNK_FREE(p,v) gnm_mem_chunk_free ((p), (v))
+static GOMemChunk *expression_pool;
+#define CHUNK_ALLOC(T,p) ((T*)go_mem_chunk_alloc (p))
+#define CHUNK_FREE(p,v) go_mem_chunk_free ((p), (v))
 #else
 #define CHUNK_ALLOC(T,c) g_new (T,1)
 #define CHUNK_FREE(p,v) g_free ((v))
@@ -667,8 +668,8 @@ bin_arith (GnmExpr const *expr, GnmEvalPos const *ep,
 		case GNM_EXPR_OP_EXP:
 			if (ia == 0 && ib <= 0)
 				return value_new_error_NUM (ep);
-			dres = powgnum ((gnm_float)ia, (gnm_float)ib);
-			if (!finitegnum (dres))
+			dres = gnm_pow ((gnm_float)ia, (gnm_float)ib);
+			if (!gnm_finite (dres))
 				return value_new_error_NUM (ep);
 			break;
 
@@ -706,8 +707,8 @@ bin_arith (GnmExpr const *expr, GnmEvalPos const *ep,
 			    (va < 0 && vb != (int)vb))
 				return value_new_error_NUM (ep);
 
-			res = powgnum (va, vb);
-			return finitegnum (res)
+			res = gnm_pow (va, vb);
+			return gnm_finite (res)
 				? value_new_float (res)
 				: value_new_error_NUM (ep);
 		}
@@ -904,7 +905,7 @@ static inline GnmValue *
 negate_value (GnmValue const *v)
 {
 	GnmValue *tmp;
-	GnmFormat *fmt; 
+	GOFormat *fmt; 
 
 	if (v->type == VALUE_INTEGER) {
 		int i = v->v_int.val;
@@ -1270,8 +1271,9 @@ gnm_expr_eval (GnmExpr const *expr, GnmEvalPos const *pos,
 		}
 		if (res->type == VALUE_ARRAY &&
 		    !(flags & GNM_EXPR_EVAL_PERMIT_NON_SCALAR)) {
+			a = value_dup (res->v_array.vals[0][0]);
 			value_release (res);
-			return value_new_error_VALUE (pos);
+			return a;
 		}
 		return res;
 	}
@@ -1486,7 +1488,7 @@ do_expr_as_string (GString *target, GnmExpr const *expr, GnmParsePos const *pp,
 		size_t prelen = target->len;
 
 		if (v->type == VALUE_STRING) {
-			gnm_strescape (target, v->v_str.val->str);
+			go_strescape (target, v->v_str.val->str);
 			return;
 		}
 
@@ -2334,6 +2336,47 @@ gnm_expr_get_range (GnmExpr const *expr)
 	}
 }
 
+
+static GSList *
+do_gnm_expr_get_ranges (GnmExpr const *expr, GSList *ranges)
+{
+	switch (expr->any.oper) {
+	case GNM_EXPR_OP_RANGE_CTOR:
+	case GNM_EXPR_OP_INTERSECT:
+	case GNM_EXPR_OP_ANY_BINARY:
+		return do_gnm_expr_get_ranges (
+			expr->binary.value_a,
+			do_gnm_expr_get_ranges (
+				expr->binary.value_b,
+				ranges));
+	case GNM_EXPR_OP_ANY_UNARY:
+		return do_gnm_expr_get_ranges (expr->unary.value, ranges);
+	case GNM_EXPR_OP_FUNCALL: {
+		GnmExprList *l;
+		for (l = expr->func.arg_list; l; l = l->next)
+			ranges = do_gnm_expr_get_ranges (l->data, ranges);
+		return ranges;
+	}
+	case GNM_EXPR_OP_SET: {
+		GnmExprList *l;
+		for (l = expr->set.set; l; l = l->next)
+			ranges = do_gnm_expr_get_ranges (l->data, ranges);
+		return ranges;
+	}
+
+	case GNM_EXPR_OP_NAME:
+		/* What?  */
+
+	default: {
+		GnmValue *v = gnm_expr_get_range (expr);
+		if (v)
+			return g_slist_insert_unique (ranges, v);
+		return ranges;
+	}
+	}
+}
+
+
 /**
  * gnm_expr_get_ranges:
  * @expr :
@@ -2345,25 +2388,8 @@ gnm_expr_get_range (GnmExpr const *expr)
 GSList *
 gnm_expr_get_ranges (GnmExpr const *expr)
 {
-	GHashTable *singles, *ranges;
-
 	g_return_val_if_fail (expr != NULL, NULL);
-
-	switch (expr->any.oper) {
-	case GNM_EXPR_OP_CELLREF :
-		return NULL;
-
-	case GNM_EXPR_OP_CONSTANT:
-		return NULL;
-
-	case GNM_EXPR_OP_NAME:
-		if (!expr->name.name->active)
-			return NULL;
-		return NULL;
-
-	default:
-		return NULL;
-	}
+	return do_gnm_expr_get_ranges (expr, NULL);
 }
 
 /**
@@ -2424,6 +2450,12 @@ gnm_expr_is_rangeref (GnmExpr const *expr)
 	};
 }
 
+GnmExprArray const *
+gnm_expr_is_array (GnmExpr const *expr)
+{
+	return (expr->any.oper == GNM_EXPR_OP_ARRAY) ? &expr->array : NULL;
+}
+
 gboolean
 gnm_expr_is_err (GnmExpr const *expr, GnmStdError err)
 {
@@ -2737,7 +2769,7 @@ expr_init (void)
 {
 #if USE_EXPR_POOLS
 	expression_pool =
-		gnm_mem_chunk_new ("expression pool",
+		go_mem_chunk_new ("expression pool",
 				   sizeof (GnmExpr),
 				   16 * 1024 - 128);
 #endif
@@ -2765,8 +2797,8 @@ void
 expr_shutdown (void)
 {
 #if USE_EXPR_POOLS
-	gnm_mem_chunk_foreach_leak (expression_pool, cb_expression_pool_leak, NULL);
-	gnm_mem_chunk_destroy (expression_pool, FALSE);
+	go_mem_chunk_foreach_leak (expression_pool, cb_expression_pool_leak, NULL);
+	go_mem_chunk_destroy (expression_pool, FALSE);
 	expression_pool = NULL;
 #endif
 }
