@@ -11,6 +11,7 @@
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include "gnumeric.h"
 #include "func.h"
 
@@ -25,7 +26,7 @@
 #include "sheet.h"
 #include "value.h"
 #include "number-match.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "func-builtin.h"
 
 #include <string.h>
@@ -85,8 +86,97 @@ func_def_cmp (gconstpointer a, gconstpointer b)
 	return g_ascii_strcasecmp (fda->name, fdb->name);
 }
 
+static char const *
+check_name_match (char const *name, char const *description, char const*tag)
+{
+	unsigned tag_len = strlen (tag);
+	char const *tmp;
+	char *desc_name, *up_name;
+
+	if (NULL == (tmp = strstr (description, tag))) {
+		fprintf (stderr, "'%s' : missing '%s' section.  text = '%s'\n", name, tag, description);
+		return NULL;
+	}
+
+	description = tmp + tag_len;
+	for (tmp = description ; *tmp && *tmp != '(' && !g_ascii_isspace(*tmp) ; tmp++)
+		;
+	desc_name = g_strndup (description, tmp-description);
+	up_name = g_ascii_strup (name, -1);
+	if (strcmp (desc_name, up_name)) {
+		fprintf (stderr, "'%s' : does not match '%s' in @FUNCTION\n", desc_name, up_name);
+		g_free (up_name);
+		g_free (desc_name);
+		return NULL;
+	}
+	g_free (up_name);
+	g_free (desc_name);
+	return tmp;
+}
+
+static void
+cb_generate_po (gpointer key, Symbol *sym, gpointer array)
+{
+	GnmFunc const *fd = sym->data;
+	char const *ptr, *tmp;
+
+	if (fd->fn_type == GNM_FUNC_TYPE_STUB)
+		gnm_func_load_stub ((GnmFunc *) fd);
+
+	if (fd->help == NULL) {
+		g_warning ("'%s' : no help defined", fd->name);
+		return;
+	}
+	if (fd->help[0].type != GNM_FUNC_HELP_OLD) {
+		g_warning ("'%s' : wrong type of help '%d' != %d", fd->name,
+			   fd->help[0].type, GNM_FUNC_HELP_OLD);
+		return;
+	}
+	if (fd->help[0].text == NULL) {
+		g_warning ("'%s' : missing help text", fd->name);
+		return;
+	}
+
+	ptr = dgettext ("gnumeric-functions", fd->help[0].text);
+	if (NULL == (ptr = check_name_match (fd->name, ptr, "@FUNCTION=")))
+		return;
+	if (NULL == (ptr = check_name_match (fd->name, ptr, "@SYNTAX=")))
+		return;
+
+	if (NULL == (tmp = strstr (ptr, "@DESCRIPTION="))) {
+		fprintf (stderr, "'%s' : missing @DESCRIPTION section\n", fd->name);
+		return;
+	}
+	if (NULL == (tmp = strstr (ptr, "@EXAMPLES="))) {
+		return;
+	}
+	if (NULL == (tmp = strstr (ptr, "@SEEALSO="))) {
+		fprintf (stderr, "'%s' : missing @SEEALSO section\n", fd->name);
+		return;
+	}
+}
+
+static void
+generate_po ()
+{
+	g_hash_table_foreach (global_symbol_table->hash,
+		(GHFunc) cb_generate_po, NULL);
+}
+
+/**
+ * function_dump_defs :
+ * @filename :
+ * @dump_type :
+ *
+ * A generic utility routine to operate on all funtion defs
+ * in various ways.  @dump_type will change/extend as needed
+ * Right now
+ * 0 : 
+ * 1 : 
+ * 2 :
+ **/
 void
-function_dump_defs (char const *filename, gboolean as_def)
+function_dump_defs (char const *filename, int dump_type)
 {
 	FILE *output_file;
 	char *up;
@@ -94,9 +184,14 @@ function_dump_defs (char const *filename, gboolean as_def)
 	GPtrArray *ordered;
 	GnmFuncGroup const *group = NULL;
 
+	if (dump_type == 2) {
+		generate_po ();
+		return;
+	}
+
 	g_return_if_fail (filename != NULL);
 
-	if ((output_file = fopen (filename, "w")) == NULL){
+	if ((output_file = g_fopen (filename, "w")) == NULL){
 		printf (_("Cannot create file %s\n"), filename);
 		exit (1);
 	}
@@ -111,7 +206,7 @@ function_dump_defs (char const *filename, gboolean as_def)
 		       ordered->len, sizeof (gpointer),
 		       func_def_cmp);
 
-	if (!as_def) {
+	if (dump_type == 0) {
 		int unique = 0;
 		for (i = 0; i < ordered->len; i++) {
 			GnmFunc const *fd = g_ptr_array_index (ordered, i);
@@ -170,10 +265,10 @@ function_dump_defs (char const *filename, gboolean as_def)
 
 	for (i = 0; i < ordered->len; i++) {
 		GnmFunc const *fd = g_ptr_array_index (ordered, i);
-		if (as_def) {
+		if (dump_type == 1) {
 			fprintf (output_file, "@CATEGORY=%s\n%s\n\n",
-				 _(fd->fn_group->display_name->str), _(fd->help));
-		} else {
+				 _(fd->fn_group->display_name->str), _(fd->help[0].text));
+		} else if (dump_type == 0) {
 			static struct {
 				char const *name;
 				char const *klass;
@@ -229,7 +324,7 @@ function_dump_defs (char const *filename, gboolean as_def)
 			fprintf (output_file,"</tr>\n");
 		}
 	}
-	if (!as_def) {
+	if (dump_type == 0) {
 		if (group) fprintf (output_file, "</table></div>\n");
 		fprintf (output_file, "<!--#include virtual=\"footer.shtml\"-->\n");
 	}
@@ -361,7 +456,7 @@ gnm_func_load_stub (GnmFunc *func)
 
 	if (func->fn.load_desc (func, &desc)) {
 		func->arg_names	 = desc.arg_names;
-		func->help	 = desc.help ? *desc.help : NULL;
+		func->help	 = desc.help ? desc.help : NULL;
 		if (desc.fn_args != NULL) {
 			func->fn_type		= GNM_FUNC_TYPE_ARGS;
 			func->fn.args.func	= desc.fn_args;
@@ -468,7 +563,7 @@ gnm_func_add (GnmFuncGroup *fn_group,
 
 	func->name		= desc->name;
 	func->arg_names		= desc->arg_names;
-	func->help		= desc->help ? *desc->help : NULL;
+	func->help		= desc->help ? desc->help : NULL;
 	func->linker		= desc->linker;
 	func->unlinker		= desc->unlinker;
 	func->ref_notify	= desc->ref_notify;
@@ -1313,14 +1408,14 @@ tokenized_help_new (GnmFunc const *func)
 	tok->help_copy = NULL;
 	tok->sections = NULL;
 
-	if (func->help != NULL && func->help [0] != '\0') {
+	if (func->help != NULL && func->help [0].type == GNM_FUNC_HELP_OLD) {
 		char *ptr, *start;
 		gboolean seek_at = TRUE;
 		gboolean last_newline = TRUE;
 
-		ptr = _(func->help);
-		tok->help_is_localized = ptr != func->help;
-		tok->help_copy = g_strdup (ptr);
+#warning fixme, use the rest of the pieces and get rid of this routine.
+		tok->help_is_localized = FALSE;
+		tok->help_copy = g_strdup (func->help [0].text);
 		tok->sections = g_ptr_array_new ();
 
 		for (start = ptr = tok->help_copy; *ptr ; ptr++) {
