@@ -8,17 +8,16 @@
 void functions_init     (void);
 void functions_shutdown (void);
 
-/* Used to build manual */
-void function_dump_defs (char const *filename, gboolean def_or_state);
+void function_dump_defs (char const *filename, int dump_type);
 
 /******************************************************************************/
 /* Function group support */
 
-typedef struct {
+struct _GnmFuncGroup {
 	GnmString *internal_name, *display_name;
 	gboolean has_translation;
 	GSList *functions;
-} GnmFuncGroup;
+};
 
 GnmFuncGroup *gnm_func_group_get_nth (gint n);
 GnmFuncGroup *gnm_func_group_fetch     		    (char const *name);
@@ -119,7 +118,6 @@ typedef enum {
 	GNM_FUNC_TEST_STATUS_EXHAUSTIVE,
 	GNM_FUNC_TEST_STATUS_UNDER_DEVELOPMENT
 } GnmFuncTestStatus;
-typedef struct _GnmFuncDescriptor GnmFuncDescriptor;
 
 typedef GnmValue 	*(*GnmFuncArgs)	  (FunctionEvalInfo *ei, GnmValue **args);
 typedef GnmValue 	*(*GnmFuncNodes)  (FunctionEvalInfo *ei, GnmExprList *l);
@@ -129,11 +127,26 @@ typedef void		 (*GnmFuncUnlink) (FunctionEvalInfo *ei);
 typedef void	 (*GnmFuncRefNotify) (GnmFunc *f, int refcount);
 typedef gboolean (*GnmFuncLoadDesc)  (GnmFunc const *f, GnmFuncDescriptor *fd);
 
+typedef enum {
+	GNM_FUNC_HELP_END,		/* Format */
+					/* ------ */
+	GNM_FUNC_HELP_OLD,		/* old token based format */
+	GNM_FUNC_HELP_NAME,		/* <NAME>:<1 SENTENCE DESCRIPTION>	(translated) */
+	GNM_FUNC_HELP_ARG,		/* <NAME>:<1 SENTENCE DESCRIPTION> 	(translated) */
+	GNM_FUNC_HELP_DESCRIPTION,	/* <LONG DESCRIPTION reference args using @arg> 	(translated) */
+	GNM_FUNC_HELP_EXAMPLES,		/* <TEXT and EXAMPLES ?? get a hook to enter the sample ?? > 	(translated) */
+	GNM_FUNC_HELP_SEEALSO		/* name,name,name ...			(not translated) */
+} GnmFuncHelpType;
+typedef struct {
+    GnmFuncHelpType	 type;
+    char const		*text;
+} GnmFuncHelp;
+
 struct _GnmFuncDescriptor {
 	char const *name;
 	char const *arg_spec;
 	char const *arg_names;
-	char const **help;	/* this is easier for compilers */
+	GnmFuncHelp const *help;
 	GnmFuncArgs	  fn_args;
 	GnmFuncNodes	  fn_nodes;
 	GnmFuncLink	  linker;
@@ -147,7 +160,7 @@ struct _GnmFuncDescriptor {
 struct _GnmFunc {
 	char const *name;
 	char const *arg_names;
-	char const *help;
+	GnmFuncHelp const *help;
 	GnmFuncType fn_type;
 	union {
 		GnmFuncNodes nodes;
