@@ -27,18 +27,38 @@
 #include "commands.h"
 #include "gui-util.h"
 
-#include <libfoocanvas/foo-canvas-line.h>
-#include <libfoocanvas/foo-canvas-rect-ellipse.h>
+#include <goffice/utils/go-glib-extras.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-line.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-rect-ellipse.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtkseparatormenuitem.h>
 #include <gtk/gtkimage.h>
+#include <gtk/gtkdnd.h>
 #include <gdk/gdkdisplay.h>
 #include <glib/gi18n.h>
 #include <math.h>
 #define GNUMERIC_ITEM "GnmPane"
 #include "item-debug.h"
 
+#define DEBUG_DND
+
+/**
+ * For now, application/x-gnumeric is disabled. It handles neither
+ * images nor graphs correctly.
+ */
+static const GtkTargetEntry drag_types_in[] =
+	{
+		{(char *) "GNUMERIC_SAME_PROC", GTK_TARGET_SAME_APP, 0},
+ 		/* {(char *) "application/x-gnumeric", 0, 0}, */
+	};
+
+static const GtkTargetEntry drag_types_out[] =
+	{
+		{(char *) "GNUMERIC_SAME_PROC", GTK_TARGET_SAME_APP, 0},
+		{(char *) "application/x-gnumeric", 0, 0},
+	};
+
 static void
 gnumeric_pane_realized (GtkWidget *widget, gpointer ignored)
 {
@@ -49,6 +69,7 @@ static void
 gnumeric_pane_header_init (GnmPane *pane, SheetControlGUI *scg,
 			   gboolean is_col_header)
 {
+	Sheet *sheet;
 	FooCanvas *canvas = gnm_simple_canvas_new (scg);
 	FooCanvasGroup *group = FOO_CANVAS_GROUP (canvas->root);
 	FooCanvasItem *item = foo_canvas_item_new (group,
@@ -57,9 +78,9 @@ gnumeric_pane_header_init (GnmPane *pane, SheetControlGUI *scg,
 		"IsColHeader", is_col_header,
 		NULL);
 
+	foo_canvas_set_center_scroll_region (canvas, FALSE);
 	/* give a non-constraining default in case something scrolls before we
-	 * are realized
-	 */
+	 * are realized */
 	foo_canvas_set_scroll_region (canvas,
 		0, 0, GNUMERIC_CANVAS_FACTOR_X, GNUMERIC_CANVAS_FACTOR_Y);
 	if (is_col_header) {
@@ -73,17 +94,10 @@ gnumeric_pane_header_init (GnmPane *pane, SheetControlGUI *scg,
 	pane->colrow_resize.start  = NULL;
 	pane->colrow_resize.guide  = NULL;
 
-#if 0
-	/* This would be simpler, just scroll the table and the head moves too.
-	 * but it will take some cleaning up that I have no time for just now.
-	 */
-	if (is_col_header)
-		gtk_layout_set_hadjustment (GTK_LAYOUT (canvas),
-			gtk_layout_get_hadjustment (GTK_LAYOUT (pane->gcanvas)));
-	else
-		gtk_layout_set_vadjustment (GTK_LAYOUT (canvas),
-			gtk_layout_get_vadjustment (GTK_LAYOUT (pane->gcanvas)));
-#endif
+	if (NULL != scg &&
+	    NULL != (sheet = sc_sheet (SHEET_CONTROL (scg))) &&
+	    fabs (1. - sheet->last_zoom_factor_used) > 1e-6)
+		foo_canvas_set_pixels_per_unit (canvas, sheet->last_zoom_factor_used);
 
 	g_signal_connect (G_OBJECT (canvas),
 		"realize",
@@ -128,8 +142,8 @@ gnm_pane_display_obj_size_tip (GnmPane *pane, SheetObject const *so)
 	scg_object_coords_to_anchor (scg, coords, &anchor);
 	sheet_object_anchor_to_pts (&anchor, sc_sheet (SHEET_CONTROL (scg)), pts);
 	msg = g_strdup_printf (_("%.1f x %.1f pts\n%d x %d pixels"),
-		MAX (fabs (pts[3] - pts[1]) + 1, 0),
-		MAX (fabs (pts[2] - pts[0]) + 1, 0),
+		MAX (fabs (pts[3] - pts[1]) + 1., 0),
+		MAX (fabs (pts[2] - pts[0]) + 1., 0),
 		MAX ((int)floor (fabs (coords [3] - coords [1]) + 1.5), 0),
 		MAX ((int)floor (fabs (coords [2] - coords [0]) + 1.5), 0));
 	gtk_label_set_text (GTK_LABEL (pane->size_tip), msg);
@@ -171,13 +185,143 @@ cb_ctrl_pts_free (GtkObject **ctrl_pts)
 	g_free (ctrl_pts);
 }
 
+static void
+cb_pane_drag_data_received (GtkWidget *widget, GdkDragContext *context,
+			    gint x, gint y, GtkSelectionData *selection_data,
+			    guint info, guint time, GnmPane *pane)
+{
+	double wx, wy;
+	GnmCanvas *gcanvas = pane->gcanvas;
+
+#ifdef DEBUG_DND
+	{
+		gchar *target_name = gdk_atom_name (selection_data->target);
+		printf ("drag-data-received - %s\n", target_name);
+		g_free (target_name);
+	}
+#endif
+
+	if (gcanvas->first.col > 0)
+		x += scg_colrow_distance_get
+			(gcanvas->simple.scg, TRUE, 0, gcanvas->first.col);
+	if (gcanvas->first.row > 0)
+		y += scg_colrow_distance_get
+			(gcanvas->simple.scg, FALSE, 0, gcanvas->first.row);
+
+	foo_canvas_c2w (FOO_CANVAS (gcanvas), x, y, &wx, &wy);
+
+	scg_drag_data_received (gcanvas->simple.scg, 
+				gtk_drag_get_source_widget (context),
+				wx, wy, selection_data);
+}
+
+static void
+cb_gnm_pane_drag_data_get (GtkWidget *widget, GdkDragContext *context,
+			   GtkSelectionData *selection_data,
+			   guint info, guint time,
+			   SheetControlGUI *scg)
+{
+#ifdef DEBUG_DND
+	gchar *target_name = gdk_atom_name (selection_data->target);
+
+	printf ("drag-data-get - %s \n", target_name);
+	g_free (target_name);
+#endif
+	scg_drag_data_get (scg, selection_data);
+}
+
+/* Move the rubber bands if we are the source */
+static gboolean
+cb_gnm_pane_drag_motion (GtkWidget *widget, GdkDragContext *context,
+			 int x, int y, guint32 time, GnmPane *pane)
+{
+	GtkWidget *source_widget = gtk_drag_get_source_widget (context);
+	SheetControlGUI *scg = GNM_CANVAS (widget)->simple.scg;
+
+	if ((IS_GNM_CANVAS (source_widget) &&
+	     GNM_CANVAS (source_widget)->simple.scg == scg)) {
+		/* same scg */
+		GnmPane  *source_pane = GNM_CANVAS (source_widget)->pane;
+		GnmCanvas *gcanvas = GNM_CANVAS (widget);
+		double wx, wy;
+
+		g_object_set_data (&context->parent_instance, "gnm-pane", pane);
+		if (gcanvas->first.col > 0)
+			x += scg_colrow_distance_get
+				(gcanvas->simple.scg, TRUE, 0, 
+				 gcanvas->first.col);
+		if (gcanvas->first.row > 0)
+			y += scg_colrow_distance_get
+				(gcanvas->simple.scg, FALSE, 0, 
+				 gcanvas->first.row);
+		foo_canvas_c2w (FOO_CANVAS (gcanvas), x, y, &wx, &wy);
+		gnm_pane_objects_drag (source_pane, NULL, wx, wy, 8,
+				       FALSE, FALSE);
+		gdk_drag_status (context, GDK_ACTION_MOVE, time);
+	}
+	return TRUE;
+}
+
+/**
+ * Move the rubber bands back to original position when curser leaves
+ * the scg, but not when it moves to another pane. We use object data,
+ * and rely on gtk sending drag_move to the new widget before sending
+ * drag_leave to the old one.
+ */
+static void
+cb_gnm_pane_drag_leave (GtkWidget *widget, GdkDragContext *context,
+		       guint32 time, GnmPane *pane)
+{
+	GtkWidget *source_widget = gtk_drag_get_source_widget (context);
+	GnmPane *source_pane;
+	GnmPane *ctxt_pane;
+
+	if (!source_widget) return;
+	
+	g_return_if_fail (IS_GNM_CANVAS (source_widget));
+
+	source_pane = GNM_CANVAS (source_widget)->pane;
+	
+	ctxt_pane = g_object_get_data (&context->parent_instance, "gnm-pane");
+	if (pane != ctxt_pane)
+		return;
+	g_object_set_data (&context->parent_instance, "gnm-pane", NULL);
+
+	gnm_pane_objects_drag (source_pane, NULL, 
+			       source_pane->drag.origin_x,
+			       source_pane->drag.origin_y,
+			       8, FALSE, FALSE);
+	source_pane->drag.had_motion = FALSE;
+}
+
+static void
+gnm_pane_drag_dest_init (GnmPane *pane, SheetControlGUI *scg)
+{
+	GtkWidget *widget = GTK_WIDGET (pane->gcanvas);
+
+	gtk_drag_dest_set (widget, GTK_DEST_DEFAULT_ALL,
+			   drag_types_in, G_N_ELEMENTS (drag_types_in), 
+			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
+	gtk_drag_dest_add_uri_targets (widget);
+	gtk_drag_dest_add_image_targets (widget);
+	gtk_drag_dest_add_text_targets (widget);
+
+	g_signal_connect (widget, "drag-data-received",
+		G_CALLBACK (cb_pane_drag_data_received), pane);
+	g_signal_connect (widget, "drag-data-get",
+			  G_CALLBACK (cb_gnm_pane_drag_data_get), scg);
+	g_signal_connect (widget, "drag-motion",
+			  G_CALLBACK (cb_gnm_pane_drag_motion), pane);
+ 	g_signal_connect (widget, "drag-leave",
+			  G_CALLBACK (cb_gnm_pane_drag_leave), pane);
+}
+
 void
 gnm_pane_init (GnmPane *pane, SheetControlGUI *scg,
 	       gboolean col_headers, gboolean row_headers, int index)
 {
 	FooCanvasItem	 *item;
 	Sheet *sheet;
-	GnmRange r;
 
 	g_return_if_fail (!pane->is_active);
 
@@ -188,6 +332,12 @@ gnm_pane_init (GnmPane *pane, SheetControlGUI *scg,
 		"popup-menu",
 		G_CALLBACK (cb_pane_popup_menu), pane);
 
+	if (NULL != scg &&
+	    NULL != (sheet = sc_sheet (SHEET_CONTROL (scg))) &&
+	    fabs (1. - sheet->last_zoom_factor_used) > 1e-6)
+		foo_canvas_set_pixels_per_unit (FOO_CANVAS (pane->gcanvas),
+						sheet->last_zoom_factor_used);
+
 	item = foo_canvas_item_new (pane->gcanvas->grid_items,
 		item_grid_get_type (),
 		"SheetControlGUI", scg,
@@ -199,7 +349,6 @@ gnm_pane_init (GnmPane *pane, SheetControlGUI *scg,
 		"SheetControlGUI", scg,
 		NULL);
 	pane->cursor.std = ITEM_CURSOR (item);
-	gnm_pane_cursor_bound_set (pane, range_init (&r, 0, 0, 0, 0)); /* A1 */
 
 	pane->editor = NULL;
 	pane->cursor.rangesel = NULL;
@@ -225,12 +374,13 @@ gnm_pane_init (GnmPane *pane, SheetControlGUI *scg,
 	/* create views for the sheet objects */
 	sheet = sc_sheet (SHEET_CONTROL (scg));
 	if (sheet != NULL) {
-		GList *ptr;
+		GSList *ptr;
 		for (ptr = sheet->sheet_objects; ptr != NULL ; ptr = ptr->next)
 			sheet_object_new_view (ptr->data,
 				(SheetObjectViewContainer *)pane);
 	}
 
+	gnm_pane_drag_dest_init (pane, scg);
 	pane->mouse_cursor = NULL;
 }
 
@@ -307,6 +457,7 @@ gnm_pane_colrow_resize_start (GnmPane *pane,
 	FooCanvasPoints *points;
 	FooCanvasItem *item;
 	double zoom;
+	gboolean text_is_rtl;
 
 	g_return_if_fail (pane != NULL);
 	g_return_if_fail (pane->colrow_resize.guide  == NULL);
@@ -315,12 +466,15 @@ gnm_pane_colrow_resize_start (GnmPane *pane,
 
 	gcanvas = pane->gcanvas;
 	scg = gcanvas->simple.scg;
+	text_is_rtl = scg->sheet_control.sheet->text_is_rtl;
 	zoom = FOO_CANVAS (gcanvas)->pixels_per_unit;
 
 	points = pane->colrow_resize.points = foo_canvas_points_new (2);
 	if (is_cols) {
-		double const x = scg_colrow_distance_get (scg, TRUE,
+		double x = scg_colrow_distance_get (scg, TRUE,
 					0, resize_pos) / zoom;
+		if (text_is_rtl)
+			x = -x;
 		points->coords [0] = x;
 		points->coords [1] = scg_colrow_distance_get (scg, FALSE,
 					0, gcanvas->first.row) / zoom;
@@ -336,21 +490,26 @@ gnm_pane_colrow_resize_start (GnmPane *pane,
 		points->coords [2] = scg_colrow_distance_get (scg, TRUE,
 					0, gcanvas->last_visible.col+1) / zoom;
 		points->coords [3] = y;
+
+		if (text_is_rtl) {
+			points->coords [0] *= -1.;
+			points->coords [2] *= -1.;
+		}
 	}
 
 	/* Position the stationary only.  Guide line is handled elsewhere. */
 	item = foo_canvas_item_new (gcanvas->action_items,
 		FOO_TYPE_CANVAS_LINE,
 		"points", points,
-		"fill_color", "black",
-		"width_pixels", 1,
+		"fill-color", "black",
+		"width-pixels", 1,
 		NULL);
 	pane->colrow_resize.start = GTK_OBJECT (item);
 
 	item = foo_canvas_item_new (gcanvas->action_items,
 		FOO_TYPE_CANVAS_LINE,
-		"fill_color", "black",
-		"width_pixels", 1,
+		"fill-color", "black",
+		"width-pixels", 1,
 		NULL);
 	pane->colrow_resize.guide = GTK_OBJECT (item);
 }
@@ -375,23 +534,18 @@ gnm_pane_colrow_resize_stop (GnmPane *pane)
 }
 
 void
-gnm_pane_colrow_resize_move (GnmPane *pane,
-			     gboolean is_cols, int resize_pos)
+gnm_pane_colrow_resize_move (GnmPane *pane, gboolean is_cols, int resize_pos)
 {
-	FooCanvasItem *resize_guide;
-	FooCanvasPoints *points;
-	double zoom;
+	FooCanvasItem *resize_guide = FOO_CANVAS_ITEM (pane->colrow_resize.guide);
+	FooCanvasPoints *points     = pane->colrow_resize.points;
+	double const	 scale	    = 1. / resize_guide->canvas->pixels_per_unit;
 
-	g_return_if_fail (pane != NULL);
-
-	resize_guide = FOO_CANVAS_ITEM (pane->colrow_resize.guide);
-	points = pane->colrow_resize.points;
-	zoom = FOO_CANVAS (pane->gcanvas)->pixels_per_unit;
-
-	if (is_cols)
-		points->coords [0] = points->coords [2] = resize_pos / zoom;
-	else
-		points->coords [1] = points->coords [3] = resize_pos / zoom;
+	if (is_cols) {
+		gboolean text_is_rtl = pane->gcanvas->simple.scg->sheet_control.sheet->text_is_rtl;
+		points->coords [0] = points->coords [2] = scale *
+			(text_is_rtl ? -resize_pos : resize_pos);
+	} else
+		points->coords [1] = points->coords [3] = scale * resize_pos;
 
 	foo_canvas_item_set (resize_guide, "points",  points, NULL);
 }
@@ -569,26 +723,41 @@ gnm_pane_edit_stop (GnmPane *pane)
 	}
 }
 
+void
+gnm_pane_objects_drag (GnmPane *pane, SheetObject *so,
+		       gdouble new_x, gdouble new_y, int drag_type, 
+		       gboolean symmetric,gboolean snap_to_grid)
+{
+ 	double dx, dy;
+ 	dx = new_x - pane->drag.last_x;
+ 	dy = new_y - pane->drag.last_y;
+	pane->drag.had_motion = TRUE;
+ 	
+ 	scg_objects_drag (pane->gcanvas->simple.scg, pane->gcanvas,
+ 		so, &dx, &dy, drag_type, symmetric, snap_to_grid, TRUE);
+ 
+ 	pane->drag.last_x += dx;
+ 	pane->drag.last_y += dy;
+}
+
 #define CTRL_PT_SIZE		4
 #define CTRL_PT_OUTLINE		0
 /* space for 2 halves and a full */
 #define CTRL_PT_TOTAL_SIZE 	(CTRL_PT_SIZE*4 + CTRL_PT_OUTLINE*2)
 
+/* new_x and new_y are in world coords */
 static void
 gnm_pane_object_move (GnmPane *pane, GObject *ctrl_pt,
 		      gdouble new_x, gdouble new_y,
-		      gboolean symmetric)
+ 		      gboolean symmetric,
+ 		      gboolean snap_to_grid)
 {
 	int const idx = GPOINTER_TO_INT (g_object_get_data (ctrl_pt, "index"));
 	SheetObject *so  = g_object_get_data (G_OBJECT (ctrl_pt), "so");
-	double dx = new_x - pane->drag.last_x;
-	double dy = new_y - pane->drag.last_y;
-	pane->drag.last_x = new_x;
-	pane->drag.last_y = new_y;
-	pane->drag.had_motion = TRUE;
-	scg_objects_drag (pane->gcanvas->simple.scg,
-		so, dx, dy, idx, symmetric);
-	if (idx != 8)
+
+	gnm_pane_objects_drag (pane, so, new_x, new_y, idx, 
+			       symmetric, snap_to_grid);
+ 	if (idx != 8)
 		gnm_pane_display_obj_size_tip (pane, so);
 }
 
@@ -596,15 +765,18 @@ static gboolean
 cb_slide_handler (GnmCanvas *gcanvas, int col, int row, gpointer ctrl_pt)
 {
 	int x, y;
-	gdouble new_x, new_y;
-	SheetControlGUI *scg = gcanvas->simple.scg;
+	SheetControlGUI const *scg = gcanvas->simple.scg;
+	double const scale = 1. / FOO_CANVAS (gcanvas)->pixels_per_unit;
 
 	x = scg_colrow_distance_get (scg, TRUE, gcanvas->first.col, col);
 	x += gcanvas->first_offset.col;
 	y = scg_colrow_distance_get (scg, FALSE, gcanvas->first.row, row);
 	y += gcanvas->first_offset.row;
-	foo_canvas_c2w (FOO_CANVAS (gcanvas), x, y, &new_x, &new_y);
-	gnm_pane_object_move (gcanvas->pane, ctrl_pt, new_x, new_y, FALSE);
+
+	if (scg->sheet_control.sheet->text_is_rtl)
+		x *= -1;
+
+	gnm_pane_object_move (gcanvas->pane, ctrl_pt, x * scale, y * scale, FALSE, FALSE);
 
 	return TRUE;
 }
@@ -725,6 +897,76 @@ control_point_set_cursor (SheetControlGUI const *scg, FooCanvasItem *ctrl_pt)
 	gnm_widget_set_cursor_type (GTK_WIDGET (ctrl_pt->canvas), cursor);
 }
 
+static void
+target_list_add_list (GtkTargetList *targets, GtkTargetList *added_targets)
+{
+	GList *ptr;
+	GtkTargetPair *tp;
+
+	g_return_if_fail (targets != NULL);
+
+	if (added_targets == NULL)
+		return;
+
+	for (ptr = added_targets->list; ptr !=  NULL; ptr = ptr->next) {
+		tp = (GtkTargetPair *)ptr->data;
+		gtk_target_list_add (targets, tp->target, tp->flags, tp->info);
+	}
+}
+
+/**
+ * Drag one or more sheet objects using GTK drag and drop, to the same
+ * sheet, another workbook, another gnumeric or a different application.
+ */
+static void
+gnm_pane_drag_begin (GnmPane *pane, SheetObject *so, GdkEvent *event)
+{
+	GdkDragContext *context;
+	GtkTargetList *targets, *im_targets;
+	FooCanvas *canvas    = FOO_CANVAS (pane->gcanvas);
+	SheetControlGUI *scg = pane->gcanvas->simple.scg;
+	GSList *objects;
+	SheetObject *imageable = NULL;
+	GSList *ptr;
+	SheetObject *candidate;
+
+	targets = gtk_target_list_new (drag_types_out, 
+				  G_N_ELEMENTS (drag_types_out));
+	objects = go_hash_keys (scg->selected_objects);
+	for (ptr = objects; ptr != NULL; ptr = ptr->next) {
+		candidate = SHEET_OBJECT (ptr->data);
+
+		if (IS_SHEET_OBJECT_IMAGEABLE (candidate)) {
+			imageable = candidate;
+			break;
+		}
+	}
+	if (imageable) {
+		im_targets = sheet_object_get_target_list (imageable);
+		if (im_targets != NULL) {
+			target_list_add_list (targets, im_targets);
+			gtk_target_list_unref (im_targets);
+		}
+	}
+#ifdef DEBUG_DND
+	{
+		GList *l;
+		printf ("%d offered formats:\n", 
+			g_list_length (targets->list));
+		for (l = targets->list; l; l = l->next) {
+			GtkTargetPair *pair = (GtkTargetPair *)l->data;
+			printf ("%s\n", gdk_atom_name (pair->target));
+ 		}
+	}
+#endif
+
+	context = gtk_drag_begin (GTK_WIDGET (canvas), targets, 
+				  GDK_ACTION_COPY | GDK_ACTION_MOVE, 
+				  pane->drag.button, event);
+	gtk_target_list_unref (targets);
+	g_slist_free (objects);
+}
+
 void
 gnm_pane_object_start_resize (GnmPane *pane, GdkEventButton *event,
 			      SheetObject *so, int drag_type, gboolean is_creation)
@@ -740,16 +982,18 @@ gnm_pane_object_start_resize (GnmPane *pane, GdkEventButton *event,
 
 	if (make_dup) {
 		SheetControlGUI *scg = pane->gcanvas->simple.scg;
-		GSList *ptr, *objs = gnm_hash_keys (scg->selected_objects);
+		GSList *ptr, *objs = go_hash_keys (scg->selected_objects);
 
 		for (ptr = objs ; ptr != NULL ; ptr = ptr->next) {
 			SheetObject *dup_obj = sheet_object_dup (ptr->data);
-			sheet_object_set_sheet (dup_obj, sc_sheet (SHEET_CONTROL (scg)));
-			scg_object_select (scg, dup_obj);
-			g_object_unref (dup_obj);
-			scg_object_unselect (scg, ptr->data);
-			if (so == ptr->data)
-				so = dup_obj;
+			if (dup_obj != NULL) {
+				sheet_object_set_sheet (dup_obj, sc_sheet (SHEET_CONTROL (scg)));
+				scg_object_select (scg, dup_obj);
+				g_object_unref (dup_obj);
+				scg_object_unselect (scg, ptr->data);
+				if (so == ptr->data)
+					so = dup_obj;
+			}
 		}
 		g_slist_free (objs);
 	}
@@ -760,6 +1004,7 @@ gnm_pane_object_start_resize (GnmPane *pane, GdkEventButton *event,
 
 	gnm_simple_canvas_grab (ctrl_pts [drag_type],
 		GDK_POINTER_MOTION_MASK |
+		GDK_BUTTON_PRESS_MASK |
 		GDK_BUTTON_RELEASE_MASK,
 		NULL, event->time);
 	pane->drag.created_objects = is_creation || make_dup;
@@ -790,7 +1035,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 
 		if (idx != 8) {
 			foo_canvas_item_set (ctrl_pt,
-				"fill_color",    "green",
+				"fill-color",    "green",
 				NULL);
 			gnm_pane_display_obj_size_tip (pane, so);
 		}
@@ -800,12 +1045,18 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 		scg_set_display_cursor (scg);
 		if (idx != 8) {
 			foo_canvas_item_set (ctrl_pt,
-				"fill_color",    "white",
+				"fill-color",    "white",
 				NULL);
 			gnm_pane_clear_obj_size_tip (pane);
 		}
 		break;
 
+	case GDK_2BUTTON_PRESS:
+		if (pane->drag.button == 1)
+			sheet_object_get_editor (so, SHEET_CONTROL (scg));
+		else
+			break;
+
 	case GDK_BUTTON_RELEASE:
 		if (pane->drag.button != (int)event->button.button)
 			return FALSE;
@@ -819,7 +1070,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 		else if (pane->drag.created_objects && idx == 7) {
 			double w, h;
 			sheet_object_default_size (so, &w, &h);
-			scg_objects_drag (scg, NULL, w, h, 7, FALSE);
+			scg_objects_drag (scg, NULL, NULL, &w, &h, 7, FALSE, FALSE, FALSE);
 			scg_objects_drag_commit	(scg, 7, TRUE);
 		}
 		gnm_pane_clear_obj_size_tip (pane);
@@ -853,13 +1104,16 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 		 * the semantics of the col,row args in the callback.  However,
 		 * that is more work than I want to do right now.
 		 */
-		if (gnm_canvas_handle_motion (GNM_CANVAS (ctrl_pt->canvas),
-					      ctrl_pt->canvas, &event->motion,
-					      GNM_CANVAS_SLIDE_X | GNM_CANVAS_SLIDE_Y | GNM_CANVAS_SLIDE_EXTERIOR_ONLY,
-					      cb_slide_handler, ctrl_pt))
+		if (idx == 8 &&  !pane->drag.created_objects)
+			gnm_pane_drag_begin (pane, so, event);
+		else if (gnm_canvas_handle_motion (GNM_CANVAS (ctrl_pt->canvas),
+						   ctrl_pt->canvas, &event->motion,
+						   GNM_CANVAS_SLIDE_X | GNM_CANVAS_SLIDE_Y | GNM_CANVAS_SLIDE_EXTERIOR_ONLY,
+						   cb_slide_handler, ctrl_pt))
 			gnm_pane_object_move (pane, G_OBJECT (ctrl_pt),
 				event->motion.x, event->motion.y,
-				(event->button.state & GDK_CONTROL_MASK) != 0);
+				(event->button.state & GDK_CONTROL_MASK) != 0,
+				(event->button.state & GDK_SHIFT_MASK) != 0);
 		break;
 
 	default:
@@ -898,9 +1152,9 @@ new_control_point (GnmPane *pane, SheetObject *so, int idx, double x, double y)
 	item = foo_canvas_item_new (
 		gcanvas->action_items,
 		FOO_TYPE_CANVAS_ELLIPSE,
-		"outline_color", "black",
-		"fill_color",    "white",
-		"width_pixels",  CTRL_PT_OUTLINE,
+		"outline-color", "black",
+		"fill-color",    "white",
+		"width-pixels",  CTRL_PT_OUTLINE,
 		NULL);
 
 	g_signal_connect (G_OBJECT (item),
@@ -950,10 +1204,10 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, FooCanvasItem **ctrl_pts,
 				GTK_WIDGET (pane->gcanvas)->window, dashed, 8, 8);
 			ctrl_pts [9] = foo_canvas_item_new (pane->gcanvas->action_items,
 				FOO_TYPE_CANVAS_RECT,
-				"fill_color",		NULL,
-				"width_units",   	1.,
-				"outline_color",	"black",
-				"outline_stipple",	stipple,
+				"fill-color",		NULL,
+				"width-units",   	1.,
+				"outline-color",	"black",
+				"outline-stipple",	stipple,
 				NULL);
 			g_object_unref (stipple);
 			foo_canvas_item_lower_to_bottom (ctrl_pts [9]);
@@ -965,8 +1219,12 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, FooCanvasItem **ctrl_pts,
 		       NULL);
 	} else {
 		double coords[4];
+		SheetObjectView *sov = sheet_object_get_view (so, (SheetObjectViewContainer *)pane);
+		if (NULL == sov)
+			sov = sheet_object_new_view (so, (SheetObjectViewContainer *)pane);
+
 		coords [0] = l; coords [2] = r; coords [1] = t; coords [3] = b;
-		sheet_object_view_set_bounds (sheet_object_get_view (so, (SheetObjectViewContainer *)pane), coords, TRUE);
+		sheet_object_view_set_bounds (sov, coords, TRUE);
 		normalize_high_low (r, l);
 		normalize_high_low (b, t);
 	}
@@ -986,17 +1244,17 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, FooCanvasItem **ctrl_pts,
 		FooCanvasItem *item = foo_canvas_item_new (
 			pane->gcanvas->action_items,
 			item_acetate_get_type (),
-			"fill_color",		NULL,
+			"fill-color",		NULL,
 #ifdef WITH_STIPPLE_BORDER
-			"width_units",		(double)(CTRL_PT_SIZE + CTRL_PT_OUTLINE),
-			"outline_color",	"black",
-			"outline_stipple",	stipple,
+			"width-units",		(double)(CTRL_PT_SIZE + CTRL_PT_OUTLINE),
+			"outline-color",	"black",
+			"outline-stipple",	stipple,
 #endif
 #if 0
 			/* work around the screwup in canvas-item-shape that adds a large
 			 * border to anything that uses miter (required for gnome-canvas
 			 * not foocanvas */
-			"join_style",		GDK_JOIN_ROUND,
+			"join-style",		GDK_JOIN_ROUND,
 #endif
 			NULL);
 #ifdef WITH_STIPPLE_BORDER
@@ -1081,15 +1339,14 @@ cb_sheet_object_canvas_event (FooCanvasItem *view, GdkEvent *event,
 		if (event->button.button > 3)
 			return FALSE;
 
-		/* If we are here the object is not selected yet */
-		g_return_val_if_fail (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so), FALSE);
-
-		if (!(event->button.state & GDK_SHIFT_MASK))
-			scg_object_unselect (pane->gcanvas->simple.scg, NULL);
-
-		scg_object_select (pane->gcanvas->simple.scg, so);
-		if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so))
-			return FALSE;	/* protected ? */
+		/* cb_sheet_object_widget_canvas_event calls even if selected */
+		if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so)) {
+			if (!(event->button.state & GDK_SHIFT_MASK))
+				scg_object_unselect (pane->gcanvas->simple.scg, NULL);
+			scg_object_select (pane->gcanvas->simple.scg, so);
+			if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so))
+				return FALSE;	/* protected ? */
+		}
 
 		if (event->button.button < 3)
 			gnm_pane_object_start_resize (pane, &event->button, so, 8, FALSE);
@@ -1115,9 +1372,16 @@ static int
 cb_sheet_object_widget_canvas_event (GtkWidget *widget, GdkEvent *event,
 				     FooCanvasItem *view)
 {
-	if (event->type == GDK_BUTTON_PRESS && event->button.button == 3)
+	if (event->type == GDK_ENTER_NOTIFY ||
+	    (event->type == GDK_BUTTON_PRESS && event->button.button == 3))
 		return cb_sheet_object_canvas_event (view, event,
 			sheet_object_view_get_so (SHEET_OBJECT_VIEW (view)));
+	if (event->type == GDK_2BUTTON_PRESS && event->button.button == 1) {
+		sheet_object_get_editor (
+			sheet_object_view_get_so (SHEET_OBJECT_VIEW (view)),
+			SHEET_CONTROL (GNM_SIMPLE_CANVAS (view->canvas)->scg));
+		return TRUE;
+	}
 
 	return FALSE;
 }
