@@ -31,11 +31,11 @@
 #include "workbook.h"
 #include "str.h"
 #include "position.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "auto-format.h"
 #include "ranges.h"
 #include "parse-util.h"
-#include <goffice/graph/go-data-impl.h>
+#include <goffice/data/go-data-impl.h>
 #include <goffice/utils/go-math.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -592,8 +592,8 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 	GnmGODataVector *vec = (GnmGODataVector *)dat;
 	GnmValue const *v;
 	GnmEvalPos ep;
-	GnmFormat const *format = NULL;
-	GnmDateConventions const *date_conv = NULL;
+	GOFormat const *format = NULL;
+	GODateConventions const *date_conv = NULL;
 
 	if (vec->val == NULL)
 		gnm_go_data_vector_load_len (dat);
@@ -864,7 +864,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 	GnmEvalPos ep;
 	GnmRange r;
 	Sheet *start_sheet, *end_sheet;
-	GOMatrixSize size = go_data_matrix_get_size (dat); /* force calculation */
+	GODataMatrixSize size = go_data_matrix_get_size (dat); /* force calculation */
 	double *vals, minimum, maximum;
 	GnmValue *v;
 	int row, col, cur;
@@ -979,7 +979,7 @@ gnm_go_data_matrix_get_value (GODataMatrix *dat, unsigned i, unsigned j)
 		gnm_go_data_matrix_load_size (dat);
 
 	eval_pos_init_dep (&ep, &mat->dep);
-	v = (GnmValue*) value_area_get_x_y (mat->val, i, j, &ep);
+	v = value_dup (value_area_get_x_y (mat->val, i, j, &ep));
 	v = value_coerce_to_number (v, &valid, &ep);
 
 	if (valid) {
@@ -996,8 +996,8 @@ gnm_go_data_matrix_get_str (GODataMatrix *dat, unsigned i, unsigned j)
 	GnmGODataMatrix *mat = (GnmGODataMatrix *)dat;
 	GnmValue const *v;
 	GnmEvalPos ep;
-	GnmFormat const *format = NULL;
-	GnmDateConventions const *date_conv = NULL;
+	GOFormat const *format = NULL;
+	GODateConventions const *date_conv = NULL;
 
 	if (mat->val == NULL)
 		gnm_go_data_matrix_load_size (dat);
