@@ -7,7 +7,6 @@
  *  Jody Goldberg (jody@gnome.org)
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "gui-clipboard.h"
 
@@ -15,23 +14,29 @@
 #include "clipboard.h"
 #include "selection.h"
 #include "application.h"
-#include "io-context.h"
 #include "workbook-control-gui-priv.h"
 #include "workbook.h"
 #include "workbook-view.h"
 #include "ranges.h"
 #include "sheet.h"
 #include "sheet-style.h"
+#include "sheet-object.h"
+#include "sheet-control-gui.h"
 #include "commands.h"
-#include "xml-io.h"
 #include "value.h"
+#include "number-match.h"
 #include "dialog-stf.h"
 #include "stf-parse.h"
 #include "mstyle.h"
+#include "gnm-format.h"
 #include "gnumeric-gconf.h"
+#include "xml-sax.h"
+#include "xml-io.h"
 
+#include <goffice/app/io-context.h>
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
+#include <glib/gi18n.h>
 #include <libxml/globals.h>
 #include <locale.h>
 #include <string.h>
@@ -40,7 +45,8 @@
 typedef struct {
 	WorkbookControlGUI *wbcg;
 	GnmPasteTarget        *paste_target;
-	GdkAtom            fallback;
+	GdkAtom            image_atom;
+	GdkAtom            string_atom;
 } GnmGtkClipboardCtxt;
 
 /* The name of our clipboard atom and the 'magic' info number */
@@ -54,8 +60,6 @@ typedef struct {
 #define CTEXT_ATOM_NAME "COMPOUND_TEXT"
 #define STRING_ATOM_NAME "STRING"
 
-/* The name of the TARGETS atom (don't change unless you know what you are doing!) */
-#define TARGETS_ATOM_NAME "TARGETS"
 
 static GnmCellRegion *
 text_to_cell_region (WorkbookControlGUI *wbcg,
@@ -69,6 +73,11 @@ text_to_cell_region (WorkbookControlGUI *wbcg,
 	char *data_converted = NULL;
 	int i;
 
+	/* See if this is a "single line + line end" or a "multiline"
+	 * string. If this is _not_ the case we won't invoke the STF, it is
+	 * unlikely that the user will actually need it in this case.
+	 * NOTE: This is making an assumption on what the user 'wants', this
+	 * is not really a good thing. We should put this in a config dialog. */
 	oneline = TRUE;
 	for (i = 0; i < data_len; i++)
 		if (data[i] == '\n') {
@@ -93,34 +102,27 @@ text_to_cell_region (WorkbookControlGUI *wbcg,
 		}
 	}
 
-	/*
-	 * See if this is a "single line + line end" or a "multiline"
-	 * string. If this is _not_ the case we won't invoke the STF, it is
-	 * unlikely that the user will actually need it in this case.
-	 * NOTE: This is making an assumption on what the user 'wants', this
-	 * is not really a good thing. We should put this in a config dialog.
-	 */
 	if (oneline) {
-		CellCopy *ccopy;
+		GnmCellCopy *cc = gnm_cell_copy_new (0, 0);
 
-		ccopy = g_new (CellCopy, 1);
-		ccopy->type = CELL_COPY_TYPE_TEXT;
-		ccopy->col_offset = 0;
-		ccopy->row_offset = 0;
-		ccopy->u.text = g_strndup (data, data_len);
+		char *tmp = g_strndup (data, data_len);
+		g_free (data_converted);
+		cc->val = format_match (tmp, NULL,
+			workbook_date_conv (wb_control_workbook (WORKBOOK_CONTROL (wbcg))));
+		cc->expr = NULL;
+		g_free (tmp);
 
 		cr = cellregion_new (NULL);
-		cr->content = g_slist_prepend (cr->content, ccopy);
+		cr->content = g_slist_prepend (cr->content, cc);
 		cr->cols = cr->rows = 1;
-
-		g_free (data_converted);
 	} else {
 		dialogresult = stf_dialog (wbcg, opt_encoding, fixed_encoding,
 					   NULL, FALSE,
 					   _("clipboard"), data, data_len);
 
 		if (dialogresult != NULL) {
-			cr = stf_parse_region (dialogresult->parseoptions, dialogresult->text, NULL);
+			cr = stf_parse_region (dialogresult->parseoptions,
+				dialogresult->text, NULL, wb_control_workbook (WORKBOOK_CONTROL (wbcg)));
 			g_return_val_if_fail (cr != NULL, cellregion_new (NULL));
 
 			stf_dialog_result_attach_formats_to_cr (dialogresult, cr);
@@ -134,6 +136,47 @@ text_to_cell_region (WorkbookControlGUI *wbcg,
 	return cr;
 }
 
+static void
+text_content_received (GtkClipboard *clipboard,  GtkSelectionData *sel,
+		       gpointer closure)
+{
+	GnmGtkClipboardCtxt *ctxt = closure;
+	WorkbookControlGUI *wbcg = ctxt->wbcg;
+	WorkbookControl	   *wbc  = WORKBOOK_CONTROL (wbcg);
+	GnmPasteTarget	   *pt   = ctxt->paste_target;
+	GnmCellRegion *content = NULL;
+
+	/* Nothing on clipboard? */
+	if (sel->length < 0) {
+		;
+	} else if (sel->target == gdk_atom_intern (UTF8_ATOM_NAME, FALSE)) {
+		content = text_to_cell_region (wbcg, sel->data, sel->length, "UTF-8", TRUE);
+	} else if (sel->target == gdk_atom_intern (CTEXT_ATOM_NAME, FALSE)) {
+		/* COMPOUND_TEXT is icky.  Just let GTK+ do the work.  */
+		char *data_utf8 = gtk_selection_data_get_text (sel);
+		content = text_to_cell_region (wbcg, data_utf8, strlen (data_utf8), "UTF-8", TRUE);
+		g_free (data_utf8);
+	} else if (sel->target == gdk_atom_intern (STRING_ATOM_NAME, FALSE)) {
+		char const *locale_encoding;
+		g_get_charset (&locale_encoding);
+
+		content = text_to_cell_region (wbcg, sel->data, sel->length, locale_encoding, FALSE);
+	}
+	if (content) {
+		/*
+		 * if the conversion from the X selection -> a cellregion
+		 * was canceled this may have content sized -1,-1
+		 */
+		if (content->cols > 0 && content->rows > 0)
+			cmd_paste_copy (wbc, pt, content);
+
+		/* Release the resources we used */
+		cellregion_unref (content);
+	}
+	g_free (ctxt->paste_target);
+	g_free (ctxt);
+}
+
 /**
  * Use the file_opener plugin service to read into a temporary workbook, in
  * order to copy from it to the paste target. A temporary sheet would do just
@@ -150,7 +193,7 @@ table_cellregion_read (WorkbookControl *wbc, const char *reader_id,
 	Workbook *wb = NULL;
 	GList *l = NULL;
 	GnmCellRegion *ret = NULL;
-	const GnmFileOpener *reader = gnm_file_opener_for_id (reader_id);
+	const GOFileOpener *reader = go_file_opener_for_id (reader_id);
 	IOContext *ioc;
 	GsfInput *input;
 
@@ -159,7 +202,7 @@ table_cellregion_read (WorkbookControl *wbc, const char *reader_id,
 		return NULL;
 	}
 
-	ioc = gnumeric_io_context_new (GNM_CMD_CONTEXT (wbc));
+	ioc = gnumeric_io_context_new (GO_CMD_CONTEXT (wbc));
 	input = gsf_input_memory_new (buffer, length, FALSE);
 	wb_view = wb_view_new_from_input  (input, reader, ioc, NULL);
 	if (gnumeric_io_error_occurred (ioc) || wb_view == NULL) {
@@ -193,7 +236,29 @@ out:
 }
 
 static void
-complex_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
+image_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
+			  gpointer closure)
+{
+	GnmGtkClipboardCtxt *ctxt = closure;
+	WorkbookControlGUI *wbcg = ctxt->wbcg;
+	GnmPasteTarget	   *pt   = ctxt->paste_target;
+
+	if (sel->length > 0) {
+		scg_paste_image (wbcg_cur_scg (wbcg), &pt->range, 
+				 sel->data, sel->length);
+		g_free (ctxt->paste_target);
+		g_free (ctxt);
+	} else  if (ctxt->string_atom !=  GDK_NONE) {
+		gtk_clipboard_request_contents (clipboard, ctxt->string_atom, 
+						text_content_received, ctxt);
+	} else {
+		g_free (ctxt->paste_target);
+		g_free (ctxt);
+	}
+}
+
+static void
+table_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 			  gpointer closure)
 {
 	GnmGtkClipboardCtxt *ctxt = closure;
@@ -210,18 +275,6 @@ complex_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 		/* The data is the gnumeric specific XML interchange format */
 		content = xml_cellregion_read (wbc, pt->sheet,
 					       sel->data, sel->length);
-	} else if (sel->target == gdk_atom_intern (UTF8_ATOM_NAME, FALSE)) {
-		content = text_to_cell_region (wbcg, sel->data, sel->length, "UTF-8", TRUE);
-	} else if (sel->target == gdk_atom_intern (CTEXT_ATOM_NAME, FALSE)) {
-		/* COMPOUND_TEXT is icky.  Just let GTK+ do the work.  */
-		char *data_utf8 = gtk_selection_data_get_text (sel);
-		content = text_to_cell_region (wbcg, data_utf8, strlen (data_utf8), "UTF-8", TRUE);
-		g_free (data_utf8);
-	} else if (sel->target == gdk_atom_intern (STRING_ATOM_NAME, FALSE)) {
-		char const *locale_encoding;
-		g_get_charset (&locale_encoding);
-
-		content = text_to_cell_region (wbcg, sel->data, sel->length, locale_encoding, FALSE);
 	} else if ((sel->target == gdk_atom_intern (OOO_ATOM_NAME, FALSE)) ||
 		   (sel->target == gdk_atom_intern (OOO11_ATOM_NAME, FALSE))) {
 		content = table_cellregion_read (wbc, "Gnumeric_OpenCalc:openoffice",
@@ -237,46 +290,43 @@ complex_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 		 * if the conversion from the X selection -> a cellregion
 		 * was canceled this may have content sized -1,-1
 		 */
-		if (content->cols > 0 && content->rows > 0)
+		if ((content->cols > 0 && content->rows > 0) ||
+		    content->objects != NULL)
 			cmd_paste_copy (wbc, pt, content);
 
 		/* Release the resources we used */
 		cellregion_unref (content);
-
 		g_free (ctxt->paste_target);
 		g_free (ctxt);
-	} else if (ctxt->fallback != GDK_NONE) {
-		GdkAtom preferred = ctxt->fallback;
-		ctxt->fallback = GDK_NONE;
-		gtk_clipboard_request_contents (clipboard, preferred,
-						complex_content_received,
-						ctxt);
+	} else if (ctxt->image_atom != GDK_NONE) {
+		gtk_clipboard_request_contents (clipboard, ctxt->image_atom,
+						image_content_received, ctxt);
+	} else if (ctxt->string_atom != GDK_NONE) {
+		gtk_clipboard_request_contents (clipboard, ctxt->string_atom, 
+						text_content_received, ctxt);
 	} else {
-		/* We're giving up */
 		g_free (ctxt->paste_target);
 		g_free (ctxt);
 	}
 }
 
 /**
- * x_clipboard_received:
+ * x_targets_received:
  *
  * Invoked when the selection has been received by our application.
  * This is triggered by a call we do to gtk_clipboard_request_contents.
  *
- * We try to import a spreadsheet/table, and fall back to a string format
- * if this fails, e.g. for html which contains something which is not a table.
+ * We try to import a spreadsheet/table, next an image, and finally fall back 
+ * to a string format if the others fail, e.g. for html which does not
+ * contain a table. 
  */
 static void
-x_clipboard_received (GtkClipboard *clipboard, GtkSelectionData *sel,
-		      gpointer closure)
+x_targets_received (GtkClipboard *clipboard, GdkAtom *targets, 
+		      gint n_targets, gpointer closure)
 {
 	GnmGtkClipboardCtxt *ctxt = closure;
-	GdkAtom table_atom = GDK_NONE, string_atom = GDK_NONE;
-	GdkAtom preferred = GDK_NONE;
-	GdkAtom const *targets = (GdkAtom *) sel->data;
-	unsigned const atom_count = (sel->length / sizeof (GdkAtom));
-	unsigned i, j;
+	GdkAtom table_atom = GDK_NONE;
+	gint i, j;
 
 	/* in order of preference */
 	static char const *table_fmts [] = {
@@ -294,15 +344,14 @@ x_clipboard_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 	};
 
 	/* Nothing on clipboard? */
-	if ((sel->length < 0) ||
-	    (sel->target != gdk_atom_intern (TARGETS_ATOM_NAME, FALSE))) {
+	if (targets == NULL || n_targets == 0) {
 		g_free (ctxt->paste_target);
 		g_free (ctxt);
 		return;
 	}
 
 #if 0
-	for (j = 0; j < atom_count && table_atom == GDK_NONE; j++)
+	for (j = 0; j < n_targets && table_atom == GDK_NONE; j++)
 		puts (gdk_atom_name (targets[j]));
 #endif
 	
@@ -312,39 +361,57 @@ x_clipboard_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 		/* Look for one we can use */
 		GdkAtom atom = gdk_atom_intern (table_fmts[i], FALSE);
 		/* is it on offer? */
-		for (j = 0; j < atom_count && table_atom == GDK_NONE; j++) {
+		for (j = 0; j < n_targets && table_atom == GDK_NONE; j++) {
 			if (targets [j] == atom)
 				table_atom = atom;
 		}
 	}
-		
+
+	if (table_atom == GDK_NONE) {
+		GtkTargetList *tl = gtk_target_list_new (NULL, 0);
+		GList *l;
+		GtkTargetPair *tp;
+		gboolean found = FALSE;
+
+		gtk_target_list_add_image_targets (tl, 0, FALSE);
+
+		/* Find an image format */
+		for (i = 0 ; i < n_targets && !found; i++) {
+			for (l = tl->list; l && !found; l = l->next) {
+				tp = (GtkTargetPair *)l->data;
+				if (tp->target == targets[i]) {
+					ctxt->image_atom = targets[i];
+					found = TRUE;
+				}
+			}
+		}
+		gtk_target_list_unref (tl);
+	}
+
 	/* Find a string format to fall back to */
-	for (i = 0 ; string_fmts[i] && string_atom == GDK_NONE ; i++) {
+	for (i = 0 ; string_fmts[i] && ctxt->string_atom == GDK_NONE ; i++) {
 		/* Look for one we can use */
 		GdkAtom atom = gdk_atom_intern (string_fmts[i],	FALSE);
 		/* is it on offer? */
-		for (j = 0; j < atom_count && string_atom == GDK_NONE;
+		for (j = 0; j < n_targets && ctxt->string_atom == GDK_NONE;
 		     j++) {
 			if (targets [j] == atom)
-				string_atom = atom;
+				ctxt->string_atom = atom;
 		}
-		if (string_atom != GDK_NONE)
+		if (ctxt->string_atom != GDK_NONE)
 			break;
 	}
 
-	if (table_atom != GDK_NONE) {
-		preferred = table_atom;
-		ctxt->fallback = string_atom;
-	} else if (string_atom != GDK_NONE) {
-		preferred = string_atom;
-		ctxt->fallback = GDK_NONE;
-	}
-
-	if (preferred != GDK_NONE)
-		gtk_clipboard_request_contents (clipboard, preferred,
-			 complex_content_received, ctxt);
+	if (table_atom != GDK_NONE)
+		gtk_clipboard_request_contents (clipboard, table_atom,
+						table_content_received, ctxt);
+	else if (ctxt->image_atom != GDK_NONE)
+		gtk_clipboard_request_contents (clipboard, ctxt->image_atom,
+						image_content_received, ctxt);
+	else if (ctxt->string_atom != GDK_NONE)
+		gtk_clipboard_request_contents (clipboard, ctxt->string_atom, 
+						text_content_received, ctxt);
 	else {
-		/* Nothing we can use - time to give up */
 		g_free (ctxt->paste_target);
 		g_free (ctxt);
 	}
@@ -356,7 +423,7 @@ table_cellregion_write (WorkbookControl *wbc, GnmCellRegion *cr,
 			char * saver_id, int *size)
 {
 	guchar *ret = NULL;
-	const GnmFileSaver *saver = gnm_file_saver_for_id (saver_id);
+	const GOFileSaver *saver = go_file_saver_for_id (saver_id);
 	GsfOutput *output;
 	IOContext *ioc;
 	Workbook *wb;
@@ -370,7 +437,7 @@ table_cellregion_write (WorkbookControl *wbc, GnmCellRegion *cr,
 		return NULL;
 
 	output = gsf_output_memory_new ();
-	ioc = gnumeric_io_context_new (GNM_CMD_CONTEXT (wbc));
+	ioc = gnumeric_io_context_new (GO_CMD_CONTEXT (wbc));
 	wb = workbook_new_with_sheets (1);
 	wb_view = workbook_view_new (wb);
 
@@ -380,8 +447,8 @@ table_cellregion_write (WorkbookControl *wbc, GnmCellRegion *cr,
 	r.end.row = cr->rows - 1;
 	
 	paste_target_init (&pt, sheet, &r, PASTE_ALL_TYPES);
-	if (clipboard_paste_region (cr, &pt, GNM_CMD_CONTEXT (wbc)) == FALSE) {
-		gnm_file_saver_save (saver, ioc, wb_view, output);
+	if (clipboard_paste_region (cr, &pt, GO_CMD_CONTEXT (wbc)) == FALSE) {
+		go_file_saver_save (saver, ioc, wb_view, output);
 		if (!gnumeric_io_error_occurred (ioc)) {
 			GsfOutputMemory *omem = GSF_OUTPUT_MEMORY (output);
 			gsf_off_t osize = gsf_output_size (output);
@@ -406,6 +473,118 @@ table_cellregion_write (WorkbookControl *wbc, GnmCellRegion *cr,
 	return ret;
 }
 
+static guchar *
+image_write (GnmCellRegion *cr, Sheet *sheet, gchar const *mime_type,
+	     int *size)
+{
+	guchar *ret = NULL;
+	SheetObject *so = NULL;
+	char *format;
+	GsfOutput *output;
+	GsfOutputMemory *omem;
+	gsf_off_t osize;
+	GSList *l;
+
+	*size = -1;
+
+	g_return_val_if_fail (cr->objects != NULL, NULL);
+	so = SHEET_OBJECT (cr->objects->data);
+	g_return_val_if_fail (so != NULL, NULL);
+
+	if (strncmp (mime_type, "image/", 6) != 0)
+		return ret;
+	for (l = cr->objects; l != NULL; l = l->next) {
+		if (IS_SHEET_OBJECT_IMAGEABLE (SHEET_OBJECT (l->data))) {
+			so = SHEET_OBJECT (l->data);
+			break;
+		}
+	}
+	if (so == NULL) {
+		g_warning ("non imageable object requested as image\n");
+		return ret;
+	}
+
+	format = go_mime_to_image_format (mime_type);
+	if (!format) {
+		g_warning ("No image format for %s\n", mime_type);
+		g_free (format);
+		return ret;
+	}
+	output = gsf_output_memory_new ();
+	omem   = GSF_OUTPUT_MEMORY (output);
+	sheet_object_write_image (so, format, output, NULL);
+	osize = gsf_output_size (output);
+			
+	*size = osize;
+	if (*size == osize) {
+		ret = g_malloc (*size);
+		memcpy (ret, gsf_output_memory_get_bytes (omem), *size);
+	} else {
+		g_warning ("Overflow");	/* Far fetched! */
+	}
+	gsf_output_close (output);
+	g_object_unref (output);
+	g_free (format);
+
+	return ret;
+}
+
+static GString *
+cellregion_to_string (GnmCellRegion const *cr,
+		      GODateConventions const *date_conv)
+{
+	GString *all, *line;
+	GSList	 *ptr;
+	GnmCellCopy const *src;
+	GnmStyle const	  *style;
+	char ***data;
+	int col, row;
+
+	g_return_val_if_fail (cr != NULL, NULL);
+	g_return_val_if_fail (cr->rows >= 0, NULL);
+	g_return_val_if_fail (cr->cols >= 0, NULL);
+
+	data = g_new0 (char **, cr->rows);
+
+	for (row = 0; row < cr->rows; row++)
+		data[row] = g_new0 (char *, cr->cols);
+
+	for (ptr = cr->content; ptr; ptr = ptr->next) {
+		src = ptr->data;
+		style = style_list_get_style (cr->styles,
+			src->col_offset, src->row_offset);
+		line = g_string_new (NULL);
+		format_value_gstring (line, mstyle_get_format (style),
+				src->val, NULL, -1, date_conv);
+		data[src->row_offset][src->col_offset] = 
+			g_string_free (line, FALSE);
+	}
+
+	all = g_string_sized_new (20 * cr->cols * cr->rows);
+	line = g_string_new (NULL);
+	for (row = 0; row < cr->rows;) {
+		g_string_assign (line, "");
+
+		for (col = 0; col < cr->cols;) {
+			if (data[row][col]) {
+				g_string_append (line, data[row][col]);
+				g_free (data[row][col]);
+			}
+			if (++col < cr->cols)
+				g_string_append_c (line, '\t');
+		}
+		g_string_append_len (all, line->str, line->len);
+		if (++row < cr->rows)
+			g_string_append_c (all, '\n');
+	}
+
+	g_string_free (line, TRUE);
+	for (row = 0; row < cr->rows; row++)
+		g_free (data[row]);
+	g_free (data);
+	return all;
+}
+
 /**
  * x_clipboard_get_cb
  *
@@ -420,6 +599,7 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 	Sheet *sheet = gnm_app_clipboard_sheet_get ();
 	GnmRange const *a = gnm_app_clipboard_area_get ();
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
+	gchar *target_name;
 
 	/*
 	 * Not sure how to handle this, not sure what purpose this has has
@@ -443,22 +623,20 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 
 	g_return_if_fail (clipboard != NULL);
 
+	target_name = gdk_atom_name (selection_data->target);
 	/*
 	 * Check whether the other application wants gnumeric XML format
 	 * in fact we only have to check the 'info' variable, however
 	 * to be absolutely sure I check if the atom checks out too
 	 */
-	if (selection_data->target == gdk_atom_intern (GNUMERIC_ATOM_NAME,
-						       FALSE)) {
-		int buffer_size;
-
-		xmlChar *buffer = xml_cellregion_write (wbc, clipboard, &buffer_size);
+	if (selection_data->target == gdk_atom_intern (GNUMERIC_ATOM_NAME, FALSE)) {
+		GsfOutputMemory *output  = gnm_cellregion_to_xml (clipboard);
 		gtk_selection_data_set (selection_data, selection_data->target, 8,
-					(guchar *) buffer, buffer_size);
-		xmlFree (buffer);
+			gsf_output_memory_get_bytes (output),
+			gsf_output_size (GSF_OUTPUT (output)));
+		g_object_unref (output);
 		to_gnumeric = TRUE;
-	} else if (selection_data->target == gdk_atom_intern (HTML_ATOM_NAME,
-							      FALSE)) {
+	} else if (selection_data->target == gdk_atom_intern (HTML_ATOM_NAME, FALSE)) {
 		char *saver_id = (char *) "Gnumeric_html:xhtml_range";
 		int buffer_size;
 		guchar *buffer = table_cellregion_write (wbc, clipboard,
@@ -468,18 +646,25 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 					selection_data->target, 8,
 					(guchar *) buffer, buffer_size);
 		g_free (buffer);
+	} else if (strncmp (target_name, "image/", 6) == 0) {
+		int buffer_size;
+		guchar *buffer = image_write (clipboard, sheet, target_name,
+					      &buffer_size);
+		gtk_selection_data_set (selection_data,
+					selection_data->target, 8,
+					(guchar *) buffer, buffer_size);
+		g_free (buffer);
 	} else {
-		PangoContext *context = gtk_widget_get_pango_context (GTK_WIDGET (wbcg_toplevel (wbcg)));
-		char *rendered_selection = cellregion_to_string (clipboard, context);
-
-		if (rendered_selection == NULL)
-			rendered_selection = g_strdup ("");
-		gtk_selection_data_set_text (selection_data, 
-					     (gchar *) rendered_selection,
-					     strlen (rendered_selection));
-
-		g_free (rendered_selection);
+		GString *res = cellregion_to_string (clipboard,
+			workbook_date_conv (sheet->workbook));
+		if (res != NULL) {
+			gtk_selection_data_set_text (selection_data, 
+				res->str, res->len);
+			g_string_free (res, TRUE);
+		} else
+			gtk_selection_data_set_text (selection_data, "", 0);
 	}
+	g_free (target_name);
 
 	/*
 	 * If this was a CUT operation we need to clear the content that was pasted
@@ -493,7 +678,7 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 				a->start.col, a->start.row,
 				a->end.col,   a->end.row,
 				CLEAR_VALUES|CLEAR_COMMENTS|CLEAR_RECALC_DEPS,
-				GNM_CMD_CONTEXT (wbc));
+				GO_CMD_CONTEXT (wbc));
 			gnm_app_clipboard_clear (TRUE);
 		}
 
@@ -508,9 +693,13 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
  */
 static gint
 x_clipboard_clear_cb (GtkClipboard *clipboard,
-		      gpointer      data)
+		      WorkbookControlGUI *wbcg)
 {
-	gnm_app_clipboard_clear (FALSE);
+	GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (wbcg_toplevel (wbcg)));
+
+	if (clipboard == 
+	    gtk_clipboard_get_for_display (display, GDK_SELECTION_CLIPBOARD))
+		gnm_app_clipboard_clear (FALSE);
 
 	return TRUE;
 }
@@ -526,42 +715,108 @@ x_request_clipboard (WorkbookControlGUI *wbcg, GnmPasteTarget const *pt)
 		 gnm_app_prefs->prefer_clipboard_selection
 		 ? GDK_SELECTION_CLIPBOARD
 		 : GDK_SELECTION_PRIMARY);
-	GdkAtom atom_targets  = gdk_atom_intern (TARGETS_ATOM_NAME, FALSE);
 
 	ctxt = g_new (GnmGtkClipboardCtxt, 1);
 	ctxt->wbcg = wbcg;
 	ctxt->paste_target = g_new (GnmPasteTarget, 1);
 	*ctxt->paste_target = *pt;
-	ctxt->fallback = GDK_NONE;
+	ctxt->image_atom = GDK_NONE;
+	ctxt->string_atom = GDK_NONE;
 
-	/* Query the formats, This will callback x_clipboard_received */
-	gtk_clipboard_request_contents (clipboard, atom_targets,
-					x_clipboard_received, ctxt);
+	/* Query the formats, This will callback x_targets_received */
+	gtk_clipboard_request_targets (clipboard, 
+				       x_targets_received, ctxt);
+}
+
+static GtkTargetEntry*
+target_list_to_entries (GtkTargetList *target_list, int *n_entries)
+{
+	GtkTargetEntry *entries;
+	int n_targets, i;
+	GList *p;
+	GtkTargetPair *tp;
+
+	if (!target_list || !target_list->list || n_entries == NULL)
+		return NULL;
+
+	n_targets = g_list_length (target_list->list);
+	if (n_targets == 0)
+		return NULL;
+
+	entries = g_new0 (GtkTargetEntry, n_targets);
+	for (p = target_list->list, i = 0; p != NULL; p = p->next, i++) {
+		tp = (GtkTargetPair *) p->data;
+		entries[i].target = gdk_atom_name (tp->target);
+		entries[i].flags  = tp->flags;
+		entries[i].info   = tp->info;
+	}
+
+	*n_entries = n_targets;
+	return entries;
 }
 
 gboolean
 x_claim_clipboard (WorkbookControlGUI *wbcg)
 {
 	GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (wbcg_toplevel (wbcg)));
-	static GtkTargetEntry const targets[] = {
-		{ (char *) GNUMERIC_ATOM_NAME,  GTK_TARGET_SAME_WIDGET, GNUMERIC_ATOM_INFO },
+	GnmCellRegion *content = gnm_app_clipboard_contents_get ();
+	SheetObject *imageable = NULL;
+	GtkTargetEntry *targets = NULL;
+	int n_targets, i;
+	GSList *ptr;
+	SheetObject *candidate;
+	GtkTargetList *tl;
+	gboolean ret;
+
+	static GtkTargetEntry const table_targets[] = {
+		{ (char *) GNUMERIC_ATOM_NAME, 0, GNUMERIC_ATOM_INFO },
 		{ (char *)"text/html", 0, 0 },
 		{ (char *)"UTF8_STRING", 0, 0 },
 		{ (char *)"COMPOUND_TEXT", 0, 0 },
 		{ (char *)"STRING", 0, 0 },
 	};
 
-	return
+	if (content &&
+	    (content->cols <= 0 || content->rows <= 0) &&
+	    content->objects != NULL) {
+		for (ptr = content->objects; ptr != NULL;
+		     ptr = ptr->next) {
+			candidate = SHEET_OBJECT (ptr->data);
+			if (IS_SHEET_OBJECT_IMAGEABLE (candidate)) {
+				imageable = candidate;
+				break;
+			}
+		}
+	}
+	if (imageable) {
+		tl = sheet_object_get_target_list (imageable);
+		/* _add_table prepends to target_list */
+		gtk_target_list_add_table (tl, table_targets, 1);
+		targets = target_list_to_entries (tl, &n_targets);
+		gtk_target_list_unref (tl);
+	} else {
+		targets = (GtkTargetEntry *) table_targets;
+		n_targets = G_N_ELEMENTS (table_targets);
+	}
+	ret =
 	gtk_clipboard_set_with_owner (
 		gtk_clipboard_get_for_display (display, GDK_SELECTION_CLIPBOARD),
-		targets, G_N_ELEMENTS (targets),
+		targets, n_targets,
 		(GtkClipboardGetFunc) x_clipboard_get_cb,
 		(GtkClipboardClearFunc) x_clipboard_clear_cb,
 		G_OBJECT (wbcg)) &&
 	gtk_clipboard_set_with_owner (
 		gtk_clipboard_get_for_display (display, GDK_SELECTION_PRIMARY),
-		targets, G_N_ELEMENTS (targets),
+		targets, n_targets,
 		(GtkClipboardGetFunc) x_clipboard_get_cb,
 		(GtkClipboardClearFunc) x_clipboard_clear_cb,
 		G_OBJECT (wbcg));
+
+	if (imageable) {
+		for (i = 0; i < n_targets; i++)
+			g_free (targets[i].target);
+		g_free (targets);
+	}
+
+	return ret;
 }
