@@ -14,7 +14,7 @@
 #include "gnumeric.h"
 #include "gui-util.h"
 #include "io-context-gtk.h"
-#include "io-context-priv.h"
+#include <goffice/app/io-context-priv.h>
 #include "application.h"
 #include "libgnumeric.h"
 #include "dialogs.h"
@@ -27,6 +27,7 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkframe.h>
+#include <gtk/gtkicontheme.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -121,8 +122,9 @@ icg_show_gui (IOContextGtk *icg)
 	GtkWidget *frame;
 
 	box = GTK_BOX (gtk_vbox_new (FALSE, 0));
-	gtk_box_pack_start (box,
-			    gtk_image_new_from_pixbuf (gnm_app_get_pixbuf ("gnumeric_splash")),
+	gtk_box_pack_start (box, gtk_image_new_from_pixbuf (
+		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+					  "gnumeric_splash", 360, 220, NULL)),
 			    TRUE, FALSE, 0);
 
 	/* Don't show this unless we need it. */
@@ -199,14 +201,14 @@ icg_user_is_impatient (IOContextGtk *icg)
 }
 
 static char *
-icg_get_password (GnmCmdContext *cc, char const *filename)
+icg_get_password (GOCmdContext *cc, char const *filename)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
 	return dialog_get_password (icg->window, filename);
 }
 
 static void
-icg_progress_set (GnmCmdContext *cc, gfloat val)
+icg_progress_set (GOCmdContext *cc, gfloat val)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
 
@@ -223,7 +225,7 @@ icg_progress_set (GnmCmdContext *cc, gfloat val)
 }
 
 static void
-icg_progress_message_set (GnmCmdContext *cc, gchar const *msg)
+icg_progress_message_set (GOCmdContext *cc, gchar const *msg)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
 
@@ -242,7 +244,7 @@ icg_progress_message_set (GnmCmdContext *cc, gchar const *msg)
 }
 
 static void
-icg_error_error_info (G_GNUC_UNUSED GnmCmdContext *cc,
+icg_error_error_info (G_GNUC_UNUSED GOCmdContext *cc,
 		      ErrorInfo *error)
 {
 	GtkWidget *dialog = gnumeric_error_info_dialog_new (error);
@@ -287,7 +289,7 @@ icg_processing_file (IOContext *ioc, char const *file)
 
 			while (1) {
 				char *last_p = p;
-				while (p > shown_text && p[-1] != '/')
+				while (p > shown_text && G_IS_DIR_SEPARATOR (p[-1]))
 					p--;
 				if (p > shown_text && shown_text + len - p < maxlen) {
 					p--;
@@ -333,7 +335,7 @@ icg_finalize (GObject *obj)
 }
 
 static void
-icg_gnm_cmd_context_init (GnmCmdContextClass *cc_class)
+icg_gnm_cmd_context_init (GOCmdContextClass *cc_class)
 {
 	cc_class->get_password         = icg_get_password;
 	cc_class->progress_set         = icg_progress_set;
@@ -369,7 +371,7 @@ icg_init (IOContextGtk *icg)
 GSF_CLASS_FULL (IOContextGtk, io_context_gtk,
 		icg_class_init, icg_init,
 		TYPE_IO_CONTEXT, 0,
-		GSF_INTERFACE (icg_gnm_cmd_context_init, GNM_CMD_CONTEXT_TYPE))
+		GSF_INTERFACE (icg_gnm_cmd_context_init, GO_CMD_CONTEXT_TYPE))
 
 void
 icg_set_transient_for (IOContextGtk *icg, GtkWindow *parent_window)
