@@ -16,25 +16,28 @@
 #include "libgnumeric.h"
 
 #include "command-context.h"
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "io-context-gtk.h"
 /* TODO: Get rid of this one */
 #include "command-context-stderr.h"
 #include "workbook-control-gui.h"
+#include "workbook-control-gui-priv.h"
 #include "workbook-view.h"
-#include "plugin.h"
+#include <goffice/app/go-plugin.h>
 #include "workbook.h"
 #include "gui-file.h"
 #include "gnumeric-gconf.h"
 #include "gnumeric-paths.h"
 #include "session.h"
 #include "sheet.h"
+#include "gnm-plugin.h"
 
 #include <gtk/gtkmain.h>
+#include <glib/gstdio.h>
 #include <goffice/utils/go-file.h>
+#include <goffice/app/go-cmd-context.h>
 
 #include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
 #include <time.h>
 #include <string.h>
@@ -45,6 +48,7 @@
 #endif
 
 static int gnumeric_show_version = FALSE;
+static int split_funcdocs = FALSE;
 static char *func_def_file = NULL;
 static char *func_state_file = NULL;
 
@@ -63,6 +67,8 @@ gnumeric_popt_options[] = {
 	  N_("Dumps the function definitions"),   N_("FILE") },
 	{ "dump-func-state", '\0', POPT_ARG_STRING, &func_state_file, 0,
 	  N_("Dumps the function definitions"),   N_("FILE") },
+	{ "split-func", '\0', POPT_ARG_NONE, &split_funcdocs, 0,
+	  N_("Generate new help and po files"),   NULL },
 
 	{ "debug", '\0', POPT_ARG_INT, &gnumeric_debugging, 0,
 	  N_("Enables some debugging functions"), N_("LEVEL") },
@@ -104,15 +110,23 @@ warn_about_ancient_gnumerics (const char *binary, IOContext *ioc)
 	struct stat buf;
 	time_t now = time (NULL);
 	int days = 180;
+	const char *sep;
+
+	if (!binary)
+		return;
+
+	for (sep = binary; *sep; sep++)
+		if (G_IS_DIR_SEPARATOR (*sep))
+			break;
 
 	if (binary &&
-	    strchr (binary, '/') != NULL &&
-	    stat (binary, &buf) != -1 &&
+	    *sep &&
+	    g_stat (binary, &buf) != -1 &&
 	    buf.st_mtime != -1 &&
 	    now - buf.st_mtime > days * 24 * 60 * 60) {
 		handle_paint_events ();
 
-		gnm_cmd_context_error_system (GNM_CMD_CONTEXT (ioc),
+		go_cmd_context_error_system (GO_CMD_CONTEXT (ioc),
 			_("Thank you for using Gnumeric!\n"
 			  "\n"
 			  "The version of Gnumeric you are using is quite old\n"
@@ -156,8 +170,8 @@ gnumeric_arg_parse (int argc, char const *argv [])
 		argc, (char **)argv,
 		GNOME_PARAM_APP_PREFIX,		GNUMERIC_PREFIX,
 		GNOME_PARAM_APP_SYSCONFDIR,	GNUMERIC_SYSCONFDIR,
-		GNOME_PARAM_APP_DATADIR,	gnumeric_data_dir,
-		GNOME_PARAM_APP_LIBDIR,		gnumeric_lib_dir,
+		GNOME_PARAM_APP_DATADIR,	gnm_sys_data_dir (),
+		GNOME_PARAM_APP_LIBDIR,		gnm_sys_lib_dir (),
 		GNOME_PARAM_POPT_TABLE,		gnumeric_popt_options,
 		NULL);
 
@@ -244,6 +258,27 @@ gnumeric_arg_parse (int argc, char const *argv [])
 }
 #endif
 
+/*
+ * WARNING WARNING WARNING
+ * This does not belong here
+ * but it is expedient for now to get things to compile
+ */
+#warning "REMOVE REMOVE REMOVE"
+static void
+store_plugin_state (void)
+{
+	GSList *active_plugins = go_plugins_get_active_plugins ();
+	gnm_gconf_set_active_plugins (active_plugins);
+	g_slist_free (active_plugins);
+}
+
+static int
+cb_kill_wbcg (WorkbookControlGUI *wbcg)
+{
+	wbcg_close_control (wbcg);
+	return FALSE;
+}
+
 int
 main (int argc, char const *argv [])
 {
@@ -252,6 +287,7 @@ main (int argc, char const *argv [])
 	gboolean with_gui;
 	IOContext *ioc;
 	WorkbookView *wbv;
+	GSList *wbcgs_to_kill = NULL;
 
 	poptContext ctx;
 
@@ -262,11 +298,11 @@ main (int argc, char const *argv [])
 
 	if (gnumeric_show_version) {
 		g_print (_("gnumeric version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
-			 GNUMERIC_VERSION, gnumeric_data_dir, gnumeric_lib_dir);
+			 GNUMERIC_VERSION, gnm_sys_data_dir (), gnm_sys_lib_dir ());
 		return 0;
 	}
 
-	with_gui = !func_def_file && !func_state_file;
+	with_gui = !func_def_file && !func_state_file && !split_funcdocs;
 
 	if (with_gui)
 		gnm_session_init (argv[0]);
@@ -279,19 +315,21 @@ main (int argc, char const *argv [])
 		handle_paint_events ();
 	} else {
 		/* TODO: Make this inconsistency go away */
-		GnmCmdContext *cc = cmd_context_stderr_new ();
+		GOCmdContext *cc = cmd_context_stderr_new ();
 		ioc = gnumeric_io_context_new (cc);
 		g_object_unref (cc);
 	}
 
-	if (func_def_file)
-		return gnm_dump_func_defs (func_def_file, TRUE);
 	if (func_state_file)
-		return gnm_dump_func_defs (func_state_file, FALSE);
+		return gnm_dump_func_defs (func_state_file, 0);
+	if (func_def_file)
+		return gnm_dump_func_defs (func_def_file, 1);
+	if (split_funcdocs)
+		return gnm_dump_func_defs (NULL, 2);
 
 	/* Keep in sync with .desktop file */
 	g_set_application_name (_("Gnumeric Spreadsheet"));
- 	plugins_init (GNM_CMD_CONTEXT (ioc));
+ 	gnm_plugins_init (GO_CMD_CONTEXT (ioc));
 
 	/* Load selected files */
 	if (ctx)
@@ -337,6 +375,9 @@ main (int argc, char const *argv [])
   				opened_workbook = TRUE;
 				icg_set_transient_for (IO_CONTEXT_GTK (ioc),
 						       wbcg_toplevel (wbcg));
+				if (immediate_exit_flag)
+					wbcgs_to_kill = g_slist_prepend (wbcgs_to_kill,
+									   wbcg);
 			}
 			/* cheesy attempt to keep the ui from freezing during
 			   load */
@@ -349,7 +390,7 @@ main (int argc, char const *argv [])
 	   files and failed to do so. */
 
 	/* If we were intentionally short circuited exit now */
-	if (!initial_workbook_open_complete && !immediate_exit_flag) {
+	if (!initial_workbook_open_complete) {
 		initial_workbook_open_complete = TRUE;
 		if (!opened_workbook) {
 			gint n_of_sheets = gnm_app_prefs->initial_sheet_number;
@@ -360,16 +401,27 @@ main (int argc, char const *argv [])
 			handle_paint_events ();
 		}
 
-		warn_about_ancient_gnumerics (g_get_prgname(), ioc);
+		if (immediate_exit_flag) {
+			GSList *l;
+			for (l = wbcgs_to_kill; l; l = l->next)
+				g_idle_add ((GSourceFunc)cb_kill_wbcg, l->data);
+		} else {
+			warn_about_ancient_gnumerics (g_get_prgname(), ioc);
+		}
 		g_object_unref (ioc);
 #ifdef WITH_GNOME
 		bonobo_main ();
 #else
 		gtk_main ();
 #endif
+	} else {
+		g_object_unref (ioc);
+		g_slist_foreach (wbcgs_to_kill, (GFunc)cb_kill_wbcg, NULL);
 	}
 
+	g_slist_free (wbcgs_to_kill);
 	gnumeric_arg_shutdown ();
+	store_plugin_state ();
 	gnm_shutdown ();
 
 #ifdef WITH_GNOME
