@@ -12,23 +12,24 @@
 #undef qgamma
 #endif
 
-#define M_PIgnum GNM_const(3.141592653589793238462643383279502884197169399375105820974944592307816406286208998628034825342117)
+#define M_PIgnum    GNM_const(3.141592653589793238462643383279502884197169399375105820974944592307816406286208998628034825342117)
 #define M_PI_2gnum (M_PIgnum / 2)
 /* The following are very good given a good compiler.  */
-#define M_LN2gnum (loggnum (2))
-#define M_LN10gnum (loggnum (10))
-#define M_SQRT2gnum (sqrtgnum (2))
+#define M_LN2gnum   GNM_const(0.693147180559945309417232121458176568075500134360255254120680009493393621969694715605863326996419)
+#define M_LN10gnum  GNM_const(2.302585092994045684017991454684364207601101488628772976033327900967572609677352480235997205089598)
+#define M_SQRT2gnum GNM_const(1.414213562373095048801688724209698078569671875376948073176679737990732478462107038850387534327642)
 
 /* ------------------------------------------------------------------------- */
 
-gnm_float gnumeric_add_epsilon (gnm_float x);
-gnm_float gnumeric_sub_epsilon (gnm_float x);
-gnm_float gnumeric_fake_floor (gnm_float x);
-gnm_float gnumeric_fake_ceil (gnm_float x);
-gnm_float gnumeric_fake_round (gnm_float x);
-gnm_float gnumeric_fake_trunc (gnm_float x);
-
-/* ------------------------------------------------------------------------- */
+gnm_float log1pmx (gnm_float x);
+gnm_float swap_log_tail (gnm_float lp);
+gnm_float lgamma1p (gnm_float a);
+gnm_float pow1p (gnm_float x, gnm_float y);
+gnm_float pow1pm1 (gnm_float x, gnm_float y);
+gnm_float gnm_trunc (gnm_float x);
+gnm_float logfbit (gnm_float x);
+gnm_float logspace_add (gnm_float logx, gnm_float logy);
+gnm_float logspace_sub (gnm_float logx, gnm_float logy);
 
 gnm_float beta (gnm_float a, gnm_float b);
 gnm_float lbeta3 (gnm_float a, gnm_float b, int *sign);
@@ -46,6 +47,7 @@ gnm_float pnorm (gnm_float x, gnm_float mu, gnm_float sigma, gboolean lower_tail
 gnm_float qnorm (gnm_float p, gnm_float mu, gnm_float sigma, gboolean lower_tail, gboolean log_p);
 
 /* The log-normal distribution.  */
+gnm_float dlnorm (gnm_float x, gnm_float logmean, gnm_float logsd, gboolean give_log);
 gnm_float plnorm (gnm_float x, gnm_float logmean, gnm_float logsd, gboolean lower_tail, gboolean log_p);
 gnm_float qlnorm (gnm_float x, gnm_float logmean, gnm_float logsd, gboolean lower_tail, gboolean log_p);
 
@@ -55,24 +57,29 @@ gnm_float pgamma (gnm_float x, gnm_float p, gnm_float scale, gboolean lower_tail
 gnm_float qgamma (gnm_float p, gnm_float alpha, gnm_float scale, gboolean lower_tail, gboolean log_p);
 
 /* The beta distribution.  */
+gnm_float dbeta (gnm_float x, gnm_float a, gnm_float b, gboolean give_log);
 gnm_float pbeta (gnm_float x, gnm_float pin, gnm_float qin, gboolean lower_tail, gboolean log_p);
 gnm_float qbeta (gnm_float alpha, gnm_float p, gnm_float q, gboolean lower_tail, gboolean log_p);
 
 /* The t distribution.  */
+gnm_float dt (gnm_float x, gnm_float n, gboolean give_log);
 gnm_float pt (gnm_float x, gnm_float n, gboolean lower_tail, gboolean log_p);
 gnm_float qt (gnm_float p, gnm_float ndf, gboolean lower_tail, gboolean log_p);
 
 /* The F distribution.  */
+gnm_float df (gnm_float x, gnm_float m, gnm_float n, gboolean give_log);
 gnm_float pf (gnm_float x, gnm_float n1, gnm_float n2, gboolean lower_tail, gboolean log_p);
 gnm_float qf (gnm_float x, gnm_float n1, gnm_float n2, gboolean lower_tail, gboolean log_p);
 
 /* The chi-squared distribution.  */
+gnm_float dchisq (gnm_float x, gnm_float df, gboolean give_log);
 gnm_float pchisq (gnm_float x, gnm_float df, gboolean lower_tail, gboolean log_p);
 gnm_float qchisq (gnm_float p, gnm_float df, gboolean lower_tail, gboolean log_p);
 
 /* The Weibull distribution.  */
 gnm_float dweibull (gnm_float x, gnm_float shape, gnm_float scale, gboolean give_log);
 gnm_float pweibull (gnm_float x, gnm_float shape, gnm_float scale, gboolean lower_tail, gboolean log_p);
+gnm_float qweibull (gnm_float p, gnm_float shape, gnm_float scale, gboolean lower_tail, gboolean log_p);
 
 /* The Poisson distribution.  */
 gnm_float dpois (gnm_float x, gnm_float lambda, gboolean give_log);
@@ -82,6 +89,7 @@ gnm_float qpois (gnm_float p, gnm_float lambda, gboolean lower_tail, gboolean lo
 /* The exponential distribution.  */
 gnm_float dexp (gnm_float x, gnm_float scale, gboolean give_log);
 gnm_float pexp (gnm_float x, gnm_float scale, gboolean lower_tail, gboolean log_p);
+gnm_float qexp (gnm_float p, gnm_float scale, gboolean lower_tail, gboolean log_p);
 
 /* Binomial distribution.  */
 gnm_float dbinom (gnm_float x, gnm_float n, gnm_float p, gboolean give_log);
@@ -91,6 +99,7 @@ gnm_float qbinom (gnm_float x, gnm_float n, gnm_float p, gboolean lower_tail, gb
 /* Negative binomial distribution.  */
 gnm_float dnbinom (gnm_float x, gnm_float n, gnm_float p, gboolean give_log);
 gnm_float pnbinom (gnm_float x, gnm_float n, gnm_float p, gboolean lower_tail, gboolean log_p);
+gnm_float qnbinom (gnm_float p, gnm_float n, gnm_float pr, gboolean lower_tail, gboolean log_p);
 
 /* Hyper-geometrical distribution.  */
 gnm_float dhyper (gnm_float x, gnm_float r, gnm_float b, gnm_float n, gboolean give_log);
@@ -99,10 +108,12 @@ gnm_float phyper (gnm_float x, gnm_float NR, gnm_float NB, gnm_float n, gboolean
 /* Geometrical distribution.  */
 gnm_float dgeom (gnm_float x, gnm_float p, gboolean give_log);
 gnm_float pgeom (gnm_float x, gnm_float p, gboolean lower_tail, gboolean log_p);
+gnm_float qgeom (gnm_float p, gnm_float prob, gboolean lower_tail, gboolean log_p);
 
 /* Cauchy distribution.  */
 gnm_float dcauchy (gnm_float x, gnm_float location, gnm_float scale, gboolean give_log);
 gnm_float pcauchy (gnm_float x, gnm_float location, gnm_float scale, gboolean lower_tail, gboolean log_p);
+gnm_float qcauchy (gnm_float p, gnm_float location, gnm_float scale, gboolean lower_tail, gboolean log_p);
 
 /* Random number generation. */
 gnm_float random_01             (void);
@@ -124,7 +135,7 @@ gnm_float random_fdist          (gnm_float nu1, gnm_float nu2);
 gnm_float random_beta           (gnm_float a, gnm_float b);
 gnm_float random_logistic       (gnm_float a);
 gnm_float random_geometric      (gnm_float p);
-gnm_float random_hypergeometric (unsigned int n1, unsigned int n2, 
+gnm_float random_hypergeometric (unsigned int n1, unsigned int n2,
 				 unsigned int t);
 gnm_float random_logarithmic    (gnm_float p);
 gnm_float random_chisq          (gnm_float nu);
@@ -150,17 +161,13 @@ void    mmult (gnm_float *A, gnm_float *B, int cols_a, int rows_a, int cols_b,
 
 /* ------------------------------------------------------------------------- */
 
-/* Misc. */
-gnm_float     gpow10 (int n);
-gnm_float     gpow2  (int n);
-int           gcd    (int a, int b);
-gnm_float     combin (int n, int k);
-gnm_float     permut (int n, int k);
-gnm_float     fact   (int n);
+int       gcd    (int a, int b);
+gnm_float combin (int n, int k);
+gnm_float permut (int n, int k);
+gnm_float fact   (int n);
+
+void mathfunc_init (void);
 
 /* ------------------------------------------------------------------------- */
 
-void continued_fraction (gnm_float val, int max_denom, int *res_num, int *res_denom);
-void stern_brocot (float val, int max_denom, int *res_num, int *res_denom);
-
 #endif
