@@ -108,9 +108,9 @@ double              mstyle_get_font_size   (const GnmStyle *st);
 GnmFont          *mstyle_get_font        (const GnmStyle *st,
 					    PangoContext *context,
 					    double zoom);
-void                mstyle_set_format      (GnmStyle *st, GnmFormat *);
+void                mstyle_set_format      (GnmStyle *st, GOFormat *);
 void                mstyle_set_format_text (GnmStyle *st, const char *format);
-GnmFormat          *mstyle_get_format      (const GnmStyle *st);
+GOFormat           *mstyle_get_format      (const GnmStyle *st);
 void                mstyle_set_align_h     (GnmStyle *st, StyleHAlignFlags a);
 StyleHAlignFlags    mstyle_get_align_h     (const GnmStyle *st);
 void                mstyle_set_align_v     (GnmStyle *st, StyleVAlignFlags a);
@@ -118,6 +118,7 @@ StyleVAlignFlags    mstyle_get_align_v     (const GnmStyle *st);
 void                mstyle_set_indent	   (GnmStyle *st, int i);
 int		    mstyle_get_indent	   (const GnmStyle *st);
 
+/* -1 == vertical, 0..359 == rotation */
 void                mstyle_set_rotation	   (GnmStyle *st, int r);
 int            	    mstyle_get_rotation    (const GnmStyle *st);
 void		    mstyle_set_text_dir    (GnmStyle *style, GnmTextDir text_dir);
