@@ -26,14 +26,14 @@
 #include "parse-util.h"
 
 #include "application.h"
-#include "workbook-priv.h"
+#include "workbook.h"
 #include "sheet.h"
 #include "value.h"
 #include "ranges.h"
 #include "cell.h"
 #include "expr.h"
 #include "number-match.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "expr-name.h"
 #include "str.h"
 /* For def_expr_name_handler: */
@@ -45,6 +45,7 @@
 #include <stdio.h>
 #include <glib.h>
 #include <string.h>
+#include <goffice/utils/go-glib-extras.h>
 
 static void
 col_name_internal (GString *target, int col)
@@ -61,6 +62,12 @@ col_name_internal (GString *target, int col)
 	int i;
 	char *dst;
 
+	if (col < 0) {
+		/* Invalid column.  */
+		g_string_append_printf (target, "[C%d]", col);
+		return;
+	}
+
 	for (i = 0; col >= steps[i]; i++)
 		col -= steps[i];
 
@@ -175,8 +182,15 @@ row_parse (char const *str, int *res, unsigned char *relative)
 	if (*ptr <= '0' || *ptr > '9')
 		return NULL;
 
+	/*
+	 * Do not allow letters after the row number.  If we did, then
+	 * the name "K3P" would lex as the reference K3 followed by the
+	 * name "P".
+	 */
 	row = strtol (ptr, (char **)&end, 10);
-	if (ptr != end && 0 < row && row <= SHEET_MAX_ROWS) {
+	if (ptr != end &&
+	    !g_unichar_isalnum (g_utf8_get_char (end)) && *end != '_' &&
+	    0 < row && row <= SHEET_MAX_ROWS) {
 		*res = row - 1;
 		return end;
 	} else
@@ -236,7 +250,7 @@ cellref_as_string (GString *target, GnmExprConventions const *conv,
 			g_string_append (target, sheet->name_quoted);
 		else {
 			g_string_append_c (target, '[');
-			g_string_append (target, sheet->workbook->filename);
+			g_string_append (target, workbook_get_uri (sheet->workbook));
 			g_string_append_c (target, ']');
 			g_string_append (target, sheet->name_quoted);
 		}
@@ -290,7 +304,7 @@ rangeref_as_string (GString *target, GnmExprConventions const *conv,
 	if (ref->a.sheet) {
 		if (pp->wb != NULL && ref->a.sheet->workbook != pp->wb) {
 			g_string_append_c (target, '[');
-			g_string_append (target, ref->a.sheet->workbook->filename);
+			g_string_append (target, workbook_get_uri (ref->a.sheet->workbook));
 			g_string_append_c (target, ']');
 		}
 		if (pp->wb == NULL && pp->sheet == NULL)
@@ -331,7 +345,10 @@ rangeref_as_string (GString *target, GnmExprConventions const *conv,
 			g_string_append_c (target, '$');
 		row_name_internal (target, r.start.row);
 
-		if (r.start.col != r.end.col || r.start.row != r.end.row) {
+		if (r.start.col != r.end.col ||
+		    ref->a.col_relative != ref->b.col_relative ||
+		    r.start.row != r.end.row ||
+		    ref->a.row_relative != ref->b.row_relative) {
 			g_string_append_c (target, ':');
 			if (!ref->b.col_relative)
 				g_string_append_c (target, '$');
@@ -565,7 +582,7 @@ gnm_expr_char_start_p (char const * c)
 		 * just checks for C-syntax numbers.
 		 */
 		errno = 0;
-		(void) strtognum (c, &end);
+		(void) gnm_strto (c, &end);
 		if (errno || *end != 0 || end == c)
 			return (c0 == '+') ? c + 1 : c;
 		/* Otherwise, it's a number.  */
@@ -590,8 +607,8 @@ gnm_expr_char_start_p (char const * c)
 void
 parse_text_value_or_expr (GnmParsePos const *pos, char const *text,
 			  GnmValue **val, GnmExpr const **expr,
-			  GnmFormat *cur_fmt,
-			  GnmDateConventions const *date_conv)
+			  GOFormat *cur_fmt,
+			  GODateConventions const *date_conv)
 {
 	char const *expr_start;
 
@@ -740,7 +757,7 @@ sheetref_parse (char const *start, Sheet **sheet, Workbook const *wb,
 	*sheet = NULL;
 	if (*start == '\'' || *start == '"') {
 		sheet_name = g_string_new (NULL);
-		end = gnm_strunescape (sheet_name, start);
+		end = go_strunescape (sheet_name, start);
 		if (end == NULL) {
 			g_string_free (sheet_name, TRUE);
 			return start;
@@ -935,7 +952,7 @@ def_expr_name_handler (GString *target,
 	if (name->optional_scope != NULL) {
 		if (name->optional_scope->workbook != pp->wb) {
 			g_string_append_c (target, '[');
-			g_string_append (target, name->optional_wb_scope->filename);
+			g_string_append (target, workbook_get_uri (name->optional_wb_scope));
 			g_string_append_c (target, ']');
 		} else {
 			g_string_append (target, name->optional_scope->name_quoted);
