@@ -15,18 +15,21 @@
 
 #include "gutils.h"
 #include "ranges.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "func.h"
-#include "datetime.h"
 #include "sheet.h"
 #include "value.h"
 #include "workbook.h"
 #include "gnumeric-gconf.h"
 #include "gnumeric-gconf-priv.h"
+
 #include <goffice/utils/go-file.h>
+#include <goffice/utils/datetime.h>
+#include <goffice/utils/go-glib-extras.h>
 
 #include <string.h>
 #include <locale.h>
+#include <time.h>
 
 #define MAX_SAVED_CUSTOM_HF_FORMATS 9
 
@@ -38,20 +41,11 @@ print_hf_new (char const *left_side_format,
 	      char const *middle_format,
 	      char const *right_side_format)
 {
-	PrintHF *format;
-
-	format = g_new0 (PrintHF, 1);
-
-	if (left_side_format)
-		format->left_format = g_strdup (left_side_format);
-
-	if (middle_format)
-		format->middle_format = g_strdup (middle_format);
-
-	if (right_side_format)
-		format->right_format = g_strdup (right_side_format);
-
-	return format;
+	PrintHF *hf = g_new0 (PrintHF, 1);
+	hf->left_format   = g_strdup (left_side_format);
+	hf->middle_format = g_strdup (middle_format);
+	hf->right_format  = g_strdup (right_side_format);
+	return hf;
 }
 
 gboolean
@@ -308,13 +302,13 @@ save_formats (void)
 		if (base-- > 0)
 			continue;
 
-		GNM_SLIST_PREPEND (left, g_strdup(hf->left_format));
-		GNM_SLIST_PREPEND (middle, g_strdup(hf->middle_format));
-		GNM_SLIST_PREPEND (right, g_strdup(hf->right_format));
+		GO_SLIST_PREPEND (left, g_strdup(hf->left_format));
+		GO_SLIST_PREPEND (middle, g_strdup(hf->middle_format));
+		GO_SLIST_PREPEND (right, g_strdup(hf->right_format));
 	}
-	GNM_SLIST_REVERSE(left);
-	GNM_SLIST_REVERSE(middle);
-	GNM_SLIST_REVERSE(right);
+	GO_SLIST_REVERSE(left);
+	GO_SLIST_REVERSE(middle);
+	GO_SLIST_REVERSE(right);
 
 	gnm_gconf_set_print_header_formats (left, middle, right);
 }
@@ -333,10 +327,12 @@ destroy_formats (void)
 void
 print_info_save (PrintInformation const *pi)
 {
+	GOConfNode *node = go_conf_get_node (gnm_conf_get_root (), PRINTSETUP_GCONF_DIR);
+
 	gnm_gconf_set_print_scale_percentage (pi->scaling.type == PERCENTAGE);
 	gnm_gconf_set_print_scale_percentage_value (pi->scaling.percentage.x);
-	go_conf_set_int (PRINTSETUP_GCONF_SCALE_WIDTH,  pi->scaling.dim.cols);
-	go_conf_set_int (PRINTSETUP_GCONF_SCALE_HEIGHT, pi->scaling.dim.rows);
+	go_conf_set_int (node, PRINTSETUP_GCONF_SCALE_WIDTH,  pi->scaling.dim.cols);
+	go_conf_set_int (node, PRINTSETUP_GCONF_SCALE_HEIGHT, pi->scaling.dim.rows);
 
 	gnm_gconf_set_print_tb_margins (&pi->margins);
 
@@ -348,9 +344,9 @@ print_info_save (PrintInformation const *pi)
 	gnm_gconf_set_print_titles (pi->print_titles);
 	gnm_gconf_set_print_order_right_then_down (pi->print_order);
 	
-	go_conf_set_string (PRINTSETUP_GCONF_REPEAT_TOP,
+	go_conf_set_string (node, PRINTSETUP_GCONF_REPEAT_TOP,
 		pi->repeat_top.use ? range_name (&pi->repeat_top.range) : "");
-	go_conf_set_string (PRINTSETUP_GCONF_REPEAT_LEFT,
+	go_conf_set_string (node, PRINTSETUP_GCONF_REPEAT_LEFT,
 		pi->repeat_left.use ? range_name (&pi->repeat_left.range) : "");
 
 	save_formats ();
@@ -364,6 +360,7 @@ print_info_save (PrintInformation const *pi)
 				      pi->footer->middle_format,
 				      pi->footer->right_format);
 
+	go_conf_free_node (node);
 }
 
 const GnomePrintUnit *
@@ -420,7 +417,7 @@ render_pages (GString *target, HFRenderInfo *info, char const *args)
 static void
 render_value_with_format (GString *target, char const *number_format, HFRenderInfo *info)
 {
-	GnmFormat *format;
+	GOFormat *format;
 
 	/* TODO : Check this assumption.  Is it a localized format ?? */
 	format = style_format_new_XL (number_format, FALSE);
@@ -528,7 +525,8 @@ hf_format_render (char const *format, HFRenderInfo *info, HFRenderType render_ty
 	GString *result;
 	char const *p;
 
-	g_return_val_if_fail (format != NULL, NULL);
+	if (!format)
+		return NULL;
 
 	result = g_string_new (NULL);
 	for (p = format; *p; p++) {
