@@ -129,7 +129,7 @@ static void
 print_sheet_objects (PrintJobInfo const *pj, Sheet const *sheet, GnmRange *range,
 		     double base_x, double base_y)
 {
-	GList *l;
+	GSList *ptr;
 	double end_x, end_y, len;
 
 	g_return_if_fail (IS_SHEET (sheet));
@@ -164,8 +164,8 @@ print_sheet_objects (PrintJobInfo const *pj, Sheet const *sheet, GnmRange *range
 #endif
 	gnome_print_clip (pj->print_context);
 
-	for (l = sheet->sheet_objects; l; l = l->next) {
-		SheetObject *so = SHEET_OBJECT (l->data);
+	for (ptr = sheet->sheet_objects; ptr; ptr = ptr->next) {
+		SheetObject *so = SHEET_OBJECT (ptr->data);
 		double coords [4];
 
 		if (!sheet_object_can_print (so) ||
@@ -313,11 +313,11 @@ print_hf_element (PrintJobInfo const *pj, char const *format,
 	g_return_if_fail (pj != NULL);
 	g_return_if_fail (pj->render_info != NULL);
 
+	if (format == NULL)
+		return;
 	text = hf_format_render (format, pj->render_info, HF_RENDER_PRINT);
 
-	g_return_if_fail (text != NULL);
-
-	if (text[0]) {
+	if (text && text[0]) {
 		double header = 0, footer = 0, left = 0, right = 0;
 		PangoLayout *layout = ensure_decoration_layout ((PrintJobInfo *)pj);
 
@@ -498,7 +498,7 @@ print_page (PrintJobInfo const *pj, Sheet const *sheet, GnmRange *range,
 	double x, y, clip_y;
 	char *pagenotxt;
 	gboolean printed;
-	GList *l;
+	GSList *ptr;
 	double header = 0, footer = 0, left = 0, right = 0;
 
 	/* FIXME: Can col / row space calculation be factored out? */
@@ -548,8 +548,8 @@ print_page (PrintJobInfo const *pj, Sheet const *sheet, GnmRange *range,
 
 	/* Check for sheet objects if nothing has been found so far */
 	if (!printed)
-		for (l = sheet->sheet_objects; l && !printed; l = l->next) {
-			SheetObject *so = SHEET_OBJECT (l->data);
+		for (ptr = sheet->sheet_objects; ptr && !printed; ptr = ptr->next) {
+			SheetObject *so = SHEET_OBJECT (ptr->data);
 			printed = range_overlap (range, &so->anchor.cell_bound);
 		}
 
@@ -1144,7 +1144,7 @@ sheet_print_selection (PrintJobInfo *pj, Sheet const *sheet,
 	GnmRange extent;
 
 	if (!(sel = selection_first_range (sheet_get_view (sheet, wb_control_view (wbc)),
-					   GNM_CMD_CONTEXT (wbc), _("Print Region"))))
+					   GO_CMD_CONTEXT (wbc), _("Print Region"))))
 		return;
 
 	extent = *sel;
@@ -1315,9 +1315,8 @@ sheet_print_real (WorkbookControlGUI *wbcg, Sheet *sheet,
 			 * FIXME: not a great message, but at this point we don't
 			 * know *what* went wrong.
 			 */
-			gnumeric_notice (wbcg_toplevel (wbcg),
-					 GTK_MESSAGE_ERROR,
-					 _("Printing failed"));
+			go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
+				_("Printing failed"));
 		}
 	}
 	
@@ -1411,7 +1410,7 @@ sheet_print (WorkbookControlGUI *wbcg, Sheet *sheet,
 	}
 	
 	gnome_print_dialog = g_object_new (GNOME_TYPE_PRINT_DIALOG,
-					   "print_config", pj->gp_config,
+					   "print-config", pj->gp_config,
 					   NULL);
 	
 	g_return_if_fail (gnome_print_dialog != NULL);
