@@ -35,7 +35,7 @@
 #include "sheet.h"
 #include "sheet-merge.h"
 #include "sheet-style.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "value.h"
 #include "parse-util.h"
 #include "sheet-control-gui.h"
@@ -44,6 +44,7 @@
 
 #include <math.h>
 #include <string.h>
+#include <goffice/utils/go-glib-extras.h>
 
 #define BUG_105322
 #undef DEBUG_BOUNDING_BOX
@@ -53,16 +54,19 @@
 #endif
 
 #if USE_RV_POOLS
-/* Memory pool for strings.  */
-static GnmMemChunk *rendered_value_pool;
-#define CHUNK_ALLOC(T,p) ((T*)gnm_mem_chunk_alloc (p))
-#define CHUNK_FREE(p,v) gnm_mem_chunk_free ((p), (v))
+/* Memory pool for RenderedValue.  */
+static GOMemChunk *rendered_value_pool;
+#define CHUNK_ALLOC(T,p) ((T*)go_mem_chunk_alloc (p))
+#define CHUNK_FREE(p,v) go_mem_chunk_free ((p), (v))
 #else
 #define CHUNK_ALLOC(T,c) g_new (T,1)
 #define CHUNK_FREE(p,v) g_free ((v))
 #endif
 
 
+static int minus_utf8_len;
+static char minus_utf8[6];
+
 static guint16
 calc_indent (PangoContext *context, const GnmStyle *mstyle, double zoom)
 {
@@ -78,12 +82,18 @@ calc_indent (PangoContext *context, const GnmStyle *mstyle, double zoom)
 	return MIN (indent, 65535);
 }
 
-/* returns TRUE if the result depends on the width of the cell */
+/**
+ * rendered_value_render :
+ *
+ * returns TRUE if the result depends on the width of the cell
+ **/
 static gboolean
-rendered_value_render (GString *str, GnmCell const *cell,
+rendered_value_render (GString *str,
+		       GnmCell const *cell,
 		       PangoContext *context, GnmStyle const *mstyle,
-		       gboolean allow_variable_width, float zoom,
-		       gboolean *display_formula, GnmColor **color)
+		       gboolean allow_variable_width, double zoom,
+		       gboolean *display_formula,
+		       GOColor *go_color)
 {
 	Sheet const *sheet = cell->base.sheet;
 
@@ -99,13 +109,14 @@ rendered_value_render (GString *str, GnmCell const *cell,
 		gnm_expr_as_gstring (str, cell->base.expression,
 				     parse_pos_init_cell (&pp, cell),
 				     gnm_expr_conventions_default);
-		*color = NULL;
+		*go_color = 0;
 	} else if (sheet && sheet->hide_zero && cell_is_zero (cell)) {
-		*color = NULL;
+		*go_color = 0;
 	} else if (mstyle_is_element_set (mstyle, MSTYLE_FORMAT)) {
+		gboolean handle_minus;
 		double col_width = -1.;
 		/* entered text CAN be null if called by set_value */
-		GnmFormat *format = mstyle_get_format (mstyle);
+		GOFormat *format = mstyle_get_format (mstyle);
 
 		/* For format general approximate the cell width in characters */
 		if (style_format_is_var_width (format)) {
@@ -119,7 +130,7 @@ rendered_value_render (GString *str, GnmCell const *cell,
 
 				if (wdigit > 0.0) {
 					double cell_width;
-					if (sheet && cell_is_merged (cell)) {
+					if (cell_is_merged (cell)) {
 						GnmRange const *merged =
 							sheet_merge_is_corner (sheet, &cell->pos);
 
@@ -145,31 +156,35 @@ rendered_value_render (GString *str, GnmCell const *cell,
 			} else if (style_format_is_general (format))
 				format = VALUE_FMT (cell->value);
 		}
-		format_value_gstring (str, format, cell->value, color,
+		format_value_gstring (str, format, cell->value, go_color,
 				      col_width,
 				      sheet ? workbook_date_conv (sheet->workbook) : NULL);
+		switch (VALUE_TYPE (cell->value)) {
+		case VALUE_INTEGER:
+			handle_minus = (value_get_as_int (cell->value) < 0);
+			break;
+		case VALUE_FLOAT:
+			handle_minus = (value_get_as_float (cell->value) < 1.0);
+			break;
+		default:
+			handle_minus = FALSE;
+			break;
+		}
+		if (handle_minus) {
+			unsigned i;
+			for (i = 0; i < str->len; i++)
+				if (str->str[i] == '-') {
+					str->str[i] = minus_utf8[0];
+					g_string_insert_len (str, i + 1, minus_utf8 + 1, minus_utf8_len - 1);
+					i += minus_utf8_len - 1;
+				}
+		}
 	} else {
 		g_warning ("No format: serious error");
 	}
 	return is_variable_width;
 }
 
-
-#if 0
-some quicky code to dump an attr list
-we can use this to export them as text
-static gboolean
-cb_dump (PangoAttribute *a)
-{
-	g_print ("dump : %d..%d\n", a->start_index, a->end_index);
-	return FALSE;
-}
-
-			pango_attr_list_filter (attrs,
-				(PangoAttrFilterFunc) cb_dump, NULL);
-#endif
-
-#ifdef HAVE_PANGO_CONTEXT_SET_MATRIX
 /* Gets the bounds of a layout in pango units.  Mostly copied from gtklabel.c */
 static void
 get_rotated_layout_bounds (PangoLayout *layout, int *width, int *height)
@@ -214,12 +229,10 @@ get_rotated_layout_bounds (PangoLayout *layout, int *width, int *height)
 	*width = ceil (x_max) - floor (x_min);
 	*height = ceil (y_max) - floor (y_min);
 }
-#endif
 
 void
 rendered_value_remeasure (RenderedValue *rv)
 {
-#ifdef HAVE_PANGO_CONTEXT_SET_MATRIX
 	if (rv->rotation) {
 		PangoMatrix rotmat = PANGO_MATRIX_INIT;
 		PangoContext *context = pango_layout_get_context (rv->layout);
@@ -231,7 +244,6 @@ rendered_value_remeasure (RenderedValue *rv)
 		pango_context_set_matrix (context, NULL);
 		pango_layout_context_changed (rv->layout);
 	} else
-#endif
 		pango_layout_get_size (rv->layout,
 				       &rv->layout_natural_width,
 				       &rv->layout_natural_height);
@@ -250,15 +262,16 @@ rendered_value_remeasure (RenderedValue *rv)
  * Return value: a new RenderedValue
  **/
 RenderedValue *
-rendered_value_new (GnmCell const *cell, GnmStyle const *mstyle,
+rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
 		    gboolean allow_variable_width,
-		    PangoContext *context, float zoom)
+		    PangoContext *context,
+		    double zoom)
 {
 	RenderedValue	*res;
-	GnmColor	*color;
+	Sheet		*sheet;
+	GOColor		 fore;
 	PangoLayout     *layout;
 	PangoAttrList   *attrs;
-	GnmColor const *fore;
 	gboolean        display_formula;
 
 	/* This screws thread safety (which we don't need).  */
@@ -271,8 +284,11 @@ rendered_value_new (GnmCell const *cell, GnmStyle const *mstyle,
 	/* Special handling for manual recalc.
 	 * If a cell has a new expression and something tries to display it we
 	 * need to recalc the value */
-	if (cell->base.flags & CELL_HAS_NEW_EXPR)
-		cell_eval ((GnmCell *)cell);
+	if (cell->base.flags & CELL_HAS_NEW_EXPR) {
+		cell_eval (cell);
+	}
+
+	sheet = cell->base.sheet;
 
 	if (str)
 		g_string_truncate (str, 0);
@@ -280,8 +296,10 @@ rendered_value_new (GnmCell const *cell, GnmStyle const *mstyle,
 		str = g_string_sized_new (100);
 
 	res = CHUNK_ALLOC (RenderedValue, rendered_value_pool);
-	res->variable_width = rendered_value_render (str, cell, context, mstyle, zoom,
-		allow_variable_width, &display_formula, &color);
+	res->variable_width = rendered_value_render
+		(str, cell, context, mstyle,
+		 allow_variable_width, zoom,
+		 &display_formula, &fore);
 	res->indent_left = res->indent_right = 0;
 	res->numeric_overflow = FALSE;
 	res->hfilled = FALSE;
@@ -301,9 +319,11 @@ rendered_value_new (GnmCell const *cell, GnmStyle const *mstyle,
 	attrs = mstyle_get_pango_attrs (mstyle, context, zoom);
 #ifdef BUG_105322
 	/* See http://bugzilla.gnome.org/show_bug.cgi?id=105322 */
-	fore = color ? color : mstyle_get_color (mstyle, MSTYLE_COLOR_FORE);
-	res->color = fore->color;
-	if (color) style_color_unref (color);
+	if (0 == fore) {
+		GnmColor const *c = mstyle_get_color (mstyle, MSTYLE_COLOR_FORE);
+		res->go_fore_color = c->go_color;
+	} else
+		res->go_fore_color = fore;
 #else
 	if (color) {
 		PangoAttrList *new_attrs = pango_attr_list_copy (attrs);
@@ -311,7 +331,7 @@ rendered_value_new (GnmCell const *cell, GnmStyle const *mstyle,
 
 		pango_attr_list_unref (attrs);
 		attrs = new_attrs;
-		attr = pango_attr_foreground_new (color->red, color->green, color->blue);
+		attr = go_color_to_pango (fore, TRUE);
 		attr->start_index = 0;
 		attr->end_index = -1;
 		pango_attr_list_insert (attrs, attr);
@@ -335,7 +355,7 @@ rendered_value_new (GnmCell const *cell, GnmStyle const *mstyle,
 #endif
 
 	if (cell->value != NULL) {
-		GnmFormat const *fmt = VALUE_FMT (cell->value);
+		GOFormat const *fmt = VALUE_FMT (cell->value);
 		if (fmt != NULL && style_format_is_markup (fmt)) {
 			PangoAttrList *orig = attrs;
 			attrs = pango_attr_list_copy (attrs);
@@ -400,7 +420,46 @@ rendered_value_destroy (RenderedValue *rv)
 	CHUNK_FREE (rendered_value_pool, rv);
 }
 
-/* Return the value as a single string without format infomation. */
+RenderedValue *
+rendered_value_recontext (RenderedValue *rv, PangoContext *context)
+{
+	RenderedValue *res;
+	PangoLayout *layout, *olayout;
+
+	res = CHUNK_ALLOC (RenderedValue, rendered_value_pool);
+
+	*res = *rv;
+	res->layout = layout = pango_layout_new (context);
+	olayout = rv->layout;
+
+	pango_layout_set_text (layout, pango_layout_get_text (olayout), -1);
+	pango_layout_set_alignment (layout, pango_layout_get_alignment (olayout));
+	pango_layout_set_attributes (layout, pango_layout_get_attributes (olayout));
+	pango_layout_set_single_paragraph_mode (layout, pango_layout_get_single_paragraph_mode (olayout));
+	pango_layout_set_justify (layout, pango_layout_get_justify (olayout));
+	pango_layout_set_width (layout, pango_layout_get_width (olayout));
+	pango_layout_set_spacing (layout, pango_layout_get_spacing (olayout));
+	/*
+	 * We really want to keep the line breaks, but currently pango
+	 * does not support that.  One one-line layouts, however, we
+	 * can simply turn off the wrapping.
+	 */
+	pango_layout_set_wrap (layout,
+			       pango_layout_get_wrap (olayout) &&
+			       pango_layout_get_line_count (olayout) > 1);
+	pango_layout_set_indent (layout, pango_layout_get_indent (olayout));
+	pango_layout_set_auto_dir (layout, pango_layout_get_auto_dir (olayout));
+	pango_layout_set_ellipsize (layout, pango_layout_get_ellipsize (olayout));
+	pango_layout_set_font_description (layout, pango_layout_get_font_description (olayout));
+	// ignore tabs
+
+	rendered_value_remeasure (res);
+	return res;
+}
+
+
+/* Return the value as a single string without format infomation.
+ */
 const char *
 rendered_value_get_text (RenderedValue const *rv)
 {
@@ -416,7 +475,7 @@ rendered_value_get_text (RenderedValue const *rv)
  * The returned value is a pointer to a PangoColor describing
  * the foreground colour.
  */
-const PangoColor *
+GOColor
 cell_get_render_color (GnmCell const *cell)
 {
 #ifndef BUG_105322
@@ -425,20 +484,14 @@ cell_get_render_color (GnmCell const *cell)
 	PangoAttribute *attr;
 #endif
 
-	g_return_val_if_fail (cell != NULL, NULL);
+	g_return_val_if_fail (cell != NULL, 0);
 
 	/* A precursor to just in time rendering Ick! */
 	if (cell->rendered_value == NULL)
 		cell_render_value ((GnmCell *)cell, TRUE);
 
 #ifdef BUG_105322
-	{
-		static PangoColor ick;
-		ick.red = cell->rendered_value->color.red;
-		ick.green = cell->rendered_value->color.green;
-		ick.blue = cell->rendered_value->color.blue;
-		return &ick;
-	}
+	return cell->rendered_value->go_fore_color;
 #else
 	attrs = pango_layout_get_attributes (cell->rendered_value->layout);
 	g_return_val_if_fail (attrs != NULL, NULL);
@@ -548,11 +601,12 @@ cell_rendered_offset (GnmCell const * cell)
 void
 rendered_value_init (void)
 {
+	minus_utf8_len = g_unichar_to_utf8 (UNICODE_MINUS_SIGN_C, minus_utf8);
 #if USE_RV_POOLS
 	rendered_value_pool =
-		gnm_mem_chunk_new ("rendered value pool",
-				   sizeof (RenderedValue),
-				   16 * 1024 - 128);
+		go_mem_chunk_new ("rendered value pool",
+				  sizeof (RenderedValue),
+				  16 * 1024 - 128);
 #endif
 }
 
@@ -570,8 +624,8 @@ void
 rendered_value_shutdown (void)
 {
 #if USE_RV_POOLS
-	gnm_mem_chunk_foreach_leak (rendered_value_pool, cb_rendered_value_pool_leak, NULL);
-	gnm_mem_chunk_destroy (rendered_value_pool, FALSE);
+	go_mem_chunk_foreach_leak (rendered_value_pool, cb_rendered_value_pool_leak, NULL);
+	go_mem_chunk_destroy (rendered_value_pool, FALSE);
 	rendered_value_pool = NULL;
 #endif
 }
