@@ -9,7 +9,7 @@
  *  (C) 1999-2001 Jody Goldberg
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "selection.h"
 
@@ -331,7 +331,7 @@ sv_menu_enable_insert (SheetView *sv, gboolean col, gboolean row)
  */
 GnmRange const *
 selection_first_range (SheetView const *sv,
-		       GnmCmdContext *cc, char const *cmd_name)
+		       GOCmdContext *cc, char const *cmd_name)
 {
 	GnmRange const *r;
 	GList *l;
@@ -343,8 +343,10 @@ selection_first_range (SheetView const *sv,
 
 	r = l->data;
 	if (cc != NULL && l->next != NULL) {
-		gnm_cmd_context_error_invalid (cc, cmd_name,
-			_("cannot be performed with multiple ranges selected"));
+		GError *msg = g_error_new (go_error_invalid(), 0,
+			_("%s does not support multiple ranges"), cmd_name);
+		go_cmd_context_error (cc, msg);
+		g_error_free (msg);
 		return NULL;
 	}
 
@@ -563,6 +565,8 @@ sv_selection_set (SheetView *sv, GnmCellPos const *edit,
 		  int base_col, int base_row,
 		  int move_col, int move_row)
 {
+	g_return_if_fail (IS_SHEET_VIEW (sv));
+
 	sheet_selection_set_internal (sv, edit,
 		base_col, base_row,
 		move_col, move_row, FALSE);
@@ -1243,7 +1247,7 @@ sv_selection_walk_step (SheetView *sv,
 
 #include <goffice/graph/gog-series.h>
 #include <goffice/graph/gog-plot-impl.h>
-#include <goffice/graph/go-data.h>
+#include <goffice/data/go-data.h>
 #include <expr.h>
 #include <graph.h>
 
@@ -1325,6 +1329,47 @@ sv_selection_to_plot (SheetView *sv, gpointer go_plot)
 	ptr = g_list_last (sv->selections);
 
 /* FIXME : a cheesy quick implementation */
+	cur_dim = desc->series.num_dim - 1;
+	if (desc->series.dim[cur_dim].val_type == GOG_DIM_MATRIX) {
+		/* Here, only the first range is used. It is assumed it is large enough
+		to retrieve the axis data and the matrix z values. We probably should raise
+		an error condition if it is not the case */
+		GnmRange vector = *((GnmRange const *)ptr->data);
+		int start_row = vector.start.row;
+		int start_col = vector.start.col;
+		int end_row = vector.end.row;
+		int end_col = vector.end.col;
+		/* check if we need X and Y axis labels */
+		if (desc->series.num_dim > 1) {
+			/* first row will be used as X labels */
+			start_row ++;
+			if (desc->series.num_dim > 2) {
+				/* first column will be used as Y labels */
+				start_col ++;
+				vector.start.row = start_row;
+				vector.start.col = vector.end.col = start_col - 1;
+				gog_series_set_dim (series, cur_dim - 1,
+					gnm_go_data_vector_new_expr (sheet,
+						gnm_expr_new_constant (
+							value_new_cellrange_r (sheet, &vector))), NULL);
+			}
+			vector.start.row = vector.end.row  = start_row - 1;
+			vector.start.col = start_col;
+			vector.end.col = end_col;
+			/* we assume that there are at most three dims (X, Y and Z) */
+			gog_series_set_dim (series, 0,
+				gnm_go_data_vector_new_expr (sheet,
+					gnm_expr_new_constant (
+						value_new_cellrange_r (sheet, &vector))), NULL);
+		}
+		vector.start.row = start_row;
+		vector.end.row = end_row;
+		gog_series_set_dim (series, cur_dim,
+			gnm_go_data_matrix_new_expr (sheet,
+				gnm_expr_new_constant (
+					value_new_cellrange_r (sheet, &vector))), NULL);
+		return;
+	}
 	cur_dim = 0;
 	for (; ptr != NULL; ptr = ptr->prev) {
 		GnmRange vector = *((GnmRange const *)ptr->data);
@@ -1366,6 +1411,11 @@ sv_selection_to_plot (SheetView *sv, gpointer go_plot)
 			       !first_series && desc->series.dim[cur_dim].is_shared)
 				++cur_dim;
 
+			while (cur_dim < desc->series.num_dim && desc->series.dim[cur_dim].priority == GOG_SERIES_ERRORS)
+				++cur_dim;
+			if (cur_dim >= desc->series.num_dim)
+				continue;
+
 			is_string_vec = characterize_vec (sheet, &vector, as_cols,
 				desc->series.dim[cur_dim].val_type == GOG_DIM_LABEL);
 			while ((desc->series.dim[cur_dim].val_type == GOG_DIM_LABEL && !is_string_vec) ||
