@@ -37,16 +37,16 @@
 #include "str.h"
 #include "number-match.h"
 #include "dialogs.h"
-#include "regutf8.h"
 #include "style-color.h"
+#include "gutils.h"
+#include <goffice/utils/regutf8.h>
 
-#include <libfoocanvas/foo-canvas-widget.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-widget.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkevents.h>
 #include <gdk/gdkkeysyms.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n.h>
-#include <string.h>
 
 typedef struct {
 	SheetObject parent;
@@ -155,7 +155,7 @@ do_focus_change (GtkWidget *widget, gboolean in)
 
 	gtk_widget_event (widget, (GdkEvent *)&fevent);
 
-	g_object_notify (G_OBJECT (widget), "has_focus");
+	g_object_notify (G_OBJECT (widget), "has-focus");
 
 	g_object_unref (widget);
 }
@@ -564,8 +564,8 @@ filter_foo_view_init (SheetObjectViewIface *sov_iface)
 typedef FooCanvasWidget		FilterFooView;
 typedef FooCanvasWidgetClass	FilterFooViewClass;
 static GSF_CLASS_FULL (FilterFooView, filter_foo_view,
-	NULL, NULL, NULL, NULL,
-	NULL, FOO_TYPE_CANVAS_WIDGET, 0,
+	NULL, NULL,
+	FOO_TYPE_CANVAS_WIDGET, 0,
 	GSF_INTERFACE (filter_foo_view_init, SHEET_OBJECT_VIEW_TYPE))
 
 static SheetObjectView *
@@ -630,7 +630,7 @@ typedef struct  {
 	GnmFilterCondition const *cond;
 	GnmValue		 *val[2];
 	go_regex_t  regexp[2];
-	GnmDateConventions const *date_conv;
+	GODateConventions const *date_conv;
 } FilterExpr;
 
 static void
@@ -674,13 +674,8 @@ filter_expr_eval (GnmFilterOp op, GnmValue const *src, go_regex_t const *regexp,
 		regmatch_t rm;
 
 		switch (go_regexec (regexp, str, 1, &rm, 0)) {
-		case REG_OK:
-			if (rm.rm_so == 0 && strlen (str) == (size_t)rm.rm_eo)
-				return op == GNM_FILTER_OP_EQUAL;
-			/* fall through */
-
-		case REG_NOMATCH:
-			return op == GNM_FILTER_OP_NOT_EQUAL;
+		case REG_NOMATCH: return op == GNM_FILTER_OP_NOT_EQUAL;
+		case REG_OK: return op == GNM_FILTER_OP_EQUAL;
 
 		default:
 			g_warning ("Unexpected regexec result");
