@@ -36,6 +36,7 @@
 #include "commands.h"
 #include "application.h"
 #include "xml-io.h"
+#include <graph.h>
 
 #include <goffice/graph/gog-graph.h>
 #include <goffice/graph/gog-object.h>
@@ -47,7 +48,9 @@
 #include <goffice/graph/gog-control-foocanvas.h>
 #include <goffice/utils/go-file.h>
 #include <goffice/utils/go-units.h>
-#include <graph.h>
+#include <goffice/utils/go-libxml-extras.h>
+#include <goffice/utils/go-glib-extras.h>
+#include <goffice/app/go-cmd-context.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-utils.h>
@@ -55,10 +58,10 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtkstock.h>
-#include <libfoocanvas/foo-canvas-line.h>
-#include <libfoocanvas/foo-canvas-rect-ellipse.h>
-#include <libfoocanvas/foo-canvas-polygon.h>
-#include <libfoocanvas/foo-canvas-text.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-line.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-rect-ellipse.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-polygon.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-text.h>
 #include <math.h>
 #include <string.h>
 
@@ -168,6 +171,30 @@ sheet_object_graph_new_view (SheetObject *so, SheetObjectViewContainer *containe
 	return gnm_pane_object_register (so, view, TRUE);
 }
 
+static GtkTargetList *
+sheet_object_graph_get_target_list (SheetObject const *so)
+{
+	GtkTargetList *tl = gtk_target_list_new (NULL, 0);
+	char *mime_str = go_image_format_to_mime ("svg");
+	GSList *mimes, *ptr;
+	char *mime;
+
+	mimes = go_strsplit_to_slist (mime_str, ',');
+	for (ptr = mimes; ptr != NULL; ptr = ptr->next) {
+		mime = (char *) ptr->data;
+
+		if (mime != NULL && *mime != '\0') 
+			gtk_target_list_add (tl, gdk_atom_intern (mime, FALSE),
+					     0, 0);
+	}
+	g_free (mime_str);
+	go_slist_free_custom (mimes, g_free);
+	/* No need to eliminate duplicates. */
+	gtk_target_list_add_image_targets (tl, 0, TRUE);
+
+	return tl;
+}
+
 static gboolean
 sog_gsf_gdk_pixbuf_save (const gchar *buf,
 			 gsize count,
@@ -183,6 +210,48 @@ sog_gsf_gdk_pixbuf_save (const gchar *buf,
 	return ok;
 }
 
+static void
+sheet_object_graph_write_image (SheetObject const *so, const char *format,
+				GsfOutput *output, GError **err)
+{
+	SheetObjectGraph *sog = SHEET_OBJECT_GRAPH (so);
+	gboolean res = FALSE;
+	double coords[4];
+	double w, h;
+	
+	if (so->sheet) {
+		sheet_object_position_pts_get (SHEET_OBJECT (sog), coords);
+		w = fabs (coords[2] - coords[0]) + 1.;
+		h = fabs (coords[3] - coords[1]) + 1.;
+	} else {
+		w = GPOINTER_TO_UINT 
+			(g_object_get_data (G_OBJECT (so), "pt-width-at-copy"));
+		h = GPOINTER_TO_UINT 
+			(g_object_get_data (G_OBJECT (so), "pt-height-at-copy"));
+	}
+
+	g_return_if_fail (w > 0 && h > 0);
+
+	if (strcmp (format, "svg") == 0) {
+		res = gog_graph_export_to_svg (sog->graph, output, w, h, 1.0);
+	} else {
+		GogRendererPixbuf *prend = GOG_RENDERER_PIXBUF (sog->renderer);
+		GdkPixbuf *pixbuf = gog_renderer_pixbuf_get (prend);
+
+		if (!pixbuf) {
+			gog_renderer_pixbuf_update (prend, w, h, 1.);
+			pixbuf = gog_renderer_pixbuf_get (prend);
+		}
+		res = gdk_pixbuf_save_to_callback (pixbuf,
+						   sog_gsf_gdk_pixbuf_save,
+						   output, format,
+						   err, NULL);
+	}
+	if (!res && err && *err == NULL)
+		*err = g_error_new (gsf_output_error_id (), 0,
+				    _("Unknown failure while saving image"));
+}
+
 /* 
  * The following are useful formats to save in:
  *  png
@@ -196,60 +265,41 @@ sog_gsf_gdk_pixbuf_save (const gchar *buf,
 static void
 sog_cb_save_as (SheetObject *so, SheetControl *sc)
 {
-	WorkbookControlGUI *wbcg;
-	char *uri;
-	GError *err = NULL;
-	gboolean ret = FALSE;
-	GsfOutput *output;
-	GSList *l = NULL;
-	GnmImageFormat fmts[] = {
+	static GOImageType const fmts[] = {
 		{(char *) "svg",  (char *) N_("SVG (vector graphics)"), (char *) "svg", FALSE},
 		{(char *) "png",  (char *) N_("PNG (raster graphics)"), (char *) "png", TRUE},
 		{(char *) "jpeg", (char *) N_("JPEG (photograph)"),     (char *) "jpg", TRUE}
 	};
-	GnmImageFormat *sel_fmt = &fmts[0];
+
+	WorkbookControlGUI *wbcg;
+	char *uri;
+	GError *err = NULL;
+	GsfOutput *output;
+	GSList *l = NULL;
+	GOImageType const *sel_fmt = &fmts[0];
 	guint i;
 	SheetObjectGraph *sog = SHEET_OBJECT_GRAPH (so);
 
 	g_return_if_fail (sog != NULL);
 
-	for (i = 0; i < sizeof fmts / sizeof fmts[0]; i++)
-		l = g_slist_prepend (l, &fmts[i]);
+	for (i = 0; i < G_N_ELEMENTS (fmts); i++)
+		l = g_slist_prepend (l, (gpointer) (fmts + i));
 	l = g_slist_reverse (l);
 
 	wbcg = scg_get_wbcg (SHEET_CONTROL_GUI (sc));
 
-#warning this violate model gui barrier
-	uri = gui_get_image_save_info (wbcg, l, &sel_fmt);
+#warning "This violates model gui barrier"
+	uri = gui_get_image_save_info (wbcg_toplevel (wbcg), l, &sel_fmt);
 	if (!uri)
 		goto out;
 	output = go_file_create (uri, &err);
 	if (!output)
 		goto out;
-	if (strcmp (sel_fmt->name, "svg") == 0) {
-		double coords [4];
-		sheet_object_position_pts_get (SHEET_OBJECT (sog), coords);
-		ret = gog_graph_export_to_svg (sog->graph, output,
-					       fabs (coords[2] - coords[0]) + 1.,
-					       fabs (coords[3] - coords[1]) + 1.,
-					       1.);
-	} else {
-		GdkPixbuf *pixbuf = gog_renderer_pixbuf_get (
-			GOG_RENDERER_PIXBUF (sog->renderer));
-
-		ret = gdk_pixbuf_save_to_callback (pixbuf,
-						   sog_gsf_gdk_pixbuf_save,
-						   output, sel_fmt->name,
-						   &err, NULL);
-	}
-	gsf_output_close (output);
+	sheet_object_write_image (so, sel_fmt->name, output, &err);
 	g_object_unref (output);
 		
-	if (!ret && err == NULL)
-		err = g_error_new (gsf_output_error_id (), 0,
-				   _("Unknown failure while saving image"));
-	if (!ret)
-		gnm_cmd_context_error (GNM_CMD_CONTEXT (wbcg), err);
+	if (err != NULL)
+		go_cmd_context_error (GO_CMD_CONTEXT (wbcg), err);
 
 out:
 	g_free (uri);
@@ -262,7 +312,7 @@ sheet_object_graph_populate_menu (SheetObject *so, GPtrArray *actions)
 	static SheetObjectAction const sog_action =
 		{ GTK_STOCK_SAVE_AS, N_("_Save as image"), NULL, 0, sog_cb_save_as };
 	SHEET_OBJECT_CLASS (parent_klass)->populate_menu (so, actions);
-	gnm_ptr_array_insert (actions, (gpointer) &sog_action, 1);
+	go_ptr_array_insert (actions, (gpointer) &sog_action, 1);
 }
 
 static gboolean
@@ -390,8 +440,8 @@ sheet_object_graph_bounds_changed (SheetObject *so)
 		double coords [4];
 		sheet_object_position_pts_get (so, coords);
 		g_object_set (SHEET_OBJECT_GRAPH (so)->renderer,
-			"logical_width_pts",  fabs (coords[2] - coords[0]),
-			"logical_height_pts", fabs (coords[3] - coords[1]),
+			"logical-width-pts",  fabs (coords[2] - coords[0]),
+			"logical-height-pts", fabs (coords[3] - coords[1]),
 			NULL);
 	}
 }
@@ -430,9 +480,17 @@ sheet_object_graph_init (GObject *obj)
 	so->anchor.direction = SO_DIR_DOWN_RIGHT;
 }
 
-GSF_CLASS (SheetObjectGraph, sheet_object_graph,
-	   sheet_object_graph_class_init, sheet_object_graph_init,
-	   SHEET_OBJECT_TYPE);
+static void
+sog_imageable_init (SheetObjectImageableIface *soi_iface)
+{
+	soi_iface->get_target_list = sheet_object_graph_get_target_list;
+	soi_iface->write_image	   = sheet_object_graph_write_image;
+}
+
+GSF_CLASS_FULL (SheetObjectGraph, sheet_object_graph,
+		sheet_object_graph_class_init, sheet_object_graph_init,
+		SHEET_OBJECT_TYPE, 0,
+		GSF_INTERFACE (sog_imageable_init, SHEET_OBJECT_IMAGEABLE_TYPE));
 
 /**
  * sheet_object_graph_new :
@@ -518,7 +576,7 @@ sheet_object_graph_guru (WorkbookControlGUI *wbcg, GogGraph *graph,
 			 GClosure *closure)
 {
 	GtkWidget *dialog = gog_guru (graph, GOG_DATA_ALLOCATOR (wbcg),
-		       GNM_CMD_CONTEXT (wbcg), wbcg_toplevel (wbcg),
+		       GO_CMD_CONTEXT (wbcg), wbcg_toplevel (wbcg),
 		       closure);
 	wbcg_edit_attach_guru (wbcg, dialog);
 	g_object_set_data_full (G_OBJECT (dialog),
