@@ -62,11 +62,8 @@ typedef struct {
 	gboolean    (*write_xml_dom) (SheetObject const *so,
 				      XmlParseContext const *ctxt,
 				      xmlNodePtr	tree);
-	gboolean     (*read_xml_sax) (SheetObject	*so,
-				      char const *type_name,	/* for versioning */
-				      XmlParseContext const *ctxt,
-				      xmlNodePtr	tree);
 	void        (*write_xml_sax) (SheetObject const *so, GsfXMLOut *output);
+	GsfXMLInNode *read_xml_sax;
 
 	/* Called with 0,0 set to the top, left corner of the object, and the
 	 * graphics context saved */
@@ -140,4 +137,15 @@ void so_vc_anchor_to_coords (SheetObjectViewContainer *sovc,
 void so_vc_coords_to_anchor (SheetObjectViewContainer *sovc,
 			     double const *input, SheetObjectAnchor *output);
 
+/***************************************************************************/
+
+struct _SheetObjectImageableIface {
+	GTypeInterface base;
+
+	GtkTargetList *(*get_target_list) (SheetObject const *so);
+	void           (*write_image)	  (SheetObject const *so, 
+					   const char *format,
+					   GsfOutput *output, GError **err);
+};
+
 #endif /* GNUMERIC_SHEET_OBJECT_PRIV_H */
