@@ -44,13 +44,15 @@
 #include "mathfunc.h"
 #include "gnumeric-expr-entry.h"
 #include "dialogs.h"
-#include "xml-io.h"
 #include "dialogs/help.h"
-#include <goffice/gui-utils/go-combo-text.h>
+#include "xml-io.h"
+
+#include <goffice/gtk/go-combo-text.h>
+#include <goffice/utils/go-libxml-extras.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <libxml/globals.h>
-#include <libfoocanvas/foo-canvas-widget.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas-widget.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtklabel.h>
@@ -419,7 +421,7 @@ sheet_widget_frame_user_config (SheetObject *so, SheetControl *sc)
   	state->sheet = sc_sheet	(sc);
   	state->old_focus = NULL;
   	state->old_label = g_strdup(swc->label);
-  	state->gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+  	state->gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"so-frame.glade", NULL, NULL);
   	state->dialog = glade_xml_get_widget (state->gui, "so_frame");
 
@@ -671,11 +673,11 @@ SOW_MAKE_TYPE (button, Button,
 		       g_object_class_install_property
 			       (object_class, SOB_PROP_TEXT,
 				g_param_spec_string ("text", NULL, NULL, NULL,
-						     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+						     GSF_PARAM_STATIC | G_PARAM_READWRITE));
 		       g_object_class_install_property
 			       (object_class, SOB_PROP_MARKUP,
 				g_param_spec_boxed ("markup", NULL, NULL, PANGO_TYPE_ATTR_LIST,
-						    (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+						    GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	       })
 
 /****************************************************************************/
@@ -761,7 +763,7 @@ cb_adjustment_value_changed (GtkAdjustment *adjustment,
 	if (sheet_widget_adjustment_get_ref (swa, &ref, TRUE) != NULL) {
 		GnmCell *cell = sheet_cell_fetch (ref.sheet, ref.col, ref.row);
 		/* TODO : add more control for precision, XL is stupid */
-		int new_val = gnumeric_fake_round (swa->adjustment->value);
+		int new_val = gnm_fake_round (swa->adjustment->value);
 		if (cell->value != NULL &&
 		    cell->value->type == VALUE_INTEGER &&
 		    cell->value->v_int.val == new_val)
@@ -944,7 +946,7 @@ sheet_widget_adjustment_user_config (SheetObject *so, SheetControl *sc)
 	state->wbcg = wbcg;
 	state->sheet = sc_sheet	(sc);
 	state->old_focus = NULL;
-	state->gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	state->gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"so-scrollbar.glade", NULL, NULL);
 	state->dialog = glade_xml_get_widget (state->gui, "SO-Scrollbar");
 
@@ -955,7 +957,7 @@ sheet_widget_adjustment_user_config (SheetObject *so, SheetControl *sc)
 		GNM_EE_ABS_ROW | GNM_EE_ABS_COL | GNM_EE_SHEET_OPTIONAL | GNM_EE_SINGLE_RANGE,
 		GNM_EE_MASK);
 	gnm_expr_entry_load_from_dep (state->expression, &swa->dep);
-	gnm_setup_label_atk (glade_xml_get_widget (state->gui, "label_linkto"),
+	go_atk_setup_label (glade_xml_get_widget (state->gui, "label_linkto"),
 			     GTK_WIDGET (state->expression));
 	gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (state->expression),
 			  1, 2, 0, 1,
@@ -1561,7 +1563,7 @@ sheet_widget_checkbox_user_config (SheetObject *so, SheetControl *sc)
 	state->sheet = sc_sheet	(sc);
 	state->old_focus = NULL;
 	state->old_label = g_strdup (swc->label);
-	state->gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	state->gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"so-checkbox.glade", NULL, NULL);
 	state->dialog = glade_xml_get_widget (state->gui, "SO-Checkbox");
 
@@ -1572,7 +1574,7 @@ sheet_widget_checkbox_user_config (SheetObject *so, SheetControl *sc)
 		GNM_EE_ABS_ROW | GNM_EE_ABS_COL | GNM_EE_SHEET_OPTIONAL | GNM_EE_SINGLE_RANGE,
 		GNM_EE_MASK);
 	gnm_expr_entry_load_from_dep (state->expression, &swc->dep);
-	gnm_setup_label_atk (glade_xml_get_widget (state->gui, "label_linkto"),
+	go_atk_setup_label (glade_xml_get_widget (state->gui, "label_linkto"),
 			     GTK_WIDGET (state->expression));
 	gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (state->expression),
 			  1, 2, 0, 1,
@@ -1725,11 +1727,11 @@ SOW_MAKE_TYPE (checkbox, Checkbox,
 		       g_object_class_install_property
 			       (object_class, SOC_PROP_TEXT,
 				g_param_spec_string ("text", NULL, NULL, NULL,
-						     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+						     GSF_PARAM_STATIC | G_PARAM_READWRITE));
 		       g_object_class_install_property
 			       (object_class, SOC_PROP_MARKUP,
 				g_param_spec_boxed ("markup", NULL, NULL, PANGO_TYPE_ATTR_LIST,
-						    (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+						    GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	       })
 
 /****************************************************************************/
