@@ -31,12 +31,13 @@
 #include "sheet-object-graph.h"
 #include "sheet-object-image.h"
 #include "graph.h"
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "application.h"
 #include "gutils.h"
 
 #include <libxml/globals.h>
-#include <libfoocanvas/foo-canvas.h>
+#include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
+#include <goffice/utils/go-glib-extras.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <string.h>
@@ -78,7 +79,7 @@ static void
 cb_so_delete (SheetObject *so, SheetControl *sc)
 {
 	cmd_objects_delete (sc_wbc (sc), 
-		gnm_slist_create (so, NULL), NULL);
+		go_slist_create (so, NULL), NULL);
 }
 void
 sheet_object_get_editor (SheetObject *so, SheetControl *sc)
@@ -93,13 +94,13 @@ static void
 cb_so_cut (SheetObject *so, SheetControl *sc)
 {
 	gnm_app_clipboard_cut_copy_obj (sc_wbc (sc), TRUE, sc_view (sc),
-		gnm_slist_create (so, NULL));
+		go_slist_create (so, NULL));
 }
 static void
 cb_so_copy (SheetObject *so, SheetControl *sc)
 {
 	gnm_app_clipboard_cut_copy_obj (sc_wbc (sc), FALSE, sc_view (sc),
-		gnm_slist_create (so, NULL));
+		go_slist_create (so, NULL));
 }
 
 static void
@@ -135,7 +136,7 @@ static void
 sheet_objects_max_extent (Sheet *sheet)
 {
 	GnmCellPos max_pos = { 0, 0 };
-	GList *ptr;
+	GSList *ptr;
 
 	for (ptr = sheet->sheet_objects; ptr != NULL ; ptr = ptr->next ) {
 		SheetObject *so = SHEET_OBJECT (ptr->data);
@@ -209,14 +210,14 @@ sheet_object_class_init (GObjectClass *klass)
 		SHEET_OBJECT_TYPE,
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (SheetObjectClass, bounds_changed),
-		(GSignalAccumulator) NULL, NULL,
+		NULL, NULL,
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
 	signals [UNREALIZED] = g_signal_new ("unrealized",
 		SHEET_OBJECT_TYPE,
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (SheetObjectClass, unrealized),
-		(GSignalAccumulator) NULL, NULL,
+		NULL, NULL,
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
 }
@@ -323,7 +324,7 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 	g_return_val_if_fail (IS_SHEET_OBJECT (so), TRUE);
 	g_return_val_if_fail (IS_SHEET (sheet), TRUE);
 	g_return_val_if_fail (so->sheet == NULL, TRUE);
-	g_return_val_if_fail (g_list_find (sheet->sheet_objects, so) == NULL, TRUE);
+	g_return_val_if_fail (g_slist_find (sheet->sheet_objects, so) == NULL, TRUE);
 
 	so->sheet = sheet;
 	if (SO_CLASS (so)->assign_to_sheet &&
@@ -333,7 +334,7 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 	}
 
 	g_object_ref (G_OBJECT (so));
-	sheet->sheet_objects = g_list_prepend (sheet->sheet_objects, so);
+	sheet->sheet_objects = g_slist_prepend (sheet->sheet_objects, so);
 	/* FIXME : add a flag to sheet to have sheet_update do this */
 	sheet_objects_max_extent (sheet);
 
@@ -357,13 +358,13 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 gboolean
 sheet_object_clear_sheet (SheetObject *so)
 {
-	GList *ptr;
+	GSList *ptr;
 	gpointer view_handler;
 
 	g_return_val_if_fail (IS_SHEET_OBJECT (so), TRUE);
 	g_return_val_if_fail (IS_SHEET (so->sheet), TRUE);
 
-	ptr = g_list_find (so->sheet->sheet_objects, so);
+	ptr = g_slist_find (so->sheet->sheet_objects, so);
 	g_return_val_if_fail (ptr != NULL, TRUE);
 
 	/* clear any pending attempts to create views */
@@ -382,8 +383,8 @@ sheet_object_clear_sheet (SheetObject *so)
 	    SO_CLASS (so)->remove_from_sheet (so))
 		return TRUE;
 
-	so->sheet->sheet_objects = g_list_remove_link (so->sheet->sheet_objects, ptr);
-	g_list_free (ptr);
+	so->sheet->sheet_objects = g_slist_remove_link (so->sheet->sheet_objects, ptr);
+	g_slist_free (ptr);
 
 	if (so->anchor.cell_bound.end.col == so->sheet->max_object_extent.col &&
 	    so->anchor.cell_bound.end.row == so->sheet->max_object_extent.row)
@@ -579,7 +580,7 @@ void
 sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 			GnmRelocUndo *undo)
 {
-	GList   *ptr, *next;
+	GSList   *ptr, *next;
 	GnmRange	 dest;
 	gboolean clear, change_sheets;
 
@@ -593,7 +594,7 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 
 	/* Clear the destination range on the target sheet */
 	if (change_sheets) {
-		GList *copy = g_list_copy (rinfo->target_sheet->sheet_objects);
+		GSList *copy = g_slist_copy (rinfo->target_sheet->sheet_objects);
 		for (ptr = copy; ptr != NULL ; ptr = ptr->next ) {
 			SheetObject *so = SHEET_OBJECT (ptr->data);
 			GnmRange const *r  = &so->anchor.cell_bound;
@@ -603,7 +604,7 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 				sheet_object_clear_sheet (so);
 			}
 		}
-		g_list_free (copy);
+		g_slist_free (copy);
 	}
 
 	ptr = rinfo->origin_sheet->sheet_objects;
@@ -660,7 +661,7 @@ GSList *
 sheet_objects_get (Sheet const *sheet, GnmRange const *r, GType t)
 {
 	GSList *res = NULL;
-	GList *ptr;
+	GSList *ptr;
 
 	g_return_val_if_fail (IS_SHEET (sheet), NULL);
 
@@ -687,7 +688,7 @@ sheet_objects_get (Sheet const *sheet, GnmRange const *r, GType t)
 void
 sheet_objects_clear (Sheet const *sheet, GnmRange const *r, GType t)
 {
-	GList *ptr, *next;
+	GSList *ptr, *next;
 
 	g_return_if_fail (IS_SHEET (sheet));
 
@@ -744,13 +745,12 @@ sheet_object_clone_sheet (Sheet const *src, Sheet *dst, GnmRange *range)
 {
 	SheetObject *so;
 	SheetObject *new_so;
-	GList *list;
+	GSList *list;
 
 	g_return_if_fail (IS_SHEET (dst));
 	g_return_if_fail (dst->sheet_objects == NULL);
 
-	list = src->sheet_objects;
-	for (; list != NULL; list = list->next) {
+	for (list = src->sheet_objects; list != NULL; list = list->next) {
 		so = (SheetObject *) list->data;
 		if (range == NULL || range_overlap (range, &so->anchor.cell_bound)) {
 			new_so = sheet_object_dup (so);
@@ -761,7 +761,7 @@ sheet_object_clone_sheet (Sheet const *src, Sheet *dst, GnmRange *range)
 		}
 	}
 
-	dst->sheet_objects = g_list_reverse (dst->sheet_objects);
+	dst->sheet_objects = g_slist_reverse (dst->sheet_objects);
 }
 
 
@@ -801,7 +801,7 @@ sheet_object_direction_set (SheetObject *so, gdouble const *coords)
 gboolean
 sheet_object_rubber_band_directly (SheetObject const *so)
 {
-	return SO_CLASS (so)->rubber_band_directly;
+	return FALSE;
 }
 
 /**
@@ -935,6 +935,46 @@ sheet_object_view_get_type (void)
 	return type;
 }
 
+/*****************************************************************************/
+
+GType
+sheet_object_imageable_get_type (void)
+{
+	static GType type = 0;
+
+	if (!type) {
+		static GTypeInfo const type_info = {
+			sizeof (SheetObjectImageableIface), /* class_size */
+			NULL,				/* base_init */
+			NULL,				/* base_finalize */
+		};
+
+		type = g_type_register_static (G_TYPE_INTERFACE,
+			"SheetObjectImageable", &type_info, 0);
+	}
+
+	return type;
+}
+
+#define SHEET_OBJECT_IMAGEABLE_CLASS(o)	(G_TYPE_INSTANCE_GET_INTERFACE ((o), SHEET_OBJECT_IMAGEABLE_TYPE, SheetObjectImageableIface))
+
+GtkTargetList *sheet_object_get_target_list (SheetObject const *so)
+{
+	if (!IS_SHEET_OBJECT_IMAGEABLE (so))
+		return NULL;
+
+	return SHEET_OBJECT_IMAGEABLE_CLASS (so)->get_target_list (so);
+}
+
+void sheet_object_write_image (SheetObject const *so, const char *format,
+			       GsfOutput *output, GError **err)
+{
+	g_return_if_fail (IS_SHEET_OBJECT_IMAGEABLE (so));
+
+	SHEET_OBJECT_IMAGEABLE_CLASS (so)->write_image (so, format, 
+							output, err);
+
+}
 
 /*****************************************************************************/
 
@@ -954,4 +994,3 @@ sheet_objects_init (void)
 	sov_so_quark = g_quark_from_static_string ("SheetObject");
 	sov_container_quark = g_quark_from_static_string ("SheetObjectViewContainer");
 }
-
