@@ -68,6 +68,14 @@ cb_update_auto_expr (gpointer data)
 
 /*************************************************************************/
 
+static void
+sv_sheet_name_changed (G_GNUC_UNUSED Sheet *sheet,
+		       G_GNUC_UNUSED GParamSpec *pspec,
+		       SheetView *sv)
+{
+	sv->edit_pos_changed.content = TRUE;
+}
+
 Sheet *
 sv_sheet (SheetView const *sv)
 {
@@ -98,7 +106,6 @@ sv_init_sc (SheetView const *sv, SheetControl *sc)
 	/* Set the visible bound, not the logical bound */
 	sc_cursor_bound (sc, selection_first_range (sv, NULL, NULL));
 	sc_ant (sc);
-	sc_direction_changed (sc);
 }
 
 void
@@ -164,8 +171,9 @@ sv_weak_unref (SheetView **ptr)
 }
 
 static GObjectClass *parent_class;
+
 static void
-s_view_finalize (GObject *object)
+sv_real_dispose (GObject *object)
 {
 	SheetView *sv = SHEET_VIEW (object);
 
@@ -178,11 +186,19 @@ s_view_finalize (GObject *object)
 			g_warning ("Unexpected left over controls");
 	}
 
+	if (sv->sheet) {
+		Sheet *sheet = sv->sheet;
+		sv->sheet = NULL;
+		g_ptr_array_remove (sheet->sheet_views, sv);
+		g_signal_handlers_disconnect_by_func (sheet, sv_sheet_name_changed, sv);
+		g_object_unref (sheet);
+	}
+
 	sv_unant (sv);
 	sv_selection_free (sv);
 	auto_expr_timer_clear (sv);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	parent_class->dispose (object);
 }
 
 static void
@@ -193,7 +209,7 @@ sheet_view_class_init (GObjectClass *klass)
 	g_return_if_fail (wbc_class != NULL);
 
 	parent_class = g_type_class_peek_parent (klass);
-	klass->finalize = s_view_finalize;
+	klass->dispose = sv_real_dispose;
 }
 
 static void
@@ -212,7 +228,6 @@ sheet_view_init (GObject *object)
 	sv->selection_content_changed = TRUE;
 	sv->reposition_selection = TRUE;
 	sv->auto_expr_timer = 0;
-	sv->text_is_rtl	= FALSE;
 
 	sv->frozen_top_left.col = sv->frozen_top_left.row =
 	sv->unfrozen_top_left.col = sv->unfrozen_top_left.row = -1;
@@ -228,15 +243,31 @@ GSF_CLASS (SheetView, sheet_view,
 SheetView *
 sheet_view_new (Sheet *sheet, WorkbookView *wbv)
 {
-	SheetView *sv = g_object_new (SHEET_VIEW_TYPE, NULL);
-	sheet_attach_view (sheet, sv);
+	SheetView *sv;
+
+	g_return_val_if_fail (IS_SHEET (sheet), NULL);
+
+	sv = g_object_new (SHEET_VIEW_TYPE, NULL);
+	sv->sheet = g_object_ref (sheet);
 	sv->wbv = wbv;
+	g_ptr_array_add (sheet->sheet_views, sv);
+
+	g_signal_connect (G_OBJECT (sheet),
+			  "notify::name",
+			  G_CALLBACK (sv_sheet_name_changed),
+			  sv);
 
 	SHEET_VIEW_FOREACH_CONTROL (sv, control,
 		sv_init_sc (sv, control););
 	return sv;
 }
 
+void
+sv_dispose (SheetView *sv)
+{
+	g_object_run_dispose (G_OBJECT (sv));
+}
+
 void
 sv_unant (SheetView *sv)
 {
@@ -312,7 +343,7 @@ sv_selection_copy (SheetView *sv, WorkbookControl *wbc)
 {
 	GnmRange const *sel;
 
-	if (!(sel = selection_first_range (sv, GNM_CMD_CONTEXT (wbc), _("Copy"))))
+	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Copy"))))
 		return FALSE;
 
 	gnm_app_clipboard_cut_copy (wbc, FALSE, sv, sel, TRUE);
@@ -337,10 +368,10 @@ sv_selection_cut (SheetView *sv, WorkbookControl *wbc)
 	 */
 	g_return_val_if_fail (IS_SHEET_VIEW (sv), FALSE);
 
-	if (!(sel = selection_first_range (sv, GNM_CMD_CONTEXT (wbc), _("Cut"))))
+	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Cut"))))
 		return FALSE;
 
-	if (sheet_range_splits_region (sv_sheet (sv), sel, NULL, GNM_CMD_CONTEXT (wbc), _("Cut")))
+	if (sheet_range_splits_region (sv_sheet (sv), sel, NULL, GO_CMD_CONTEXT (wbc), _("Cut")))
 		return FALSE;
 
 	gnm_app_clipboard_cut_copy (wbc, TRUE, sv, sel, TRUE);
@@ -778,12 +809,3 @@ sv_set_initial_top_left (SheetView *sv, int col, int row)
 	sv->initial_top_left.col = col;
 	sv->initial_top_left.row = row;
 }
-
-void
-sv_direction_changed (SheetView *sv)
-{
-	if (sv->sheet != NULL) {
-		sv->text_is_rtl = sv->sheet->text_is_rtl;
-		SHEET_VIEW_FOREACH_CONTROL (sv, sc, sc_direction_changed (sc););
-	}
-}
