@@ -14,11 +14,13 @@
 #include "gnumeric.h"
 #include "libgnumeric.h"
 #include "gnumeric-paths.h"
-#include "plugin.h"
+#include "gnm-plugin.h"
+#include "command-context.h"
 #include "command-context-stderr.h"
-#include "io-context.h"
 #include "workbook-view.h"
-#include "file.h"
+#include <goffice/app/file.h>
+#include <goffice/app/io-context.h>
+#include <goffice/app/go-cmd-context.h>
 #include <goffice/utils/go-file.h>
 #include <gsf/gsf-utils.h>
 #include <string.h>
@@ -28,6 +30,7 @@ static gboolean ssconvert_list_exporters = FALSE;
 static gboolean ssconvert_list_importers = FALSE;
 static gboolean ssconvert_one_file_per_sheet = FALSE;
 static char const *ssconvert_import_encoding = NULL;
+static char const *ssconvert_import_id = NULL;
 static char const *ssconvert_export_id = NULL;
 
 #ifdef WIN32
@@ -47,6 +50,8 @@ ssconvert_popt_options[] = {
 
 	{ "import-encoding", 'E', POPT_ARG_STRING, &ssconvert_import_encoding, 0,
 	  N_("Optionally specify an encoding for imported content"), N_("ENCODING")  },
+	{ "import-type", 'I', POPT_ARG_STRING, &ssconvert_import_id, 0,
+	  N_("Optionally specify which importer to use"), "ID"  },
 	{ "export-type", 'T', POPT_ARG_STRING, &ssconvert_export_id, 0,
 	  N_("Optionally specify which exporter to use"), "ID"  },
 	{ "list-exporters", '\0', POPT_ARG_NONE, &ssconvert_list_exporters, 0,
@@ -92,21 +97,22 @@ list_them (get_them_f get_them,
 }
 
 static int
-convert (char const **args, GnmCmdContext *cc)
+convert (char const **args, GOCmdContext *cc)
 {
 	int res = 0;
-	GnmFileSaver *fs = NULL;
+	GOFileSaver *fs = NULL;
+	GOFileOpener *fo = NULL;
 	char *outfile = go_shell_arg_to_uri (args[1]);
 
 	if (ssconvert_export_id != NULL) {
-		fs = gnm_file_saver_for_id (ssconvert_export_id);
+		fs = go_file_saver_for_id (ssconvert_export_id);
 		if (fs == NULL) {
 			res = 1;
 			fprintf (stderr, _("Unknown exporter '%s'.\n"
 				 "Try --list-exporters to see a list of possibilities.\n"),
 				 ssconvert_export_id);
 		} else if (outfile == NULL &&
-			   gnm_file_saver_get_extension	(fs) != NULL) {
+			   go_file_saver_get_extension	(fs) != NULL) {
 			char *basename = g_path_get_basename (args[0]);
 			if (basename != NULL) {
 				char *t = strrchr (basename, '.');
@@ -115,7 +121,7 @@ convert (char const **args, GnmCmdContext *cc)
 					t = strrchr (args[0], '.');
 					g_string_append_len (res, args[0], t - args[0] + 1);
 					g_string_append (res, 
-						gnm_file_saver_get_extension (fs));
+						go_file_saver_get_extension (fs));
 					outfile = g_string_free (res, FALSE);
 				}
 				g_free (basename);
@@ -123,7 +129,7 @@ convert (char const **args, GnmCmdContext *cc)
 		}
 	} else {
 		if (outfile != NULL) {
-			fs = gnm_file_saver_for_file_name (outfile);
+			fs = go_file_saver_for_file_name (outfile);
 			if (fs == NULL) {
 				res = 2;
 				fprintf (stderr, _("Unable to guess exporter to use for '%s'.\n"
@@ -135,21 +141,31 @@ convert (char const **args, GnmCmdContext *cc)
 	if (outfile == NULL)
 		fprintf (stderr, _("An output file name or an explicit export type is required.\n"
 			 "Try --list-exporters to see a list of possibilities.\n"));
+	
+	if (ssconvert_import_id != NULL) {
+		fo = go_file_opener_for_id (ssconvert_import_id);
+		if (fo == NULL) {
+			res = 1;
+			fprintf (stderr, _("Unknown importer '%s'.\n"
+				 "Try --list-importers to see a list of possibilities.\n"),
+				 ssconvert_import_id);
+		} 
+	}
 
 	if (fs != NULL) {
 		IOContext *io_context = gnumeric_io_context_new (cc);
 		char *uri = go_shell_arg_to_uri (args[0]);
-		WorkbookView *wbv = wb_view_new_from_uri (uri, NULL,
+		WorkbookView *wbv = wb_view_new_from_uri (uri, fo,
 			io_context, ssconvert_import_encoding);
 		g_free (uri);
-		if (gnm_file_saver_get_save_scope (fs) !=
+		if (go_file_saver_get_save_scope (fs) !=
 		    FILE_SAVE_WORKBOOK) {
 			if (ssconvert_one_file_per_sheet) {
 				g_warning ("TODO");
 			} else
 				fprintf (stderr, _("Selected exporter (%s) does not support saving multiple sheets in one file.\n"
 						   "Only the current sheet will be saved."),
-					 gnm_file_saver_get_id (fs));
+					 go_file_saver_get_id (fs));
 		}
 		res = !wb_view_save_as (wbv, fs, outfile, cc);
 		g_object_unref (wb_view_workbook (wbv));
@@ -163,7 +179,7 @@ main (int argc, char const *argv [])
 {
 	ErrorInfo	*plugin_errs;
 	int		 res = 0;
-	GnmCmdContext	*cc;
+	GOCmdContext	*cc;
 	poptContext ctx;
 
 	gnm_pre_parse_init (argv[0]);
@@ -179,7 +195,7 @@ main (int argc, char const *argv [])
 
 	if (ssconvert_show_version) {
 		printf (_("ssconvert version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
-			GNUMERIC_VERSION, gnumeric_data_dir, gnumeric_lib_dir);
+			GNUMERIC_VERSION, gnm_sys_data_dir (), gnm_sys_lib_dir ());
 		poptFreeContext (ctx);
 		return 0;
 	}
@@ -187,18 +203,18 @@ main (int argc, char const *argv [])
 	gnm_common_init (FALSE);
 
 	cc = cmd_context_stderr_new ();
-	plugins_init (cc);
-	plugin_db_activate_plugin_list (
-		plugins_get_available_plugins (), &plugin_errs);
+	gnm_plugins_init (GO_CMD_CONTEXT (cc));
+	go_plugin_db_activate_plugin_list (
+		go_plugins_get_available_plugins (), &plugin_errs);
 
 	if (ssconvert_list_exporters)
 		list_them (&get_file_savers,
-			(get_desc_f) &gnm_file_saver_get_id,
-			(get_desc_f) &gnm_file_saver_get_description);
+			(get_desc_f) &go_file_saver_get_id,
+			(get_desc_f) &go_file_saver_get_description);
 	else if (ssconvert_list_importers)
 		list_them (&get_file_openers,
-			(get_desc_f) &gnm_file_opener_get_id,
-			(get_desc_f) &gnm_file_opener_get_description);
+			(get_desc_f) &go_file_opener_get_id,
+			(get_desc_f) &go_file_opener_get_description);
 	else {
 		char const **args = poptGetArgs (ctx);
 		if (args && args[0])
