@@ -12,11 +12,11 @@
 #include "gnumeric.h"
 #include "libgnumeric.h"
 #include "gnumeric-paths.h"
-#include "plugin.h"
+#include <goffice/app/go-plugin.h>
 #include "command-context-stderr.h"
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "workbook-view.h"
-#include "file.h"
+#include <goffice/app/file.h>
 #include "workbook.h"
 #include "sheet.h"
 #include "cell.h"
@@ -27,6 +27,7 @@
 #include "sheet-object-graph.h"
 
 #include <goffice/utils/go-file.h>
+#include <goffice/app/go-cmd-context.h>
 #include <goffice/graph/gog-object.h>
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-libxml.h>
@@ -182,7 +183,7 @@ main (int argc, char const *argv [])
 {
 	ErrorInfo	*plugin_errs;
 	int		 res = 0;
-	GnmCmdContext	*cc;
+	GOCmdContext	*cc;
 	poptContext ctx;
 
 	gnm_pre_parse_init (argv[0]);
@@ -193,7 +194,7 @@ main (int argc, char const *argv [])
 
 	if (ssindex_show_version) {
 		printf (_("ssindex version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
-			GNUMERIC_VERSION, gnumeric_data_dir, gnumeric_lib_dir);
+			GNUMERIC_VERSION, gnm_sys_data_dir (), gnm_sys_lib_dir ());
 		poptFreeContext (ctx);
 		return 0;
 	} else if (!ssindex_run_indexer && !ssindex_list_mime_types) {
@@ -204,9 +205,9 @@ main (int argc, char const *argv [])
 	gnm_common_init (FALSE);
 
 	cc = cmd_context_stderr_new ();
-	plugins_init (cc);
-	plugin_db_activate_plugin_list (
-		plugins_get_available_plugins (), &plugin_errs);
+	gnm_plugins_init (GO_CMD_CONTEXT (cc));
+	go_plugin_db_activate_plugin_list (
+		go_plugins_get_available_plugins (), &plugin_errs);
 
 	if (ssindex_run_indexer) {
 		IOContext *ioc = gnumeric_io_context_new (cc);
@@ -226,7 +227,7 @@ main (int argc, char const *argv [])
 	} else if (ssindex_list_mime_types) {
 		GList  *o;
 		for (o = get_file_openers (); o != NULL ; o = o->next) {
-			GSList const *mime = gnm_file_opener_get_mimes (o->data);
+			GSList const *mime = go_file_opener_get_mimes (o->data);
 			for (; mime != NULL ; mime = mime->next)
 				printf ("%s\n", (char const *)mime->data);
 		}
