@@ -21,18 +21,18 @@
  */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "stf.h"
 
-#include "plugin-util.h"
-#include "file.h"
+#include <goffice/app/file.h>
 #include "sheet.h"
 #include "sheet-view.h"
 #include "sheet-style.h"
 #include "style.h"
 #include "mstyle.h"
-#include "io-context-priv.h"
+#include <goffice/app/io-context-priv.h>
+#include <goffice/utils/go-glib-extras.h>
 #include "command-context.h"
 #include "workbook-control.h"
 #include "workbook-view.h"
@@ -42,12 +42,13 @@
 #include "position.h"
 #include "expr.h"
 #include "value.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "selection.h"
 #include "ranges.h"
 #include "clipboard.h"
 #include "parse-util.h"
 #include "commands.h"
+#include "gui-util.h"
 
 #include <gsf/gsf-input.h>
 #include <string.h>
@@ -57,6 +58,7 @@
 #include <gsf/gsf-utils.h>
 #include <locale.h>
 
+
 /**
  * stf_open_and_read
  * @filename : name of the file to open&read
@@ -100,7 +102,7 @@ stf_open_and_read (GsfInput *input, size_t *readsize)
 }
 
 static char *
-stf_preparse (GnmCmdContext *context, GsfInput *input, size_t *data_len)
+stf_preparse (GOCmdContext *context, GsfInput *input, size_t *data_len)
 {
 	char *data;
 
@@ -108,7 +110,7 @@ stf_preparse (GnmCmdContext *context, GsfInput *input, size_t *data_len)
 
 	if (!data) {
 		if (context)
-			gnm_cmd_context_error_import (context,
+			go_cmd_context_error_import (context,
 				_("Error while trying to read file"));
 		return NULL;
 	}
@@ -134,9 +136,10 @@ stf_apply_formats (StfParseOptions_t *parseoptions,
 
 	for (ui = 0; ui < parseoptions->formats->len; ui++) {
 		if (parseoptions->col_import_array == NULL ||
+		    parseoptions->col_import_array_len <= ui ||
 		    parseoptions->col_import_array[ui]) {
 			GnmStyle *style = mstyle_new ();
-			GnmFormat *sf = g_ptr_array_index 
+			GOFormat *sf = g_ptr_array_index 
 				(parseoptions->formats, ui);
 			mstyle_set_format (style, sf);
 			sheet_style_apply_range (sheet, &range, style);
@@ -169,8 +172,8 @@ stf_store_results (DialogStfResult_t *dialogresult,
  * Main routine, handles importing a file including all dialog mumbo-jumbo
  **/
 static void
-stf_read_workbook (GnmFileOpener const *fo,  gchar const *enc,
-		   IOContext *context, WorkbookView *wbv, GsfInput *input)
+stf_read_workbook (GOFileOpener const *fo,  gchar const *enc,
+		   IOContext *context, gpointer wbv, GsfInput *input)
 {
 	DialogStfResult_t *dialogresult = NULL;
 	char *name, *nameutf8;
@@ -191,7 +194,7 @@ stf_read_workbook (GnmFileOpener const *fo,  gchar const *enc,
 		return;
 	}
 
-	data = stf_preparse (GNM_CMD_CONTEXT (context), input, &data_len);
+	data = stf_preparse (GO_CMD_CONTEXT (context), input, &data_len);
 	if (!data) {
 		g_free (nameutf8);
 		return;
@@ -200,7 +203,7 @@ stf_read_workbook (GnmFileOpener const *fo,  gchar const *enc,
 	/* Add Sheet */
 	book = wb_view_workbook (wbv);
 	sheet = sheet_new (book, nameutf8);
-	workbook_sheet_attach (book, sheet, NULL);
+	workbook_sheet_attach (book, sheet);
 
 	dialogresult = stf_dialog (WORKBOOK_CONTROL_GUI (context->impl),
 				   enc, FALSE, NULL, FALSE, 
@@ -211,7 +214,7 @@ stf_read_workbook (GnmFileOpener const *fo,  gchar const *enc,
 	} else {
 		/* the user has cancelled */
                 /* the caller should notice that we have no sheets */
-		workbook_sheet_detach (book, sheet, TRUE);
+		workbook_sheet_delete (sheet);
 	}
 
 	g_free (data);
@@ -252,14 +255,14 @@ cb_get_content (Sheet *sheet, int col, int row,
  * Main routine, handles importing a file including all dialog mumbo-jumbo
  **/
 void
-stf_text_to_columns (WorkbookControl *wbc, GnmCmdContext *cc)
+stf_text_to_columns (WorkbookControl *wbc, GOCmdContext *cc)
 {
 	DialogStfResult_t *dialogresult = NULL;
 	SheetView	*sv;
 	Sheet		*src_sheet, *target_sheet;
 	GnmRange const	*src;
-	GnmRange		 target;
-	GsfOutputMemory	*buf;
+	GnmRange	 target;
+	GsfOutput	*buf;
 	guint8 const	*data;
 	size_t data_len;
 
@@ -269,7 +272,7 @@ stf_text_to_columns (WorkbookControl *wbc, GnmCmdContext *cc)
 	if (src == NULL)
 		return;
 	if (range_width	(src) > 1) {
-		gnm_cmd_context_error (cc, g_error_new (gnm_error_invalid (), 0,
+		go_cmd_context_error (cc, g_error_new (go_error_invalid (), 0,
 			_("Only 1 one column of <b>input</b> data can be parsed at a time, not %d"),
 			range_width (src)));
 		return;
@@ -291,11 +294,11 @@ stf_text_to_columns (WorkbookControl *wbc, GnmCmdContext *cc)
 		src->end.col, src->end.row,
 		(CellIterFunc) &cb_get_content, buf);
 
-	gsf_output_close (GSF_OUTPUT (buf));
-	data = gsf_output_memory_get_bytes (buf);
-	data_len = (size_t)gsf_output_size (GSF_OUTPUT (buf));
+	gsf_output_close (buf);
+	data = gsf_output_memory_get_bytes (GSF_OUTPUT_MEMORY (buf));
+	data_len = (size_t)gsf_output_size (buf);
 	if (data_len == 0) {
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (cc),
+		go_cmd_context_error_import (GO_CMD_CONTEXT (cc),
 					     _("There is no data "
 					       "to convert"));
 	} else {
@@ -306,7 +309,7 @@ stf_text_to_columns (WorkbookControl *wbc, GnmCmdContext *cc)
 	}
 	if (dialogresult != NULL) {
 		GnmCellRegion *cr = stf_parse_region (dialogresult->parseoptions,
-						   dialogresult->text, NULL);
+			dialogresult->text, NULL, target_sheet->workbook);
 		if (cr != NULL) {
 			stf_dialog_result_attach_formats_to_cr (dialogresult, cr);
 			target.end.col = target.start.col + cr->cols - 1;
@@ -315,7 +318,7 @@ stf_text_to_columns (WorkbookControl *wbc, GnmCmdContext *cc)
 		if (cr == NULL ||
 		    cmd_text_to_columns (wbc, src, src_sheet, 
 					 &target, target_sheet, cr))
-			gnm_cmd_context_error_import (GNM_CMD_CONTEXT (cc),
+			go_cmd_context_error_import (GO_CMD_CONTEXT (cc),
 					     _("Error while trying to "
 					       "parse data into sheet"));
 		stf_dialog_result_free (dialogresult);
@@ -335,9 +338,9 @@ stf_text_to_columns (WorkbookControl *wbc, GnmCmdContext *cc)
  * Attempt to auto-detect CSV or tab-delimited file
  **/
 static void
-stf_read_workbook_auto_csvtab (GnmFileOpener const *fo, gchar const *enc,
+stf_read_workbook_auto_csvtab (GOFileOpener const *fo, gchar const *enc,
 			       IOContext *context,
-			       WorkbookView *wbv, GsfInput *input)
+			       gpointer wbv, GsfInput *input)
 {
 	Sheet *sheet;
 	Workbook *book;
@@ -350,15 +353,15 @@ stf_read_workbook_auto_csvtab (GnmFileOpener const *fo, gchar const *enc,
 	g_return_if_fail (wbv != NULL);
 
 	book = wb_view_workbook (wbv);
-	data = stf_preparse (GNM_CMD_CONTEXT (context), input, &data_len);
+	data = stf_preparse (GO_CMD_CONTEXT (context), input, &data_len);
 	if (!data)
 		return;
 
-	enc = gnm_guess_encoding (data, data_len, enc, &utf8data);
+	enc = go_guess_encoding (data, data_len, enc, &utf8data);
 	g_free (data);
 
 	if (!enc) {
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (context),
+		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
 				     _("That file is not in the given encoding."));
 		return;
 	}
@@ -368,34 +371,40 @@ stf_read_workbook_auto_csvtab (GnmFileOpener const *fo, gchar const *enc,
 	name = g_path_get_basename (gsf_input_name (input));
 	sheet = sheet_new (book, name);
 	g_free (name);
-	workbook_sheet_attach (book, sheet, NULL);
+	workbook_sheet_attach (book, sheet);
 
 	if (stf_parse_sheet (po, utf8data, NULL, sheet, 0, 0)) {
 		workbook_recalc (book);
 		sheet_queue_respan (sheet, 0, SHEET_MAX_ROWS-1);
+		if (po->cols_exceeded) {
+/* Using go_cmd_context_error_import will destroy the successfully imported portion */
+/* 			go_cmd_context_error_import (GO_CMD_CONTEXT (context), */
+/* 						      _("Some columns of data were" */
+/* 							" dropped since they exceeded" */
+/* 							" the available sheet size.")); */
+			go_gtk_notice_dialog (wbcg_toplevel (WORKBOOK_CONTROL_GUI (context->impl)),
+					 GTK_MESSAGE_WARNING,_("Some columns of data were"
+							       " dropped since they exceeded"
+							       " the available sheet size."));
+		}
 	} else {
-		workbook_sheet_detach (book, sheet, TRUE);
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (context),
+		workbook_sheet_delete (sheet);
+		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
 			_("Parse error while trying to parse data into sheet"));
 	}
 
+
 	stf_parse_options_free (po);
 	g_free (utf8data);
 }
 
 /***********************************************************************************/
 
-static gboolean
-stf_write_func (const char *string, GsfOutput *output)
-{
-	return (gsf_output_puts (output, string) >= 0);
-}
-
 static void
-stf_write_workbook (GnmFileSaver const *fs, IOContext *context,
-		    WorkbookView const *wbv, GsfOutput *output)
+stf_write_workbook (GOFileSaver const *fs, IOContext *context,
+		    gconstpointer wbv, GsfOutput *output)
 {
-	StfE_Result_t *result = NULL;
+	GnmStfExport *result = NULL;
 
 	if (IS_WORKBOOK_CONTROL_GUI (context->impl))
 		result = stf_export_dialog (WORKBOOK_CONTROL_GUI (context->impl),
@@ -406,58 +415,74 @@ stf_write_workbook (GnmFileSaver const *fs, IOContext *context,
 		return;
 	}
 
-	stf_export_options_set_write_callback (result->export_options,
-		(StfEWriteFunc) stf_write_func, (gpointer) output);
-	if (stf_export (result->export_options) == FALSE)
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (context),
-#warning change string after branch
-			_("Error while trying to write csv file"));
-	stf_export_dialog_result_free (result);
+	g_object_set (G_OBJECT (result), "sink", output, NULL);
+	if (stf_export (result) == FALSE)
+		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
+			_("Error while trying to export file as text"));
+	g_object_unref (result);
 }
 
 static void
-stf_write_csv (GnmFileSaver const *fs, IOContext *context,
-	       WorkbookView const *wbv, GsfOutput *output)
+stf_write_csv (GOFileSaver const *fs, IOContext *context,
+	       gconstpointer wbv, GsfOutput *output)
 {
-	StfExportOptions_t *config = stf_export_options_new ();
-	stf_export_options_set_terminator_type (config, TERMINATOR_TYPE_LINEFEED);
-	stf_export_options_set_cell_separator  (config, ',');
-	stf_export_options_set_quoting_mode    (config, QUOTING_MODE_AUTO);
-	stf_export_options_set_quoting_char    (config, '"');
-	stf_export_options_sheet_list_add      (config,
-						wb_view_cur_sheet (wbv));
-	stf_export_options_set_write_callback  (config,
-		(StfEWriteFunc) stf_write_func, (gpointer) output);
+	GnmStfExport *config = g_object_new
+		(GNM_STF_EXPORT_TYPE,
+		 "sink", output,
+		 "quoting-triggers", ", \t\n\"",
+		 NULL);
+	stf_export_options_sheet_list_add (config,
+					   wb_view_cur_sheet (wbv));
 
 	if (stf_export (config) == FALSE)
-		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (context),
-			_("Error while trying to write csv file"));
-	stf_export_options_free (config);
+		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
+			_("Error while trying to write CSV file"));
+
+	g_object_unref (config);
 }
 
 static gboolean
-csv_tsv_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
+csv_tsv_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
-	if (pl == FILE_PROBE_CONTENT) {
-		/* Rough and ready heuristic.  If the first 80 bytes have no
-		 * nuls this may be text */
-		guint8 const *header;
-		int i = 80;
+	/* Rough and ready heuristic.  If the first 80 bytes have no
+	 * nuls this may be text */
+	const int N = 80;
 
-		if (gsf_input_seek (input, 0, G_SEEK_SET) ||
-		    NULL == (header = gsf_input_read (input, i, NULL)))
+	if (pl == FILE_PROBE_CONTENT) {
+		guint8 const *header;
+		int i;
+		const char *enc;
+		char *header_utf8;
+		const char *p;
+
+		if (gsf_input_seek (input, 0, G_SEEK_SET))
 			return FALSE;
-		while (i-- > 0)
-			if (*header++ == 0)
-				return FALSE;
-		return TRUE;
+		i = gsf_input_remaining (input);
+		if (i > N) i = N;
+		if (NULL == (header = gsf_input_read (input, i, NULL)))
+			return FALSE;
+
+		enc = go_guess_encoding (header, i, NULL, &header_utf8);
+		if (!enc)
+			return FALSE;
+
+		for (p = header_utf8; *p; p = g_utf8_next_char (p)) {
+			gunichar uc = g_utf8_get_char (p);
+			if (!g_unichar_isprint (uc)) {
+				p = NULL;
+				break;
+			}
+		}
+
+		g_free (header_utf8);
+		return p == NULL;
 	} else {
-	char const *name = gsf_input_name (input);
-	if (name == NULL)
-		return FALSE;
-	name = gsf_extension_pointer (name);
-	return (name != NULL &&
-		(g_ascii_strcasecmp (name, "csv") == 0 ||
+		char const *name = gsf_input_name (input);
+		if (name == NULL)
+			return FALSE;
+		name = gsf_extension_pointer (name);
+		return (name != NULL &&
+			(g_ascii_strcasecmp (name, "csv") == 0 ||
 			 g_ascii_strcasecmp (name, "tsv") == 0 ||
 			 g_ascii_strcasecmp (name, "txt") == 0));
 	}
@@ -466,20 +491,41 @@ csv_tsv_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 void
 stf_init (void)
 {
-	gnm_file_opener_register (gnm_file_opener_new_with_enc (
+	GSList *suffixes = go_slist_create (
+		g_strdup ("csv"),
+		g_strdup ("tsv"),
+		g_strdup ("txt"),
+		NULL);
+	GSList *mimes = go_slist_create (
+		g_strdup ("application/csv"),
+		g_strdup ("application/tab-separated-values"),
+		g_strdup ("text/comma-separated-values"),
+		g_strdup ("text/csv"),
+		g_strdup ("text/spreadsheet"),
+		g_strdup ("text/tab-separated-values"),
+		g_strdup ("text/x-comma-separated-values"),
+		NULL);
+	GOFileSaver *saver;
+	go_file_opener_register (go_file_opener_new_with_enc (
 		"Gnumeric_stf:stf_csvtab",
 		_("Comma or tab separated values (CSV/TSV)"),
+		suffixes, mimes,
 		csv_tsv_probe, stf_read_workbook_auto_csvtab), 0);
-	gnm_file_opener_register (gnm_file_opener_new_with_enc (
+	go_file_opener_register (go_file_opener_new_with_enc (
 		"Gnumeric_stf:stf_assistant",
 		_("Text import (configurable)"),
+		NULL, NULL,
 		NULL, stf_read_workbook), 0);
-	gnm_file_saver_register (gnm_file_saver_new (
+
+	go_file_saver_register (go_file_saver_new (
 		"Gnumeric_stf:stf_assistant", "txt",
 		_("Text export (configurable)"),
 		FILE_FL_WRITE_ONLY, stf_write_workbook));
-	gnm_file_saver_register (gnm_file_saver_new (
+	saver = go_file_saver_new (
 		"Gnumeric_stf:stf_csv", "csv",
 		_("Comma separated values (CSV)"),
-		FILE_FL_WRITE_ONLY, stf_write_csv));
+		FILE_FL_WRITE_ONLY, stf_write_csv);
+	go_file_saver_set_save_scope (saver, FILE_SAVE_SHEET);
+	go_file_saver_register (saver);
+
 }
