@@ -12,9 +12,8 @@
 #include "style.h"
 #include "style-font.h"
 
-#include "format.h"
+#include "gnm-format.h"
 #include "style-color.h"
-#include "global-gnome-font.h"
 #include "application.h"
 #include "sheet.h"
 #include "cell.h"
@@ -38,8 +37,6 @@ static GHashTable *style_font_negative_hash;
 double gnumeric_default_font_width;
 static char *gnumeric_default_font_name;
 static double gnumeric_default_font_size;
-static PangoFontFamily	**pango_families;
-static GStringChunk	 *size_names;
 
 /**
  * get_substitute_font
@@ -345,15 +342,6 @@ style_font_hash_func (gconstpointer v)
 	return k->size_pts + g_str_hash (k->font_name);
 }
 
-static int
-compare_family_pointers_by_name (gconstpointer a, gconstpointer b)
-{
-	PangoFontFamily * const * const fa = a;
-	PangoFontFamily * const * const fb = b;
-	return g_utf8_collate (pango_font_family_get_name (*fa),
-			       pango_font_family_get_name (*fb));
-}
-
 /**
  * gnm_pango_context_get :
  *
@@ -388,7 +376,6 @@ font_init (void)
 {
 	PangoContext *context;
 	GnmFont *gnumeric_default_font = NULL;
-	int n_families, i;
 
 	gnumeric_default_font_name = g_strdup (gnm_app_prefs->default_font.name);
 	gnumeric_default_font_size = gnm_app_prefs->default_font.size;
@@ -426,29 +413,6 @@ font_init (void)
 
 	gnumeric_default_font_width = gnumeric_default_font->approx_width.pts.digit;
 	style_font_unref (gnumeric_default_font);
-
-	size_names = g_string_chunk_new (128);
-
-	pango_context_list_families (context,
-		&pango_families, &n_families);
-	qsort (pango_families, n_families, sizeof (*pango_families),
-	       compare_family_pointers_by_name);
-
-	for (i = 0 ; i < n_families ; i++)
-		gnumeric_font_family_list = g_list_prepend (
-			gnumeric_font_family_list,
-			(gpointer) pango_font_family_get_name (pango_families[i]));
-
-	gnumeric_font_family_list = g_list_reverse (gnumeric_font_family_list);
-
-	for (i = 0; gnumeric_point_sizes [i] != 0; i++){
-		char buffer[4 * sizeof (int)];
-		sprintf (buffer, "%d", gnumeric_point_sizes [i]);
-		gnumeric_point_size_list = g_list_prepend (
-			gnumeric_point_size_list,
-			g_string_chunk_insert (size_names, buffer));
-	}
-
 	g_object_unref (G_OBJECT (context));
 }
 
@@ -457,21 +421,11 @@ font_shutdown (void)
 {
 	g_free (gnumeric_default_font_name);
 	gnumeric_default_font_name = NULL;
-
-	g_free (pango_families);
-	pango_families = NULL;
-	g_list_free (gnumeric_font_family_list);
-	gnumeric_font_family_list = NULL;
-	g_list_free (gnumeric_point_size_list);
-	gnumeric_point_size_list = NULL;
-	g_string_chunk_free (size_names);
-	size_names = NULL;
 }
 
 void
 style_init (void)
 {
-	number_format_init ();
 	style_font_hash = g_hash_table_new (style_font_hash_func,
 					    style_font_equal);
 	style_font_negative_hash = g_hash_table_new (style_font_hash_func,
@@ -500,7 +454,6 @@ void
 style_shutdown (void)
 {
 	font_shutdown ();
-	number_format_shutdown ();
 	{
 		/* Make a list of the fonts, then unref them.  */
 		GSList *fonts = NULL, *tmp;
