@@ -1,16 +1,16 @@
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "libgnumeric.h"
 
 #include "command-context.h"
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "io-context-gtk.h"
 /* TODO: Get rid of this one */
 #include "command-context-stderr.h"
 #include "workbook-control-gui.h"
 #include "workbook-view.h"
-#include "plugin.h"
+#include <goffice/app/go-plugin.h>
 #include "selection.h"
 #include "sheet-view.h"
 #include "commands.h"
@@ -19,15 +19,12 @@
 #include "gnumeric-paths.h"
 
 #include <gtk/gtkmain.h>
-
-#ifdef WITH_BONOBO
+#ifdef WITH_GNOME
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-ui-main.h>
 #endif
 
 int gnumeric_no_splash = TRUE;
-char const *gnumeric_lib_dir = GNUMERIC_LIBDIR;
-char const *gnumeric_data_dir = GNUMERIC_DATADIR;
 
 const struct poptOption
 gnumeric_popt_options[] = {
@@ -67,7 +64,7 @@ cb_exercise_pango (gpointer data)
 			sc, sc_set_top_left (sc, 0, (state-TEST_STEPS)*STEP_SIZE););
 	} else if (state == (TEST_STEPS*2)) {
 		workbook_set_dirty (wb_control_workbook (wbc), FALSE);
-		workbook_unref (wb_control_workbook (wbc));
+		g_object_unref (wb_control_workbook (wbc));
 	}
 
 	return state++ < TEST_STEPS*2;
@@ -76,41 +73,35 @@ cb_exercise_pango (gpointer data)
 int
 main (int argc, char *argv [])
 {
-	GnmCmdContext *cc;
+	GOCmdContext *cc;
 	WorkbookControl *wbc;
 	IOContext *ioc;
 	poptContext ctx;
 
-	init_init (argv[0]);
-
-	ctx = gnumeric_arg_parse (argc, argv);
+	gnm_pre_parse_init (argv[0]);
+	gtk_init (&argc, (char ***)&argv);
+	gnm_common_init (FALSE);
 
 	cc  = cmd_context_stderr_new ();
 	ioc = gnumeric_io_context_new (cc);
 	g_object_unref (cc);
 
-	/* TODO: Use the ioc. */
-	gnm_common_init (FALSE);
-
- 	plugins_init (GNM_CMD_CONTEXT (ioc));
+ 	gnm_plugins_init (GO_CMD_CONTEXT (ioc));
 	g_object_unref (ioc);
 
-#ifdef WITH_BONOBO
-	bonobo_activate ();
-#endif
 	initial_workbook_open_complete = TRUE; /* make the last unref exit */
 
 	wbc = workbook_control_gui_new (NULL, workbook_new_with_sheets (1), NULL);
 
 	g_idle_add (cb_exercise_pango, wbc);
 
+#ifdef WITH_GNOME
+	bonobo_main ();
+#else
 	gtk_main ();
+#endif
 
 	gnm_shutdown ();
 
-#ifdef WITH_BONOBO
-	bonobo_ui_debug_shutdown ();
-#endif
-
 	return 0;
 }
