@@ -38,7 +38,7 @@
 #include "workbook.h"
 #include "workbook-control.h"
 #include "command-context.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "sheet-object-cell-comment.h"
 #include "commands.h"
 #include "style-color.h"
@@ -174,6 +174,9 @@ dao_command_descriptor (data_analysis_output_t *dao, char const *format,
 void
 dao_adjust (data_analysis_output_t *dao, gint cols, gint rows)
 {
+	int max_rows = SHEET_MAX_ROWS - dao->start_row;
+	int max_cols = SHEET_MAX_COLS - dao->start_col;
+
 	if (dao->cols == 1 && dao->rows == 1) {
 		if (cols != -1)
 			dao->cols = cols;
@@ -185,6 +188,11 @@ dao_adjust (data_analysis_output_t *dao, gint cols, gint rows)
 		if (rows != -1)
 			dao->rows = MIN (rows, dao->rows);
 	}
+	
+	if (dao->cols > max_cols)
+		dao->cols = max_cols;
+	if (dao->rows > max_rows)
+		dao->rows = max_rows;
 }
 
 /**
@@ -216,14 +224,14 @@ dao_prepare_output (WorkbookControl *wbc, data_analysis_output_t *dao,
 		dao->start_col = dao->start_row = 0;
 		dao->rows = SHEET_MAX_ROWS;
 		dao->cols = SHEET_MAX_COLS;
-		workbook_sheet_attach (wb, dao->sheet, NULL);
+		workbook_sheet_attach (wb, dao->sheet);
 	} else if (dao->type == NewWorkbookOutput) {
 		Workbook *wb = workbook_new ();
 		dao->sheet = sheet_new (wb, name);
 		dao->start_col = dao->start_row = 0;
 		dao->rows = SHEET_MAX_ROWS;
 		dao->cols = SHEET_MAX_COLS;
-		workbook_sheet_attach (wb, dao->sheet, NULL);
+		workbook_sheet_attach (wb, dao->sheet);
 		dao->wbc = wb_control_wrapper_new (dao->wbc, NULL, wb, NULL);
 	}
 	if (dao->rows == 0 || (dao->rows == 1 && dao->cols == 1))
@@ -255,7 +263,7 @@ dao_format_output (data_analysis_output_t *dao, char const *cmd)
 
 	if (dao->type == RangeOutput
 	    && sheet_range_splits_region (dao->sheet, &range, NULL,
-					  GNM_CMD_CONTEXT (dao->wbc), cmd))
+					  GO_CMD_CONTEXT (dao->wbc), cmd))
 		return TRUE;
 
 	if (dao->clear_outputrange)
@@ -269,7 +277,7 @@ dao_format_output (data_analysis_output_t *dao, char const *cmd)
 			    range.start.col, range.start.row,
 			    range.end.col, range.end.row,
 			    clear_flags | CLEAR_NOCHECKARRAY | CLEAR_MERGES,
-			    GNM_CMD_CONTEXT (dao->wbc));
+			    GO_CMD_CONTEXT (dao->wbc));
 	return FALSE;
 }
 
@@ -732,7 +740,7 @@ dao_set_percent (data_analysis_output_t *dao, int col1, int row1,
 		 int col2, int row2)
 {
 	GnmStyle *mstyle = mstyle_new ();
-	GnmFormat *style_format = NULL;
+	GOFormat *style_format = NULL;
 
 	style_format = style_format_default_percentage ();
 	mstyle_set_format (mstyle, style_format);
@@ -757,7 +765,7 @@ dao_set_date (data_analysis_output_t *dao, int col1, int row1,
 		 int col2, int row2)
 {
 	GnmStyle *mstyle = mstyle_new ();
-	GnmFormat *style_format = NULL;
+	GOFormat *style_format = NULL;
 
 	style_format = style_format_default_date ();
 	mstyle_set_format (mstyle, style_format);
