@@ -35,7 +35,7 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
 				 * When we have pos and neg, prefer the new point only
 				 * if it makes the pos-neg x-internal smaller.
 				 */
-				if (gnumabs (x - data->xneg) < gnumabs (data->xpos - data->xneg)) {
+				if (gnm_abs (x - data->xneg) < gnm_abs (data->xpos - data->xneg)) {
 					data->xpos = x;
 					data->ypos = y;
 				}
@@ -47,7 +47,7 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
 		} else {
 			data->xpos = x;
 			data->ypos = y;
-			data->havexpos = 1;
+			data->havexpos = TRUE;
 		}
 		return FALSE;
 	} else if (y < 0) {
@@ -57,7 +57,7 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
 				 * When we have pos and neg, prefer the new point only
 				 * if it makes the pos-neg x-internal smaller.
 				 */
-				if (gnumabs (x - data->xpos) < gnumabs (data->xpos - data->xneg)) {
+				if (gnm_abs (x - data->xpos) < gnm_abs (data->xpos - data->xneg)) {
 					data->xneg = x;
 					data->yneg = y;
 				}
@@ -70,11 +70,12 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
 		} else {
 			data->xneg = x;
 			data->yneg = y;
-			data->havexneg = 1;
+			data->havexneg = TRUE;
 		}
 		return FALSE;
 	} else {
 		/* Lucky guess...  */
+		data->have_root = TRUE;
 		data->root = x;
 		return TRUE;
 	}
@@ -93,7 +94,7 @@ fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
 	GoalSeekStatus status;
 
 #ifdef DEBUG_GOAL_SEEK
-	printf ("fake_df (x=%.20" GNUM_FORMAT_g ", xstep=%.20" GNUM_FORMAT_g ")\n",
+	printf ("fake_df (x=%.20" GNM_FORMAT_g ", xstep=%.20" GNM_FORMAT_g ")\n",
 		x, xstep);
 #endif
 
@@ -120,8 +121,8 @@ fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
 		return status;
 	}
 #ifdef DEBUG_GOAL_SEEK
-		printf ("==> xl=%.20" GNUM_FORMAT_g "; yl=%.20" GNUM_FORMAT_g "\n",
-			xl, yl);
+	printf ("==> xl=%.20" GNM_FORMAT_g "; yl=%.20" GNM_FORMAT_g "\n",
+		xl, yl);
 #endif
 
 	status = f (xr, &yr, user_data);
@@ -132,21 +133,23 @@ fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
 		return status;
 	}
 #ifdef DEBUG_GOAL_SEEK
-		printf ("==> xr=%.20" GNUM_FORMAT_g "; yr=%.20" GNUM_FORMAT_g "\n",
-			xr, yr);
+	printf ("==> xr=%.20" GNM_FORMAT_g "; yr=%.20" GNM_FORMAT_g "\n",
+		xr, yr);
 #endif
 
 	*dfx = (yr - yl) / (xr - xl);
 #ifdef DEBUG_GOAL_SEEK
-		printf ("==> %.20" GNUM_FORMAT_g "\n", *dfx);
+	printf ("==> %.20" GNM_FORMAT_g "\n", *dfx);
 #endif
-	return finitegnum (*dfx) ? GOAL_SEEK_OK : GOAL_SEEK_ERROR;
+	return gnm_finite (*dfx) ? GOAL_SEEK_OK : GOAL_SEEK_ERROR;
 }
 
 void
 goal_seek_initialize (GoalSeekData *data)
 {
-	data->havexpos = data->havexneg = FALSE;
+	data->havexpos = data->havexneg = data->have_root = FALSE;
+	data->xpos = data->xneg = data->root = gnm_nan;
+	data->ypos = data->yneg = gnm_nan;
 	data->xmin = -1e10;
 	data->xmax = +1e10;
 	data->precision = 1e-10;
@@ -163,6 +166,9 @@ goal_seek_point (GoalSeekFunction f, GoalSeekData *data,
 	GoalSeekStatus status;
 	gnm_float y0;
 
+	if (data->have_root)
+		return GOAL_SEEK_OK;
+
 	if (x0 < data->xmin || x0 > data->xmax)
 		return GOAL_SEEK_ERROR;
 
@@ -196,6 +202,9 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 	int iterations;
 	gnm_float precision = data->precision / 2;
 
+	if (data->have_root)
+		return GOAL_SEEK_OK;
+
 #ifdef DEBUG_GOAL_SEEK
 	printf ("goal_seek_newton\n");
 #endif
@@ -213,8 +222,8 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 			return status;
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("x0 = %.20" GNUM_FORMAT_g "\n", x0);
-		printf ("                                        y0 = %.20" GNUM_FORMAT_g "\n", y0);
+		printf ("x0 = %.20" GNM_FORMAT_g "\n", x0);
+		printf ("                                        y0 = %.20" GNM_FORMAT_g "\n", y0);
 #endif
 
 		if (update_data (x0, y0, data))
@@ -225,13 +234,13 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 		else {
 			gnm_float xstep;
 
-			if (gnumabs (x0) < 1e-10)
+			if (gnm_abs (x0) < 1e-10)
 				if (data->havexneg && data->havexpos)
-					xstep = gnumabs (data->xpos - data->xneg) / 1e6;
+					xstep = gnm_abs (data->xpos - data->xneg) / 1e6;
 				else
 					xstep = (data->xmax - data->xmin) / 1e6;
 			else
-				xstep = gnumabs (x0) / 1e6;
+				xstep = gnm_abs (x0) / 1e6;
 
 			status = fake_df (f, x0, &df0, xstep, data, user_data);
 		}
@@ -247,22 +256,18 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 		 * just one side of the root.
 		 */
 		x1 = x0 - 1.000001 * y0 / df0;
-		if (x1 == x0) {
-			data->root = x0;
-			return GOAL_SEEK_OK;
-		}
-
-		stepsize = gnumabs (x1 - x0) / (gnumabs (x0) + gnumabs (x1));
+		stepsize = gnm_abs (x1 - x0) / (gnm_abs (x0) + gnm_abs (x1));
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("                                        df0 = %.20" GNUM_FORMAT_g "\n", df0);
-		printf ("                                        ss = %.20" GNUM_FORMAT_g "\n", stepsize);
+		printf ("                                        df0 = %.20" GNM_FORMAT_g "\n", df0);
+		printf ("                                        ss = %.20" GNM_FORMAT_g "\n", stepsize);
 #endif
 
 		x0 = x1;
 
 		if (stepsize < precision) {
 			data->root = x0;
+			data->have_root = TRUE;
 			return GOAL_SEEK_OK;
 		}
 	}
@@ -293,6 +298,9 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 	gnm_float stepsize;
 	int newton_submethod = 0;
 
+	if (data->have_root)
+		return GOAL_SEEK_OK;
+
 #ifdef DEBUG_GOAL_SEEK
 	printf ("goal_seek_bisection\n");
 #endif
@@ -300,11 +308,11 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 	if (!data->havexpos || !data->havexneg)
 		return GOAL_SEEK_ERROR;
 
-	stepsize = gnumabs (data->xpos - data->xneg)
-		/ (gnumabs (data->xpos) + gnumabs (data->xneg));
+	stepsize = gnm_abs (data->xpos - data->xneg)
+		/ (gnm_abs (data->xpos) + gnm_abs (data->xneg));
 
 	/* log_2 (10) = 3.3219 < 4.  */
-	for (iterations = 0; iterations < 100 + GNUM_DIG * 4; iterations++) {
+	for (iterations = 0; iterations < 100 + GNM_DIG * 4; iterations++) {
 		gnm_float xmid, ymid;
 		GoalSeekStatus status;
 		enum { M_SECANT, M_RIDDER, M_NEWTON, M_MIDPOINT } method;
@@ -338,7 +346,7 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 				return GOAL_SEEK_OK;
 			}
 
-			det = sqrtgnum (ymid * ymid - data->ypos * data->yneg);
+			det = gnm_sqrt (ymid * ymid - data->ypos * data->yneg);
 			if (det == 0)
 				 /* This might happen with underflow, I guess. */
 				continue;
@@ -373,7 +381,7 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 					continue;
 			}
 
-			xstep = gnumabs (data->xpos - data->xneg) / 1e6;
+			xstep = gnm_abs (data->xpos - data->xneg) / 1e6;
 			status = fake_df (f, x0, &df0, xstep, data, user_data);
 			if (status != GOAL_SEEK_OK)
 				continue;
@@ -408,8 +416,8 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 			default: themethod = "?";
 			}
 
-			printf ("xmid = %.20" GNUM_FORMAT_g " (%s)\n", xmid, themethod);
-			printf ("                                        ymid = %.20" GNUM_FORMAT_g "\n", ymid);
+			printf ("xmid = %.20" GNM_FORMAT_g " (%s)\n", xmid, themethod);
+			printf ("                                        ymid = %.20" GNM_FORMAT_g "\n", ymid);
 		}
 #endif
 
@@ -417,11 +425,11 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 			return GOAL_SEEK_OK;
 		}
 
-		stepsize = gnumabs (data->xpos - data->xneg)
-			/ (gnumabs (data->xpos) + gnumabs (data->xneg));
+		stepsize = gnm_abs (data->xpos - data->xneg)
+			/ (gnm_abs (data->xpos) + gnm_abs (data->xneg));
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("                                          ss = %.20" GNUM_FORMAT_g "\n", stepsize);
+		printf ("                                          ss = %.20" GNM_FORMAT_g "\n", stepsize);
 #endif
 
 		if (stepsize < data->precision) {
@@ -431,6 +439,7 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 			if (data->ypos < ymid)
 				ymid = data->ypos, xmid = data->xpos;
 
+			data->have_root = TRUE;
 			data->root = xmid;
 			return GOAL_SEEK_OK;
 		}
@@ -449,6 +458,9 @@ goal_seek_trawl_uniformly (GoalSeekFunction f,
 {
 	int i;
 
+	if (data->have_root)
+		return GOAL_SEEK_OK;
+
 	if (xmin > xmax || xmin < data->xmin || xmax > data->xmax)
 		return GOAL_SEEK_ERROR;
 
@@ -466,8 +478,8 @@ goal_seek_trawl_uniformly (GoalSeekFunction f,
 			continue;
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("x = %.20" GNUM_FORMAT_g "\n", x);
-		printf ("                                        y = %.20" GNUM_FORMAT_g "\n", y);
+		printf ("x = %.20" GNM_FORMAT_g "\n", x);
+		printf ("                                        y = %.20" GNM_FORMAT_g "\n", y);
 #endif
 
 		if (update_data (x, y, data))
@@ -487,6 +499,9 @@ goal_seek_trawl_normally (GoalSeekFunction f,
 {
 	int i;
 
+	if (data->have_root)
+		return GOAL_SEEK_OK;
+
 	if (sigma <= 0 || mu < data->xmin || mu > data->xmax)
 		return GOAL_SEEK_ERROR;
 
@@ -507,8 +522,8 @@ goal_seek_trawl_normally (GoalSeekFunction f,
 			continue;
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("x = %.20" GNUM_FORMAT_g "\n", x);
-		printf ("                                        y = %.20" GNUM_FORMAT_g "\n", y);
+		printf ("x = %.20" GNM_FORMAT_g "\n", x);
+		printf ("                                        y = %.20" GNM_FORMAT_g "\n", y);
 #endif
 
 		if (update_data (x, y, data))
