@@ -15,7 +15,7 @@
 
 #include "parse-util.h"
 #include "style.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "str.h"
 #include "position.h"
 #include "mathfunc.h"
@@ -30,14 +30,15 @@
 #include <sheet.h>
 #include <cell.h>
 #include <number-match.h>
+#include <goffice/utils/go-glib-extras.h>
 
 #ifndef USE_VALUE_POOLS
 #define USE_VALUE_POOLS 1
 #endif
 
 #if USE_VALUE_POOLS
-#define CHUNK_ALLOC(T,p) ((T*)gnm_mem_chunk_alloc (p))
-#define CHUNK_FREE(p,v) gnm_mem_chunk_free ((p), (v))
+#define CHUNK_ALLOC(T,p) ((T*)go_mem_chunk_alloc (p))
+#define CHUNK_FREE(p,v) go_mem_chunk_free ((p), (v))
 #else
 #define CHUNK_ALLOC(T,c) g_new (T,1)
 #define CHUNK_FREE(p,v) g_free ((v))
@@ -70,7 +71,7 @@ value_new_empty (void)
 }
 
 /* Memory pool for ints and bools.  */
-static GnmMemChunk *value_int_pool;
+static GOMemChunk *value_int_pool;
 GnmValue *
 value_new_bool (gboolean b)
 {
@@ -91,11 +92,11 @@ value_new_int (int i)
 	return (GnmValue *)v;
 }
 
-static GnmMemChunk *value_float_pool;
+static GOMemChunk *value_float_pool;
 GnmValue *
 value_new_float (gnm_float f)
 {
-	if (finitegnum (f)) {
+	if (gnm_finite (f)) {
 		GnmValueFloat *v = CHUNK_ALLOC (GnmValueFloat, value_float_pool);
 		*((GnmValueType *)&(v->type)) = VALUE_FLOAT;
 		v->fmt = NULL;
@@ -108,7 +109,7 @@ value_new_float (gnm_float f)
 }
 
 /* Memory pool for error values.  */
-static GnmMemChunk *value_error_pool;
+static GOMemChunk *value_error_pool;
 GnmValue *
 value_new_error (GnmEvalPos const *ep, char const *mesg)
 {
@@ -234,7 +235,7 @@ value_error_classify (GnmValue const *v)
 }
 
 
-static GnmMemChunk *value_string_pool;
+static GOMemChunk *value_string_pool;
 
 /* NOTE : absorbs the reference */
 GnmValue *
@@ -259,7 +260,7 @@ value_new_string_nocopy (char *str)
 	return value_new_string_str (gnm_string_get_nocopy (str));
 }
 
-static GnmMemChunk *value_range_pool;
+static GOMemChunk *value_range_pool;
 GnmValue *
 value_new_cellrange_unsafe (GnmCellRef const *a, GnmCellRef const *b)
 {
@@ -349,7 +350,7 @@ value_new_cellrange_r (Sheet *sheet, GnmRange const *r)
 	return (GnmValue *)v;
 }
 
-static GnmMemChunk *value_array_pool;
+static GOMemChunk *value_array_pool;
 GnmValue *
 value_new_array_non_init (guint cols, guint rows)
 {
@@ -391,7 +392,7 @@ value_new_array_empty (guint cols, guint rows)
 }
 
 GnmValue *
-value_new_from_string (GnmValueType t, char const *str, GnmFormat *sf,
+value_new_from_string (GnmValueType t, char const *str, GOFormat *sf,
 		       gboolean translated)
 {
 	GnmValue *res = NULL;
@@ -431,7 +432,7 @@ value_new_from_string (GnmValueType t, char const *str, GnmFormat *sf,
 		gnm_float d;
 
 		errno = 0;
-		d = strtognum (str, &end);
+		d = gnm_strto (str, &end);
 		if (str != end && *end == '\0' && errno != ERANGE)
 			res = value_new_float (d);
 		break;
@@ -646,7 +647,7 @@ value_cmp_reverse (void const *ptr_a, void const *ptr_b)
 	return b->type - a->type;
 }
 
-gint
+gboolean
 value_equal (GnmValue const *a, GnmValue const *b)
 {
 	if (a->type != b->type)
@@ -714,7 +715,7 @@ value_hash (GnmValue const *v)
 
 	case VALUE_FLOAT: {
 		int expt;
-		gnm_float mant = frexpgnum (gnumabs (v->v_float.val), &expt);
+		gnm_float mant = gnm_frexp (gnm_abs (v->v_float.val), &expt);
 		guint h = ((guint)(0x80000000u * mant)) ^ expt;
 		if (v->v_float.val >= 0)
 			h ^= 0x55555555;
@@ -816,7 +817,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		GnmStdError e = value_error_classify (v);
 		if (e == GNM_ERROR_UNKNOWN) {
 			g_string_append_c (target, '#');
-			gnm_strescape (target, v->v_err.mesg->str);
+			go_strescape (target, v->v_err.mesg->str);
 		} else
 			g_string_append (target, value_error_name (e, conv->output_translated));
 		return;
@@ -840,7 +841,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		return;
 
 	case VALUE_FLOAT:
-		g_string_append_printf (target, "%.*" GNUM_FORMAT_g, GNUM_DIG,
+		g_string_append_printf (target, "%.*" GNM_FORMAT_g, GNM_DIG,
 					v->v_float.val);
 		return;
 
@@ -878,7 +879,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 
 				/* quote strings */
 				if (val->type == VALUE_STRING)
-					gnm_strescape (target, val->v_str.val->str);
+					go_strescape (target, val->v_str.val->str);
 				else
 					value_get_as_gstring (val, target, conv);
 			}
@@ -975,7 +976,7 @@ value_get_as_int (GnmValue const *v)
 		return 0;
 
 	case VALUE_FLOAT:
-		return (int) gnumeric_fake_trunc (v->v_float.val);
+		return (int) gnm_fake_trunc (v->v_float.val);
 
 	case VALUE_BOOLEAN:
 		return v->v_bool.val ? 1 : 0;
@@ -1004,7 +1005,7 @@ value_get_as_float (GnmValue const *v)
 		return 0.;
 
 	case VALUE_STRING:
-		return strtognum (v->v_str.val->str, NULL);
+		return gnm_strto (v->v_str.val->str, NULL);
 
 	case VALUE_CELLRANGE:
 		g_warning ("Getting range as a double: what to do?");
@@ -1236,7 +1237,7 @@ value_diff (GnmValue const *a, GnmValue const *b)
 	case VALUE_FLOAT: {
 		gnm_float const da = value_get_as_float (a);
 		gnm_float const db = value_get_as_float (b);
-		return gnumabs (da - db);
+		return gnm_abs (da - db);
 	}
 	default:
 		return TYPE_MISMATCH;
@@ -1348,13 +1349,13 @@ value_compare (GnmValue const *a, GnmValue const *b, gboolean case_sensitive)
 }
 
 void
-value_set_fmt (GnmValue *v, GnmFormat const *fmt)
+value_set_fmt (GnmValue *v, GOFormat const *fmt)
 {
 	if (fmt != NULL)
-		style_format_ref ((GnmFormat *)fmt);
+		style_format_ref ((GOFormat *)fmt);
 	if (VALUE_FMT (v) != NULL)
 		style_format_unref (VALUE_FMT (v));
-	VALUE_FMT (v) = (GnmFormat *)fmt;
+	VALUE_FMT (v) = (GOFormat *)fmt;
 }
 
 /****************************************************************************/
@@ -1515,7 +1516,7 @@ free_criterias (GSList *criterias)
  * @fun : #criteria_test_fun_t result
  * @test_value : #GnmValue the value to compare against.
  * @iter_flags :
- * @date_conv : #GnmDateConventions
+ * @date_conv : #GODateConventions
  *
  * If @crit_val is a number set @text_val and @fun to test for equality, other
  * wise parse it as a string and see if it matches one of the available
@@ -1523,7 +1524,7 @@ free_criterias (GSList *criterias)
  **/
 void
 parse_criteria (GnmValue *crit_val, criteria_test_fun_t *fun, GnmValue **test_value,
-		CellIterFlags *iter_flags, GnmDateConventions const *date_conv)
+		CellIterFlags *iter_flags, GODateConventions const *date_conv)
 {
 	int len;
 	char const *criteria;
@@ -1577,7 +1578,7 @@ parse_criteria_range (Sheet *sheet, int b_col, int b_row, int e_col, int e_row,
 	GSList              *conditions;
 	GnmCell 		    *cell;
 	func_criteria_t     *cond;
-	GnmDateConventions const *date_conv = workbook_date_conv (sheet->workbook);
+	GODateConventions const *date_conv = workbook_date_conv (sheet->workbook);
 
         int i, j;
 
@@ -1746,32 +1747,32 @@ value_init (void)
 #if USE_VALUE_POOLS
 	/* GnmValueInt and GnmValueBool ought to have the same size.  */
 	value_int_pool =
-		gnm_mem_chunk_new ("value int/bool pool",
+		go_mem_chunk_new ("value int/bool pool",
 				   MAX (sizeof (GnmValueInt), sizeof (GnmValueBool)),
 				   16 * 1024 - 128);
 
 	value_float_pool =
-		gnm_mem_chunk_new ("value float pool",
+		go_mem_chunk_new ("value float pool",
 				   sizeof (GnmValueFloat),
 				   16 * 1024 - 128);
 
 	value_error_pool =
-		gnm_mem_chunk_new ("value error pool",
+		go_mem_chunk_new ("value error pool",
 				   sizeof (GnmValueErr),
 				   16 * 1024 - 128);
 
 	value_string_pool =
-		gnm_mem_chunk_new ("value string pool",
+		go_mem_chunk_new ("value string pool",
 				   sizeof (GnmValueStr),
 				   16 * 1024 - 128);
 
 	value_range_pool =
-		gnm_mem_chunk_new ("value range pool",
+		go_mem_chunk_new ("value range pool",
 				   sizeof (GnmValueRange),
 				   16 * 1024 - 128);
 
 	value_array_pool =
-		gnm_mem_chunk_new ("value array pool",
+		go_mem_chunk_new ("value array pool",
 				   sizeof (GnmValueArray),
 				   16 * 1024 - 128);
 #endif
@@ -1788,22 +1789,22 @@ value_shutdown (void)
 	}
 
 #if USE_VALUE_POOLS
-	gnm_mem_chunk_destroy (value_int_pool, FALSE);
+	go_mem_chunk_destroy (value_int_pool, FALSE);
 	value_int_pool = NULL;
 
-	gnm_mem_chunk_destroy (value_float_pool, FALSE);
+	go_mem_chunk_destroy (value_float_pool, FALSE);
 	value_float_pool = NULL;
 
-	gnm_mem_chunk_destroy (value_error_pool, FALSE);
+	go_mem_chunk_destroy (value_error_pool, FALSE);
 	value_error_pool = NULL;
 
-	gnm_mem_chunk_destroy (value_string_pool, FALSE);
+	go_mem_chunk_destroy (value_string_pool, FALSE);
 	value_string_pool = NULL;
 
-	gnm_mem_chunk_destroy (value_range_pool, FALSE);
+	go_mem_chunk_destroy (value_range_pool, FALSE);
 	value_range_pool = NULL;
 
-	gnm_mem_chunk_destroy (value_array_pool, FALSE);
+	go_mem_chunk_destroy (value_array_pool, FALSE);
 	value_array_pool = NULL;
 #endif
 }
