@@ -33,7 +33,7 @@
 #include "cell.h"
 #include "stf.h"
 #include "value.h"
-#include "format.h"
+#include "gnm-format.h"
 #include "sheet.h"
 #include "sort.h"
 #include "sheet-merge.h"
@@ -52,22 +52,22 @@
 #include "workbook-control-gui-priv.h"
 #include "workbook-control.h"
 #include "workbook-cmd-format.h"
-#include "io-context.h"
-#include "plugin-util.h"
 #include "dialogs/dialogs.h"
 #include "sheet-object-image.h"
 #include "sheet-object-widget.h"
 #include "gnm-so-filled.h"
 #include "gnm-so-line.h"
 #include "sheet-object-graph.h"
-
 #include "gui-util.h"
 #include "gui-file.h"
 #include "gnumeric-gconf.h"
+
+#include <goffice/app/io-context.h>
 #include <goffice/graph/gog-guru.h>
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/graph/gog-data-set.h>
 #include <goffice/utils/go-file.h>
+#include <goffice/utils/go-glib-extras.h>
 
 #include "widgets/widget-editable-label.h"
 #include <gtk/gtkactiongroup.h>
@@ -91,7 +91,7 @@ static GNM_ACTION_DEF (cb_file_open)	{ gui_file_open (wbcg, NULL); }
 static GNM_ACTION_DEF (cb_file_save)	{ gui_file_save (wbcg, wb_control_view (WORKBOOK_CONTROL (wbcg))); }
 static GNM_ACTION_DEF (cb_file_save_as)	{ gui_file_save_as (wbcg, wb_control_view (WORKBOOK_CONTROL (wbcg))); }
 static GNM_ACTION_DEF (cb_file_sendto)	{
-	wb_view_sendto (wb_control_view (WORKBOOK_CONTROL (wbcg)), GNM_CMD_CONTEXT (wbcg)); }
+	wb_view_sendto (wb_control_view (WORKBOOK_CONTROL (wbcg)), GO_CMD_CONTEXT (wbcg)); }
 static GNM_ACTION_DEF (cb_file_page_setup) { dialog_printer_setup (wbcg, wbcg_cur_sheet (wbcg)); }
 static GNM_ACTION_DEF (cb_file_print)	{
 	sheet_print (wbcg, wbcg_cur_sheet (wbcg), FALSE, PRINT_ACTIVE_SHEET); }
@@ -155,7 +155,7 @@ static GNM_ACTION_DEF (cb_file_quit)
 					if (wb_control_workbook (wbc) == wba)
 						continue;
 					workbook_set_dirty (wba, FALSE);
-					workbook_unref (wba);
+					g_object_unref (wba);
 				}
 				ptr = old_ptr;
 				break;
@@ -165,20 +165,24 @@ static GNM_ACTION_DEF (cb_file_quit)
 
 	if (discard_all) {
 		workbook_set_dirty (wb_control_workbook (wbc), FALSE);
-		workbook_unref (wb_control_workbook (wbc));
+		g_object_unref (wb_control_workbook (wbc));
 		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next)
-			workbook_unref (ptr->data);
+			g_object_unref (ptr->data);
 	} else
 	/* only close pristine books if nothing was canceled. */
 	if (ok && wbcg_close_if_user_permits (wbcg,
 					      wb_control_view (wbc), TRUE, TRUE, ask_user)
 	    > 0)
 		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next)
-			workbook_unref (ptr->data);
+			g_object_unref (ptr->data);
 
 	g_list_free (workbooks);
 	g_list_free (clean_no_closed);
 }
+static GNM_ACTION_DEF (cb_new_doc_metadata)
+{
+	dialog_doc_metadata_new (wbcg);
+}
 
 /****************************************************************************/
 
@@ -203,7 +207,7 @@ static GNM_ACTION_DEF (cb_edit_delete_rows)
 	GnmRange const *sel;
 	int rows;
 
-	if (!(sel = selection_first_range (sv, GNM_CMD_CONTEXT (wbc), _("Delete"))))
+	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Delete"))))
 		return;
 	rows = range_height (sel);
 
@@ -217,7 +221,7 @@ static GNM_ACTION_DEF (cb_edit_delete_columns)
 	GnmRange const *sel;
 	int cols;
 
-	if (!(sel = selection_first_range (sv, GNM_CMD_CONTEXT (wbc), _("Delete"))))
+	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Delete"))))
 		return;
 	cols = range_width (sel);
 
@@ -262,7 +266,7 @@ static GNM_ACTION_DEF (cb_edit_cut)
 		SheetView *sv = wb_control_cur_sheet_view (wbc);
 		if (scg != NULL && scg->selected_objects != NULL)
 			gnm_app_clipboard_cut_copy_obj (wbc, TRUE, sv,
-				gnm_hash_keys (scg->selected_objects));
+				go_hash_keys (scg->selected_objects));
 		else
 			sv_selection_cut (sv, wbc);
 	} else
@@ -277,7 +281,7 @@ static GNM_ACTION_DEF (cb_edit_copy)
 		SheetView *sv = wb_control_cur_sheet_view (wbc);
 		if (scg != NULL && scg->selected_objects != NULL)
 			gnm_app_clipboard_cut_copy_obj (wbc, FALSE, sv,
-				gnm_hash_keys (scg->selected_objects));
+				go_hash_keys (scg->selected_objects));
 		else
 			sv_selection_copy (sv, wbc);
 	} else
@@ -355,7 +359,7 @@ cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
 			 old_text,
 			 new_text);
 
-		gnumeric_notice (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR, err);
+		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR, err);
 		g_free (err);
 		break;
 	}
@@ -403,12 +407,11 @@ cb_edit_search_replace_action (WorkbookControlGUI *wbcg,
 			       GnmSearchReplace *sr)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	Sheet *sheet = wb_control_cur_sheet (wbc);
 
 	sr->query_func = cb_edit_search_replace_query;
 	sr->user_data = wbcg;
 
-	return cmd_search_replace (wbc, sheet, sr);
+	return cmd_search_replace (wbc, sr);
 }
 
 
@@ -421,7 +424,7 @@ static GNM_ACTION_DEF (cb_edit_fill_autofill)
 	SheetView *sv = wb_control_cur_sheet_view (wbc);
 	Sheet	  *sheet = wb_control_cur_sheet (wbc);
 
-	GnmRange const *total = selection_first_range (sv, GNM_CMD_CONTEXT (wbc), _("Autofill"));
+	GnmRange const *total = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Autofill"));
 	if (total) {
 		GnmRange src = *total;
 		gboolean do_loop;
@@ -621,6 +624,10 @@ static GNM_ACTION_DEF (cb_define_name)
 {
 	dialog_define_names (wbcg);
 }
+static GNM_ACTION_DEF (cb_paste_names)
+{
+	dialog_paste_names (wbcg);
+}
 
 static GNM_ACTION_DEF (cb_insert_rows)
 {
@@ -633,7 +640,7 @@ static GNM_ACTION_DEF (cb_insert_rows)
 	 * selected region, (use selection_apply).  Arrays and Merged regions
 	 * are permitted.
 	 */
-	if (!(sel = selection_first_range (sv, GNM_CMD_CONTEXT (wbc), _("Insert rows"))))
+	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Insert rows"))))
 		return;
 	cmd_insert_rows (wbc, sheet, sel->start.row, range_height (sel));
 }
@@ -649,7 +656,7 @@ static GNM_ACTION_DEF (cb_insert_cols)
 	 * selected region, (use selection_apply).  Arrays and Merged regions
 	 * are permitted.
 	 */
-	if (!(sel = selection_first_range (sv, GNM_CMD_CONTEXT (wbc),
+	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc),
 					   _("Insert columns"))))
 		return;
 	cmd_insert_cols (wbc, sheet, sel->start.col, range_width (sel));
@@ -727,7 +734,7 @@ static GNM_ACTION_DEF (cb_auto_filter)
 	if (filter == NULL) {
 		GnmRange region;
 		GnmRange const *src = selection_first_range (sv,
-			GNM_CMD_CONTEXT (wbcg), _("Add Filter"));
+			GO_CMD_CONTEXT (wbcg), _("Add Filter"));
 
 		if (src == NULL)
 			return;
@@ -738,7 +745,7 @@ static GNM_ACTION_DEF (cb_auto_filter)
 		if (src->start.row == src->end.row)
 			sheet_filter_guess_region  (sv->sheet, &region);
 		if (region.start.row == region.end.row) {
-			gnm_cmd_context_error_invalid	(GNM_CMD_CONTEXT (wbcg),
+			go_cmd_context_error_invalid	(GO_CMD_CONTEXT (wbcg),
 				 _("AutoFilter"), _("Requires more than 1 row"));
 			return;
 		}
@@ -754,7 +761,7 @@ static GNM_ACTION_DEF (cb_auto_filter)
 static GNM_ACTION_DEF (cb_show_all)		{ filter_show_all (wbcg_cur_sheet (wbcg)); }
 static GNM_ACTION_DEF (cb_data_filter)		{ dialog_advanced_filter (wbcg); }
 static GNM_ACTION_DEF (cb_data_validate)	{ dialog_cell_format (wbcg, FD_VALIDATION); }
-static GNM_ACTION_DEF (cb_data_text_to_columns) { stf_text_to_columns (WORKBOOK_CONTROL (wbcg), GNM_CMD_CONTEXT (wbcg)); }
+static GNM_ACTION_DEF (cb_data_text_to_columns) { stf_text_to_columns (WORKBOOK_CONTROL (wbcg), GO_CMD_CONTEXT (wbcg)); }
 static GNM_ACTION_DEF (cb_data_consolidate)	{ dialog_consolidate (wbcg); }
 
 #ifdef ENABLE_PIVOTS
@@ -767,12 +774,12 @@ hide_show_detail_real (WorkbookControlGUI *wbcg, gboolean is_cols, gboolean show
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	SheetView *sv = wb_control_cur_sheet_view (wbc);
 	char const *operation = show ? _("Show Detail") : _("Hide Detail");
-	GnmRange const *r = selection_first_range (sv, GNM_CMD_CONTEXT (wbc),
+	GnmRange const *r = selection_first_range (sv, GO_CMD_CONTEXT (wbc),
 						operation);
 
 	/* This operation can only be performed on a whole existing group */
 	if (sheet_colrow_can_group (sv_sheet (sv), r, is_cols)) {
-		gnm_cmd_context_error_invalid (GNM_CMD_CONTEXT (wbc), operation,
+		go_cmd_context_error_invalid (GO_CMD_CONTEXT (wbc), operation,
 					_("can only be performed on an existing group"));
 		return;
 	}
@@ -787,7 +794,7 @@ hide_show_detail (WorkbookControlGUI *wbcg, gboolean show)
 	SheetView *sv = wb_control_cur_sheet_view (wbc);
 	char const *operation = show ? _("Show Detail") : _("Hide Detail");
 	GnmRange const *r = selection_first_range (sv,
-		GNM_CMD_CONTEXT (wbc), operation);
+		GO_CMD_CONTEXT (wbc), operation);
 	gboolean is_cols;
 
 	/* We only operate on a single selection */
@@ -815,7 +822,7 @@ group_ungroup_colrow (WorkbookControlGUI *wbcg, gboolean group)
 	SheetView *sv = wb_control_cur_sheet_view (wbc);
 	char const *operation = group ? _("Group") : _("Ungroup");
 	GnmRange const *r = selection_first_range (sv,
-		GNM_CMD_CONTEXT (wbc), operation);
+		GO_CMD_CONTEXT (wbc), operation);
 	gboolean is_cols;
 
 	/* We only operate on a single selection */
@@ -849,10 +856,12 @@ static GNM_ACTION_DEF (cb_help_docs)
 #warning "handle translations when we generate them"
 #ifndef G_OS_WIN32
 	argv[0] = (char *)"yelp";
-	argv[1] = gnm_sys_data_dir ("doc/C/gnumeric.xml");
+	argv[1] = g_build_filename (gnm_sys_data_dir (), "doc", "C",
+			"gnumeric.xml", NULL);
 #else
 	argv[0] = (char *)"hh";
-	argv[1] = gnm_sys_data_dir ("doc/C/gnumeric.chm");
+	argv[1] = g_build_filename (gnm_sys_data_dir (), "doc", "C",
+			"gnumeric.chm", NULL);
 #endif
 	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
 		NULL, NULL, NULL, &error);
@@ -863,7 +872,7 @@ static GNM_ACTION_DEF (cb_help_web)
 {
 	GError *err = go_url_show ("http://www.gnumeric.org/");
 	if (err != NULL) {
-		gnm_cmd_context_error (GNM_CMD_CONTEXT (wbcg), err);
+		go_cmd_context_error (GO_CMD_CONTEXT (wbcg), err);
 		g_error_free (err);
 	}
 }
@@ -872,7 +881,7 @@ static GNM_ACTION_DEF (cb_help_irc)
 {
 	GError *err = go_url_show ("irc://irc.gnome.org/gnumeric");
 	if (err != NULL) {
-		gnm_cmd_context_error (GNM_CMD_CONTEXT (wbcg), err);
+		go_cmd_context_error (GO_CMD_CONTEXT (wbcg), err);
 		g_error_free (err);
 	}
 }
@@ -881,7 +890,7 @@ static GNM_ACTION_DEF (cb_help_bug)
 {
 	GError *err = go_url_show ("http://bugzilla.gnome.org/enter_bug.cgi?product=Gnumeric");
 	if (err != NULL) {
-		gnm_cmd_context_error (GNM_CMD_CONTEXT (wbcg), err);
+		go_cmd_context_error (GO_CMD_CONTEXT (wbcg), err);
 		g_error_free (err);
 	}
 }
@@ -917,7 +926,7 @@ static GNM_ACTION_DEF (cb_autosum)
 
 static GNM_ACTION_DEF (cb_insert_image)
 {
-	char *uri = gui_image_file_select (wbcg, NULL);
+	char *uri = go_gtk_select_image (wbcg_toplevel (wbcg), NULL);
 
 	if (uri) {
 		GError *err = NULL;
@@ -931,7 +940,7 @@ static GNM_ACTION_DEF (cb_insert_image)
 			scg_mode_create_object (wbcg_cur_scg (wbcg), SHEET_OBJECT (soi));
 			g_object_unref (input);
 		} else
-			gnm_cmd_context_error (GNM_CMD_CONTEXT (wbcg), err);
+			go_cmd_context_error (GO_CMD_CONTEXT (wbcg), err);
 
 		g_free (uri);
 	}
@@ -954,7 +963,7 @@ sort_by_rows (WorkbookControlGUI *wbcg, gboolean descending)
 
 	sv = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
 
-	if (!(tmp = selection_first_range (sv, GNM_CMD_CONTEXT (wbcg), _("Sort"))))
+	if (!(tmp = selection_first_range (sv, GO_CMD_CONTEXT (wbcg), _("Sort"))))
 		return;
 
 	sel = range_dup (tmp);
@@ -1286,12 +1295,12 @@ static GNM_ACTION_DEF (cb_format_clear_borders)	{ mutate_borders (wbcg, FALSE);
 
 static void
 modify_format (WorkbookControlGUI *wbcg,
-	       GnmFormat *(*format_modify_fn) (GnmFormat const *format),
+	       GOFormat *(*format_modify_fn) (GOFormat const *format),
 	       char const *descriptor)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookView const *wbv;
-	GnmFormat *new_fmt;
+	GOFormat *new_fmt;
 
 	wbv = wb_control_view (wbc);
 	g_return_if_fail (wbv != NULL);
@@ -1413,14 +1422,8 @@ static GNM_ACTION_DEF (cb_format_row_unhide)
 	cmd_selection_colrow_hide (WORKBOOK_CONTROL (wbcg), FALSE, TRUE);
 }
 
-#ifdef GTK_STOCK_ABOUT
-#define GNM_ABOUT GTK_STOCK_ABOUT
-#else
-#define GNM_ABOUT NULL
-#endif
-
 /* Actions that are always sensitive */
-static /* const 142334 */ GtkActionEntry permanent_actions[] = {
+static const GtkActionEntry permanent_actions[] = {
 	{ "MenuFile",		NULL, N_("_File") },
 	{ "MenuEdit",		NULL, N_("_Edit") },
 		{ "MenuEditClear",	GTK_STOCK_CLEAR, N_("C_lear") },
@@ -1472,7 +1475,7 @@ static /* const 142334 */ GtkActionEntry permanent_actions[] = {
 	{ "HelpBug", NULL, N_("Report a _Problem"),
 		NULL, N_("Report problem "),
 		G_CALLBACK (cb_help_bug) },
-	{ "HelpAbout", GNM_ABOUT, N_("_About"),
+	{ "HelpAbout", GTK_STOCK_ABOUT, N_("_About"),
 		NULL, N_("About this application"),
 		G_CALLBACK (cb_help_about) },
 
@@ -1483,7 +1486,7 @@ static /* const 142334 */ GtkActionEntry permanent_actions[] = {
 		G_CALLBACK (cb_repeat) }
 };
 
-static /* const 142334 */ GtkActionEntry actions[] = {
+static const GtkActionEntry actions[] = {
 /* File */
 	{ "FileNew", GTK_STOCK_NEW, NULL,
 		NULL, N_("Create a new workbook"),
@@ -1507,7 +1510,7 @@ static /* const 142334 */ GtkActionEntry actions[] = {
 		NULL, N_("Print preview"),
 		G_CALLBACK (cb_file_print_preview) },
 	{ "FilePrint", GTK_STOCK_PRINT, NULL,
-		NULL, N_("Print the current file"),
+		"<control>p", N_("Print the current file"),
 		G_CALLBACK (cb_file_print) },
 	{ "FileSummary", GTK_STOCK_PROPERTIES, N_("Proper_ties..."),
 		NULL, N_("Edit descriptive information"),
@@ -1522,6 +1525,11 @@ static /* const 142334 */ GtkActionEntry actions[] = {
 		NULL, N_("Quit the application"),
 		G_CALLBACK (cb_file_quit) },
 
+#warning new hook put here to avoid patch conflict
+	{ "FileSummary_new", GTK_STOCK_PROPERTIES, N_("NEW Proper_ties..."),
+		NULL, N_("Edit descriptive information"),
+		G_CALLBACK (cb_new_doc_metadata) },
+
 /* Edit -> Clear */
 	{ "EditClearAll", NULL, N_("_All"),
 		NULL, N_("Clear the selected cells' formats, comments, and contents"),
@@ -1690,6 +1698,9 @@ static /* const 142334 */ GtkActionEntry actions[] = {
 	{ "EditNames", NULL, N_("_Define..."),
 		"<control>F3", N_("Edit sheet and workbook names"),
 		G_CALLBACK (cb_define_name) },
+	{ "PasteNames", GTK_STOCK_PASTE, NULL,
+		"F3", N_("Paste the definition a name, or names"),
+		G_CALLBACK (cb_paste_names) },
 #if 0
 	{ "EditGenerateName", NULL,  N_("_Auto generate names..."),
 		NULL, N_("Use the current selection to create names"),
@@ -2003,36 +2014,27 @@ static /* const 142334 */ GtkActionEntry actions[] = {
 	{ "CopyRight", NULL, "", "<control>R", NULL, G_CALLBACK (cb_copyright) }
 };
 
-#define TOGGLE_HANDLER(flag, code)					\
+#define TOGGLE_HANDLER(flag,property)					\
 static GNM_ACTION_DEF (cb_sheet_pref_ ## flag )				\
 {									\
 	g_return_if_fail (IS_WORKBOOK_CONTROL_GUI (wbcg));		\
 									\
 	if (!wbcg->updating_ui) {					\
 		Sheet *sheet = wbcg_cur_sheet (wbcg);			\
-		g_return_if_fail (IS_SHEET (sheet));			\
-									\
-		sheet->flag = !sheet->flag;				\
-		code							\
+		go_object_toggle (sheet, property);			\
 	}								\
 }
 
-TOGGLE_HANDLER (display_formulas, sheet_toggle_show_formula (sheet);)
-TOGGLE_HANDLER (hide_zero, sheet_toggle_hide_zeros (sheet); )
-TOGGLE_HANDLER (hide_grid, sheet_adjust_preferences (sheet, TRUE, FALSE);)
-TOGGLE_HANDLER (hide_col_header, sheet_adjust_preferences (sheet, FALSE, FALSE);)
-TOGGLE_HANDLER (hide_row_header, sheet_adjust_preferences (sheet, FALSE, FALSE);)
-TOGGLE_HANDLER (display_outlines, sheet_adjust_preferences (sheet, TRUE, TRUE);)
-TOGGLE_HANDLER (outline_symbols_below, {
-		sheet_set_outline_direction (sheet, FALSE);
-		sheet_adjust_preferences (sheet, TRUE, TRUE);
-})
-TOGGLE_HANDLER (outline_symbols_right,{
-		sheet_set_outline_direction (sheet, TRUE);
-		sheet_adjust_preferences (sheet, TRUE, TRUE);
-})
+TOGGLE_HANDLER (display_formulas, "display-formulas")
+TOGGLE_HANDLER (hide_zero, "display-zeros")
+TOGGLE_HANDLER (hide_grid, "display-grid")
+TOGGLE_HANDLER (hide_col_header, "display-column-header")
+TOGGLE_HANDLER (hide_row_header, "display-row-header")
+TOGGLE_HANDLER (display_outlines, "display-outlines")
+TOGGLE_HANDLER (outline_symbols_below, "display-outlines-below")
+TOGGLE_HANDLER (outline_symbols_right, "display-outlines-right")
 
-static /* const 142334 */ GtkToggleActionEntry toggle_actions[] = {
+static const GtkToggleActionEntry toggle_actions[] = {
 	{ "SheetDisplayOutlines", NULL, N_("Display _Outlines"),
 		"<control>8", N_("Toggle whether or not to display outline groups"),
 		G_CALLBACK (cb_sheet_pref_display_outlines) },
@@ -2099,7 +2101,7 @@ static /* const 142334 */ GtkToggleActionEntry toggle_actions[] = {
 		N_("in or out"), G_CALLBACK (cb_view_fullscreen), FALSE }
 };
 
-static /* const 142334 */ GtkToggleActionEntry font_toggle_actions[] = {
+static const GtkToggleActionEntry font_toggle_actions[] = {
 	{ "FontBold", GTK_STOCK_BOLD,
 		N_("_Bold"), "<control>B",	/* ALSO "<control>2" */
 		N_("Bold"), G_CALLBACK (cb_font_bold), FALSE },
