@@ -27,7 +27,7 @@
 #include <sheet-view.h>
 #include <selection.h>
 #include <commands.h>
-#include <format.h>
+#include <gnm-format.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <gtk/gtkentry.h>
@@ -338,6 +338,7 @@ cb_gee_key_press_event (GtkEntry	  *entry,
 		}
 		return TRUE;
 	}
+
 	default:
 		break;
 	}
@@ -422,7 +423,7 @@ gee_class_init (GObjectClass *gobject_class)
 		GNM_EXPR_ENTRY_TYPE,
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (GnmExprEntryClass, update),
-		(GSignalAccumulator) NULL, NULL,
+		NULL, NULL,
 		g_cclosure_marshal_VOID__BOOLEAN,
 		G_TYPE_NONE,
 		1, G_TYPE_BOOLEAN);
@@ -430,7 +431,7 @@ gee_class_init (GObjectClass *gobject_class)
 		GNM_EXPR_ENTRY_TYPE,
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (GnmExprEntryClass, changed),
-		(GSignalAccumulator) NULL, NULL,
+		NULL, NULL,
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
 	signals[ACTIVATE] =
@@ -438,40 +439,40 @@ gee_class_init (GObjectClass *gobject_class)
 		G_OBJECT_CLASS_TYPE (gobject_class),
 		G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		G_STRUCT_OFFSET (GnmExprEntryClass, activate),
-		(GSignalAccumulator) NULL, NULL,
+		NULL, NULL,
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
 
 	g_object_class_install_property (gobject_class,
 		PROP_UPDATE_POLICY,
-		g_param_spec_enum ("update_policy", "Update policy",
+		g_param_spec_enum ("update-policy", "Update policy",
 			"How frequently changes to the entry should be applied",
 			GTK_TYPE_UPDATE_TYPE, GTK_UPDATE_CONTINUOUS,
-			G_PARAM_READWRITE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_class,
 		PROP_WITH_ICON,
-		g_param_spec_boolean ("with_icon", "With icon",
+		g_param_spec_boolean ("with-icon", "With icon",
 			"Should there be an icon to the right of the entry",
 			TRUE,
-			G_PARAM_READWRITE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_class,
 		PROP_TEXT,
 		g_param_spec_string ("text", "Text",
 			"The contents of the entry",
 			"",
-			G_PARAM_READABLE | G_PARAM_WRITABLE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_class,
 		PROP_SCG,
 		g_param_spec_object ("scg", "SheetControlGUI",
 			"The GUI container associated with the entry.",
 			SHEET_CONTROL_GUI_TYPE,
-			G_PARAM_READWRITE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_class,
 		PROP_WBCG,
 		g_param_spec_object ("wbcg", "WorkbookControlGUI",
 			"The toplevel GUI container associated with the entry.",
 			WORKBOOK_CONTROL_GUI_TYPE,
-			G_PARAM_READWRITE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
 static void
@@ -838,7 +839,7 @@ gnm_expr_entry_set_update_policy (GnmExprEntry *gee,
 	if (gee->update_policy == policy)
 		return;
 	gee->update_policy = policy;
-	g_object_notify (G_OBJECT (gee), "update_policy");
+	g_object_notify (G_OBJECT (gee), "update-policy");
 }
 
 /**
@@ -855,8 +856,8 @@ GnmExprEntry *
 gnm_expr_entry_new (WorkbookControlGUI *wbcg, gboolean with_icon)
 {
 	return g_object_new (GNM_EXPR_ENTRY_TYPE,
-			     "scg",	 wbcg_cur_scg (wbcg),
-			     "with_icon", with_icon,
+			     "scg",	  wbcg_cur_scg (wbcg),
+			     "with-icon", with_icon,
 			     NULL);
 }
 
