@@ -9,11 +9,9 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "widget-font-selector.h"
 
-#include "../global-gnome-font.h"
 #include <value.h>
 #include <mstyle.h>
 #include <preview-grid.h>
@@ -22,10 +20,8 @@
 #include <mstyle.h>
 #include <preview-grid.h>
 
+#include <goffice/utils/go-font.h>
 #include <gsf/gsf-impl-utils.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtktreeview.h>
@@ -33,6 +29,10 @@
 #include <gtk/gtkliststore.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <glade/glade.h>
+#include <glib/gi18n.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
 
 struct _FontSelector {
 	GtkHBox box;
@@ -49,6 +49,9 @@ struct _FontSelector {
 	FooCanvasItem *font_preview_grid;
 
 	GnmStyle     *mstyle;
+
+	GSList       *family_names;
+	GSList       *font_sizes;
 };
 
 typedef struct {
@@ -85,7 +88,7 @@ fs_modify_style (FontSelector *fs, GnmStyle *modification)
 	g_return_if_fail (modification != NULL);
 
 	fs->mstyle = mstyle_copy_merge (original, modification);
-	g_signal_emit (GTK_OBJECT (fs),
+	g_signal_emit (G_OBJECT (fs),
 		fs_signals[FONT_CHANGED], 0, modification);
 	foo_canvas_item_set (fs->font_preview_grid,
 		"default-style",  fs->mstyle,
@@ -162,37 +165,41 @@ static void
 font_selected (GtkTreeSelection *selection,
 	       FontSelector *fs)
 {
+	gchar *text;
+	GnmStyle *change;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		GnmStyle *change = mstyle_new ();
-		gchar *text;
+	gtk_tree_selection_get_selected (selection, &model, &iter);
+	gtk_tree_model_get (model, &iter, 0, &text, -1);
+	gtk_entry_set_text (GTK_ENTRY (fs->font_name_entry), text);
 
-		gtk_tree_model_get (model, &iter, 0, &text, -1);
-		gtk_entry_set_text (GTK_ENTRY (fs->font_name_entry), text);
-
-		mstyle_set_font_name (change, text);
-		g_free (text);
-		fs_modify_style (fs, change);
-	}
+	change = mstyle_new ();
+	mstyle_set_font_name (change, text);
+	g_free (text);
+	fs_modify_style (fs, change);
 }
 
 static void
 fs_fill_font_name_list (FontSelector *fs)
 {
-	GList *l;
+	GSList *l;
 	GtkListStore *store;
 	GtkTreeIter iter;
+	PangoContext *context;
 
+#warning "FIXME: We need to do this when we realize the widget as we don't have a screen until then."
+	context = gtk_widget_get_pango_context (GTK_WIDGET (fs));
+
+	fs->family_names = go_fonts_list_families (context);
 	list_init (fs->font_name_list);
 	store = GTK_LIST_STORE (gtk_tree_view_get_model (fs->font_name_list));
-	 for (l = gnumeric_font_family_list; l; l = l->next) {
+	for (l = fs->family_names; l; l = l->next) {
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter, 0, l->data, -1);
-	 }
+	}
 
-	 g_signal_connect (
+	g_signal_connect (
 		 G_OBJECT (gtk_tree_view_get_selection (fs->font_name_list)), "changed",
 		 GTK_SIGNAL_FUNC (font_selected), fs);
 }
@@ -209,37 +216,39 @@ static void
 style_selected (GtkTreeSelection *selection,
 		FontSelector *fs)
 {
+	GnmStyle *change = mstyle_new ();
 	GtkTreeModel *model;
 	GtkTreeIter iter;
+	GtkTreePath *path;
+	int row;
 
-	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		GnmStyle *change = mstyle_new ();
-		GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
-		int row = *gtk_tree_path_get_indices (path);
-		gtk_tree_path_free (path);
+	gtk_tree_selection_get_selected (selection, &model, &iter);
+	path = gtk_tree_model_get_path (model, &iter);
+	row = *gtk_tree_path_get_indices (path);
+	gtk_tree_path_free (path);
 
-		switch (row) {
-		case 0:
-			mstyle_set_font_bold (change, FALSE);
-			mstyle_set_font_italic (change, FALSE);
-			break;
-		case 1:
-			mstyle_set_font_bold (change, TRUE);
-			mstyle_set_font_italic (change, FALSE);
-			break;
-		case 2:
-			mstyle_set_font_bold (change, TRUE);
-			mstyle_set_font_italic (change, TRUE);
-			break;
-		case 3:
-			mstyle_set_font_bold (change, FALSE);
-			mstyle_set_font_italic (change, TRUE);
-			break;
-		}
+	switch (row) {
+	case 0:
+		mstyle_set_font_bold (change, FALSE);
+		mstyle_set_font_italic (change, FALSE);
+		break;
+	case 1:
+		mstyle_set_font_bold (change, TRUE);
+		mstyle_set_font_italic (change, FALSE);
+		break;
 
-		gtk_entry_set_text (GTK_ENTRY (fs->font_style_entry), _(styles[row]));
-		fs_modify_style (fs, change);
+	case 2:
+		mstyle_set_font_bold (change, TRUE);
+		mstyle_set_font_italic (change, TRUE);
+		break;
+	case 3:
+		mstyle_set_font_bold (change, FALSE);
+		mstyle_set_font_italic (change, TRUE);
+		break;
 	}
+
+	gtk_entry_set_text (GTK_ENTRY (fs->font_style_entry), _(styles[row]));
+	fs_modify_style (fs, change);
 }
 
 static void
@@ -281,45 +290,44 @@ static void
 size_selected (GtkTreeSelection *selection,
 	       FontSelector *fs)
 {
+	GnmStyle *change = mstyle_new ();
+	gchar *text;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		GnmStyle *change = mstyle_new ();
-		gchar *text;
-
-		gtk_tree_model_get (model, &iter, 0, &text, -1);
-		gtk_entry_set_text (GTK_ENTRY (fs->font_size_entry), text);
-		mstyle_set_font_size (change, atof (text));
-		g_free (text);
-		fs_modify_style (fs, change);
-	}
+	gtk_tree_selection_get_selected (selection, &model, &iter);
+	gtk_tree_model_get (model, &iter, 0, &text, -1);
+	gtk_entry_set_text (GTK_ENTRY (fs->font_size_entry), text);
+	mstyle_set_font_size (change, atof (text));
+	g_free (text);
+	fs_modify_style (fs, change);
 }
 
 static void
 size_changed (GtkEntry *entry, FontSelector *fs)
 {
 	int i;
-	 char const *text = gtk_entry_get_text (entry);
-	 double size = atof (text);
-	 if (size >= 1. && size < 128) {
-		 GnmStyle *change = mstyle_new ();
-		 mstyle_set_font_size (change, size);
-		 fs_modify_style (fs, change);
-	 }
-	 g_signal_handlers_block_by_func (
-	 			gtk_tree_view_get_selection (fs->font_size_list),
-				 size_selected, fs);
-	for (i = 0; gnumeric_point_sizes[i] != 0; i++) {
-		if (gnumeric_point_sizes[i] == size) {
-			select_row (fs->font_size_list, i);
-			 g_signal_handlers_unblock_by_func (
-						gtk_tree_view_get_selection (fs->font_size_list),
-						size_selected, fs);
-			return;
-		}
+	char const *text = gtk_entry_get_text (entry);
+	double size = atof (text);
+	int psize = (int)(size * PANGO_SCALE + 0.5);
+	GSList *l;
+
+	if (size >= 1. && size < 128) {
+		GnmStyle *change = mstyle_new ();
+		mstyle_set_font_size (change, size);
+		fs_modify_style (fs, change);
 	}
-	select_row (fs->font_size_list, -1);
+	g_signal_handlers_block_by_func (
+		gtk_tree_view_get_selection (fs->font_size_list),
+		size_selected, fs);
+
+	for (i = 0, l = fs->font_sizes; l; i++, l = l->next) {
+		int this_psize = GPOINTER_TO_INT (l->data);
+		if (this_psize == psize)
+			break;
+	}
+
+	select_row (fs->font_size_list, l ? i : -1);
 	g_signal_handlers_unblock_by_func (
 				gtk_tree_view_get_selection (fs->font_size_list),
 				size_selected, fs);
@@ -328,17 +336,20 @@ size_changed (GtkEntry *entry, FontSelector *fs)
 static void
 fs_fill_font_size_list (FontSelector *fs)
 {
-	int i;
 	GtkListStore *store;
 	GtkTreeIter iter;
+	GSList *ptr;
+
+	fs->font_sizes = go_fonts_list_sizes ();
 
 	list_init (fs->font_size_list);
 	store = GTK_LIST_STORE (gtk_tree_view_get_model (fs->font_size_list));
-	for (i = 0; gnumeric_point_sizes[i] != 0; i++) {
-		char buffer[4 * sizeof (int)];
-		sprintf (buffer, "%d", gnumeric_point_sizes[i]);
+	for (ptr = fs->font_sizes ; ptr != NULL ; ptr = ptr->next) {
+		int psize = GPOINTER_TO_INT (ptr->data);
+		char *size_text = g_strdup_printf ("%g", psize / (double)PANGO_SCALE);
 		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter, 0, buffer, -1);
+		gtk_list_store_set (store, &iter, 0, size_text, -1);
+		g_free (size_text);
 	}
 	g_signal_connect (
 		G_OBJECT (gtk_tree_view_get_selection (fs->font_size_list)), "changed",
@@ -428,6 +439,17 @@ fs_destroy (GtkObject *object)
 		fs->gui = NULL;
 	}
 
+	if (fs->family_names) {
+		g_slist_foreach (fs->family_names, (GFunc)g_free, NULL);
+		g_slist_free (fs->family_names);
+		fs->family_names = NULL;
+	}
+
+	if (fs->font_sizes) {
+		g_slist_free (fs->font_sizes);
+		fs->font_sizes = NULL;
+	}
+
 	((GtkObjectClass *)fs_parent_class)->destroy (object);
 }
 
@@ -482,13 +504,13 @@ void
 font_selector_set_name (FontSelector *fs,
 			const char *font_name)
 {
-	GList *l;
+	GSList *l;
 	int row;
 
 	g_return_if_fail (IS_FONT_SELECTOR (fs));
 	g_return_if_fail (font_name != NULL);
 
-	for (row = 0, l = gnumeric_font_family_list; l; l = l->next, row++)
+	for (row = 0, l = fs->family_names; l; l = l->next, row++)
 		if (g_ascii_strcasecmp (font_name, l->data) == 0)
 			break;
 
@@ -566,23 +588,11 @@ void
 font_selector_set_points (FontSelector *fs,
 			  double point_size)
 {
-	int i;
-
-	g_return_if_fail (IS_FONT_SELECTOR (fs));
-
-	for (i = 0; gnumeric_point_sizes[i] != 0; i++) {
-		if (gnumeric_point_sizes[i] == point_size) {
-			select_row (fs->font_size_list, i);
-			break;
-		}
-	}
-
-	if (gnumeric_point_sizes[i] == 0) {
-		char *buffer;
-		buffer = g_strdup_printf ("%g", point_size);
+	const char *old_text = gtk_entry_get_text (GTK_ENTRY (fs->font_size_entry));
+	char *buffer = g_strdup_printf ("%g", point_size);
+	if (strcmp (old_text, buffer) != 0)
 		gtk_entry_set_text (GTK_ENTRY (fs->font_size_entry), buffer);
-		g_free (buffer);
-	}
+	g_free (buffer);
 }
 
 void
