@@ -35,7 +35,7 @@
 #include "ranges.h"
 #include "expr-name.h"
 #include "command-context.h"
-
+#include <goffice/utils/go-file.h>
 #include <gsf/gsf-impl-utils.h>
 
 #define WBC_CLASS(o) WORKBOOK_CONTROL_CLASS (G_OBJECT_GET_CLASS (o))
@@ -80,21 +80,19 @@ wb_control_update_title (WorkbookControl *wbc)
 
 	if (wbc_class != NULL && wbc_class->set_title != NULL) {
 		Workbook const *wb = wb_control_workbook (wbc);
-		if (workbook_is_dirty (wb)) {
-			char *tmp = g_strconcat ("*", wb->basename, NULL);
-			wbc_class->set_title (wbc, tmp);
-			g_free (tmp);
-		} else
-			wbc_class->set_title (wbc, wb->basename);
+		char *basename = go_basename_from_uri (wb->uri);
+		char *title = g_strconcat
+			(workbook_is_dirty (wb) ? "*" : "",
+			 basename ? basename : wb->uri,
+			 NULL);
+		wbc_class->set_title (wbc, title);
+		g_free (title);
+		g_free (basename);
 	}
 }
 
-WBC_VIRTUAL (prefs_update,
-	(WorkbookControl *wbc), (wbc))
 WBC_VIRTUAL (style_feedback,
 	(WorkbookControl *wbc, GnmStyle const *changes), (wbc, changes))
-WBC_VIRTUAL (zoom_feedback,
-	(WorkbookControl *wbc), (wbc))
 WBC_VIRTUAL (edit_line_set,
 	(WorkbookControl *wbc, char const *text), (wbc, text))
 WBC_VIRTUAL (selection_descr_set,
@@ -103,8 +101,6 @@ WBC_VIRTUAL (auto_expr_value, (WorkbookControl *wbc), (wbc))
 
 WBC_VIRTUAL_FULL (sheet_remove, sheet.remove,
 	(WorkbookControl *wbc, Sheet *sheet), (wbc, sheet))
-WBC_VIRTUAL_FULL (sheet_rename, sheet.rename,
-	(WorkbookControl *wbc, Sheet *sheet), (wbc, sheet))
 WBC_VIRTUAL_FULL (sheet_focus, sheet.focus,
 	(WorkbookControl *wbc, Sheet *sheet), (wbc, sheet))
 WBC_VIRTUAL_FULL (sheet_move, sheet.move,
@@ -124,13 +120,9 @@ WBC_VIRTUAL_FULL (undo_redo_labels, undo_redo.labels,
 	(WorkbookControl *wbc, char const *undo, char const *redo),
 	(wbc, undo, redo))
 
-WBC_VIRTUAL_FULL (menu_state_sheet_prefs, menu_state.sheet_prefs,
-	(WorkbookControl *wbc, Sheet const *sheet), (wbc, sheet))
 WBC_VIRTUAL_FULL (menu_state_update, menu_state.update,
         (WorkbookControl *wbc, int flags),
 	(wbc, flags))
-WBC_VIRTUAL_FULL (menu_state_sheet_count, menu_state.sheet_count,
-	(WorkbookControl *wbc), (wbc))
 
 WBC_VIRTUAL (paste_from_selection,
 	(WorkbookControl *wbc, GnmPasteTarget const *pt), (wbc, pt))
@@ -158,7 +150,6 @@ wb_control_sheet_add (WorkbookControl *wbc, SheetView *sv)
 			wb_view_edit_line_set (wbv, wbc);
 			wb_control_auto_expr_value (wbc);
 			wb_control_style_feedback (wbc, NULL);
-			wb_control_menu_state_sheet_prefs (wbc, new_sheet);
 			wb_control_menu_state_update (wbc, MS_ALL);
 			wb_control_update_action_sensitivity (wbc);
 		}
@@ -249,7 +240,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 		if (nexpr == NULL || expr_name_is_placeholder (nexpr)) {
 			GnmRange const *r = selection_first_range (
 				wb_control_cur_sheet_view (wbc),
-				GNM_CMD_CONTEXT (wbc),
+				GO_CMD_CONTEXT (wbc),
 				_("Define Name"));
 			if (r != NULL) {
 				GnmCellRef a, b;
@@ -270,7 +261,8 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 		} else {
 			target = gnm_expr_get_range (nexpr->expr);
 			if (target == NULL) {
-				gnm_cmd_context_error_invalid (GNM_CMD_CONTEXT (wbc), _("Address"), text);
+				go_cmd_context_error_invalid (GO_CMD_CONTEXT (wbc),
+					_("Address"), text);
 				return FALSE;
 			}
 		}
