@@ -2,8 +2,8 @@
 #define GNUMERIC_WORKBOOK_VIEW_H
 
 #include "gnumeric.h"
-#include "file.h"
 #include <glib-object.h>
+#include <gsf/gsf.h>
 
 struct _WorkbookView {
 	GObject  base;
@@ -28,6 +28,7 @@ struct _WorkbookView {
 	GnmExpr const *auto_expr;
 	char	  *auto_expr_desc;
 	char	  *auto_expr_value_as_string;
+	gboolean  auto_expr_use_max_precision;
 
 	/* selection */
 	char	  *selection_description;
@@ -65,7 +66,6 @@ void         	 wb_view_set_attribute	  (WorkbookView *wbv, char const *name,
 					   char const *value);
 void		 wb_view_preferred_size	  (WorkbookView *wbv,
 					   int w_pixels, int h_pixels);
-void		 wb_view_prefs_update	  (WorkbookView *wbv);
 void		 wb_view_format_feedback  (WorkbookView *wbv, gboolean display);
 void             wb_view_menus_update     (WorkbookView *wbv);
 void		 wb_view_selection_desc   (WorkbookView *wbv, gboolean use_pos,
@@ -76,21 +76,23 @@ void		 wb_view_auto_expr_recalc (WorkbookView *wbv, gboolean display);
 void		 wb_view_auto_expr	  (WorkbookView *wbv,
 					   char const *name,
 					   char const *func_name);
+void             wb_view_auto_expr_precision (WorkbookView *wbv,
+					      gboolean use_max_precision);
 
 /* I/O routines */
-gboolean wb_view_save_as (WorkbookView *wbv, GnmFileSaver *fs,
-			  char const *file_name, GnmCmdContext *cc);
-gboolean wb_view_save	 (WorkbookView *wbv, GnmCmdContext *cc);
-gboolean wb_view_sendto	 (WorkbookView *wbv, GnmCmdContext *cc);
+gboolean wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs,
+			  char const *file_name, GOCmdContext *cc);
+gboolean wb_view_save	 (WorkbookView *wbv, GOCmdContext *cc);
+gboolean wb_view_sendto	 (WorkbookView *wbv, GOCmdContext *cc);
 
 WorkbookView *wb_view_new_from_input  (GsfInput *input,
-				       GnmFileOpener const *optional_format,
+				       GOFileOpener const *optional_format,
 				       IOContext *io_context,
 				       gchar const *optional_encoding);
-WorkbookView *wb_view_new_from_file  (char const *file_name,
-				      GnmFileOpener const *optional_format,
-				      IOContext *io_context, 
-				      gchar const *optional_encoding);
+WorkbookView *wb_view_new_from_uri  (char const *uri,
+				     GOFileOpener const *optional_format,
+				     IOContext *io_context, 
+				     gchar const *optional_encoding);
 
 #define WORKBOOK_VIEW_FOREACH_CONTROL(wbv, control, code)			\
 do {										\
