@@ -7,29 +7,24 @@
 
 #include "gnumeric.h"
 #include "summary.h"
-#include "file.h"
+#include <goffice/app/file.h>
 #include <glib-object.h>
 
 GType       workbook_get_type            (void);
 Workbook   *workbook_new                 (void);
 Workbook   *workbook_new_with_sheets     (int sheet_count);
-void	    workbook_unref		 (Workbook *wb);
 
 /* Sheet support routines */
 GList      *workbook_sheets              (Workbook const *wb);
 int         workbook_sheet_count         (Workbook const *wb);
 Sheet      *workbook_sheet_by_index	 (Workbook const *wb, int i);
 Sheet      *workbook_sheet_by_name       (Workbook const *wb, char const *sheet_name);
-void        workbook_sheet_attach        (Workbook *wb, Sheet *new_sheet,
-					  Sheet const *insert_after);
+void        workbook_sheet_attach        (Workbook *wb, Sheet *new_sheet);
+void        workbook_sheet_attach_at_pos (Workbook *wb, Sheet *new_sheet, int pos);
 void	    workbook_sheet_detach        (Workbook *wb, Sheet *sheet, gboolean recalc);
-gboolean    workbook_sheet_hide_controls (Workbook *wb, Sheet *sheet);
-void        workbook_sheet_unhide_controls (Workbook *wb, Sheet *sheet);
-Sheet	   *workbook_sheet_add		 (Workbook *wb,
-					  Sheet const *insert_after,
-					  gboolean make_dirty);
+Sheet	   *workbook_sheet_add		 (Workbook *wb, int pos, gboolean make_dirty);
 void        workbook_sheet_delete        (Sheet *sheet);
-gboolean    workbook_sheet_move          (Sheet *sheet, int direction);
+void        workbook_sheet_move          (Sheet *sheet, int direction);
 char       *workbook_sheet_get_free_name (Workbook *wb,
 					  char const *base,
 					  gboolean always_suffix,
@@ -45,12 +40,12 @@ gboolean    workbook_sheet_recolor       (Workbook *wb,
 gboolean    workbook_sheet_rename        (Workbook *wb,
 					  GSList *sheet_indices,
 					  GSList *new_names,
-					  GnmCmdContext *cc);
+					  GOCmdContext *cc);
 gboolean    workbook_sheet_rename_check  (Workbook *wb,
 					  GSList *sheet_indices,
 					  GSList *new_names,
 					  GSList *sheet_indices_deleted,
-					  GnmCmdContext *cc);
+					  GOCmdContext *cc);
 gboolean    workbook_sheet_change_protection  (Workbook *wb,
 					       GSList *sheets,
 					       GSList *locks);
@@ -65,11 +60,10 @@ unsigned    workbook_find_command	(Workbook *wb,
 /* IO Routines */
 gboolean       workbook_set_uri		(Workbook *wb, char const *uri);
 char const    *workbook_get_uri		(Workbook const *wb);
-char const    *workbook_get_basename	(Workbook const *wb);
 
 gboolean       workbook_set_saveinfo	(Workbook *wb,
-					 FileFormatLevel, GnmFileSaver *);
-GnmFileSaver *workbook_get_file_saver	(Workbook *wb);
+					 FileFormatLevel, GOFileSaver *);
+GOFileSaver *workbook_get_file_saver	(Workbook *wb);
 
 gboolean    workbook_is_pristine	(Workbook const *wb);
 void        workbook_set_dirty		(Workbook *wb, gboolean is_dirty);
@@ -94,15 +88,22 @@ void     workbook_recalc                 (Workbook *wb);	/* in eval.c */
 void     workbook_recalc_all             (Workbook *wb);	/* in eval.c */
 gboolean workbook_enable_recursive_dirty (Workbook *wb, gboolean enable);
 void     workbook_autorecalc_enable	 (Workbook *wb, gboolean enable);
-gboolean workbook_autorecalc             (Workbook *wb);
+gboolean workbook_autorecalc             (Workbook const *wb);
 void     workbook_iteration_enabled	 (Workbook *wb, gboolean enable);
 void     workbook_iteration_max_number	 (Workbook *wb, int max_number);
 void     workbook_iteration_tolerance	 (Workbook *wb, double tolerance);
 
-GnmDateConventions const *workbook_date_conv (Workbook const *wb);
+GODateConventions const *workbook_date_conv (Workbook const *wb);
 gboolean workbook_set_1904 (Workbook *wb, gboolean flag);
 
 void workbook_attach_view (Workbook *wb, WorkbookView *wbv);
 void workbook_detach_view (WorkbookView *wbv);
 
+WorkbookSheetState *workbook_sheet_state_new (const Workbook *wb);
+void workbook_sheet_state_free (WorkbookSheetState *wss);
+void workbook_sheet_state_restore (Workbook *wb, const WorkbookSheetState *wss);
+int workbook_sheet_state_size (const WorkbookSheetState *wss);
+char *workbook_sheet_state_diff (const WorkbookSheetState *wss_a,
+				 const WorkbookSheetState *wss_b);
+
 #endif /* GNUMERIC_WORKBOOK_H */
